@@ -83,7 +83,7 @@ if [[ -n "${HADOOP_PROFILE}" ]]; then
   fi
 fi
 
-if [[ "${SKIP_ERRORPRONE}" = "true" ]]; then
+if [[ -n "${SKIP_ERROR_PRONE}" ]]; then
   YETUS_ARGS=("--skip-errorprone" "${YETUS_ARGS[@]}")
 fi
 
@@ -101,10 +101,6 @@ if [[ -n "${ASF_NIGHTLIES_GENERAL_CHECK_BASE}" ]]; then
   YETUS_ARGS=("--asf-nightlies-general-check-base=${ASF_NIGHTLIES_GENERAL_CHECK_BASE}" "${YETUS_ARGS[@]}")
 fi
 
-if [[ -n "${JAVA8_HOME}" ]]; then
-  YETUS_ARGS=("--java8-home=${JAVA8_HOME}" "${YETUS_ARGS[@]}")
-fi
-
 if [[ true !=  "${USE_YETUS_PRERELEASE}" ]]; then
   YETUS_ARGS=("--shelldocs=${WORKSPACE}/yetus-${YETUS_RELEASE}/bin/shelldocs" "${YETUS_ARGS[@]}")
   TESTPATCHBIN="${WORKSPACE}/yetus-${YETUS_RELEASE}/bin/test-patch"
