@@ -113,6 +113,11 @@ public class ClusterStatus implements ClusterMetrics {
     return metrics.getDeadServerNames();
   }
 
+  @Override
+  public List<ServerName> getUnknownServerNames() {
+    return metrics.getUnknownServerNames();
+  }
+
   @Override
   public Map<ServerName, ServerMetrics> getLiveServerMetrics() {
     return metrics.getLiveServerMetrics();
@@ -186,6 +191,7 @@ public class ClusterStatus implements ClusterMetrics {
   }
 
   /** Returns the HBase version string as reported by the HMaster */
+  @Override
   public String getHBaseVersion() {
     return metrics.getHBaseVersion();
   }
@@ -269,7 +275,7 @@ public class ClusterStatus implements ClusterMetrics {
   }
 
   /**
-   * @return Server's load or null if not found.
+   * n * @return Server's load or null if not found.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link #getLiveServerMetrics} instead.
    */
@@ -279,6 +285,7 @@ public class ClusterStatus implements ClusterMetrics {
     return serverMetrics == null ? null : new ServerLoad(serverMetrics);
   }
 
+  @Override
   public String getClusterId() {
     return metrics.getClusterId();
   }
@@ -289,6 +296,7 @@ public class ClusterStatus implements ClusterMetrics {
   }
 
   /**
+   * Get the list of master coprocessor names.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link #getMasterCoprocessorNames} instead.
    */
@@ -299,6 +307,7 @@ public class ClusterStatus implements ClusterMetrics {
   }
 
   /**
+   * Get the last major compaction time for a given table.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link #getLastMajorCompactionTimestamp(TableName)} instead.
    */
@@ -308,6 +317,7 @@ public class ClusterStatus implements ClusterMetrics {
   }
 
   /**
+   * Get the last major compaction time for a given region.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link #getLastMajorCompactionTimestamp(byte[])} instead.
    */
@@ -317,6 +327,7 @@ public class ClusterStatus implements ClusterMetrics {
   }
 
   /**
+   * Returns true if the balancer is enabled.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 No flag in 2.0
    */
   @Deprecated
@@ -344,6 +355,11 @@ public class ClusterStatus implements ClusterMetrics {
     return metrics.getTableRegionStatesCount();
   }
 
+  @Override
+  public List<ServerTask> getMasterTasks() {
+    return metrics.getMasterTasks();
+  }
+
   @Override
   public String toString() {
     StringBuilder sb = new StringBuilder(1024);
