@@ -31,6 +31,7 @@ import org.apache.hadoop.hbase.client.RegionInfoDisplay;
 import org.apache.hadoop.hbase.exceptions.DeserializationException;
 import org.apache.hadoop.hbase.master.RegionState;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.io.DataInputBuffer;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
@@ -93,7 +94,7 @@ public class HRegionInfo implements RegionInfo {
   private static final int MAX_REPLICA_ID = 0xFFFF;
 
   /**
-   * @return the encodedName
+   * n * @return the encodedName
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link org.apache.hadoop.hbase.client.RegionInfo#encodeRegionName(byte[])}.
    */
@@ -211,7 +212,7 @@ public class HRegionInfo implements RegionInfo {
    * Construct HRegionInfo with explicit parameters
    * @param tableName the table name
    * @param startKey  first key in region
-   * @param endKey    end of key range
+   * @param endKey    end of key range n
    */
   public HRegionInfo(final TableName tableName, final byte[] startKey, final byte[] endKey)
     throws IllegalArgumentException {
@@ -220,50 +221,50 @@ public class HRegionInfo implements RegionInfo {
 
   /**
    * Construct HRegionInfo with explicit parameters
-   * @param tableName the table descriptor
+   * @param tableName the table name
    * @param startKey  first key in region
    * @param endKey    end of key range
    * @param split     true if this region has split and we have daughter regions regions that may or
-   *                  may not hold references to this region.
+   *                  may not hold references to this region. n
    */
   public HRegionInfo(final TableName tableName, final byte[] startKey, final byte[] endKey,
     final boolean split) throws IllegalArgumentException {
-    this(tableName, startKey, endKey, split, System.currentTimeMillis());
+    this(tableName, startKey, endKey, split, EnvironmentEdgeManager.currentTime());
   }
 
   /**
    * Construct HRegionInfo with explicit parameters
-   * @param tableName the table descriptor
+   * @param tableName the table name
    * @param startKey  first key in region
    * @param endKey    end of key range
    * @param split     true if this region has split and we have daughter regions regions that may or
    *                  may not hold references to this region.
-   * @param regionid  Region id to use.
+   * @param regionId  Region id to use.
    */
   public HRegionInfo(final TableName tableName, final byte[] startKey, final byte[] endKey,
-    final boolean split, final long regionid) throws IllegalArgumentException {
-    this(tableName, startKey, endKey, split, regionid, DEFAULT_REPLICA_ID);
+    final boolean split, final long regionId) throws IllegalArgumentException {
+    this(tableName, startKey, endKey, split, regionId, DEFAULT_REPLICA_ID);
   }
 
   /**
    * Construct HRegionInfo with explicit parameters
-   * @param tableName the table descriptor
+   * @param tableName the table name
    * @param startKey  first key in region
    * @param endKey    end of key range
    * @param split     true if this region has split and we have daughter regions regions that may or
    *                  may not hold references to this region.
-   * @param regionid  Region id to use.
+   * @param regionId  Region id to use.
    * @param replicaId the replicaId to use
    */
   public HRegionInfo(final TableName tableName, final byte[] startKey, final byte[] endKey,
-    final boolean split, final long regionid, final int replicaId) throws IllegalArgumentException {
+    final boolean split, final long regionId, final int replicaId) throws IllegalArgumentException {
     super();
     if (tableName == null) {
       throw new IllegalArgumentException("TableName cannot be null");
     }
     this.tableName = tableName;
     this.offLine = false;
-    this.regionId = regionid;
+    this.regionId = regionId;
     this.replicaId = replicaId;
     if (this.replicaId > MAX_REPLICA_ID) {
       throw new IllegalArgumentException("ReplicaId cannot be greater than" + MAX_REPLICA_ID);
@@ -279,7 +280,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Costruct a copy of another HRegionInfo
+   * Construct a copy of another HRegionInfo
    */
   public HRegionInfo(RegionInfo other) {
     super();
@@ -303,8 +304,9 @@ public class HRegionInfo implements RegionInfo {
 
   /**
    * Make a region name of passed parameters.
+   * @param tableName the table name
    * @param startKey  Can be null
-   * @param regionid  Region id (Usually timestamp from when region was created).
+   * @param regionId  Region id (Usually timestamp from when region was created).
    * @param newFormat should we create the region name in the new format (such that it contains its
    *                  encoded name?).
    * @return Region name made of passed tableName, startKey and id
@@ -314,12 +316,13 @@ public class HRegionInfo implements RegionInfo {
   @Deprecated
   @InterfaceAudience.Private
   public static byte[] createRegionName(final TableName tableName, final byte[] startKey,
-    final long regionid, boolean newFormat) {
-    return RegionInfo.createRegionName(tableName, startKey, Long.toString(regionid), newFormat);
+    final long regionId, boolean newFormat) {
+    return RegionInfo.createRegionName(tableName, startKey, Long.toString(regionId), newFormat);
   }
 
   /**
    * Make a region name of passed parameters.
+   * @param tableName the table name
    * @param startKey  Can be null
    * @param id        Region id (Usually timestamp from when region was created).
    * @param newFormat should we create the region name in the new format (such that it contains its
@@ -337,8 +340,9 @@ public class HRegionInfo implements RegionInfo {
 
   /**
    * Make a region name of passed parameters.
+   * @param tableName the table name
    * @param startKey  Can be null
-   * @param regionid  Region id (Usually timestamp from when region was created).
+   * @param regionId  Region id (Usually timestamp from when region was created).
    * @param newFormat should we create the region name in the new format (such that it contains its
    *                  encoded name?).
    * @return Region name made of passed tableName, startKey, id and replicaId
@@ -348,13 +352,14 @@ public class HRegionInfo implements RegionInfo {
   @Deprecated
   @InterfaceAudience.Private
   public static byte[] createRegionName(final TableName tableName, final byte[] startKey,
-    final long regionid, int replicaId, boolean newFormat) {
-    return RegionInfo.createRegionName(tableName, startKey, Bytes.toBytes(Long.toString(regionid)),
+    final long regionId, int replicaId, boolean newFormat) {
+    return RegionInfo.createRegionName(tableName, startKey, Bytes.toBytes(Long.toString(regionId)),
       replicaId, newFormat);
   }
 
   /**
    * Make a region name of passed parameters.
+   * @param tableName the table name
    * @param startKey  Can be null
    * @param id        Region id (Usually timestamp from when region was created).
    * @param newFormat should we create the region name in the new format (such that it contains its
@@ -372,8 +377,9 @@ public class HRegionInfo implements RegionInfo {
 
   /**
    * Make a region name of passed parameters.
+   * @param tableName the table name
    * @param startKey  Can be null
-   * @param id        Region id (Usually timestamp from when region was created).
+   * @param id        Region id (Usually timestamp from when region was created)
    * @param newFormat should we create the region name in the new format
    * @return Region name made of passed tableName, startKey, id and replicaId
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
@@ -399,8 +405,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Gets the start key from the specified region name.
-   * @return Start key.
+   * Gets the start key from the specified region name. n * @return Start key.
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link org.apache.hadoop.hbase.client.RegionInfo#getStartKey(byte[])}.
    */
@@ -410,10 +415,9 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Separate elements of a regionName.
-   * @return Array of byte[] containing tableName, startKey and id
-   * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
-   *             {@link RegionInfo#parseRegionName(byte[])}.
+   * Separate elements of a regionName. n * @return Array of byte[] containing tableName, startKey
+   * and id n * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
+   * {@link RegionInfo#parseRegionName(byte[])}.
    */
   @Deprecated
   @InterfaceAudience.Private
@@ -422,9 +426,9 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * @return if region name is encoded.
-   * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
-   *             {@link org.apache.hadoop.hbase.client.RegionInfo#isEncodedRegionName(byte[])}.
+   * n * @return if region name is encoded. n * @deprecated As of release 2.0.0, this will be
+   * removed in HBase 3.0.0 Use
+   * {@link org.apache.hadoop.hbase.client.RegionInfo#isEncodedRegionName(byte[])}.
    */
   @Deprecated
   public static boolean isEncodedRegionName(byte[] regionName) throws IOException {
@@ -490,7 +494,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Get current table name of the region
+   * Get current table name of the region n
    */
   @Override
   public TableName getTable() {
@@ -552,6 +556,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
+   * Set or clear the split status flag.
    * @param split set split status
    */
   public void setSplit(boolean split) {
@@ -690,6 +695,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
+   * Serialize a {@link HRegionInfo} into a byte array.
    * @return This instance serialized as protobuf w/ a magic pb prefix.
    * @see #parseFrom(byte[])
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
@@ -701,6 +707,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
+   * Parse a serialized representation of a {@link HRegionInfo}.
    * @return A deserialized {@link HRegionInfo} or null if we failed deserialize or passed bytes
    *         null
    * @see #toByteArray()
@@ -714,6 +721,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
+   * Parse a serialized representation of a {@link HRegionInfo}.
    * @return A deserialized {@link HRegionInfo} or null if we failed deserialize or passed bytes
    *         null
    * @see #toByteArray()
@@ -731,9 +739,9 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
+   * Parse a serialized representation of a {@link HRegionInfo}.
    * @param bytes A pb RegionInfo serialized with a pb magic prefix.
-   * @return A deserialized {@link HRegionInfo}
-   * @see #toByteArray()
+   * @return A deserialized {@link HRegionInfo} n * @see #toByteArray()
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link org.apache.hadoop.hbase.client.RegionInfo#parseFrom(byte[])}.
    */
@@ -743,11 +751,11 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
+   * Parse a serialized representation of a {@link HRegionInfo}.
    * @param bytes  A pb RegionInfo serialized with a pb magic prefix.
    * @param offset starting point in the byte array
    * @param len    length to read on the byte array
-   * @return A deserialized {@link HRegionInfo}
-   * @see #toByteArray()
+   * @return A deserialized {@link HRegionInfo} n * @see #toByteArray()
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link org.apache.hadoop.hbase.client.RegionInfo#parseFrom(byte[], int, int)}.
    */
@@ -772,8 +780,8 @@ public class HRegionInfo implements RegionInfo {
   /**
    * Use this instead of {@link #toByteArray()} when writing to a stream and you want to use the pb
    * mergeDelimitedFrom (w/o the delimiter, pb reads to EOF which may not be what you want).
-   * @return This instance serialized as a delimited protobuf w/ a magic pb prefix.
-   * @see #toByteArray()
+   * @return This instance serialized as a delimited protobuf w/ a magic pb prefix. n * @see
+   *         #toByteArray()
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link RegionInfo#toDelimitedByteArray(RegionInfo)}.
    */
@@ -783,8 +791,8 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Get the descriptive name as {@link RegionState} does it but with hidden startkey optionally
-   * @return descriptive string
+   * Get the descriptive name as {@link RegionState} does it but with hidden startkey optionally nn
+   * * @return descriptive string
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             RegionInfoDisplay#getDescriptiveNameFromRegionStateForDisplay(RegionState,
    *             Configuration) over in hbase-server module.
@@ -797,8 +805,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Get the end key for display. Optionally hide the real end key.
-   * @return the endkey
+   * Get the end key for display. Optionally hide the real end key. nn * @return the endkey
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             RegionInfoDisplay#getEndKeyForDisplay(RegionInfo, Configuration) over in
    *             hbase-server module.
@@ -810,8 +817,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Get the start key for display. Optionally hide the real start key.
-   * @return the startkey
+   * Get the start key for display. Optionally hide the real start key. nn * @return the startkey
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             RegionInfoDisplay#getStartKeyForDisplay(RegionInfo, Configuration) over in
    *             hbase-server module.
@@ -823,8 +829,8 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Get the region name for display. Optionally hide the start key.
-   * @return region name as String
+   * Get the region name for display. Optionally hide the start key. nn * @return region name as
+   * String
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             RegionInfoDisplay#getRegionNameAsStringForDisplay(RegionInfo, Configuration) over
    *             in hbase-server module.
@@ -836,8 +842,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Get the region name for display. Optionally hide the start key.
-   * @return region name bytes
+   * Get the region name for display. Optionally hide the start key. nn * @return region name bytes
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             RegionInfoDisplay#getRegionNameForDisplay(RegionInfo, Configuration) over in
    *             hbase-server module.
@@ -850,10 +855,9 @@ public class HRegionInfo implements RegionInfo {
 
   /**
    * Parses an HRegionInfo instance from the passed in stream. Presumes the HRegionInfo was
-   * serialized to the stream with {@link #toDelimitedByteArray()}
-   * @return An instance of HRegionInfo.
-   * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
-   *             {@link RegionInfo#parseFrom(DataInputStream)}.
+   * serialized to the stream with {@link #toDelimitedByteArray()} n * @return An instance of
+   * HRegionInfo. n * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
+   * {@link RegionInfo#parseFrom(DataInputStream)}.
    */
   @Deprecated
   @InterfaceAudience.Private
@@ -881,8 +885,8 @@ public class HRegionInfo implements RegionInfo {
    * to EOF which may not be what you want). {@link #parseDelimitedFrom(byte[], int, int)} can be
    * used to read back the instances.
    * @param infos HRegionInfo objects to serialize
-   * @return This instance serialized as a delimited protobuf w/ a magic pb prefix.
-   * @see #toByteArray()
+   * @return This instance serialized as a delimited protobuf w/ a magic pb prefix. n * @see
+   *         #toByteArray()
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link RegionInfo#toDelimitedByteArray(RegionInfo...)}.
    */
@@ -923,8 +927,7 @@ public class HRegionInfo implements RegionInfo {
   }
 
   /**
-   * Check whether two regions are adjacent
-   * @return true if two regions are adjacent
+   * Check whether two regions are adjacent nn * @return true if two regions are adjacent
    * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0 Use
    *             {@link org.apache.hadoop.hbase.client.RegionInfo#areAdjacent(RegionInfo, RegionInfo)}.
    */
