@@ -29,6 +29,8 @@ import static org.apache.hadoop.hbase.util.ConcurrentMapUtils.computeIfAbsent;
 import static org.apache.hadoop.hbase.util.ConcurrentMapUtils.computeIfAbsentEx;
 
 import edu.umd.cs.findbugs.annotations.Nullable;
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.context.Scope;
 import java.io.Closeable;
 import java.io.IOException;
 import java.io.InterruptedIOException;
@@ -50,10 +52,10 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.locks.ReentrantLock;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.AuthUtil;
-import org.apache.hadoop.hbase.CallQueueTooBigException;
 import org.apache.hadoop.hbase.CatalogReplicaMode;
 import org.apache.hadoop.hbase.ChoreService;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
+import org.apache.hadoop.hbase.HBaseServerException;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionLocation;
 import org.apache.hadoop.hbase.MasterNotRunningException;
@@ -67,6 +69,7 @@ import org.apache.hadoop.hbase.ZooKeeperConnectionException;
 import org.apache.hadoop.hbase.client.Scan.ReadType;
 import org.apache.hadoop.hbase.client.backoff.ClientBackoffPolicy;
 import org.apache.hadoop.hbase.client.backoff.ClientBackoffPolicyFactory;
+import org.apache.hadoop.hbase.client.trace.TableOperationSpanBuilder;
 import org.apache.hadoop.hbase.exceptions.ClientExceptionsUtil;
 import org.apache.hadoop.hbase.exceptions.ConnectionClosedException;
 import org.apache.hadoop.hbase.exceptions.RegionMovedException;
@@ -76,6 +79,8 @@ import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
 import org.apache.hadoop.hbase.log.HBaseMarkers;
 import org.apache.hadoop.hbase.regionserver.RegionServerStoppedException;
 import org.apache.hadoop.hbase.security.User;
+import org.apache.hadoop.hbase.trace.HBaseSemanticAttributes;
+import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.ExceptionUtil;
@@ -89,8 +94,6 @@ import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.hbase.thirdparty.com.google.common.base.Supplier;
-import org.apache.hbase.thirdparty.com.google.common.base.Suppliers;
 import org.apache.hbase.thirdparty.com.google.common.base.Throwables;
 import org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
 import org.apache.hbase.thirdparty.com.google.protobuf.BlockingRpcChannel;
@@ -111,6 +114,8 @@ import org.apache.hadoop.hbase.shaded.protobuf.generated.HBaseProtos;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.DecommissionRegionServersRequest;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.DecommissionRegionServersResponse;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.FlushMasterStoreRequest;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.FlushMasterStoreResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.IsBalancerEnabledRequest;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.IsBalancerEnabledResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.IsNormalizerEnabledRequest;
@@ -119,6 +124,10 @@ import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.IsRpcThrot
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.IsRpcThrottleEnabledResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.ListDecommissionedRegionServersRequest;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.ListDecommissionedRegionServersResponse;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.ModifyColumnStoreFileTrackerRequest;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.ModifyColumnStoreFileTrackerResponse;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.ModifyTableStoreFileTrackerRequest;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.ModifyTableStoreFileTrackerResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.NormalizeRequest;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.NormalizeResponse;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.MasterProtos.RecommissionRegionServerRequest;
@@ -158,15 +167,10 @@ import org.apache.hadoop.hbase.shaded.protobuf.generated.ReplicationProtos.Updat
     value = "AT_OPERATION_SEQUENCE_ON_CONCURRENT_ABSTRACTION",
     justification = "Access to the conncurrent hash map is under a lock so should be fine.")
 @InterfaceAudience.Private
-class ConnectionImplementation implements ClusterConnection, Closeable {
+public class ConnectionImplementation implements ClusterConnection, Closeable {
   public static final String RETRIES_BY_SERVER_KEY = "hbase.client.retries.by.server";
-
-  public static final String MASTER_STATE_CACHE_TIMEOUT_SEC =
-    "hbase.client.master.state.cache.timeout.sec";
   private static final Logger LOG = LoggerFactory.getLogger(ConnectionImplementation.class);
 
-  private final long pause;
-  private final long pauseForCQTBE;// pause for CallQueueTooBigException, if specified
   // The mode tells if HedgedRead, LoadBalance mode is supported.
   // The default mode is CatalogReplicaMode.None.
   private CatalogReplicaMode metaReplicaMode;
@@ -177,9 +181,13 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
   final int rpcTimeout;
 
   /**
-   * Global nonceGenerator shared per client.Currently there's no reason to limit its scope. Once
+   * Global nonceGenerator shared per client. Currently there's no reason to limit its scope. Once
    * it's set under nonceGeneratorCreateLock, it is never unset or changed.
    */
+  // XXX: It is a bad pattern to assign a value to a static field from a constructor. However
+  // it would likely change semantics if we change it because the NonceGenerator is selected
+  // from configuration passed in as a parameter of the constructor. This has been cleaned up
+  // in later branches.
   private static volatile NonceGenerator nonceGenerator = null;
   /** The nonce generator lock. Only taken when creating Connection, which gets a private copy. */
   private static final Object nonceGeneratorCreateLock = new Object();
@@ -241,12 +249,6 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
   /** lock guards against multiple threads trying to query the meta region at the same time */
   private final ReentrantLock userRegionLock = new ReentrantLock();
 
-  /**
-   * Supplier to get masterState.By default uses simple supplier without TTL cache. When
-   * hbase.client.master.state.cache.timeout.sec > 0 it uses TTL Cache.
-   */
-  private final Supplier<Boolean> masterStateSupplier;
-
   private ChoreService choreService;
 
   /**
@@ -254,6 +256,14 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
    * @param conf Configuration object
    */
   ConnectionImplementation(Configuration conf, ExecutorService pool, User user) throws IOException {
+    this(conf, pool, user, null);
+  }
+
+  /**
+   * Constructor, for creating cluster connection with provided ConnectionRegistry.
+   */
+  ConnectionImplementation(Configuration conf, ExecutorService pool, User user,
+    ConnectionRegistry registry) throws IOException {
     this.conf = conf;
     this.user = user;
     if (user != null && user.isLoginFromKeytab()) {
@@ -262,16 +272,6 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
     this.batchPool = (ThreadPoolExecutor) pool;
     this.connectionConfig = new ConnectionConfiguration(conf);
     this.closed = false;
-    this.pause = conf.getLong(HConstants.HBASE_CLIENT_PAUSE, HConstants.DEFAULT_HBASE_CLIENT_PAUSE);
-    long configuredPauseForCQTBE = conf.getLong(HConstants.HBASE_CLIENT_PAUSE_FOR_CQTBE, pause);
-    if (configuredPauseForCQTBE < pause) {
-      LOG.warn("The " + HConstants.HBASE_CLIENT_PAUSE_FOR_CQTBE + " setting: "
-        + configuredPauseForCQTBE + " is smaller than " + HConstants.HBASE_CLIENT_PAUSE
-        + ", will use " + pause + " instead.");
-      this.pauseForCQTBE = pause;
-    } else {
-      this.pauseForCQTBE = configuredPauseForCQTBE;
-    }
     this.metaReplicaCallTimeoutScanInMicroSecond =
       connectionConfig.getMetaReplicaCallTimeoutMicroSecondScan();
 
@@ -290,18 +290,11 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
     }
 
     this.stats = ServerStatisticTracker.create(conf);
-    this.interceptor = (new RetryingCallerInterceptorFactory(conf)).build();
+    this.interceptor = new RetryingCallerInterceptorFactory(conf).build();
     this.rpcControllerFactory = RpcControllerFactory.instantiate(conf);
     this.rpcCallerFactory = RpcRetryingCallerFactory.instantiate(conf, interceptor, this.stats);
     this.backoffPolicy = ClientBackoffPolicyFactory.create(conf);
     this.asyncProcess = new AsyncProcess(this, conf, rpcCallerFactory, rpcControllerFactory);
-    if (conf.getBoolean(CLIENT_SIDE_METRICS_ENABLED_KEY, false)) {
-      this.metrics =
-        new MetricsConnection(this.toString(), this::getBatchPool, this::getMetaLookupPool);
-    } else {
-      this.metrics = null;
-    }
-    this.metaCache = new MetaCache(this.metrics);
 
     boolean shouldListen =
       conf.getBoolean(HConstants.STATUS_PUBLISHED, HConstants.STATUS_PUBLISHED_DEFAULT);
@@ -313,9 +306,21 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
     this.alternateBufferedMutatorClassName = this.conf.get(BufferedMutator.CLASSNAME_KEY);
 
     try {
-      this.registry = ConnectionRegistryFactory.getRegistry(conf);
+      if (registry == null) {
+        this.registry = ConnectionRegistryFactory.getRegistry(conf);
+      } else {
+        this.registry = registry;
+      }
       retrieveClusterId();
 
+      if (conf.getBoolean(CLIENT_SIDE_METRICS_ENABLED_KEY, false)) {
+        String scope = MetricsConnection.getScope(conf, clusterId, this);
+        this.metrics = new MetricsConnection(scope, this::getBatchPool, this::getMetaLookupPool);
+      } else {
+        this.metrics = null;
+      }
+      this.metaCache = new MetaCache(this.metrics);
+
       this.rpcClient = RpcClientFactory.createClient(this.conf, this.clusterId, this.metrics);
 
       // Do we publish the status?
@@ -355,7 +360,7 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
           .createSelector(replicaSelectorClass, META_TABLE_NAME, getChoreService(), () -> {
             int numOfReplicas = 1;
             try {
-              RegionLocations metaLocations = registry.getMetaRegionLocations()
+              RegionLocations metaLocations = this.registry.getMetaRegionLocations()
                 .get(connectionConfig.getReadRpcTimeout(), TimeUnit.MILLISECONDS);
               numOfReplicas = metaLocations.size();
             } catch (Exception e) {
@@ -375,44 +380,11 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
       default:
         // Doing nothing
     }
-
-    long masterStateCacheTimeout = conf.getLong(MASTER_STATE_CACHE_TIMEOUT_SEC, 0);
-
-    Supplier<Boolean> masterConnSupplier = masterConnectionStateSupplier();
-    if (masterStateCacheTimeout <= 0L) {
-      this.masterStateSupplier = masterConnSupplier;
-    } else {
-      this.masterStateSupplier = Suppliers.memoizeWithExpiration(masterConnSupplier,
-        masterStateCacheTimeout, TimeUnit.SECONDS);
-    }
-  }
-
-  /**
-   * Visible for tests
-   */
-  Supplier<Boolean> masterConnectionStateSupplier() {
-    return () -> {
-      if (this.masterServiceState.getStub() == null) {
-        return false;
-      }
-      try {
-        LOG.trace("Getting master state using rpc call");
-        return this.masterServiceState.isMasterRunning();
-      } catch (UndeclaredThrowableException e) {
-        // It's somehow messy, but we can receive exceptions such as
-        // java.net.ConnectException but they're not declared. So we catch it...
-        LOG.info("Master connection is not running anymore", e.getUndeclaredThrowable());
-        return false;
-      } catch (IOException se) {
-        LOG.warn("Checking master connection", se);
-        return false;
-      }
-    };
   }
 
   private void spawnRenewalChore(final UserGroupInformation user) {
     ChoreService service = getChoreService();
-    service.scheduleChore(AuthUtil.getAuthRenewalChore(user));
+    service.scheduleChore(AuthUtil.getAuthRenewalChore(user, conf));
   }
 
   /**
@@ -498,24 +470,28 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
 
   @Override
   public Hbck getHbck() throws IOException {
-    return getHbck(get(registry.getActiveMaster()));
+    return TraceUtil.trace(() -> getHbck(get(registry.getActiveMaster())),
+      () -> TraceUtil.createSpan(this.getClass().getSimpleName() + ".getHbck"));
   }
 
   @Override
   public Hbck getHbck(ServerName masterServer) throws IOException {
-    checkClosed();
-    if (isDeadServer(masterServer)) {
-      throw new RegionServerStoppedException(masterServer + " is dead.");
-    }
-    String key =
-      getStubKey(MasterProtos.HbckService.BlockingInterface.class.getName(), masterServer);
+    return TraceUtil.trace(() -> {
+      checkClosed();
+      if (isDeadServer(masterServer)) {
+        throw new RegionServerStoppedException(masterServer + " is dead.");
+      }
+      String key =
+        getStubKey(MasterProtos.HbckService.BlockingInterface.class.getName(), masterServer);
 
-    return new HBaseHbck(
-      (MasterProtos.HbckService.BlockingInterface) computeIfAbsentEx(stubs, key, () -> {
-        BlockingRpcChannel channel =
-          this.rpcClient.createBlockingRpcChannel(masterServer, user, rpcTimeout);
-        return MasterProtos.HbckService.newBlockingStub(channel);
-      }), rpcControllerFactory);
+      return new HBaseHbck(
+        (MasterProtos.HbckService.BlockingInterface) computeIfAbsentEx(stubs, key, () -> {
+          BlockingRpcChannel channel =
+            this.rpcClient.createBlockingRpcChannel(masterServer, user, rpcTimeout);
+          return MasterProtos.HbckService.newBlockingStub(channel);
+        }), rpcControllerFactory);
+    }, () -> TraceUtil.createSpan(this.getClass().getSimpleName() + ".getHbck")
+      .setAttribute(HBaseSemanticAttributes.SERVER_NAME_KEY, masterServer.getServerName()));
   }
 
   @Override
@@ -523,6 +499,16 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
     return this.metrics;
   }
 
+  @Override
+  public User getUser() {
+    return user;
+  }
+
+  @Override
+  public ConnectionRegistry getConnectionRegistry() {
+    return registry;
+  }
+
   private ThreadPoolExecutor getBatchPool() {
     if (batchPool == null) {
       synchronized (this) {
@@ -555,7 +541,7 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
     }
     ThreadPoolExecutor tpe =
       new ThreadPoolExecutor(coreThreads, maxThreads, keepAliveTime, TimeUnit.SECONDS, workQueue,
-        new ThreadFactoryBuilder().setDaemon(true).setNameFormat(toString() + nameHint + "-pool-%d")
+        new ThreadFactoryBuilder().setNameFormat(toString() + nameHint + "-pool-%d")
           .setUncaughtExceptionHandler(Threads.LOGGING_EXCEPTION_HANDLER).build());
     tpe.allowCoreThreadTimeOut(true);
     return tpe;
@@ -639,7 +625,7 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
   }
 
   /**
-   * If choreService has not been created yet, create the ChoreService.
+   * If choreService has not been created yet, create the ChoreService. n
    */
   synchronized ChoreService getChoreService() {
     if (choreService == null) {
@@ -957,13 +943,9 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
         metaCache.clearCache(tableName, row, replicaId);
       }
       // Query the meta region
-      long pauseBase = this.pause;
-      long lockStartTime = 0;
-      boolean lockedUserRegion = false;
+      long pauseBase = connectionConfig.getPauseMillis();
+      takeUserRegionLock();
       try {
-        takeUserRegionLock();
-        lockStartTime = EnvironmentEdgeManager.currentTime();
-        lockedUserRegion = true;
         // We don't need to check if useCache is enabled or not. Even if useCache is false
         // we already cleared the cache for this row before acquiring userRegion lock so if this
         // row is present in cache that means some other thread has populated it while we were
@@ -977,9 +959,13 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
             RegionInfo.DEFAULT_REPLICA_ID);
         }
         s.resetMvccReadPoint();
-        try (ReversedClientScanner rcs =
-          new ReversedClientScanner(conf, s, TableName.META_TABLE_NAME, this, rpcCallerFactory,
-            rpcControllerFactory, getMetaLookupPool(), metaReplicaCallTimeoutScanInMicroSecond)) {
+        final Span span = new TableOperationSpanBuilder(this)
+          .setTableName(TableName.META_TABLE_NAME).setOperation(s).build();
+        try (Scope ignored = span.makeCurrent();
+          ReversedClientScanner rcs =
+            new ReversedClientScanner(conf, s, TableName.META_TABLE_NAME, this, rpcCallerFactory,
+              rpcControllerFactory, getMetaLookupPool(), connectionConfig.getMetaReadRpcTimeout(),
+              connectionConfig.getMetaScanTimeout(), metaReplicaCallTimeoutScanInMicroSecond)) {
           boolean tableNotFound = true;
           for (;;) {
             Result regionInfoRow = rcs.next();
@@ -1048,9 +1034,10 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
         if (e instanceof RemoteException) {
           e = ((RemoteException) e).unwrapRemoteException();
         }
-        if (e instanceof CallQueueTooBigException) {
-          // Give a special check on CallQueueTooBigException, see #HBASE-17114
-          pauseBase = this.pauseForCQTBE;
+        if (HBaseServerException.isServerOverloaded(e)) {
+          // Give a special pause when encountering an exception indicating the server
+          // is overloaded. see #HBASE-17114 and HBASE-26807
+          pauseBase = connectionConfig.getPauseMillisForServerOverloaded();
         }
         if (tries < maxAttempts - 1) {
           LOG.debug("locateRegionInMeta parentTable='{}', attempt={} of {} failed; retrying "
@@ -1062,13 +1049,7 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
         relocateMeta =
           !(e instanceof RegionOfflineException || e instanceof NoServerForRegionException);
       } finally {
-        if (lockedUserRegion) {
-          userRegionLock.unlock();
-          // update duration of the lock being held
-          if (metrics != null) {
-            metrics.updateUserRegionLockHeld(EnvironmentEdgeManager.currentTime() - lockStartTime);
-          }
-        }
+        userRegionLock.unlock();
       }
       try {
         Thread.sleep(ConnectionUtils.getPauseTime(pauseBase, tries));
@@ -1082,19 +1063,9 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
   void takeUserRegionLock() throws IOException {
     try {
       long waitTime = connectionConfig.getMetaOperationTimeout();
-      if (metrics != null) {
-        metrics.updateUserRegionLockQueue(userRegionLock.getQueueLength());
-      }
-      final long waitStartTime = EnvironmentEdgeManager.currentTime();
       if (!userRegionLock.tryLock(waitTime, TimeUnit.MILLISECONDS)) {
-        if (metrics != null) {
-          metrics.incrUserRegionLockTimeout();
-        }
         throw new LockTimeoutException("Failed to get user region lock in" + waitTime + " ms. "
           + " for accessing meta region server.");
-      } else if (metrics != null) {
-        // successfully grabbed the lock, start timer of holding the lock
-        metrics.updateUserRegionLockWaiting(EnvironmentEdgeManager.currentTime() - waitStartTime);
       }
     } catch (InterruptedException ie) {
       LOG.error("Interrupted while waiting for a lock", ie);
@@ -1211,6 +1182,7 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
      * @param timeout  how long to wait before timeout, in unit of millisecond
      * @param maxTries how many times to try
      */
+    @SuppressWarnings("JavaUtilDate")
     public ServerErrorTracker(long timeout, int maxTries) {
       this.maxTries = maxTries;
       this.canRetryUntil = EnvironmentEdgeManager.currentTime() + timeout;
@@ -1276,6 +1248,7 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
    * Class to make a MasterServiceStubMaker stub.
    */
   private final class MasterServiceStubMaker {
+
     private void isMasterRunning(MasterProtos.MasterService.BlockingInterface stub)
       throws IOException {
       try {
@@ -1375,13 +1348,6 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
 
   final MasterServiceState masterServiceState = new MasterServiceState(this);
 
-  /**
-   * Visible for tests
-   */
-  MasterServiceState getMasterServiceState() {
-    return this.masterServiceState;
-  }
-
   @Override
   public MasterKeepAliveConnection getMaster() throws IOException {
     return getKeepAliveMasterService();
@@ -1392,16 +1358,13 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
   }
 
   private MasterKeepAliveConnection getKeepAliveMasterService() throws IOException {
-    if (!isKeepAliveMasterConnectedAndRunning()) {
-      synchronized (masterLock) {
-        if (!isKeepAliveMasterConnectedAndRunning()) {
-          MasterServiceStubMaker stubMaker = new MasterServiceStubMaker();
-          this.masterServiceState.stub = stubMaker.makeStub();
-        }
-        resetMasterServiceState(this.masterServiceState);
+    synchronized (masterLock) {
+      if (!isKeepAliveMasterConnectedAndRunning(this.masterServiceState)) {
+        MasterServiceStubMaker stubMaker = new MasterServiceStubMaker();
+        this.masterServiceState.stub = stubMaker.makeStub();
       }
+      resetMasterServiceState(this.masterServiceState);
     }
-
     // Ugly delegation just so we can add in a Close method.
     final MasterProtos.MasterService.BlockingInterface stub = this.masterServiceState.stub;
     return new MasterKeepAliveConnection() {
@@ -1945,6 +1908,26 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
         HBaseProtos.LogRequest request) throws ServiceException {
         return stub.getLogEntries(controller, request);
       }
+
+      @Override
+      public ModifyTableStoreFileTrackerResponse modifyTableStoreFileTracker(
+        RpcController controller, ModifyTableStoreFileTrackerRequest request)
+        throws ServiceException {
+        return stub.modifyTableStoreFileTracker(controller, request);
+      }
+
+      @Override
+      public ModifyColumnStoreFileTrackerResponse modifyColumnStoreFileTracker(
+        RpcController controller, ModifyColumnStoreFileTrackerRequest request)
+        throws ServiceException {
+        return stub.modifyColumnStoreFileTracker(controller, request);
+      }
+
+      @Override
+      public FlushMasterStoreResponse flushMasterStore(RpcController controller,
+        FlushMasterStoreRequest request) throws ServiceException {
+        return stub.flushMasterStore(controller, request);
+      }
     };
   }
 
@@ -1954,9 +1937,21 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
     }
   }
 
-  private boolean isKeepAliveMasterConnectedAndRunning() {
-    LOG.trace("Getting master connection state from TTL Cache");
-    return masterStateSupplier.get();
+  private boolean isKeepAliveMasterConnectedAndRunning(MasterServiceState mss) {
+    if (mss.getStub() == null) {
+      return false;
+    }
+    try {
+      return mss.isMasterRunning();
+    } catch (UndeclaredThrowableException e) {
+      // It's somehow messy, but we can receive exceptions such as
+      // java.net.ConnectException but they're not declared. So we catch it...
+      LOG.info("Master connection is not running anymore", e.getUndeclaredThrowable());
+      return false;
+    } catch (IOException se) {
+      LOG.warn("Checking master connection", se);
+      return false;
+    }
   }
 
   void releaseMaster(MasterServiceState mss) {
@@ -1991,6 +1986,11 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
     cacheLocation(hri.getTable(), source, newHrl);
   }
 
+  @Override
+  public void deleteCachedRegionLocation(final HRegionLocation location) {
+    metaCache.clearCache(location);
+  }
+
   /**
    * Update the location with the new value (if the exception is a RegionMovedException) or delete
    * it from the cache. Does nothing if we can be sure from the exception that the location is still
@@ -2117,28 +2117,32 @@ class ConnectionImplementation implements ClusterConnection, Closeable {
 
   @Override
   public void close() {
-    if (this.closed) {
-      return;
-    }
-    closeMaster();
-    shutdownPools();
-    if (this.metrics != null) {
-      this.metrics.shutdown();
-    }
-    this.closed = true;
-    if (this.registry != null) {
-      registry.close();
-    }
-    this.stubs.clear();
-    if (clusterStatusListener != null) {
-      clusterStatusListener.close();
-    }
-    if (rpcClient != null) {
-      rpcClient.close();
-    }
-    if (choreService != null) {
-      choreService.shutdown();
-    }
+    TraceUtil.trace(() -> {
+      if (this.closed) {
+        return;
+      }
+      closeMaster();
+      shutdownPools();
+      if (this.metrics != null) {
+        this.metrics.shutdown();
+      }
+      this.closed = true;
+      if (this.registry != null) {
+        registry.close();
+      }
+      this.stubs.clear();
+      if (clusterStatusListener != null) {
+        clusterStatusListener.close();
+      }
+      if (rpcClient != null) {
+        rpcClient.close();
+      }
+      synchronized (this) {
+        if (choreService != null) {
+          choreService.shutdown();
+        }
+      }
+    }, this.getClass().getSimpleName() + ".close");
   }
 
   /**
