@@ -47,8 +47,8 @@ import org.apache.yetus.audience.InterfaceAudience;
  * <p>
  * Specifying timestamps, deleteFamily and deleteColumns will delete all versions with a timestamp
  * less than or equal to that passed. If no timestamp is specified, an entry is added with a
- * timestamp of 'now' where 'now' is the servers's System.currentTimeMillis(). Specifying a
- * timestamp to the deleteColumn method will delete versions only with a timestamp equal to that
+ * timestamp of 'now' where 'now' is the servers's EnvironmentEdgeManager.currentTime(). Specifying
+ * a timestamp to the deleteColumn method will delete versions only with a timestamp equal to that
  * specified. If no timestamp is passed to deleteColumn, internally, it figures the most recent
  * cell's timestamp and adds a delete at that timestamp; i.e. it deletes the most recently added
  * cell.
@@ -95,7 +95,7 @@ public class Delete extends Mutation {
    * <p>
    * This timestamp is ONLY used for a delete row operation. If specifying families or columns, you
    * must specify each timestamp individually.
-   * @param row We make a local copy of this passed in row.
+   * @param row We make a local copy of this passed in row. nn
    */
   public Delete(final byte[] row, final int rowOffset, final int rowLength) {
     this(row, rowOffset, rowLength, HConstants.LATEST_TIMESTAMP);
@@ -109,8 +109,6 @@ public class Delete extends Mutation {
    * <p>
    * This timestamp is ONLY used for a delete row operation. If specifying families or columns, you
    * must specify each timestamp individually.
-   * @param row       We make a local copy of this passed in row.
-   * @param timestamp maximum version timestamp (only for delete row)
    */
   public Delete(final byte[] row, final int rowOffset, final int rowLength, long timestamp) {
     checkRow(row, rowOffset, rowLength);
@@ -119,6 +117,7 @@ public class Delete extends Mutation {
   }
 
   /**
+   * Create a Delete operation using another Delete as template.
    * @param deleteToCopy delete to copy
    */
   public Delete(final Delete deleteToCopy) {
@@ -140,9 +139,8 @@ public class Delete extends Mutation {
   /**
    * Advanced use only. Add an existing delete marker to this Delete object.
    * @param kv An existing KeyValue of type "delete".
-   * @return this for invocation chaining
-   * @deprecated As of release 2.0.0, this will be removed in HBase 3.0.0. Use {@link #add(Cell)}
-   *             instead
+   * @return this for invocation chaining n * @deprecated As of release 2.0.0, this will be removed
+   *         in HBase 3.0.0. Use {@link #add(Cell)} instead
    */
   @SuppressWarnings("unchecked")
   @Deprecated
@@ -153,8 +151,9 @@ public class Delete extends Mutation {
   /**
    * Add an existing delete marker to this Delete object.
    * @param cell An existing cell of type "delete".
-   * @return this for invocation chaining
+   * @return this for invocation chaining n
    */
+  @Override
   public Delete add(Cell cell) throws IOException {
     super.add(cell);
     return this;
