@@ -32,9 +32,9 @@ import java.util.concurrent.ConcurrentSkipListMap;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Supplier;
+import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.hadoop.ipc.RemoteException;
 import org.apache.yetus.audience.InterfaceAudience;
 
 import org.apache.hbase.thirdparty.com.google.protobuf.Descriptors.MethodDescriptor;
@@ -57,11 +57,33 @@ public class MetricsConnection implements StatisticTrackable {
   /** Set this key to {@code true} to enable metrics collection of client requests. */
   public static final String CLIENT_SIDE_METRICS_ENABLED_KEY = "hbase.client.metrics.enable";
 
+  /**
+   * Set to specify a custom scope for the metrics published through {@link MetricsConnection}. The
+   * scope is added to JMX MBean objectName, and defaults to a combination of the Connection's
+   * clusterId and hashCode. For example, a default value for a connection to cluster "foo" might be
+   * "foo-7d9d0818", where "7d9d0818" is the hashCode of the underlying AsyncConnectionImpl. Users
+   * may set this key to give a more contextual name for this scope. For example, one might want to
+   * differentiate a read connection from a write connection by setting the scopes to "foo-read" and
+   * "foo-write" respectively. Scope is the only thing that lends any uniqueness to the metrics.
+   * Care should be taken to avoid using the same scope for multiple Connections, otherwise the
+   * metrics may aggregate in unforeseen ways.
+   */
+  public static final String METRICS_SCOPE_KEY = "hbase.client.metrics.scope";
+
+  /**
+   * Returns the scope for a MetricsConnection based on the configured {@link #METRICS_SCOPE_KEY} or
+   * by generating a default from the passed clusterId and connectionObj's hashCode.
+   * @param conf          configuration for the connection
+   * @param clusterId     clusterId for the connection
+   * @param connectionObj either a Connection or AsyncConnectionImpl, the instance creating this
+   *                      MetricsConnection.
+   */
+  static String getScope(Configuration conf, String clusterId, Object connectionObj) {
+    return conf.get(METRICS_SCOPE_KEY,
+      clusterId + "@" + Integer.toHexString(connectionObj.hashCode()));
+  }
+
   private static final String CNT_BASE = "rpcCount_";
-  private static final String FAILURE_CNT_BASE = "rpcFailureCount_";
-  private static final String TOTAL_EXCEPTION_CNT = "rpcTotalExceptions";
-  private static final String LOCAL_EXCEPTION_CNT_BASE = "rpcLocalExceptions_";
-  private static final String REMOTE_EXCEPTION_CNT_BASE = "rpcRemoteExceptions_";
   private static final String DRTN_BASE = "rpcCallDurationMs_";
   private static final String REQ_BASE = "rpcCallRequestSizeBytes_";
   private static final String RESP_BASE = "rpcCallResponseSizeBytes_";
@@ -250,7 +272,7 @@ public class MetricsConnection implements StatisticTrackable {
 
   private final MetricRegistry registry;
   private final JmxReporter reporter;
-  private final String scope;
+  protected final String scope;
 
   private final NewMetric<Timer> timerFactory = new NewMetric<Timer>() {
     @Override
@@ -291,10 +313,6 @@ public class MetricsConnection implements StatisticTrackable {
   protected final Counter hedgedReadWin;
   protected final Histogram concurrentCallsPerServerHist;
   protected final Histogram numActionsPerServerHist;
-  protected final Counter userRegionLockTimeoutCount;
-  protected final Timer userRegionLockWaitingTimer;
-  protected final Timer userRegionLockHeldTimer;
-  protected final Histogram userRegionLockQueueHist;
   protected final Counter nsLookups;
   protected final Counter nsLookupsFailed;
 
@@ -356,14 +374,6 @@ public class MetricsConnection implements StatisticTrackable {
       registry.histogram(name(MetricsConnection.class, "concurrentCallsPerServer", scope));
     this.numActionsPerServerHist =
       registry.histogram(name(MetricsConnection.class, "numActionsPerServer", scope));
-    this.userRegionLockTimeoutCount =
-      registry.counter(name(this.getClass(), "userRegionLockTimeoutCount", scope));
-    this.userRegionLockWaitingTimer =
-      registry.timer(name(this.getClass(), "userRegionLockWaitingDuration", scope));
-    this.userRegionLockHeldTimer =
-      registry.timer(name(this.getClass(), "userRegionLockHeldDuration", scope));
-    this.userRegionLockQueueHist =
-      registry.histogram(name(MetricsConnection.class, "userRegionLockQueueLength", scope));
     this.nsLookups = registry.counter(name(this.getClass(), NS_LOOKUPS, scope));
     this.nsLookupsFailed = registry.counter(name(this.getClass(), NS_LOOKUPS_FAILED, scope));
 
@@ -403,10 +413,6 @@ public class MetricsConnection implements StatisticTrackable {
     metaCacheMisses.inc();
   }
 
-  public long getMetaCacheMisses() {
-    return metaCacheMisses.getCount();
-  }
-
   /** Increment the number of meta cache drops requested for entire RegionServer. */
   public void incrMetaCacheNumClearServer() {
     metaCacheNumClearServer.inc();
@@ -443,24 +449,6 @@ public class MetricsConnection implements StatisticTrackable {
     this.runnerStats.updateDelayInterval(interval);
   }
 
-  /** incr */
-  public void incrUserRegionLockTimeout() {
-    userRegionLockTimeoutCount.inc();
-  }
-
-  /** update */
-  public void updateUserRegionLockWaiting(long duration) {
-    userRegionLockWaitingTimer.update(duration, TimeUnit.MILLISECONDS);
-  }
-
-  public void updateUserRegionLockHeld(long duration) {
-    userRegionLockHeldTimer.update(duration, TimeUnit.MILLISECONDS);
-  }
-
-  public void updateUserRegionLockQueue(int count) {
-    userRegionLockQueueHist.update(count);
-  }
-
   /**
    * Get a metric for {@code key} from {@code map}, or create it with {@code factory}.
    */
@@ -479,7 +467,7 @@ public class MetricsConnection implements StatisticTrackable {
   }
 
   /** Report RPC context to metrics system. */
-  public void updateRpc(MethodDescriptor method, Message param, CallStats stats, Throwable e) {
+  public void updateRpc(MethodDescriptor method, Message param, CallStats stats) {
     int callsPerServer = stats.getConcurrentCallsPerServer();
     if (callsPerServer > 0) {
       concurrentCallsPerServerHist.update(callsPerServer);
@@ -487,20 +475,6 @@ public class MetricsConnection implements StatisticTrackable {
     // Update the counter that tracks RPCs by type.
     final String methodName = method.getService().getName() + "_" + method.getName();
     getMetric(CNT_BASE + methodName, rpcCounters, counterFactory).inc();
-    if (e != null) {
-      getMetric(FAILURE_CNT_BASE + methodName, rpcCounters, counterFactory).inc();
-      getMetric(TOTAL_EXCEPTION_CNT, rpcCounters, counterFactory).inc();
-      if (e instanceof RemoteException) {
-        String fullClassName = ((RemoteException) e).getClassName();
-        String simpleClassName = (fullClassName != null)
-          ? fullClassName.substring(fullClassName.lastIndexOf(".") + 1)
-          : "unknown";
-        getMetric(REMOTE_EXCEPTION_CNT_BASE + simpleClassName, rpcCounters, counterFactory).inc();
-      } else {
-        getMetric(LOCAL_EXCEPTION_CNT_BASE + e.getClass().getSimpleName(), rpcCounters,
-          counterFactory).inc();
-      }
-    }
     // this implementation is tied directly to protobuf implementation details. would be better
     // if we could dispatch based on something static, ie, request Message type.
     if (method.getService() == ClientService.getDescriptor()) {
