@@ -27,8 +27,8 @@ import java.time.Instant;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.atomic.AtomicBoolean;
-import org.apache.hadoop.hbase.CallQueueTooBigException;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
+import org.apache.hadoop.hbase.HBaseServerException;
 import org.apache.hadoop.hbase.exceptions.PreemptiveFastFailException;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.ExceptionUtil;
@@ -56,7 +56,7 @@ public class RpcRetryingCallerImpl<T> implements RpcRetryingCaller<T> {
   private final int startLogErrorsCnt;
 
   private final long pause;
-  private final long pauseForCQTBE;
+  private final long pauseForServerOverloaded;
   private final int maxAttempts;// how many times to try
   private final int rpcTimeout;// timeout for each rpc request
   private final AtomicBoolean cancelled = new AtomicBoolean(false);
@@ -64,15 +64,16 @@ public class RpcRetryingCallerImpl<T> implements RpcRetryingCaller<T> {
   private final RetryingCallerInterceptorContext context;
   private final RetryingTimeTracker tracker;
 
-  public RpcRetryingCallerImpl(long pause, long pauseForCQTBE, int retries, int startLogErrorsCnt) {
-    this(pause, pauseForCQTBE, retries, RetryingCallerInterceptorFactory.NO_OP_INTERCEPTOR,
-      startLogErrorsCnt, 0);
+  public RpcRetryingCallerImpl(long pause, long pauseForServerOverloaded, int retries,
+    int startLogErrorsCnt) {
+    this(pause, pauseForServerOverloaded, retries,
+      RetryingCallerInterceptorFactory.NO_OP_INTERCEPTOR, startLogErrorsCnt, 0);
   }
 
-  public RpcRetryingCallerImpl(long pause, long pauseForCQTBE, int retries,
+  public RpcRetryingCallerImpl(long pause, long pauseForServerOverloaded, int retries,
     RetryingCallerInterceptor interceptor, int startLogErrorsCnt, int rpcTimeout) {
     this.pause = pause;
-    this.pauseForCQTBE = pauseForCQTBE;
+    this.pauseForServerOverloaded = pauseForServerOverloaded;
     this.maxAttempts = retries2Attempts(retries);
     this.interceptor = interceptor;
     context = interceptor.createEmptyContext();
@@ -144,8 +145,10 @@ public class RpcRetryingCallerImpl<T> implements RpcRetryingCaller<T> {
         // If the server is dead, we need to wait a little before retrying, to give
         // a chance to the regions to be moved
         // get right pause time, start by RETRY_BACKOFF[0] * pauseBase, where pauseBase might be
-        // special when encountering CallQueueTooBigException, see #HBASE-17114
-        long pauseBase = (t instanceof CallQueueTooBigException) ? pauseForCQTBE : pause;
+        // special when encountering an exception indicating the server is overloaded.
+        // see #HBASE-17114 and HBASE-26807
+        long pauseBase =
+          HBaseServerException.isServerOverloaded(t) ? pauseForServerOverloaded : pause;
         expectedSleep = callable.sleep(pauseBase, tries);
 
         // If, after the planned sleep, there won't be enough time left, we stop now.
@@ -153,7 +156,7 @@ public class RpcRetryingCallerImpl<T> implements RpcRetryingCaller<T> {
         if (duration > callTimeout) {
           String msg = "callTimeout=" + callTimeout + ", callDuration=" + duration + ": "
             + t.getMessage() + " " + callable.getExceptionMessageAdditionalDetail();
-          throw (SocketTimeoutException) (new SocketTimeoutException(msg).initCause(t));
+          throw (SocketTimeoutException) new SocketTimeoutException(msg).initCause(t);
         }
       } finally {
         interceptor.updateFailureInfo(context);
@@ -232,7 +235,7 @@ public class RpcRetryingCallerImpl<T> implements RpcRetryingCaller<T> {
 
   private int getTimeout(int callTimeout) {
     int timeout = tracker.getRemainingTime(callTimeout);
-    if (timeout <= 0 || rpcTimeout > 0 && rpcTimeout < timeout) {
+    if (timeout <= 0 || (rpcTimeout > 0 && rpcTimeout < timeout)) {
       timeout = rpcTimeout;
     }
     return timeout;
