@@ -109,9 +109,9 @@ public class SingleColumnValueExcludeFilter extends SingleColumnValueFilter {
   }
 
   /**
-   * Constructor for protobuf deserialization only.
-   * @deprecated Since 2.0.0. Will be removed in 3.0.0. Use
-   *             {@link #SingleColumnValueExcludeFilter(byte[], byte[], CompareOperator, ByteArrayComparable, boolean, boolean)}
+   * Constructor for protobuf deserialization only. nnnnnn * @deprecated Since 2.0.0. Will be
+   * removed in 3.0.0. Use
+   * {@link #SingleColumnValueExcludeFilter(byte[], byte[], CompareOperator, ByteArrayComparable, boolean, boolean)}
    */
   @Deprecated
   protected SingleColumnValueExcludeFilter(final byte[] family, final byte[] qualifier,
@@ -122,7 +122,7 @@ public class SingleColumnValueExcludeFilter extends SingleColumnValueFilter {
   }
 
   /**
-   * Constructor for protobuf deserialization only.
+   * Constructor for protobuf deserialization only. nnnnnn
    */
   protected SingleColumnValueExcludeFilter(final byte[] family, final byte[] qualifier,
     final CompareOperator op, ByteArrayComparable comparator, final boolean filterIfMissing,
@@ -173,8 +173,10 @@ public class SingleColumnValueExcludeFilter extends SingleColumnValueFilter {
   }
 
   /**
+   * Parse a serialized representation of {@link SingleColumnValueExcludeFilter}
    * @param pbBytes A pb serialized {@link SingleColumnValueExcludeFilter} instance
    * @return An instance of {@link SingleColumnValueExcludeFilter} made from <code>bytes</code>
+   * @throws DeserializationException if an error occurred
    * @see #toByteArray
    */
   public static SingleColumnValueExcludeFilter parseFrom(final byte[] pbBytes)
@@ -202,14 +204,17 @@ public class SingleColumnValueExcludeFilter extends SingleColumnValueFilter {
   }
 
   /**
-   * @return true if and only if the fields of the filter that are serialized are equal to the
-   *         corresponding fields in other. Used for testing.
+   * Returns true if and only if the fields of the filter that are serialized are equal to the
+   * corresponding fields in other. Used for testing.
    */
   @Override
   boolean areSerializedFieldsEqual(Filter o) {
-    if (o == this) return true;
-    if (!(o instanceof SingleColumnValueExcludeFilter)) return false;
-
+    if (o == this) {
+      return true;
+    }
+    if (!(o instanceof SingleColumnValueExcludeFilter)) {
+      return false;
+    }
     return super.areSerializedFieldsEqual(o);
   }
 
