@@ -18,10 +18,13 @@
 package org.apache.hadoop.hbase.ipc;
 
 import static org.apache.hadoop.hbase.ipc.IPCUtil.buildRequestHeader;
+import static org.apache.hadoop.hbase.ipc.IPCUtil.createRemoteException;
 import static org.apache.hadoop.hbase.ipc.IPCUtil.getTotalSizeWhenWrittenDelimited;
+import static org.apache.hadoop.hbase.ipc.IPCUtil.isFatalConnectionException;
 import static org.apache.hadoop.hbase.ipc.IPCUtil.setCancelled;
 import static org.apache.hadoop.hbase.ipc.IPCUtil.write;
 
+import io.opentelemetry.context.Scope;
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.DataInputStream;
@@ -40,7 +43,6 @@ import java.util.Queue;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ThreadLocalRandom;
-import java.util.concurrent.atomic.AtomicInteger;
 import javax.security.sasl.SaslException;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.CellScanner;
@@ -53,7 +55,6 @@ import org.apache.hadoop.hbase.security.HBaseSaslRpcClient;
 import org.apache.hadoop.hbase.security.SaslUtil;
 import org.apache.hadoop.hbase.security.SaslUtil.QualityOfProtection;
 import org.apache.hadoop.hbase.security.provider.SaslClientAuthenticationProvider;
-import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.ExceptionUtil;
 import org.apache.hadoop.io.IOUtils;
@@ -61,14 +62,12 @@ import org.apache.hadoop.ipc.RemoteException;
 import org.apache.hadoop.net.NetUtils;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.hadoop.util.StringUtils;
-import org.apache.htrace.core.TraceScope;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import org.apache.hbase.thirdparty.com.google.protobuf.Message;
 import org.apache.hbase.thirdparty.com.google.protobuf.RpcCallback;
-import org.apache.hbase.thirdparty.com.google.protobuf.TextFormat;
 import org.apache.hbase.thirdparty.io.netty.buffer.ByteBuf;
 import org.apache.hbase.thirdparty.io.netty.buffer.PooledByteBufAllocator;
 
@@ -97,13 +96,6 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
       justification = "We are always under lock actually")
   private Thread thread;
 
-  // Used for ensuring two reader threads don't run over each other. Should only be used
-  // in reader thread run() method, to avoid deadlocks with synchronization on BlockingRpcConnection
-  private final Object readerThreadLock = new Object();
-
-  // Used to suffix the threadName in a way that we can differentiate them in logs/thread dumps.
-  private final AtomicInteger attempts = new AtomicInteger();
-
   // connected socket. protected for writing UT.
   protected Socket socket = null;
   private DataInputStream in;
@@ -188,6 +180,8 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
             try {
               BlockingRpcConnection.this.wait();
             } catch (InterruptedException e) {
+              // Restore interrupt status
+              Thread.currentThread().interrupt();
             }
             // check if we need to quit, so continue the main loop instead of fallback.
             continue;
@@ -196,8 +190,8 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
           if (call.isDone()) {
             continue;
           }
-          try {
-            tracedWriteRequest(call);
+          try (Scope scope = call.span.makeCurrent()) {
+            writeRequest(call);
           } catch (IOException e) {
             // exception here means the call has not been added to the pendingCalls yet, so we need
             // to fail it by our own.
@@ -329,17 +323,6 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
       if (thread == null) {
         return false;
       }
-
-      // If closeConn is called while we are in the readResponse method, it's possible that a new
-      // call to setupIOStreams comes in and creates a new value for "thread" before readResponse
-      // finishes. Once readResponse finishes, it will come in here and thread will be non-null
-      // above, but pointing at a new thread. In that case, we should end to avoid a situation
-      // where two threads are forever competing for the same socket.
-      if (!isCurrentThreadExpected()) {
-        LOG.debug("Thread replaced by new connection thread. Ending waitForWork loop.");
-        return false;
-      }
-
       if (!calls.isEmpty()) {
         return true;
       }
@@ -353,23 +336,6 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
       } catch (InterruptedException e) {
         // Restore interrupt status
         Thread.currentThread().interrupt();
-
-        String msg = "Interrupted while waiting for work";
-
-        // If we were interrupted by closeConn, it would have set thread to null.
-        // We are synchronized here and if we somehow got interrupted without setting thread to
-        // null, we want to make sure the connection is closed since the read thread would be dead.
-        // Rather than do a null check here, we check if the current thread is the expected thread.
-        // This guards against the case where a call to setupIOStreams got the synchronized lock
-        // first after closeConn, thus changing the thread to a new thread.
-        if (isCurrentThreadExpected()) {
-          LOG.debug(msg + ", closing connection");
-          closeConn(new InterruptedIOException(msg));
-        } else {
-          LOG.debug(msg);
-        }
-
-        return false;
       }
     }
   }
@@ -377,24 +343,13 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
   @Override
   public void run() {
     if (LOG.isTraceEnabled()) {
-      LOG.trace("starting");
+      LOG.trace(threadName + ": starting");
     }
-
-    // We have a synchronization here because it's possible in error scenarios for a new
-    // thread to be started while readResponse is still reading on the socket. We don't want
-    // two threads to be reading from the same socket/inputstream.
-    // The below calls can synchronize on "BlockingRpcConnection.this".
-    // We should not synchronize on readerThreadLock anywhere else, to avoid deadlocks
-    synchronized (readerThreadLock) {
-      if (LOG.isTraceEnabled()) {
-        LOG.trace("started");
-      }
-      while (waitForWork()) {
-        readResponse();
-      }
+    while (waitForWork()) {
+      readResponse();
     }
     if (LOG.isTraceEnabled()) {
-      LOG.trace("stopped");
+      LOG.trace(threadName + ": stopped");
     }
   }
 
@@ -440,8 +395,7 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
         // A provider which failed authentication, but doesn't have the ability to relogin with
         // some external system (e.g. username/password, the password either works or it doesn't)
         if (!provider.canRetry()) {
-          LOG.warn("Exception encountered while connecting to the server " + remoteId.getAddress(),
-            ex);
+          LOG.warn("Exception encountered while connecting to the server : " + ex);
           if (ex instanceof RemoteException) {
             throw (RemoteException) ex;
           }
@@ -456,8 +410,7 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
         // Other providers, like kerberos, could request a new ticket from a keytab. Let
         // them try again.
         if (currRetries < maxRetries) {
-          LOG.debug("Exception encountered while connecting to the server " + remoteId.getAddress(),
-            ex);
+          LOG.debug("Exception encountered while connecting to the server", ex);
 
           // Invoke the provider to perform the relogin
           provider.relogin();
@@ -538,7 +491,6 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
             // fall back to simple auth because server told us so.
             // do not change authMethod and useSasl here, we should start from secure when
             // reconnecting because regionserver may change its sasl config after restart.
-            saslRpcClient = null;
           }
         }
         this.in = new DataInputStream(new BufferedInputStream(inStream));
@@ -568,7 +520,7 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
     }
 
     // start the receiver thread after the socket connection has been set up
-    thread = new Thread(this, threadName + " (attempt: " + attempts.incrementAndGet() + ")");
+    thread = new Thread(this, threadName);
     thread.setDaemon(true);
     thread.start();
   }
@@ -641,13 +593,6 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
     this.out = new DataOutputStream(new BufferedOutputStream(saslRpcClient.getOutputStream()));
   }
 
-  private void tracedWriteRequest(Call call) throws IOException {
-    try (
-      TraceScope ignored = TraceUtil.createTrace("RpcClientImpl.tracedWriteRequest", call.span)) {
-      writeRequest(call);
-    }
-  }
-
   /**
    * Initiates a call by sending the parameter to the remote server. Note: this is not called from
    * the Connection thread, but by other threads.
@@ -682,7 +627,7 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
         call.callStats.setRequestSizeBytes(write(this.out, requestHeader, call.param, cellBlock));
       } catch (Throwable t) {
         if (LOG.isTraceEnabled()) {
-          LOG.trace("Error while writing {}", call.toShortString(), t);
+          LOG.trace("Error while writing {}", call.toShortString());
         }
         IOException e = IPCUtil.toIOE(t);
         closeConn(e);
@@ -710,25 +655,6 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
       // Read the header
       ResponseHeader responseHeader = ResponseHeader.parseDelimitedFrom(in);
       int id = responseHeader.getCallId();
-      if (LOG.isTraceEnabled()) {
-        LOG.trace("got response header " + TextFormat.shortDebugString(responseHeader)
-          + ", totalSize: " + totalSize + " bytes");
-      }
-      RemoteException remoteExc;
-      if (responseHeader.hasException()) {
-        ExceptionResponse exceptionResponse = responseHeader.getException();
-        remoteExc = IPCUtil.createRemoteException(exceptionResponse);
-        if (IPCUtil.isFatalConnectionException(exceptionResponse)) {
-          // Here we will cleanup all calls so do not need to fall back, just return.
-          synchronized (this) {
-            closeConn(remoteExc);
-          }
-          return;
-        }
-      } else {
-        remoteExc = null;
-      }
-
       call = calls.remove(id); // call.done have to be set before leaving this method
       expectedCall = (call != null && !call.isDone());
       if (!expectedCall) {
@@ -739,34 +665,46 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
         // this connection.
         int readSoFar = getTotalSizeWhenWrittenDelimited(responseHeader);
         int whatIsLeftToRead = totalSize - readSoFar;
-        LOG.debug("Unknown callId: " + id + ", skipping over this response of " + whatIsLeftToRead
-          + " bytes");
         IOUtils.skipFully(in, whatIsLeftToRead);
         if (call != null) {
           call.callStats.setResponseSizeBytes(totalSize);
+          call.callStats
+            .setCallTimeMs(EnvironmentEdgeManager.currentTime() - call.callStats.getStartTime());
         }
         return;
       }
-      call.callStats.setResponseSizeBytes(totalSize);
-      if (remoteExc != null) {
-        call.setException(remoteExc);
-        return;
+      if (responseHeader.hasException()) {
+        ExceptionResponse exceptionResponse = responseHeader.getException();
+        RemoteException re = createRemoteException(exceptionResponse);
+        call.setException(re);
+        call.callStats.setResponseSizeBytes(totalSize);
+        call.callStats
+          .setCallTimeMs(EnvironmentEdgeManager.currentTime() - call.callStats.getStartTime());
+        if (isFatalConnectionException(exceptionResponse)) {
+          synchronized (this) {
+            closeConn(re);
+          }
+        }
+      } else {
+        Message value = null;
+        if (call.responseDefaultType != null) {
+          Message.Builder builder = call.responseDefaultType.newBuilderForType();
+          ProtobufUtil.mergeDelimitedFrom(builder, in);
+          value = builder.build();
+        }
+        CellScanner cellBlockScanner = null;
+        if (responseHeader.hasCellBlockMeta()) {
+          int size = responseHeader.getCellBlockMeta().getLength();
+          byte[] cellBlock = new byte[size];
+          IOUtils.readFully(this.in, cellBlock, 0, cellBlock.length);
+          cellBlockScanner = this.rpcClient.cellBlockBuilder.createCellScanner(this.codec,
+            this.compressor, cellBlock);
+        }
+        call.setResponse(value, cellBlockScanner);
+        call.callStats.setResponseSizeBytes(totalSize);
+        call.callStats
+          .setCallTimeMs(EnvironmentEdgeManager.currentTime() - call.callStats.getStartTime());
       }
-      Message value = null;
-      if (call.responseDefaultType != null) {
-        Message.Builder builder = call.responseDefaultType.newBuilderForType();
-        ProtobufUtil.mergeDelimitedFrom(builder, in);
-        value = builder.build();
-      }
-      CellScanner cellBlockScanner = null;
-      if (responseHeader.hasCellBlockMeta()) {
-        int size = responseHeader.getCellBlockMeta().getLength();
-        byte[] cellBlock = new byte[size];
-        IOUtils.readFully(this.in, cellBlock, 0, cellBlock.length);
-        cellBlockScanner =
-          this.rpcClient.cellBlockBuilder.createCellScanner(this.codec, this.compressor, cellBlock);
-      }
-      call.setResponse(value, cellBlockScanner);
     } catch (IOException e) {
       if (expectedCall) {
         call.setException(e);
@@ -776,33 +714,16 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
         // since we expect certain responses to not make it by the specified
         // {@link ConnectionId#rpcTimeout}.
         if (LOG.isTraceEnabled()) {
-          LOG.trace("ignored ex for call {}", call, e);
+          LOG.trace("ignored", e);
         }
       } else {
         synchronized (this) {
-          // The exception we received may have been caused by another thread closing
-          // this connection. It's possible that before getting to this point, a new connection was
-          // created. In that case, it doesn't help and can actually hurt to close again here.
-          if (isCurrentThreadExpected()) {
-            LOG.debug("Closing connection after error in call {}", call, e);
-            closeConn(e);
-          }
+          closeConn(e);
         }
       }
     }
   }
 
-  /**
-   * For use in the reader thread, tests if the current reader thread is the one expected to be
-   * running. When closeConn is called, the reader thread is expected to end. setupIOStreams then
-   * creates a new thread and updates the thread pointer. At that point, the new thread should be
-   * the only one running. We use this method to guard against cases where the old thread may be
-   * erroneously running or closing the connection in error states.
-   */
-  private boolean isCurrentThreadExpected() {
-    return thread == Thread.currentThread();
-  }
-
   @Override
   protected synchronized void callTimeout(Call call) {
     // call sender
@@ -879,7 +800,9 @@ class BlockingRpcConnection extends RpcConnection implements Runnable {
         if (callSender != null) {
           callSender.sendCall(call);
         } else {
-          tracedWriteRequest(call);
+          // this is in the same thread with the caller so do not need to attach the trace context
+          // again.
+          writeRequest(call);
         }
       }
     });
