@@ -35,13 +35,14 @@ import java.lang.reflect.Method;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 import java.util.NavigableSet;
 import java.util.function.Function;
+import java.util.stream.Collectors;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.Cell.Type;
 import org.apache.hadoop.hbase.CellBuilderType;
 import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.CellUtil;
@@ -192,6 +193,7 @@ public final class ProtobufUtil {
   }
 
   /**
+   * Check for {@link ProtobufMagic#PB_MAGIC}
    * @param bytes Bytes to check.
    * @return True if passed <code>bytes</code> has {@link ProtobufMagic#PB_MAGIC} for a prefix.
    */
@@ -200,6 +202,7 @@ public final class ProtobufUtil {
   }
 
   /**
+   * Check for {@link ProtobufMagic#PB_MAGIC}
    * @param bytes  Bytes to check.
    * @param offset offset to start at
    * @param len    length to use
@@ -210,6 +213,7 @@ public final class ProtobufUtil {
   }
 
   /**
+   * Check for {@link ProtobufMagic#PB_MAGIC}
    * @param bytes bytes to check
    * @throws DeserializationException if we are missing the pb magic prefix
    */
@@ -255,7 +259,7 @@ public final class ProtobufUtil {
    * Like {@link #getRemoteException(ServiceException)} but more generic, able to handle more than
    * just {@link ServiceException}. Prefer this method to
    * {@link #getRemoteException(ServiceException)} because trying to contain direct protobuf
-   * references.
+   * references. n
    */
   public static IOException handleRemoteException(Exception e) {
     return makeIOExceptionOfException(e);
@@ -359,7 +363,7 @@ public final class ProtobufUtil {
   /**
    * Convert a protocol buffer Get to a client Get
    * @param proto the protocol buffer Get to convert
-   * @return the converted client Get
+   * @return the converted client Get n
    */
   public static Get toGet(final ClientProtos.Get proto) throws IOException {
     if (proto == null) return null;
@@ -444,7 +448,7 @@ public final class ProtobufUtil {
   /**
    * Convert a protocol buffer Mutate to a Put.
    * @param proto The protocol buffer MutationProto to convert
-   * @return A client Put.
+   * @return A client Put. n
    */
   public static Put toPut(final MutationProto proto) throws IOException {
     return toPut(proto, null);
@@ -454,7 +458,7 @@ public final class ProtobufUtil {
    * Convert a protocol buffer Mutate to a Put.
    * @param proto       The protocol buffer MutationProto to convert
    * @param cellScanner If non-null, the Cell data that goes with this proto.
-   * @return A client Put.
+   * @return A client Put. n
    */
   public static Put toPut(final MutationProto proto, final CellScanner cellScanner)
     throws IOException {
@@ -521,7 +525,7 @@ public final class ProtobufUtil {
             } else {
               put.add(cellBuilder.clear().setRow(put.getRow()).setFamily(family)
                 .setQualifier(qv.hasQualifier() ? qv.getQualifier().toByteArray() : null)
-                .setTimestamp(ts).setType(Type.Put)
+                .setTimestamp(ts).setType(Cell.Type.Put)
                 .setValue(qv.hasValue() ? qv.getValue().toByteArray() : null).build());
             }
           }
@@ -538,7 +542,7 @@ public final class ProtobufUtil {
   /**
    * Convert a protocol buffer Mutate to a Delete
    * @param proto the protocol buffer Mutate to convert
-   * @return the converted client Delete
+   * @return the converted client Delete n
    */
   public static Delete toDelete(final MutationProto proto) throws IOException {
     return toDelete(proto, null);
@@ -548,7 +552,7 @@ public final class ProtobufUtil {
    * Convert a protocol buffer Mutate to a Delete
    * @param proto       the protocol buffer Mutate to convert
    * @param cellScanner if non-null, the data that goes with this delete.
-   * @return the converted client Delete
+   * @return the converted client Delete n
    */
   public static Delete toDelete(final MutationProto proto, final CellScanner cellScanner)
     throws IOException {
@@ -676,7 +680,6 @@ public final class ProtobufUtil {
 
   /**
    * Convert a protocol buffer Mutate to an Append
-   * @param proto the protocol buffer Mutate to convert
    * @return the converted client Append
    */
   public static Append toAppend(final MutationProto proto, final CellScanner cellScanner)
@@ -694,7 +697,6 @@ public final class ProtobufUtil {
 
   /**
    * Convert a protocol buffer Mutate to an Increment
-   * @param proto the protocol buffer Mutate to convert
    * @return the converted client Increment
    */
   public static Increment toIncrement(final MutationProto proto, final CellScanner cellScanner)
@@ -714,7 +716,7 @@ public final class ProtobufUtil {
   /**
    * Convert a MutateRequest to Mutation
    * @param proto the protocol buffer Mutate to convert
-   * @return the converted Mutation
+   * @return the converted Mutation n
    */
   public static Mutation toMutation(final MutationProto proto) throws IOException {
     MutationType type = proto.getMutateType();
@@ -735,8 +737,7 @@ public final class ProtobufUtil {
 
   /**
    * Convert a protocol buffer Mutate to a Get.
-   * @param proto the protocol buffer Mutate to convert.
-   * @return the converted client get.
+   * @param proto the protocol buffer Mutate to convert. n * @return the converted client get. n
    */
   public static Get toGet(final MutationProto proto, final CellScanner cellScanner)
     throws IOException {
@@ -816,7 +817,7 @@ public final class ProtobufUtil {
   /**
    * Convert a client Scan to a protocol buffer Scan
    * @param scan the client Scan to convert
-   * @return the converted protocol buffer Scan
+   * @return the converted protocol buffer Scan n
    */
   public static ClientProtos.Scan toScan(final Scan scan) throws IOException {
     ClientProtos.Scan.Builder scanBuilder = ClientProtos.Scan.newBuilder();
@@ -909,7 +910,7 @@ public final class ProtobufUtil {
   /**
    * Convert a protocol buffer Scan to a client Scan
    * @param proto the protocol buffer Scan to convert
-   * @return the converted client Scan
+   * @return the converted client Scan n
    */
   public static Scan toScan(final ClientProtos.Scan proto) throws IOException {
     byte[] startRow = HConstants.EMPTY_START_ROW;
@@ -1010,7 +1011,7 @@ public final class ProtobufUtil {
   /**
    * Create a protocol buffer Get based on a client Get.
    * @param get the client Get
-   * @return a protocol buffer Get
+   * @return a protocol buffer Get n
    */
   public static ClientProtos.Get toGet(final Get get) throws IOException {
     ClientProtos.Get.Builder builder = ClientProtos.Get.newBuilder();
@@ -1075,8 +1076,7 @@ public final class ProtobufUtil {
   }
 
   /**
-   * Create a protocol buffer Mutate based on a client Mutation
-   * @return a protobuf'd Mutation
+   * Create a protocol buffer Mutate based on a client Mutation nn * @return a protobuf'd Mutation n
    */
   public static MutationProto toMutation(final MutationType type, final Mutation mutation,
     final long nonce) throws IOException {
@@ -1125,8 +1125,8 @@ public final class ProtobufUtil {
 
   /**
    * Create a protocol buffer MutationProto based on a client Mutation. Does NOT include data.
-   * Understanding is that the Cell will be transported other than via protobuf.
-   * @return a protobuf'd Mutation
+   * Understanding is that the Cell will be transported other than via protobuf. nnn * @return a
+   * protobuf'd Mutation n
    */
   public static MutationProto toMutationNoData(final MutationType type, final Mutation mutation,
     final MutationProto.Builder builder) throws IOException {
@@ -1135,8 +1135,8 @@ public final class ProtobufUtil {
 
   /**
    * Create a protocol buffer MutationProto based on a client Mutation. Does NOT include data.
-   * Understanding is that the Cell will be transported other than via protobuf.
-   * @return a protobuf'd Mutation
+   * Understanding is that the Cell will be transported other than via protobuf. nn * @return a
+   * protobuf'd Mutation n
    */
   public static MutationProto toMutationNoData(final MutationType type, final Mutation mutation)
     throws IOException {
@@ -1162,8 +1162,8 @@ public final class ProtobufUtil {
 
   /**
    * Code shared by {@link #toMutation(MutationType, Mutation)} and
-   * {@link #toMutationNoData(MutationType, Mutation)}
-   * @return A partly-filled out protobuf'd Mutation.
+   * {@link #toMutationNoData(MutationType, Mutation)} nn * @return A partly-filled out protobuf'd
+   * Mutation.
    */
   private static MutationProto.Builder getMutationBuilderAndSetCommonFields(final MutationType type,
     final Mutation mutation, MutationProto.Builder builder) {
@@ -1268,7 +1268,7 @@ public final class ProtobufUtil {
    * Convert a protocol buffer Result to a client Result
    * @param proto   the protocol buffer Result to convert
    * @param scanner Optional cell scanner.
-   * @return the converted client Result
+   * @return the converted client Result n
    */
   public static Result toResult(final ClientProtos.Result proto, final CellScanner scanner)
     throws IOException {
@@ -1382,8 +1382,8 @@ public final class ProtobufUtil {
   }
 
   /**
-   * Convert a delete KeyValue type to protocol buffer DeleteType.
-   * @return protocol buffer DeleteType
+   * Convert a delete KeyValue type to protocol buffer DeleteType. n * @return protocol buffer
+   * DeleteType n
    */
   public static DeleteType toDeleteType(KeyValue.Type type) throws IOException {
     switch (type) {
@@ -1403,7 +1403,7 @@ public final class ProtobufUtil {
   /**
    * Convert a protocol buffer DeleteType to delete KeyValue type.
    * @param type The DeleteType
-   * @return The type.
+   * @return The type. n
    */
   public static KeyValue.Type fromDeleteType(DeleteType type) throws IOException {
     switch (type) {
@@ -1475,12 +1475,18 @@ public final class ProtobufUtil {
     }
   }
 
+  /**
+   * @see #buildGetServerInfoRequest()
+   */
+  private static GetServerInfoRequest GET_SERVER_INFO_REQUEST =
+    GetServerInfoRequest.newBuilder().build();
+
   /**
    * Create a new GetServerInfoRequest
    * @return a GetServerInfoRequest
    */
   public static GetServerInfoRequest buildGetServerInfoRequest() {
-    return GetServerInfoRequest.getDefaultInstance();
+    return GET_SERVER_INFO_REQUEST;
   }
 
   public static ScanMetrics toScanMetrics(final byte[] bytes) {
@@ -1567,7 +1573,7 @@ public final class ProtobufUtil {
    * This version of protobuf's mergeFrom avoids the hard-coded 64MB limit for decoding buffers when
    * working with byte arrays
    * @param builder current message builder
-   * @param b       byte array
+   * @param b       byte array n
    */
   public static void mergeFrom(Message.Builder builder, byte[] b) throws IOException {
     final CodedInputStream codedInput = CodedInputStream.newInstance(b);
@@ -1580,7 +1586,7 @@ public final class ProtobufUtil {
    * This version of protobuf's mergeFrom avoids the hard-coded 64MB limit for decoding buffers when
    * working with byte arrays
    * @param builder current message builder
-   * @param b       byte array
+   * @param b       byte array nnn
    */
   public static void mergeFrom(Message.Builder builder, byte[] b, int offset, int length)
     throws IOException {
@@ -1634,7 +1640,7 @@ public final class ProtobufUtil {
    *             magic and that is then followed by a protobuf that has a serialized
    *             {@link ServerName} in it.
    * @return Returns null if <code>data</code> is null else converts passed data to a ServerName
-   *         instance.
+   *         instance. n
    */
   public static ServerName toServerName(final byte[] data) throws DeserializationException {
     if (data == null || data.length <= 0) return null;
@@ -1670,14 +1676,17 @@ public final class ProtobufUtil {
   }
 
   public static RSGroupInfo toGroupInfo(RSGroupProtos.RSGroupInfo proto) {
-    RSGroupInfo RSGroupInfo = new RSGroupInfo(proto.getName());
-    for (HBaseProtos.ServerName el : proto.getServersList()) {
-      RSGroupInfo.addServer(Address.fromParts(el.getHostName(), el.getPort()));
-    }
-    for (TableProtos.TableName pTableName : proto.getTablesList()) {
-      RSGroupInfo.addTable(ProtobufUtil.toTableName(pTableName));
-    }
-    return RSGroupInfo;
+    RSGroupInfo rsGroupInfo = new RSGroupInfo(proto.getName());
+
+    Collection<Address> addresses = proto.getServersList().parallelStream()
+      .map(serverName -> Address.fromParts(serverName.getHostName(), serverName.getPort()))
+      .collect(Collectors.toList());
+    rsGroupInfo.addAllServers(addresses);
+
+    Collection<TableName> tables = proto.getTablesList().parallelStream()
+      .map(ProtobufUtil::toTableName).collect(Collectors.toList());
+    rsGroupInfo.addAllTables(tables);
+    return rsGroupInfo;
   }
 
   public static HBaseProtos.TimeRange toTimeRange(TimeRange timeRange) {
