@@ -29,12 +29,8 @@ import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.ZooKeeperConnectionException;
 import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.Connection;
-import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.security.SecurityCapability;
-import org.apache.hadoop.hbase.ipc.CoprocessorRpcChannel;
-import org.apache.hadoop.hbase.protobuf.generated.AccessControlProtos;
-import org.apache.hadoop.hbase.protobuf.generated.AccessControlProtos.AccessControlService.BlockingInterface;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.yetus.audience.InterfaceAudience;
 
@@ -49,7 +45,7 @@ public class AccessControlClient {
   /**
    * Return true if authorization is supported and enabled
    * @param connection The connection to use
-   * @return true if authorization is supported and enabled, false otherwise
+   * @return true if authorization is supported and enabled, false otherwise n
    */
   public static boolean isAuthorizationEnabled(Connection connection) throws IOException {
     return connection.getAdmin().getSecurityCapabilities()
@@ -59,25 +55,24 @@ public class AccessControlClient {
   /**
    * Return true if cell authorization is supported and enabled
    * @param connection The connection to use
-   * @return true if cell authorization is supported and enabled, false otherwise
+   * @return true if cell authorization is supported and enabled, false otherwise n
    */
   public static boolean isCellAuthorizationEnabled(Connection connection) throws IOException {
     return connection.getAdmin().getSecurityCapabilities()
       .contains(SecurityCapability.CELL_AUTHORIZATION);
   }
 
-  private static BlockingInterface getAccessControlServiceStub(Table ht) throws IOException {
-    CoprocessorRpcChannel service = ht.coprocessorService(HConstants.EMPTY_START_ROW);
-    BlockingInterface protocol = AccessControlProtos.AccessControlService.newBlockingStub(service);
-    return protocol;
-  }
-
   /**
    * Grants permission on the specified table for the specified user
    * @param connection               The Connection instance to use
+   * @param tableName                the table name
+   * @param userName                 the user name
+   * @param family                   the column family
+   * @param qual                     the column qualifier
    * @param mergeExistingPermissions If set to false, later granted permissions will override
    *                                 previous granted permissions. otherwise, it'll merge with
    *                                 previous granted permissions.
+   * @param actions                  the actions
    */
   private static void grant(Connection connection, final TableName tableName, final String userName,
     final byte[] family, final byte[] qual, boolean mergeExistingPermissions,
@@ -91,6 +86,11 @@ public class AccessControlClient {
    * Grants permission on the specified table for the specified user. If permissions for a specified
    * user exists, later granted permissions will override previous granted permissions.
    * @param connection The Connection instance to use
+   * @param tableName  the table name
+   * @param userName   the user name
+   * @param family     the column family
+   * @param qual       the column qualifier
+   * @param actions    the actions
    */
   public static void grant(Connection connection, final TableName tableName, final String userName,
     final byte[] family, final byte[] qual, final Permission.Action... actions) throws Throwable {
@@ -99,9 +99,13 @@ public class AccessControlClient {
 
   /**
    * Grants permission on the specified namespace for the specified user.
+   * @param connection               The Connection instance to use
+   * @param namespace                the namespace
+   * @param userName                 the user name
    * @param mergeExistingPermissions If set to false, later granted permissions will override
    *                                 previous granted permissions. otherwise, it'll merge with
    *                                 previous granted permissions.
+   * @param actions                  the actions
    */
   private static void grant(Connection connection, final String namespace, final String userName,
     boolean mergeExistingPermissions, final Permission.Action... actions) throws Throwable {
@@ -115,6 +119,9 @@ public class AccessControlClient {
    * specified namespace exists, later granted permissions will override previous granted
    * permissions.
    * @param connection The Connection instance to use
+   * @param namespace  the namespace
+   * @param userName   the user name
+   * @param actions    the actions
    */
   public static void grant(Connection connection, final String namespace, final String userName,
     final Permission.Action... actions) throws Throwable {
@@ -123,9 +130,12 @@ public class AccessControlClient {
 
   /**
    * Grant global permissions for the specified user.
+   * @param connection               The Connection instance to use
+   * @param userName                 the user name
    * @param mergeExistingPermissions If set to false, later granted permissions will override
    *                                 previous granted permissions. otherwise, it'll merge with
    *                                 previous granted permissions.
+   * @param actions                  the actions
    */
   private static void grant(Connection connection, final String userName,
     boolean mergeExistingPermissions, final Permission.Action... actions) throws Throwable {
@@ -136,7 +146,7 @@ public class AccessControlClient {
 
   /**
    * Grant global permissions for the specified user. If permissions for the specified user exists,
-   * later granted permissions will override previous granted permissions.
+   * later granted permissions will override previous granted permissions. nnnn
    */
   public static void grant(Connection connection, final String userName,
     final Permission.Action... actions) throws Throwable {
@@ -152,7 +162,7 @@ public class AccessControlClient {
 
   /**
    * Revokes the permission on the table
-   * @param connection The Connection instance to use
+   * @param connection The Connection instance to use nnnnnn
    */
   public static void revoke(Connection connection, final TableName tableName, final String username,
     final byte[] family, final byte[] qualifier, final Permission.Action... actions)
@@ -163,7 +173,7 @@ public class AccessControlClient {
 
   /**
    * Revokes the permission on the namespace for the specified user.
-   * @param connection The Connection instance to use
+   * @param connection The Connection instance to use nnnn
    */
   public static void revoke(Connection connection, final String namespace, final String userName,
     final Permission.Action... actions) throws Throwable {
@@ -187,7 +197,7 @@ public class AccessControlClient {
    * along with the list of superusers would be returned. Else, no rows get returned.
    * @param connection The Connection instance to use
    * @param tableRegex The regular expression string to match against
-   * @return List of UserPermissions
+   * @return List of UserPermissions n
    */
   public static List<UserPermission> getUserPermissions(Connection connection, String tableRegex)
     throws Throwable {
