@@ -55,7 +55,7 @@ public class VisibilityClient {
   /**
    * Return true if cell visibility features are supported and enabled
    * @param connection The connection to use
-   * @return true if cell visibility features are supported and enabled, false otherwise
+   * @return true if cell visibility features are supported and enabled, false otherwise n
    */
   public static boolean isCellVisibilityEnabled(Connection connection) throws IOException {
     return connection.getAdmin().getSecurityCapabilities()
@@ -63,8 +63,8 @@ public class VisibilityClient {
   }
 
   /**
-   * Utility method for adding label to the system.
-   * @deprecated Use {@link #addLabel(Connection,String)} instead.
+   * Utility method for adding label to the system. nnnn * @deprecated Use
+   * {@link #addLabel(Connection,String)} instead.
    */
   @Deprecated
   public static VisibilityLabelsResponse addLabel(Configuration conf, final String label)
@@ -75,7 +75,7 @@ public class VisibilityClient {
   }
 
   /**
-   * Utility method for adding label to the system.
+   * Utility method for adding label to the system. nnnn
    */
   public static VisibilityLabelsResponse addLabel(Connection connection, final String label)
     throws Throwable {
@@ -83,8 +83,8 @@ public class VisibilityClient {
   }
 
   /**
-   * Utility method for adding labels to the system.
-   * @deprecated Use {@link #addLabels(Connection,String[])} instead.
+   * Utility method for adding labels to the system. nnnn * @deprecated Use
+   * {@link #addLabels(Connection,String[])} instead.
    */
   @Deprecated
   public static VisibilityLabelsResponse addLabels(Configuration conf, final String[] labels)
@@ -95,7 +95,7 @@ public class VisibilityClient {
   }
 
   /**
-   * Utility method for adding labels to the system.
+   * Utility method for adding labels to the system. nnnn
    */
   public static VisibilityLabelsResponse addLabels(Connection connection, final String[] labels)
     throws Throwable {
@@ -133,8 +133,8 @@ public class VisibilityClient {
   }
 
   /**
-   * Sets given labels globally authorized for the user.
-   * @deprecated Use {@link #setAuths(Connection,String[],String)} instead.
+   * Sets given labels globally authorized for the user. nnnnn * @deprecated Use
+   * {@link #setAuths(Connection,String[],String)} instead.
    */
   @Deprecated
   public static VisibilityLabelsResponse setAuths(Configuration conf, final String[] auths,
@@ -145,7 +145,7 @@ public class VisibilityClient {
   }
 
   /**
-   * Sets given labels globally authorized for the user.
+   * Sets given labels globally authorized for the user. nnnnn
    */
   public static VisibilityLabelsResponse setAuths(Connection connection, final String[] auths,
     final String user) throws Throwable {
@@ -153,8 +153,8 @@ public class VisibilityClient {
   }
 
   /**
-   * Returns labels, the given user is globally authorized for.
-   * @deprecated Use {@link #getAuths(Connection,String)} instead.
+   * Returns labels, the given user is globally authorized for. n * @deprecated Use
+   * {@link #getAuths(Connection,String)} instead.
    */
   @Deprecated
   public static GetAuthsResponse getAuths(Configuration conf, final String user) throws Throwable {
@@ -164,8 +164,10 @@ public class VisibilityClient {
   }
 
   /**
-   * @param connection the Connection instance to use.
-   * @return labels, the given user is globally authorized for.
+   * Get the authorization for a given user
+   * @param connection the Connection instance to use
+   * @param user       the user
+   * @return labels the given user is globally authorized for
    */
   public static GetAuthsResponse getAuths(Connection connection, final String user)
     throws Throwable {
@@ -197,6 +199,7 @@ public class VisibilityClient {
 
   /**
    * Retrieve the list of visibility labels defined in the system.
+   * @param conf  the configuration to use
    * @param regex The regular expression to filter which labels are returned.
    * @return labels The list of visibility labels defined in the system.
    * @deprecated Use {@link #listLabels(Connection,String)} instead.
@@ -213,7 +216,7 @@ public class VisibilityClient {
    * Retrieve the list of visibility labels defined in the system.
    * @param connection The Connection instance to use.
    * @param regex      The regular expression to filter which labels are returned.
-   * @return labels The list of visibility labels defined in the system.
+   * @return labels The list of visibility labels defined in the system. n
    */
   public static ListLabelsResponse listLabels(Connection connection, final String regex)
     throws Throwable {
@@ -249,8 +252,8 @@ public class VisibilityClient {
   }
 
   /**
-   * Removes given labels from user's globally authorized list of labels.
-   * @deprecated Use {@link #clearAuths(Connection,String[],String)} instead.
+   * Removes given labels from user's globally authorized list of labels. nnnnn * @deprecated Use
+   * {@link #clearAuths(Connection,String[],String)} instead.
    */
   @Deprecated
   public static VisibilityLabelsResponse clearAuths(Configuration conf, final String[] auths,
@@ -261,7 +264,7 @@ public class VisibilityClient {
   }
 
   /**
-   * Removes given labels from user's globally authorized list of labels.
+   * Removes given labels from user's globally authorized list of labels. nnnnn
    */
   public static VisibilityLabelsResponse clearAuths(Connection connection, final String[] auths,
     final String user) throws Throwable {
@@ -285,7 +288,7 @@ public class VisibilityClient {
             setAuthReqBuilder.setUser(ByteStringer.wrap(Bytes.toBytes(user)));
             for (String auth : auths) {
               if (auth.length() > 0) {
-                setAuthReqBuilder.addAuth((ByteString.copyFromUtf8(auth)));
+                setAuthReqBuilder.addAuth(ByteString.copyFromUtf8(auth));
               }
             }
             if (setOrClear) {
