@@ -28,7 +28,6 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Random;
@@ -48,9 +47,11 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.hbase.CallDroppedException;
 import org.apache.hadoop.hbase.CallQueueTooBigException;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
+import org.apache.hadoop.hbase.HBaseServerException;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.HRegionLocation;
@@ -67,6 +68,7 @@ import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
 import org.apache.hadoop.hbase.testclassification.ClientTests;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Threads;
 import org.junit.Assert;
 import org.junit.Before;
@@ -425,6 +427,8 @@ public class TestAsyncProcess {
             try {
               Thread.sleep(sleep);
             } catch (InterruptedException e) {
+              // Restore interrupt status
+              Thread.currentThread().interrupt();
             }
           }
           return mr;
@@ -522,15 +526,14 @@ public class TestAsyncProcess {
   @Test
   public void testListRowAccess() {
     int count = 10;
-    List<String> values = new LinkedList<>();
+    List<String> values = new ArrayList<>();
     for (int i = 0; i != count; ++i) {
       values.add(String.valueOf(i));
     }
 
-    ListRowAccess<String> taker = new ListRowAccess(values);
+    ListRowAccess<String> taker = new ListRowAccess<>(values);
     assertEquals(count, taker.size());
 
-    int restoreCount = 0;
     int takeCount = 0;
     Iterator<String> it = taker.iterator();
     while (it.hasNext()) {
@@ -1011,9 +1014,9 @@ public class TestAsyncProcess {
     };
     t2.start();
 
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     ap.submit(null, DUMMY_TABLE, new ArrayList<>(), false, null, false);
-    long end = System.currentTimeMillis();
+    long end = EnvironmentEdgeManager.currentTime();
 
     // Adds 100 to secure us against approximate timing.
     Assert.assertTrue(start + 100L + sleepTime > end);
@@ -1024,7 +1027,12 @@ public class TestAsyncProcess {
   }
 
   private ClusterConnection createHConnection() throws IOException {
-    ClusterConnection hc = createHConnectionCommon();
+    return createHConnection(CONNECTION_CONFIG);
+  }
+
+  private ClusterConnection createHConnection(ConnectionConfiguration configuration)
+    throws IOException {
+    ClusterConnection hc = createHConnectionCommon(configuration);
     setMockLocation(hc, DUMMY_BYTES_1, new RegionLocations(loc1));
     setMockLocation(hc, DUMMY_BYTES_2, new RegionLocations(loc2));
     setMockLocation(hc, DUMMY_BYTES_3, new RegionLocations(loc3));
@@ -1035,8 +1043,9 @@ public class TestAsyncProcess {
     return hc;
   }
 
-  private ClusterConnection createHConnectionWithReplicas() throws IOException {
-    ClusterConnection hc = createHConnectionCommon();
+  private ClusterConnection createHConnectionWithReplicas(ConnectionConfiguration configuration)
+    throws IOException {
+    ClusterConnection hc = createHConnectionCommon(configuration);
     setMockLocation(hc, DUMMY_BYTES_1, hrls1);
     setMockLocation(hc, DUMMY_BYTES_2, hrls2);
     setMockLocation(hc, DUMMY_BYTES_3, hrls3);
@@ -1064,13 +1073,14 @@ public class TestAsyncProcess {
       Mockito.anyBoolean())).thenReturn(result);
   }
 
-  private ClusterConnection createHConnectionCommon() {
+  private ClusterConnection
+    createHConnectionCommon(ConnectionConfiguration connectionConfiguration) {
     ClusterConnection hc = Mockito.mock(ClusterConnection.class);
     NonceGenerator ng = Mockito.mock(NonceGenerator.class);
     Mockito.when(ng.getNonceGroup()).thenReturn(HConstants.NO_NONCE);
     Mockito.when(hc.getNonceGenerator()).thenReturn(ng);
     Mockito.when(hc.getConfiguration()).thenReturn(CONF);
-    Mockito.when(hc.getConnectionConfiguration()).thenReturn(CONNECTION_CONFIG);
+    Mockito.when(hc.getConnectionConfiguration()).thenReturn(connectionConfiguration);
     return hc;
   }
 
@@ -1320,7 +1330,7 @@ public class TestAsyncProcess {
     MyAsyncProcess ap = new MyAsyncProcess(conn, copyConf);
     try (HTable ht = (HTable) conn.getTable(DUMMY_TABLE)) {
       ht.multiAp = ap;
-      List<Get> gets = new LinkedList<>();
+      List<Get> gets = new ArrayList<>();
       gets.add(new Get(DUMMY_BYTES_1));
       gets.add(new Get(DUMMY_BYTES_2));
       try {
@@ -1339,7 +1349,7 @@ public class TestAsyncProcess {
       assertEquals(readTimeout, ap.previousTimeout);
       ap.previousTimeout = -1;
 
-      List<Delete> deletes = new LinkedList<>();
+      List<Delete> deletes = new ArrayList<>();
       deletes.add(new Delete(DUMMY_BYTES_1));
       deletes.add(new Delete(DUMMY_BYTES_2));
       ht.delete(deletes);
@@ -1546,11 +1556,11 @@ public class TestAsyncProcess {
     // TODO: this is kind of timing dependent... perhaps it should detect from createCaller
     // that the replica call has happened and that way control the ordering.
     Configuration conf = new Configuration();
-    ClusterConnection conn = createHConnectionWithReplicas();
     conf.setInt(AsyncProcess.PRIMARY_CALL_TIMEOUT_KEY, replicaAfterMs * 1000);
     if (retries >= 0) {
       conf.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER, retries);
     }
+    ClusterConnection conn = createHConnectionWithReplicas(new ConnectionConfiguration(conf));
     MyAsyncProcessWithReplicas ap = new MyAsyncProcessWithReplicas(conn, conf);
     ap.setCallDelays(primaryMs, replicaMs);
     return ap;
@@ -1664,20 +1674,30 @@ public class TestAsyncProcess {
   }
 
   /**
-   * Test and make sure we could use a special pause setting when retry with
-   * CallQueueTooBigException, see HBASE-17114
-   * @throws Exception if unexpected error happened during test
+   * Below tests make sure we could use a special pause setting when retry an exception where
+   * {@link HBaseServerException#isServerOverloaded(Throwable)} is true, see HBASE-17114
    */
+
   @Test
-  public void testRetryPauseWithCallQueueTooBigException() throws Exception {
-    Configuration myConf = new Configuration(CONF);
+  public void testRetryPauseWhenServerOverloadedDueToCQTBE() throws Exception {
+    testRetryPauseWhenServerIsOverloaded(new CallQueueTooBigException());
+  }
+
+  @Test
+  public void testRetryPauseWhenServerOverloadedDueToCDE() throws Exception {
+    testRetryPauseWhenServerIsOverloaded(new CallDroppedException());
+  }
+
+  private void testRetryPauseWhenServerIsOverloaded(HBaseServerException exception)
+    throws IOException {
+    Configuration conf = new Configuration(CONF);
     final long specialPause = 500L;
     final int retries = 1;
-    myConf.setLong(HConstants.HBASE_CLIENT_PAUSE_FOR_CQTBE, specialPause);
-    myConf.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER, retries);
-    ClusterConnection conn = new MyConnectionImpl(myConf);
-    AsyncProcessWithFailure ap =
-      new AsyncProcessWithFailure(conn, myConf, new CallQueueTooBigException());
+    conf.setLong(ConnectionConfiguration.HBASE_CLIENT_PAUSE_FOR_SERVER_OVERLOADED, specialPause);
+    conf.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER, retries);
+
+    ClusterConnection conn = new MyConnectionImpl(conf);
+    AsyncProcessWithFailure ap = new AsyncProcessWithFailure(conn, conf, exception);
     BufferedMutatorParams bufferParam = createBufferedMutatorParams(ap, DUMMY_TABLE);
     BufferedMutatorImpl mutator = new BufferedMutatorImpl(conn, bufferParam, ap);
 
@@ -1686,7 +1706,7 @@ public class TestAsyncProcess {
     Put p = createPut(1, true);
     mutator.mutate(p);
 
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     try {
       mutator.flush();
       Assert.fail();
@@ -1694,7 +1714,7 @@ public class TestAsyncProcess {
       assertEquals(1, expected.getNumExceptions());
       assertTrue(expected.getRow(0) == p);
     }
-    long actualSleep = System.currentTimeMillis() - startTime;
+    long actualSleep = EnvironmentEdgeManager.currentTime() - startTime;
     long expectedSleep = 0L;
     for (int i = 0; i < retries; i++) {
       expectedSleep += ConnectionUtils.getPauseTime(specialPause, i);
@@ -1707,13 +1727,13 @@ public class TestAsyncProcess {
 
     // check and confirm normal IOE will use the normal pause
     final long normalPause =
-      myConf.getLong(HConstants.HBASE_CLIENT_PAUSE, HConstants.DEFAULT_HBASE_CLIENT_PAUSE);
-    ap = new AsyncProcessWithFailure(conn, myConf, new IOException());
+      conf.getLong(HConstants.HBASE_CLIENT_PAUSE, HConstants.DEFAULT_HBASE_CLIENT_PAUSE);
+    ap = new AsyncProcessWithFailure(conn, conf, new IOException());
     bufferParam = createBufferedMutatorParams(ap, DUMMY_TABLE);
     mutator = new BufferedMutatorImpl(conn, bufferParam, ap);
     Assert.assertNotNull(mutator.getAsyncProcess().createServerErrorTracker());
     mutator.mutate(p);
-    startTime = System.currentTimeMillis();
+    startTime = EnvironmentEdgeManager.currentTime();
     try {
       mutator.flush();
       Assert.fail();
@@ -1721,7 +1741,7 @@ public class TestAsyncProcess {
       assertEquals(1, expected.getNumExceptions());
       assertTrue(expected.getRow(0) == p);
     }
-    actualSleep = System.currentTimeMillis() - startTime;
+    actualSleep = EnvironmentEdgeManager.currentTime() - startTime;
     expectedSleep = 0L;
     for (int i = 0; i < retries; i++) {
       expectedSleep += ConnectionUtils.getPauseTime(normalPause, i);
@@ -1734,9 +1754,9 @@ public class TestAsyncProcess {
 
   @Test
   public void testRetryWithExceptionClearsMetaCache() throws Exception {
-    ClusterConnection conn = createHConnection();
-    Configuration myConf = conn.getConfiguration();
+    Configuration myConf = new Configuration(CONF);
     myConf.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER, 0);
+    ClusterConnection conn = createHConnection(new ConnectionConfiguration(myConf));
 
     AsyncProcessWithFailure ap =
       new AsyncProcessWithFailure(conn, myConf, new RegionOpeningException("test"));
