@@ -30,8 +30,8 @@ import java.util.Random;
 import java.util.SortedMap;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentSkipListMap;
+import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import org.apache.commons.lang3.NotImplementedException;
@@ -56,6 +56,7 @@ import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.testclassification.ClientTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.hbase.util.Threads;
 import org.apache.hadoop.util.Tool;
@@ -70,7 +71,6 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import org.apache.hbase.thirdparty.com.google.common.base.Stopwatch;
-import org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
 import org.apache.hbase.thirdparty.com.google.protobuf.ByteString;
 import org.apache.hbase.thirdparty.com.google.protobuf.RpcController;
 import org.apache.hbase.thirdparty.com.google.protobuf.ServiceException;
@@ -102,7 +102,8 @@ import org.apache.hadoop.hbase.shaded.protobuf.generated.ClientProtos.ScanRespon
 import org.apache.hadoop.hbase.shaded.protobuf.generated.HBaseProtos.RegionSpecifier.RegionSpecifierType;
 
 /**
- * Test client behavior w/o setting up a cluster. Mock up cluster emissions.
+ * Test client behavior w/o setting up a cluster. Mock up cluster emissions. See below for a method
+ * that tests retries/timeouts currently commented out.
  */
 @Category({ ClientTests.class, SmallTests.class })
 public class TestClientNoCluster extends Configured implements Tool {
@@ -113,6 +114,12 @@ public class TestClientNoCluster extends Configured implements Tool {
 
   private static final Logger LOG = LoggerFactory.getLogger(TestClientNoCluster.class);
   private Configuration conf;
+  /**
+   * A server that does not exist. I've changed the server in the below to 'localhost' so we have a
+   * servername that resolves -- otherwise, we just fail on server name lookup with UnknownHost...
+   * With localhost, was able to reproduce stack traces that looked like production stack traces.
+   * Was useful figuring out how retry/timeouts are functioning.
+   */
   public static final ServerName META_SERVERNAME =
     ServerName.valueOf("meta.example.org", 16010, 12345);
 
@@ -148,7 +155,7 @@ public class TestClientNoCluster extends Configured implements Tool {
   }
 
   /**
-   * Remove the @Ignore to try out timeout and retry asettings
+   * Remove the @Ignore to try out timeout and retry settings
    */
   @Ignore
   @Test
@@ -156,6 +163,7 @@ public class TestClientNoCluster extends Configured implements Tool {
     Configuration localConfig = HBaseConfiguration.create(this.conf);
     // This override mocks up our exists/get call to throw a RegionServerStoppedException.
     localConfig.set("hbase.client.connection.impl", RpcTimeoutConnection.class.getName());
+    // localConfig.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER, 7);
     Connection connection = ConnectionFactory.createConnection(localConfig);
     Table table = connection.getTable(TableName.META_TABLE_NAME);
     Throwable t = null;
@@ -167,9 +175,6 @@ public class TestClientNoCluster extends Configured implements Tool {
       // I expect this exception.
       LOG.info("Got expected exception", e);
       t = e;
-    } catch (RetriesExhaustedException e) {
-      // This is the old, unwanted behavior. If we get here FAIL!!!
-      fail();
     } finally {
       table.close();
     }
@@ -179,7 +184,35 @@ public class TestClientNoCluster extends Configured implements Tool {
   }
 
   /**
-   * Test that operation timeout prevails over rpc default timeout and retries, etc.
+   * Remove the @Ignore to try out timeout and retry settings
+   */
+  // @Ignore
+  @Test
+  public void testAsyncTimeoutAndRetries()
+    throws IOException, ExecutionException, InterruptedException {
+    Configuration localConfig = HBaseConfiguration.create(this.conf);
+    localConfig.set(ConnectionFactory.HBASE_CLIENT_ASYNC_CONNECTION_IMPL,
+      RpcTimeoutAsyncConnection.class.getName());
+    localConfig.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER, 9);
+    AsyncConnection connection = ConnectionFactory.createAsyncConnection(localConfig).get();
+    AsyncTable table = connection.getTable(TableName.META_TABLE_NAME);
+    Throwable t = null;
+    LOG.info("Start");
+    try {
+      // An exists call turns into a get w/ a flag.
+      table.exists(new Get(Bytes.toBytes("abc"))).get();
+    } catch (Throwable throwable) {
+      // What to catch?
+      t = throwable;
+    } finally {
+      connection.close();
+    }
+    LOG.info("Stop");
+    assertTrue(t != null);
+  }
+
+  /**
+   * Test that operation timeout prevails over rpc default timeout and retries, etc. n
    */
   @Test
   public void testRpcTimeout() throws IOException {
@@ -204,9 +237,6 @@ public class TestClientNoCluster extends Configured implements Tool {
       // I expect this exception.
       LOG.info("Got expected exception", e);
       t = e;
-    } catch (RetriesExhaustedException e) {
-      // This is the old, unwanted behavior. If we get here FAIL!!!
-      fail();
     } finally {
       table.close();
       connection.close();
@@ -337,7 +367,7 @@ public class TestClientNoCluster extends Configured implements Tool {
       try {
         Mockito
           .when(stub.get((RpcController) Mockito.any(), (ClientProtos.GetRequest) Mockito.any()))
-          .thenThrow(new ServiceException(new RegionServerStoppedException("From Mockito")));
+          .thenThrow(new ServiceException(new java.net.ConnectException("Connection refused")));
       } catch (ServiceException e) {
         throw new IOException(e);
       }
@@ -349,6 +379,16 @@ public class TestClientNoCluster extends Configured implements Tool {
     }
   }
 
+  /**
+   * Override to check we are setting rpc timeout right.
+   */
+  static class RpcTimeoutAsyncConnection extends AsyncConnectionImpl {
+    RpcTimeoutAsyncConnection(Configuration configuration, ConnectionRegistry registry,
+      String clusterId, User user) {
+      super(configuration, registry, clusterId, user);
+    }
+  }
+
   /**
    * Fake many regionservers and many regions on a connection implementation.
    */
@@ -560,8 +600,8 @@ public class TestClientNoCluster extends Configured implements Tool {
   }
 
   /**
-   * @param name region name or encoded region name.
-   * @return True if we are dealing with a hbase:meta region.
+   * @param name region name or encoded region name. n * @return True if we are dealing with a
+   *             hbase:meta region.
    */
   static boolean isMetaRegion(final byte[] name, final RegionSpecifierType type) {
     switch (type) {
@@ -585,7 +625,7 @@ public class TestClientNoCluster extends Configured implements Tool {
     CellProtos.Cell.Builder cellBuilder = CellProtos.Cell.newBuilder();
     cellBuilder.setRow(row);
     cellBuilder.setFamily(CATALOG_FAMILY_BYTESTRING);
-    cellBuilder.setTimestamp(System.currentTimeMillis());
+    cellBuilder.setTimestamp(EnvironmentEdgeManager.currentTime());
     return cellBuilder;
   }
 
@@ -616,9 +656,8 @@ public class TestClientNoCluster extends Configured implements Tool {
 
   /**
    * Format passed integer. Zero-pad. Copied from hbase-server PE class and small amendment. Make
-   * them share.
-   * @return Returns zero-prefixed 10-byte wide decimal version of passed number (Does absolute in
-   *         case number is negative).
+   * them share. n * @return Returns zero-prefixed 10-byte wide decimal version of passed number
+   * (Does absolute in case number is negative).
    */
   private static byte[] format(final long number) {
     byte[] b = new byte[10];
@@ -630,7 +669,9 @@ public class TestClientNoCluster extends Configured implements Tool {
     return b;
   }
 
-  /** Returns <code>count</code> regions */
+  /**
+   * nn * @return <code>count</code> regions
+   */
   private static HRegionInfo[] makeHRegionInfos(final byte[] tableName, final int count,
     final long namespaceSpan) {
     byte[] startKey = HConstants.EMPTY_BYTE_ARRAY;
@@ -650,7 +691,9 @@ public class TestClientNoCluster extends Configured implements Tool {
     return hris;
   }
 
-  /** Returns Return <code>count</code> servernames. */
+  /**
+   * n * @return Return <code>count</code> servernames.
+   */
   private static ServerName[] makeServerNames(final int count) {
     ServerName[] sns = new ServerName[count];
     for (int i = 0; i < count; i++) {
@@ -693,12 +736,12 @@ public class TestClientNoCluster extends Configured implements Tool {
   }
 
   /**
-   * Code for each 'client' to run.
+   * Code for each 'client' to run. nnnn
    */
   static void cycle(int id, final Configuration c, final Connection sharedConnection)
     throws IOException {
     long namespaceSpan = c.getLong("hbase.test.namespace.span", 1000000);
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     final int printInterval = 100000;
     Random rd = new Random(id);
     boolean get = c.getBoolean("hbase.test.do.gets", false);
@@ -718,7 +761,7 @@ public class TestClientNoCluster extends Configured implements Tool {
           }
         }
         LOG.info("Finished a cycle putting " + namespaceSpan + " in "
-          + (System.currentTimeMillis() - startTime) + "ms");
+          + (EnvironmentEdgeManager.currentTime() - startTime) + "ms");
       }
     } else {
       try (BufferedMutator mutator = sharedConnection.getBufferedMutator(tableName)) {
@@ -736,7 +779,7 @@ public class TestClientNoCluster extends Configured implements Tool {
           }
         }
         LOG.info("Finished a cycle putting " + namespaceSpan + " in "
-          + (System.currentTimeMillis() - startTime) + "ms");
+          + (EnvironmentEdgeManager.currentTime() - startTime) + "ms");
       }
     }
   }
@@ -779,14 +822,8 @@ public class TestClientNoCluster extends Configured implements Tool {
     getConf().setInt("hbase.test.multi.too.many", 10);
     final int clients = 2;
 
-    // Have them all share the same connection so they all share the same instance of
-    // ManyServersManyRegionsConnection so I can keep an eye on how many requests by server.
-    final ExecutorService pool =
-      Executors.newCachedThreadPool(new ThreadFactoryBuilder().setNameFormat("p-pool-%d")
-        .setUncaughtExceptionHandler(Threads.LOGGING_EXCEPTION_HANDLER).build());
-    // Executors.newFixedThreadPool(servers * 10, Threads.getNamedThreadFactory("p"));
     // Share a connection so I can keep counts in the 'server' on concurrency.
-    final Connection sharedConnection = ConnectionFactory.createConnection(getConf()/* , pool */);
+    final Connection sharedConnection = ConnectionFactory.createConnection(getConf());
     try {
       Thread[] ts = new Thread[clients];
       for (int j = 0; j < ts.length; j++) {
@@ -799,7 +836,7 @@ public class TestClientNoCluster extends Configured implements Tool {
             try {
               cycle(id, c, sharedConnection);
             } catch (IOException e) {
-              e.printStackTrace();
+              LOG.info("Exception in cycle " + id, e);
             }
           }
         };
@@ -816,7 +853,7 @@ public class TestClientNoCluster extends Configured implements Tool {
 
   /**
    * Run a client instance against a faked up server.
-   * @param args TODO
+   * @param args TODO n
    */
   public static void main(String[] args) throws Exception {
     System.exit(ToolRunner.run(HBaseConfiguration.create(), new TestClientNoCluster(), args));
