@@ -26,7 +26,6 @@ import java.io.OutputStream;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.List;
-import org.apache.hadoop.hbase.KeyValue.Type;
 import org.apache.hadoop.hbase.io.util.StreamUtils;
 import org.apache.hadoop.hbase.util.ByteBufferUtils;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -52,15 +51,15 @@ public class KeyValueUtil {
 
   public static int length(short rlen, byte flen, int qlen, int vlen, int tlen, boolean withTags) {
     if (withTags) {
-      return (int) (KeyValue.getKeyValueDataStructureSize(rlen, flen, qlen, vlen, tlen));
+      return (int) KeyValue.getKeyValueDataStructureSize(rlen, flen, qlen, vlen, tlen);
     }
-    return (int) (KeyValue.getKeyValueDataStructureSize(rlen, flen, qlen, vlen));
+    return (int) KeyValue.getKeyValueDataStructureSize(rlen, flen, qlen, vlen);
   }
 
   /**
    * Returns number of bytes this cell's key part would have been used if serialized as in
-   * {@link KeyValue}. Key includes rowkey, family, qualifier, timestamp and type.
-   * @return the key length
+   * {@link KeyValue}. Key includes rowkey, family, qualifier, timestamp and type. n * @return the
+   * key length
    */
   public static int keyLength(final Cell cell) {
     return keyLength(cell.getRowLength(), cell.getFamilyLength(), cell.getQualifierLength());
@@ -97,8 +96,8 @@ public class KeyValueUtil {
   }
 
   /**
-   * The position will be set to the beginning of the new ByteBuffer
-   * @return the Bytebuffer containing the key part of the cell
+   * The position will be set to the beginning of the new ByteBuffer n * @return the Bytebuffer
+   * containing the key part of the cell
    */
   public static ByteBuffer copyKeyToNewByteBuffer(final Cell cell) {
     byte[] bytes = new byte[keyLength(cell)];
@@ -108,8 +107,8 @@ public class KeyValueUtil {
   }
 
   /**
-   * Copies the key to a new KeyValue
-   * @return the KeyValue that consists only the key part of the incoming cell
+   * Copies the key to a new KeyValue n * @return the KeyValue that consists only the key part of
+   * the incoming cell
    */
   public static KeyValue toNewKeyCell(final Cell cell) {
     byte[] bytes = new byte[keyLength(cell)];
@@ -204,7 +203,7 @@ public class KeyValueUtil {
 
   /**
    * Creates a new KeyValue object positioned in the supplied ByteBuffer and sets the ByteBuffer's
-   * position to the start of the next KeyValue. Does not allocate a new array or copy data.
+   * position to the start of the next KeyValue. Does not allocate a new array or copy data. nnn
    */
   public static KeyValue nextShallowCopy(final ByteBuffer bb, final boolean includesMvccVersion,
     boolean includesTags) {
@@ -214,7 +213,6 @@ public class KeyValueUtil {
     if (bb.remaining() < 1) {
       return null;
     }
-    KeyValue keyValue = null;
     int underlyingArrayOffset = bb.arrayOffset() + bb.position();
     int keyLength = bb.getInt();
     int valueLength = bb.getInt();
@@ -226,7 +224,7 @@ public class KeyValueUtil {
       ByteBufferUtils.skip(bb, tagsLength);
     }
     int kvLength = (int) KeyValue.getKeyValueDataStructureSize(keyLength, valueLength, tagsLength);
-    keyValue = new KeyValue(bb.array(), underlyingArrayOffset, kvLength);
+    KeyValue keyValue = new KeyValue(bb.array(), underlyingArrayOffset, kvLength);
     if (includesMvccVersion) {
       long mvccVersion = ByteBufferUtils.readVLong(bb);
       keyValue.setSequenceId(mvccVersion);
@@ -238,8 +236,7 @@ public class KeyValueUtil {
 
   /**
    * Decrement the timestamp. For tests (currently wasteful) Remember timestamps are sorted reverse
-   * chronologically.
-   * @return previous key
+   * chronologically. n * @return previous key
    */
   public static KeyValue previousKey(final KeyValue in) {
     return createFirstOnRow(CellUtil.cloneRow(in), CellUtil.cloneFamily(in),
@@ -249,15 +246,16 @@ public class KeyValueUtil {
   /**
    * Create a KeyValue for the specified row, family and qualifier that would be larger than or
    * equal to all other possible KeyValues that have the same row, family, qualifier. Used for
-   * reseeking. Should NEVER be returned to a client. row key row offset row length family name
-   * family offset family length column qualifier qualifier offset qualifier length
+   * reseeking. Should NEVER be returned to a client. n * row key n * row offset n * row length n *
+   * family name n * family offset n * family length n * column qualifier n * qualifier offset n *
+   * qualifier length
    * @return Last possible key on passed row, family, qualifier.
    */
   public static KeyValue createLastOnRow(final byte[] row, final int roffset, final int rlength,
     final byte[] family, final int foffset, final int flength, final byte[] qualifier,
     final int qoffset, final int qlength) {
     return new KeyValue(row, roffset, rlength, family, foffset, flength, qualifier, qoffset,
-      qlength, HConstants.OLDEST_TIMESTAMP, Type.Minimum, null, 0, 0);
+      qlength, HConstants.OLDEST_TIMESTAMP, KeyValue.Type.Minimum, null, 0, 0);
   }
 
   /**
@@ -268,7 +266,7 @@ public class KeyValueUtil {
    */
   public static KeyValue createFirstOnRow(final byte[] row, int roffset, short rlength) {
     return new KeyValue(row, roffset, rlength, null, 0, 0, null, 0, 0, HConstants.LATEST_TIMESTAMP,
-      Type.Maximum, null, 0, 0);
+      KeyValue.Type.Maximum, null, 0, 0);
   }
 
   /**
@@ -278,7 +276,7 @@ public class KeyValueUtil {
    * @return Last possible KeyValue on passed <code>row</code>
    */
   public static KeyValue createLastOnRow(final byte[] row) {
-    return new KeyValue(row, null, null, HConstants.LATEST_TIMESTAMP, Type.Minimum);
+    return new KeyValue(row, null, null, HConstants.LATEST_TIMESTAMP, KeyValue.Type.Minimum);
   }
 
   /**
@@ -299,7 +297,7 @@ public class KeyValueUtil {
    * @return First possible key on passed <code>row</code> and timestamp.
    */
   public static KeyValue createFirstOnRow(final byte[] row, final long ts) {
-    return new KeyValue(row, null, null, ts, Type.Maximum);
+    return new KeyValue(row, null, null, ts, KeyValue.Type.Maximum);
   }
 
   /**
@@ -312,10 +310,12 @@ public class KeyValueUtil {
    */
   public static KeyValue createFirstOnRow(final byte[] row, final byte[] family,
     final byte[] qualifier) {
-    return new KeyValue(row, family, qualifier, HConstants.LATEST_TIMESTAMP, Type.Maximum);
+    return new KeyValue(row, family, qualifier, HConstants.LATEST_TIMESTAMP, KeyValue.Type.Maximum);
   }
 
   /**
+   * Create a KeyValue for the specified row, family and qualifier that would be smaller than all
+   * other possible KeyValues that have the same row, family, qualifier. Used for seeking.
    * @param row - row key (arbitrary byte array)
    * @param f   - family name
    * @param q   - column qualifier
@@ -324,7 +324,7 @@ public class KeyValueUtil {
    */
   public static KeyValue createFirstOnRow(final byte[] row, final byte[] f, final byte[] q,
     final long ts) {
-    return new KeyValue(row, f, q, ts, Type.Maximum);
+    return new KeyValue(row, f, q, ts, KeyValue.Type.Maximum);
   }
 
   /**
@@ -345,7 +345,7 @@ public class KeyValueUtil {
     final byte[] family, final int foffset, final int flength, final byte[] qualifier,
     final int qoffset, final int qlength) {
     return new KeyValue(row, roffset, rlength, family, foffset, flength, qualifier, qoffset,
-      qlength, HConstants.LATEST_TIMESTAMP, Type.Maximum, null, 0, 0);
+      qlength, HConstants.LATEST_TIMESTAMP, KeyValue.Type.Maximum, null, 0, 0);
   }
 
   /**
@@ -408,11 +408,11 @@ public class KeyValueUtil {
 
   /*************** misc **********************************/
   /**
-   * @return <code>cell</code> if it is an object of class {@link KeyValue} else we will return a
-   *         new {@link KeyValue} instance made from <code>cell</code> Note: Even if the cell is an
-   *         object of any of the subclass of {@link KeyValue}, we will create a new
-   *         {@link KeyValue} object wrapping same buffer. This API is used only with MR based tools
-   *         which expect the type to be exactly KeyValue. That is the reason for doing this way.
+   * n * @return <code>cell</code> if it is an object of class {@link KeyValue} else we will return
+   * a new {@link KeyValue} instance made from <code>cell</code> Note: Even if the cell is an object
+   * of any of the subclass of {@link KeyValue}, we will create a new {@link KeyValue} object
+   * wrapping same buffer. This API is used only with MR based tools which expect the type to be
+   * exactly KeyValue. That is the reason for doing this way.
    * @deprecated without any replacement.
    */
   @Deprecated
@@ -444,9 +444,8 @@ public class KeyValueUtil {
   }
 
   /**
-   * Write out a KeyValue in the manner in which we used to when KeyValue was a Writable.
-   * @return Length written on stream
-   * @see #create(DataInput) for the inverse function
+   * Write out a KeyValue in the manner in which we used to when KeyValue was a Writable. nn
+   * * @return Length written on stream n * @see #create(DataInput) for the inverse function
    */
   public static long write(final KeyValue kv, final DataOutput out) throws IOException {
     // This is how the old Writables write used to serialize KVs. Need to figure
@@ -566,7 +565,7 @@ public class KeyValueUtil {
       throw new IllegalArgumentException(msg);
     }
     byte type = buf[pos];
-    if (!Type.isValidType(type)) {
+    if (!KeyValue.Type.isValidType(type)) {
       String msg = "Invalid type in KeyValue, type=" + type + bytesToHex(buf, offset, length);
       LOG.warn(msg);
       throw new IllegalArgumentException(msg);
@@ -640,7 +639,7 @@ public class KeyValueUtil {
    * @param in       inputStream to read.
    * @param withTags whether the keyvalue should include tags are not
    * @return Created KeyValue OR if we find a length of zero, we will return null which can be
-   *         useful marking a stream as done.
+   *         useful marking a stream as done. n
    */
   public static KeyValue createKeyValueFromInputStream(InputStream in, boolean withTags)
     throws IOException {
@@ -664,24 +663,24 @@ public class KeyValueUtil {
   }
 
   /**
-   * Returns a KeyValue made of a byte array that holds the key-only part. Needed to convert hfile
-   * index members to KeyValues.
+   * n * @return A KeyValue made of a byte array that holds the key-only part. Needed to convert
+   * hfile index members to KeyValues.
    */
   public static KeyValue createKeyValueFromKey(final byte[] b) {
     return createKeyValueFromKey(b, 0, b.length);
   }
 
   /**
-   * Return a KeyValue made of a byte buffer that holds the key-only part. Needed to convert hfile
-   * index members to KeyValues.
+   * n * @return A KeyValue made of a byte buffer that holds the key-only part. Needed to convert
+   * hfile index members to KeyValues.
    */
   public static KeyValue createKeyValueFromKey(final ByteBuffer bb) {
     return createKeyValueFromKey(bb.array(), bb.arrayOffset(), bb.limit());
   }
 
   /**
-   * Return a KeyValue made of a byte array that holds the key-only part. Needed to convert hfile
-   * index members to KeyValues.
+   * nnn * @return A KeyValue made of a byte array that holds the key-only part. Needed to convert
+   * hfile index members to KeyValues.
    */
   public static KeyValue createKeyValueFromKey(final byte[] b, final int o, final int l) {
     byte[] newb = new byte[l + KeyValue.ROW_OFFSET];
@@ -692,19 +691,19 @@ public class KeyValueUtil {
   }
 
   /**
-   * Where to read bytes from. Creates a byte array to hold the KeyValue backing bytes copied from
-   * the steam.
+   * n * Where to read bytes from. Creates a byte array to hold the KeyValue backing bytes copied
+   * from the steam.
    * @return KeyValue created by deserializing from <code>in</code> OR if we find a length of zero,
-   *         we will return null which can be useful marking a stream as done.
+   *         we will return null which can be useful marking a stream as done. n
    */
   public static KeyValue create(final DataInput in) throws IOException {
     return create(in.readInt(), in);
   }
 
   /**
-   * Create a KeyValue reading <code>length</code> from <code>in</code>
-   * @return Created KeyValue OR if we find a length of zero, we will return null which can be
-   *         useful marking a stream as done.
+   * Create a KeyValue reading <code>length</code> from <code>in</code> nn * @return Created
+   * KeyValue OR if we find a length of zero, we will return null which can be useful marking a
+   * stream as done. n
    */
   public static KeyValue create(int length, final DataInput in) throws IOException {
 
@@ -741,7 +740,6 @@ public class KeyValueUtil {
       int qlen = cell.getQualifierLength();
       int vlen = cell.getValueLength();
       int tlen = cell.getTagsLength();
-      int size = 0;
       // write key length
       int klen = keyLength(rlen, flen, qlen);
       ByteBufferUtils.putInt(out, klen);
@@ -761,7 +759,7 @@ public class KeyValueUtil {
       out.write(cell.getTypeByte());
       // write value
       out.write(cell.getValueArray(), cell.getValueOffset(), vlen);
-      size = klen + vlen + KeyValue.KEYVALUE_INFRASTRUCTURE_SIZE;
+      int size = klen + vlen + KeyValue.KEYVALUE_INFRASTRUCTURE_SIZE;
       // write tags if we have to
       if (withTags && tlen > 0) {
         // 2 bytes tags length followed by tags bytes
