@@ -60,6 +60,7 @@ import org.apache.hbase.thirdparty.org.apache.commons.collections4.CollectionUti
 @edu.umd.cs.findbugs.annotations.SuppressWarnings(
     value = "EQ_CHECK_FOR_OPERAND_NOT_COMPATIBLE_WITH_THIS",
     justification = "It has been like this forever")
+@SuppressWarnings("MixedMutabilityReturnType")
 public class Bytes implements Comparable<Bytes> {
 
   // Using the charset canonical name for String/byte[] conversions is much
@@ -199,16 +200,12 @@ public class Bytes implements Comparable<Bytes> {
     return this.bytes;
   }
 
-  /**
-   * @param b Use passed bytes as backing array for this instance.
-   */
+  /** Use passed bytes as backing array for this instance. */
   public void set(final byte[] b) {
     set(b, 0, b.length);
   }
 
-  /**
-   * @param b Use passed bytes as backing array for this instance.
-   */
+  /** Use passed bytes as backing array for this instance. */
   public void set(final byte[] b, final int offset, final int length) {
     this.bytes = b;
     this.offset = offset;
@@ -239,8 +236,7 @@ public class Bytes implements Comparable<Bytes> {
     return this.length;
   }
 
-  /**
-   *   */
+  /** Return the offset into the buffer. */
   public int getOffset() {
     return this.offset;
   }
@@ -271,17 +267,13 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
-   * Compares the bytes in this object to the specified byte array
-   * @return Positive if left is bigger than right, 0 if they are equal, and negative if left is
-   *         smaller than right.
+   * Compares the bytes in this object to the specified byte array n * @return Positive if left is
+   * bigger than right, 0 if they are equal, and negative if left is smaller than right.
    */
   public int compareTo(final byte[] that) {
     return BYTES_RAWCOMPARATOR.compare(this.bytes, this.offset, this.length, that, 0, that.length);
   }
 
-  /**
-   * @see Object#equals(Object)
-   */
   @Override
   public boolean equals(Object right_obj) {
     if (right_obj instanceof byte[]) {
@@ -293,15 +285,13 @@ public class Bytes implements Comparable<Bytes> {
     return false;
   }
 
-  /**
-   * @see Object#toString()
-   */
   @Override
   public String toString() {
     return Bytes.toString(bytes, offset, length);
   }
 
   /**
+   * Convert a list of byte[] to an array
    * @param array List of byte [].
    * @return Array of byte [].
    */
@@ -314,21 +304,15 @@ public class Bytes implements Comparable<Bytes> {
     return results;
   }
 
-  /**
-   * Returns a copy of the bytes referred to by this writable
-   */
+  /** Returns a copy of the bytes referred to by this writable */
   public byte[] copyBytes() {
     return Arrays.copyOfRange(bytes, offset, offset + length);
   }
 
-  /**
-   * Byte array comparator class.
-   */
+  /** Byte array comparator class. */
   @InterfaceAudience.Public
   public static class ByteArrayComparator implements RawComparator<byte[]> {
-    /**
-     * Constructor
-     */
+
     public ByteArrayComparator() {
       super();
     }
@@ -374,14 +358,10 @@ public class Bytes implements Comparable<Bytes> {
     }
   }
 
-  /**
-   * Pass this to TreeMaps where byte [] are keys.
-   */
+  /** Pass this to TreeMaps where byte [] are keys. */
   public final static Comparator<byte[]> BYTES_COMPARATOR = new ByteArrayComparator();
 
-  /**
-   * Use comparing byte arrays, byte-by-byte
-   */
+  /** Use comparing byte arrays, byte-by-byte */
   public final static RawComparator<byte[]> BYTES_RAWCOMPARATOR = new ByteArrayComparator();
 
   /**
@@ -521,6 +501,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Convert a byte[] into a string. Charset is assumed to be UTF-8.
    * @param b Presumed UTF-8 encoded byte array.
    * @return String made from <code>b</code>
    */
@@ -589,8 +570,7 @@ public class Bytes implements Comparable<Bytes> {
 
   /**
    * Write a printable representation of a byte array.
-   * @param b byte array
-   * @see #toStringBinary(byte[], int, int)
+   * @param b byte array n * @see #toStringBinary(byte[], int, int)
    */
   public static String toStringBinary(final byte[] b) {
     if (b == null) return "null";
@@ -818,7 +798,8 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
-   * Presumes float encoded as IEEE 754 floating-point "single format"
+   * Put a float value out to the specified byte array position. Presumes float encoded as IEEE 754
+   * floating-point "single format"
    * @param bytes byte array
    * @return Float made from passed byte array.
    */
@@ -827,7 +808,8 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
-   * Presumes float encoded as IEEE 754 floating-point "single format"
+   * Put a float value out to the specified byte array position. Presumes float encoded as IEEE 754
+   * floating-point "single format"
    * @param bytes  array to convert
    * @param offset offset into array
    * @return Float made from passed byte array.
@@ -837,6 +819,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Put a float value out to the specified byte array position.
    * @param bytes  byte array
    * @param offset offset to write to
    * @param f      float value
@@ -846,33 +829,24 @@ public class Bytes implements Comparable<Bytes> {
     return putInt(bytes, offset, Float.floatToRawIntBits(f));
   }
 
-  /**
-   * @param f float value
-   * @return the float represented as byte []
-   */
+  /** Return the float represented as byte[] */
   public static byte[] toBytes(final float f) {
     // Encode it as int
     return Bytes.toBytes(Float.floatToRawIntBits(f));
   }
 
-  /**
-   * @param bytes byte array
-   * @return Return double made from passed bytes.
-   */
+  /** Return double made from passed bytes. */
   public static double toDouble(final byte[] bytes) {
     return toDouble(bytes, 0);
   }
 
-  /**
-   * @param bytes  byte array
-   * @param offset offset where double is
-   * @return Return double made from passed bytes.
-   */
+  /** Return double made from passed bytes. */
   public static double toDouble(final byte[] bytes, final int offset) {
     return Double.longBitsToDouble(toLong(bytes, offset, SIZEOF_LONG));
   }
 
   /**
+   * Put a double value out to the specified byte array position as the IEEE 754 double format.
    * @param bytes  byte array
    * @param offset offset to write to
    * @param d      value
@@ -1143,10 +1117,7 @@ public class Bytes implements Comparable<Bytes> {
     return offset + SIZEOF_SHORT;
   }
 
-  /**
-   * Convert a BigDecimal value to a byte array
-   * @return the byte array
-   */
+  /** Convert a BigDecimal value to a byte array */
   public static byte[] toBytes(BigDecimal val) {
     byte[] valueBytes = val.unscaledValue().toByteArray();
     byte[] result = new byte[valueBytes.length + SIZEOF_INT];
@@ -1155,18 +1126,12 @@ public class Bytes implements Comparable<Bytes> {
     return result;
   }
 
-  /**
-   * Converts a byte array to a BigDecimal
-   * @return the char value
-   */
+  /** Converts a byte array to a BigDecimal */
   public static BigDecimal toBigDecimal(byte[] bytes) {
     return toBigDecimal(bytes, 0, bytes.length);
   }
 
-  /**
-   * Converts a byte array to a BigDecimal value
-   * @return the char value
-   */
+  /** Converts a byte array to a BigDecimal value */
   public static BigDecimal toBigDecimal(byte[] bytes, int offset, final int length) {
     if (bytes == null || length < SIZEOF_INT + 1 || (offset + length > bytes.length)) {
       return null;
@@ -1197,6 +1162,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Encode a long value as a variable length integer.
    * @param vint Integer to make a vint of.
    * @return Vint as bytes array.
    */
@@ -1235,6 +1201,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Reads a zero-compressed encoded long from input buffer and returns it.
    * @param buffer buffer to convert
    * @return vint bytes as an integer.
    */
@@ -1291,6 +1258,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Lexicographically compare two arrays.
    * @param left  left operand
    * @param right right operand
    * @return 0 if equal, &lt; 0 if left is less than right, etc.
@@ -1613,6 +1581,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Lexicographically determine the equality of two arrays.
    * @param left  left operand
    * @param right right operand
    * @return True if equal
@@ -1633,6 +1602,16 @@ public class Bytes implements Comparable<Bytes> {
     return compareTo(left, right) == 0;
   }
 
+  /**
+   * Lexicographically determine the equality of two arrays.
+   * @param left        left operand
+   * @param leftOffset  offset into left operand
+   * @param leftLen     length of left operand
+   * @param right       right operand
+   * @param rightOffset offset into right operand
+   * @param rightLen    length of right operand
+   * @return True if equal
+   */
   public static boolean equals(final byte[] left, int leftOffset, int leftLen, final byte[] right,
     int rightOffset, int rightLen) {
     // short circuit case
@@ -1657,6 +1636,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Lexicographically determine the equality of two byte[], one as ByteBuffer.
    * @param a   left operand
    * @param buf right operand
    * @return True if equal
@@ -1686,6 +1666,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Calculate a hash code from a given byte array.
    * @param b bytes to hash
    * @return Runs {@link WritableComparator#hashBytes(byte[], int)} on the passed in array. This
    *         method is what {@link org.apache.hadoop.io.Text} use calculating hash code.
@@ -1695,6 +1676,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Calculate a hash code from a given byte array.
    * @param b      value
    * @param length length of the value
    * @return Runs {@link WritableComparator#hashBytes(byte[], int)} on the passed in array. This
@@ -1705,6 +1687,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Calculate a hash code from a given byte array suitable for use as a key in maps.
    * @param b bytes to hash
    * @return A hash of <code>b</code> as an Integer that can be used as key in Maps.
    */
@@ -1713,6 +1696,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Calculate a hash code from a given byte array suitable for use as a key in maps.
    * @param b      bytes to hash
    * @param length length to hash
    * @return A hash of <code>b</code> as an Integer that can be used as key in Maps.
@@ -1722,6 +1706,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Concatenate byte arrays.
    * @param a lower half
    * @param b upper half
    * @return New array that has a in lower half and b in upper half.
@@ -1731,6 +1716,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Concatenate byte arrays.
    * @param a first third
    * @param b second third
    * @param c third third
@@ -1745,6 +1731,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Concatenate byte arrays.
    * @param arrays all the arrays to concatenate together.
    * @return New array made from the concatenation of the given arrays.
    */
@@ -1763,6 +1750,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Make a new byte array from a subset of bytes at the head of another.
    * @param a      array
    * @param length amount of bytes to grab
    * @return First <code>length</code> bytes from <code>a</code>
@@ -1777,6 +1765,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Make a new byte array from a subset of bytes at the tail of another.
    * @param a      array
    * @param length amount of bytes to snarf
    * @return Last <code>length</code> bytes from <code>a</code>
@@ -1791,6 +1780,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Make a new byte array from a subset of bytes at the head of another, zero padded as desired.
    * @param a      array
    * @param length new array size
    * @return Value in <code>a</code> plus <code>length</code> prepended 0 bytes
@@ -1804,6 +1794,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Make a new byte array from a subset of bytes at the tail of another, zero padded as desired.
    * @param a      array
    * @param length new array size
    * @return Value in <code>a</code> plus <code>length</code> appended 0 bytes
@@ -1949,6 +1940,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Calculate the hash code for a given range of bytes.
    * @param bytes  array to hash
    * @param offset offset to start from
    * @param length length to hash
@@ -1961,6 +1953,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Create an array of byte[] given an array of String.
    * @param t operands
    * @return Array of byte arrays made from passed array of Text
    */
@@ -1973,6 +1966,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Create an array of byte[] given an array of String.
    * @param t operands
    * @return Array of binary byte arrays made from passed array of binary strings
    */
@@ -1985,6 +1979,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Create a byte[][] where first and only entry is <code>column</code>
    * @param column operand
    * @return A byte array of a byte array where first and only entry is <code>column</code>
    */
@@ -1993,6 +1988,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Create a byte[][] where first and only entry is <code>column</code>
    * @param column operand
    * @return A byte array of a byte array where first and only entry is <code>column</code>
    */
@@ -2188,7 +2184,7 @@ public class Bytes implements Comparable<Bytes> {
     for (int i = 0; i < value.length; i++) {
       int cur = ((int) amo % 256) * sign;
       amo = (amo >> 8);
-      int val = ((~value[value.length - i - 1]) & 0x0ff) + 1;
+      int val = (~value[value.length - i - 1] & 0x0ff) + 1;
       int total = cur - val;
       if (total >= 0) {
         amo += sign;
@@ -2248,7 +2244,7 @@ public class Bytes implements Comparable<Bytes> {
    * Copy the byte array given in parameter and return an instance of a new byte array with the same
    * length and the same content.
    * @param bytes the byte array to copy from
-   * @return a copy of the given designated byte array
+   * @return a copy of the given designated byte array nn
    */
   public static byte[] copy(byte[] bytes, final int offset, final int length) {
     if (bytes == null) return null;
@@ -2401,6 +2397,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Return true if target is present as an element anywhere in the given array.
    * @param array  an array of {@code byte} values, possibly empty
    * @param target a primitive {@code byte} value
    * @return {@code true} if {@code target} is present as an element anywhere in {@code array}.
@@ -2410,6 +2407,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
+   * Return true if target is present as an element anywhere in the given array.
    * @param array  an array of {@code byte} values, possibly empty
    * @param target an array of {@code byte}
    * @return {@code true} if {@code target} is present anywhere in {@code array}
@@ -2427,7 +2425,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
-   * Fill given array with zeros at the specified position.
+   * Fill given array with zeros at the specified position. nnn
    */
   public static void zero(byte[] b, int offset, int length) {
     checkPositionIndex(offset, b.length, "offset");
@@ -2510,8 +2508,7 @@ public class Bytes implements Comparable<Bytes> {
   }
 
   /**
-   * Create a byte array which is multiple given bytes
-   * @return byte array
+   * Create a byte array which is multiple given bytes nn * @return byte array
    */
   public static byte[] multiple(byte[] srcBytes, int multiNum) {
     if (multiNum <= 0) {
@@ -2566,7 +2563,7 @@ public class Bytes implements Comparable<Bytes> {
 
   /**
    * Create a byte array from a string of hash digits. The length of the string must be a multiple
-   * of 2
+   * of 2 n
    */
   public static byte[] fromHex(String hex) {
     checkArgument(hex.length() % 2 == 0, "length must be a multiple of 2");
