@@ -25,7 +25,6 @@ import java.lang.management.ManagementFactory;
 import java.lang.management.ThreadInfo;
 import java.lang.management.ThreadMXBean;
 import java.lang.reflect.Constructor;
-import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.nio.charset.Charset;
@@ -34,7 +33,7 @@ import org.slf4j.Logger;
 
 @InterfaceAudience.Private
 public class ReflectionUtils {
-  @SuppressWarnings("unchecked")
+  @SuppressWarnings({ "unchecked", "TypeParameterUnusedInFormals" })
   public static <T> T instantiateWithCustomCtor(String className, Class<?>[] ctorArgTypes,
     Object[] ctorArgs) {
     try {
@@ -49,7 +48,7 @@ public class ReflectionUtils {
     }
   }
 
-  private static <T> T instantiate(final String className, Constructor<T> ctor, Object[] ctorArgs) {
+  public static <T> T instantiate(final String className, Constructor<T> ctor, Object... ctorArgs) {
     try {
       ctor.setAccessible(true);
       return ctor.newInstance(ctorArgs);
@@ -63,6 +62,31 @@ public class ReflectionUtils {
     }
   }
 
+  @SuppressWarnings({ "unchecked", "TypeParameterUnusedInFormals" })
+  public static <T> T newInstance(String className, Object... params) {
+    Class<T> type;
+    try {
+      type = (Class<T>) getClassLoader().loadClass(className);
+    } catch (ClassNotFoundException | ClassCastException e) {
+      throw new UnsupportedOperationException("Unable to load specified class " + className, e);
+    }
+    return instantiate(type.getName(), findConstructor(type, params), params);
+  }
+
+  public static ClassLoader getClassLoader() {
+    ClassLoader cl = Thread.currentThread().getContextClassLoader();
+    if (cl == null) {
+      cl = ReflectionUtils.class.getClassLoader();
+    }
+    if (cl == null) {
+      cl = ClassLoader.getSystemClassLoader();
+    }
+    if (cl == null) {
+      throw new RuntimeException("A ClassLoader could not be found");
+    }
+    return cl;
+  }
+
   public static <T> T newInstance(Class<T> type, Object... params) {
     return instantiate(type.getName(), findConstructor(type, params), params);
   }
@@ -78,16 +102,20 @@ public class ReflectionUtils {
 
       boolean match = true;
       for (int i = 0; i < ctorParamTypes.length && match; ++i) {
-        Class<?> paramType = paramTypes[i].getClass();
-        match = (!ctorParamTypes[i].isPrimitive())
-          ? ctorParamTypes[i].isAssignableFrom(paramType)
-          : ((int.class.equals(ctorParamTypes[i]) && Integer.class.equals(paramType))
-            || (long.class.equals(ctorParamTypes[i]) && Long.class.equals(paramType))
-            || (double.class.equals(ctorParamTypes[i]) && Double.class.equals(paramType))
-            || (char.class.equals(ctorParamTypes[i]) && Character.class.equals(paramType))
-            || (short.class.equals(ctorParamTypes[i]) && Short.class.equals(paramType))
-            || (boolean.class.equals(ctorParamTypes[i]) && Boolean.class.equals(paramType))
-            || (byte.class.equals(ctorParamTypes[i]) && Byte.class.equals(paramType)));
+        if (paramTypes[i] == null) {
+          match = !ctorParamTypes[i].isPrimitive();
+        } else {
+          Class<?> paramType = paramTypes[i].getClass();
+          match = !ctorParamTypes[i].isPrimitive()
+            ? ctorParamTypes[i].isAssignableFrom(paramType)
+            : ((int.class.equals(ctorParamTypes[i]) && Integer.class.equals(paramType))
+              || (long.class.equals(ctorParamTypes[i]) && Long.class.equals(paramType))
+              || (double.class.equals(ctorParamTypes[i]) && Double.class.equals(paramType))
+              || (char.class.equals(ctorParamTypes[i]) && Character.class.equals(paramType))
+              || (short.class.equals(ctorParamTypes[i]) && Short.class.equals(paramType))
+              || (boolean.class.equals(ctorParamTypes[i]) && Boolean.class.equals(paramType))
+              || (byte.class.equals(ctorParamTypes[i]) && Byte.class.equals(paramType)));
+        }
       }
 
       if (match) {
@@ -112,7 +140,7 @@ public class ReflectionUtils {
     boolean dumpStack = false;
     if (log.isInfoEnabled()) {
       synchronized (ReflectionUtils.class) {
-        long now = System.currentTimeMillis();
+        long now = EnvironmentEdgeManager.currentTime();
         if (now - previousLogTime >= minInterval * 1000) {
           previousLogTime = now;
           dumpStack = true;
@@ -136,7 +164,7 @@ public class ReflectionUtils {
    * @param stream the stream to
    * @param title  a string title for the stack trace
    */
-  private static void printThreadInfo(PrintStream stream, String title) {
+  static void printThreadInfo(PrintStream stream, String title) {
     final int STACK_DEPTH = 20;
     boolean contention = threadBean.isThreadContentionMonitoringEnabled();
     long[] threadIds = threadBean.getAllThreadIds();
@@ -213,38 +241,4 @@ public class ReflectionUtils {
     return parameterTypes;
   }
 
-  public static Field getModifiersField() throws IllegalAccessException, NoSuchFieldException {
-    // this is copied from https://github.com/powermock/powermock/pull/1010/files to work around
-    // JDK 12+
-    Field modifiersField = null;
-    try {
-      modifiersField = Field.class.getDeclaredField("modifiers");
-    } catch (NoSuchFieldException e) {
-      try {
-        Method getDeclaredFields0 =
-          Class.class.getDeclaredMethod("getDeclaredFields0", boolean.class);
-        boolean accessibleBeforeSet = getDeclaredFields0.isAccessible();
-        getDeclaredFields0.setAccessible(true);
-        Field[] fields = (Field[]) getDeclaredFields0.invoke(Field.class, false);
-        getDeclaredFields0.setAccessible(accessibleBeforeSet);
-        for (Field field : fields) {
-          if ("modifiers".equals(field.getName())) {
-            modifiersField = field;
-            break;
-          }
-        }
-        if (modifiersField == null) {
-          throw e;
-        }
-      } catch (NoSuchMethodException ex) {
-        e.addSuppressed(ex);
-        throw e;
-      } catch (InvocationTargetException ex) {
-        e.addSuppressed(ex);
-        throw e;
-      }
-    }
-    return modifiersField;
-  }
-
 }
