@@ -129,6 +129,18 @@ public class TestHBaseConfiguration {
     assertEquals("/var/lib/hadoop-hdfs/dn_socket", conf.get("dfs.domain.socket.path"));
   }
 
+  @Test
+  public void testDeprecatedConfigurations() {
+    // Configuration.addDeprecations before create Configuration object
+    Configuration.addDeprecations(new Configuration.DeprecationDelta[] {
+      new Configuration.DeprecationDelta("hbase.deprecated.conf", "hbase.new.conf"),
+      new Configuration.DeprecationDelta("hbase.deprecated.conf2", "hbase.new.conf2") });
+    Configuration conf = HBaseConfiguration.create();
+    conf.addResource("hbase-deprecated-conf.xml");
+    assertEquals("1000", conf.get("hbase.new.conf"));
+    assertEquals("1000", conf.get("hbase.new.conf2"));
+  }
+
   private static class ReflectiveCredentialProviderClient {
     public static final String HADOOP_CRED_PROVIDER_FACTORY_CLASS_NAME =
       "org.apache.hadoop.security.alias.JavaKeyStoreProvider$Factory";
@@ -204,9 +216,6 @@ public class TestHBaseConfiguration {
         getCredentialEntryMethod = loadMethod(hadoopCredProviderClz,
           HADOOP_CRED_PROVIDER_GET_CREDENTIAL_ENTRY_METHOD_NAME, String.class);
 
-        Method getAliasesMethod =
-          loadMethod(hadoopCredProviderClz, HADOOP_CRED_PROVIDER_GET_ALIASES_METHOD_NAME);
-
         createCredentialEntryMethod = loadMethod(hadoopCredProviderClz,
           HADOOP_CRED_PROVIDER_CREATE_CREDENTIAL_ENTRY_METHOD_NAME, String.class, char[].class);
 
@@ -249,7 +258,7 @@ public class TestHBaseConfiguration {
     }
 
     /**
-     * Wrapper to fetch the configured {@code List<CredentialProvider>}s. Configuration with
+     * Wrapper to fetch the configured {@code List<CredentialProvider>}s. n * Configuration with
      * GENERAL_SECURITY_CREDENTIAL_PROVIDER_PATHS defined
      * @return List of CredentialProviders, or null if they could not be loaded
      */
@@ -274,8 +283,8 @@ public class TestHBaseConfiguration {
 
     /**
      * Create a CredentialEntry using the configured Providers. If multiple CredentialProviders are
-     * configured, the first will be used. Configuration for the CredentialProvider CredentialEntry
-     * name (alias) The credential
+     * configured, the first will be used. n * Configuration for the CredentialProvider n *
+     * CredentialEntry name (alias) n * The credential
      */
     public void createEntry(Configuration conf, String name, char[] credential) throws Exception {
       if (!isHadoopCredentialProviderAvailable()) {
@@ -294,8 +303,8 @@ public class TestHBaseConfiguration {
 
     /**
      * Create a CredentialEntry with the give name and credential in the credentialProvider. The
-     * credentialProvider argument must be an instance of Hadoop CredentialProvider. Instance of
-     * CredentialProvider CredentialEntry name (alias) The credential to store
+     * credentialProvider argument must be an instance of Hadoop CredentialProvider. n * Instance of
+     * CredentialProvider n * CredentialEntry name (alias) n * The credential to store
      */
     private void createEntryInProvider(Object credentialProvider, String name, char[] credential)
       throws Exception {
