@@ -18,6 +18,12 @@
 package org.apache.hadoop.hbase.util;
 
 import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -33,7 +39,6 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Random;
 import java.util.concurrent.ThreadLocalRandom;
-import junit.framework.TestCase;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.testclassification.MiscTests;
@@ -41,18 +46,18 @@ import org.apache.hadoop.hbase.unsafe.HBasePlatformDependent;
 import org.apache.hadoop.io.WritableUtils;
 import org.junit.Assert;
 import org.junit.ClassRule;
+import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
 @Category({ MiscTests.class, MediumTests.class })
-public class TestBytes extends TestCase {
+public class TestBytes {
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE = HBaseClassTestRule.forClass(TestBytes.class);
 
   private static void setUnsafe(boolean value) throws Exception {
     Field field = Bytes.class.getDeclaredField("UNSAFE_UNALIGNED");
     field.setAccessible(true);
-
-    Field modifiersField = ReflectionUtils.getModifiersField();
+    Field modifiersField = Field.class.getDeclaredField("modifiers");
     modifiersField.setAccessible(true);
     int oldModifiers = field.getModifiers();
     modifiersField.setInt(field, oldModifiers & ~Modifier.FINAL);
@@ -64,10 +69,12 @@ public class TestBytes extends TestCase {
     assertEquals(Bytes.UNSAFE_UNALIGNED, value);
   }
 
+  @Test
   public void testShort() throws Exception {
     testShort(false);
   }
 
+  @Test
   public void testShortUnsafe() throws Exception {
     testShort(true);
   }
@@ -85,6 +92,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testNullHashCode() {
     byte[] b = null;
     Exception ee = null;
@@ -96,19 +104,17 @@ public class TestBytes extends TestCase {
     assertNotNull(ee);
   }
 
+  @Test
   public void testAdd() {
     byte[] a = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
     byte[] b = { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 };
     byte[] c = { 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2 };
-    byte[] d = { 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3 };
     byte[] result1 = Bytes.add(a, b, c);
     byte[] result2 = Bytes.add(new byte[][] { a, b, c });
     assertEquals(0, Bytes.compareTo(result1, result2));
-    byte[] result4 = Bytes.add(result1, d);
-    byte[] result5 = Bytes.add(new byte[][] { result1, d });
-    assertEquals(0, Bytes.compareTo(result1, result2));
   }
 
+  @Test
   public void testSplit() {
     byte[] lowest = Bytes.toBytes("AAA");
     byte[] middle = Bytes.toBytes("CCC");
@@ -130,6 +136,7 @@ public class TestBytes extends TestCase {
     assertTrue(Bytes.equals(parts[2], middle));
   }
 
+  @Test
   public void testSplit2() {
     // More split tests.
     byte[] lowest = Bytes.toBytes("http://A");
@@ -143,6 +150,7 @@ public class TestBytes extends TestCase {
     assertTrue(Bytes.equals(parts[1], middle));
   }
 
+  @Test
   public void testSplit3() {
     // Test invalid split cases
     byte[] low = { 1, 1, 1 };
@@ -177,6 +185,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToInt() {
     int[] ints = { -1, 123, Integer.MIN_VALUE, Integer.MAX_VALUE };
     for (int anInt : ints) {
@@ -188,6 +197,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToLong() {
     long[] longs = { -1L, 123L, Long.MIN_VALUE, Long.MAX_VALUE };
     for (long aLong : longs) {
@@ -199,6 +209,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToFloat() {
     float[] floats = { -1f, 123.123f, Float.MAX_VALUE };
     for (float aFloat : floats) {
@@ -209,6 +220,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToDouble() {
     double[] doubles = { Double.MIN_VALUE, Double.MAX_VALUE };
     for (double aDouble : doubles) {
@@ -219,6 +231,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToBigDecimal() {
     BigDecimal[] decimals =
       { new BigDecimal("-1"), new BigDecimal("123.123"), new BigDecimal("123123123123") };
@@ -238,6 +251,7 @@ public class TestBytes extends TestCase {
     return result;
   }
 
+  @Test
   public void testToBytesForByteBuffer() {
     byte[] array = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
     ByteBuffer target = ByteBuffer.wrap(array);
@@ -261,6 +275,7 @@ public class TestBytes extends TestCase {
     assertEquals(5, target2.limit());
   }
 
+  @Test
   public void testGetBytesForByteBuffer() {
     byte[] array = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
     ByteBuffer target = ByteBuffer.wrap(array);
@@ -274,6 +289,7 @@ public class TestBytes extends TestCase {
     assertEquals(7, target.limit());
   }
 
+  @Test
   public void testReadAsVLong() throws Exception {
     long[] longs = { -1L, 123L, Long.MIN_VALUE, Long.MAX_VALUE };
     for (long aLong : longs) {
@@ -287,6 +303,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToStringBinaryForBytes() {
     byte[] array = { '0', '9', 'a', 'z', 'A', 'Z', '@', 1 };
     String actual = Bytes.toStringBinary(array);
@@ -298,6 +315,7 @@ public class TestBytes extends TestCase {
     assertEquals(expected2, actual2);
   }
 
+  @Test
   public void testToStringBinaryForArrayBasedByteBuffer() {
     byte[] array = { '0', '9', 'a', 'z', 'A', 'Z', '@', 1 };
     ByteBuffer target = ByteBuffer.wrap(array);
@@ -306,6 +324,7 @@ public class TestBytes extends TestCase {
     assertEquals(expected, actual);
   }
 
+  @Test
   public void testToStringBinaryForReadOnlyByteBuffer() {
     byte[] array = { '0', '9', 'a', 'z', 'A', 'Z', '@', 1 };
     ByteBuffer target = ByteBuffer.wrap(array).asReadOnlyBuffer();
@@ -314,6 +333,7 @@ public class TestBytes extends TestCase {
     assertEquals(expected, actual);
   }
 
+  @Test
   public void testBinarySearch() {
     byte[][] arr = { { 1 }, { 3 }, { 5 }, { 7 }, { 9 }, { 11 }, { 13 }, { 15 }, };
     byte[] key1 = { 3, 1 };
@@ -340,6 +360,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToStringBytesBinaryReversible() {
     byte[] randomBytes = new byte[1000];
     for (int i = 0; i < 1000; i++) {
@@ -361,6 +382,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testStartsWith() {
     assertTrue(Bytes.startsWith(Bytes.toBytes("hello"), Bytes.toBytes("h")));
     assertTrue(Bytes.startsWith(Bytes.toBytes("hello"), Bytes.toBytes("")));
@@ -369,6 +391,7 @@ public class TestBytes extends TestCase {
     assertFalse(Bytes.startsWith(Bytes.toBytes(""), Bytes.toBytes("hello")));
   }
 
+  @Test
   public void testIncrementBytes() {
     assertTrue(checkTestIncrementBytes(10, 1));
     assertTrue(checkTestIncrementBytes(12, 123435445));
@@ -402,6 +425,7 @@ public class TestBytes extends TestCase {
     return (Bytes.toLong(testValue) + amount) == incrementResult;
   }
 
+  @Test
   public void testFixedSizeString() throws IOException {
     ByteArrayOutputStream baos = new ByteArrayOutputStream();
     DataOutputStream dos = new DataOutputStream(baos);
@@ -427,6 +451,7 @@ public class TestBytes extends TestCase {
     assertEquals("", Bytes.readStringFixedSize(dis, 9));
   }
 
+  @Test
   public void testCopy() {
     byte[] bytes = Bytes.toBytes("ABCDEFGHIJKLMNOPQRSTUVWXYZ");
     byte[] copy = Bytes.copy(bytes);
@@ -434,6 +459,7 @@ public class TestBytes extends TestCase {
     assertTrue(Bytes.equals(bytes, copy));
   }
 
+  @Test
   public void testToBytesBinaryTrailingBackslashes() {
     try {
       Bytes.toBytesBinary("abc\\x00\\x01\\");
@@ -442,11 +468,13 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToStringBinary_toBytesBinary_Reversable() {
     String bytes = Bytes.toStringBinary(Bytes.toBytes(2.17));
     assertEquals(2.17, Bytes.toDouble(Bytes.toBytesBinary(bytes)), 0);
   }
 
+  @Test
   public void testUnsignedBinarySearch() {
     byte[] bytes = new byte[] { 0, 5, 123, 127, -128, -100, -1 };
     Assert.assertEquals(1, Bytes.unsignedBinarySearch(bytes, 0, bytes.length, (byte) 5));
@@ -458,6 +486,7 @@ public class TestBytes extends TestCase {
     Assert.assertEquals(-6 - 1, Bytes.unsignedBinarySearch(bytes, 0, bytes.length, (byte) -5));
   }
 
+  @Test
   public void testUnsignedIncrement() {
     byte[] a = Bytes.toBytes(0);
     int a2 = Bytes.toInt(Bytes.unsignedCopyAndIncrement(a), 0);
@@ -474,6 +503,7 @@ public class TestBytes extends TestCase {
     Assert.assertEquals(256, c2);
   }
 
+  @Test
   public void testIndexOf() {
     byte[] array = Bytes.toBytes("hello");
     assertEquals(1, Bytes.indexOf(array, (byte) 'e'));
@@ -484,6 +514,7 @@ public class TestBytes extends TestCase {
     assertEquals(-1, Bytes.indexOf(array, Bytes.toBytes("hll")));
   }
 
+  @Test
   public void testContains() {
     byte[] array = Bytes.toBytes("hello world");
     assertTrue(Bytes.contains(array, (byte) 'e'));
@@ -494,6 +525,7 @@ public class TestBytes extends TestCase {
     assertFalse(Bytes.contains(array, Bytes.toBytes("owo")));
   }
 
+  @Test
   public void testZero() {
     byte[] array = Bytes.toBytes("hello");
     Bytes.zero(array);
@@ -512,6 +544,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testPutBuffer() {
     byte[] b = new byte[100];
     for (byte i = 0; i < 100; i++) {
@@ -522,6 +555,7 @@ public class TestBytes extends TestCase {
     }
   }
 
+  @Test
   public void testToFromHex() {
     List<String> testStrings = new ArrayList<>(8);
     testStrings.addAll(Arrays.asList("", "00", "A0", "ff", "FFffFFFFFFFFFF", "12",
@@ -550,45 +584,4 @@ public class TestBytes extends TestCase {
       assertArrayEquals(testData, result);
     }
   }
-
-  public void testFindCommonPrefix() throws Exception {
-    testFindCommonPrefix(false);
-  }
-
-  public void testFindCommonPrefixUnsafe() throws Exception {
-    testFindCommonPrefix(true);
-  }
-
-  private static void testFindCommonPrefix(boolean unsafe) throws Exception {
-    setUnsafe(unsafe);
-    try {
-      // tests for common prefixes less than 8 bytes in length (i.e. using non-vectorized path)
-      byte[] hello = Bytes.toBytes("hello");
-      byte[] helloWorld = Bytes.toBytes("helloworld");
-
-      assertEquals(5,
-        Bytes.findCommonPrefix(hello, helloWorld, hello.length, helloWorld.length, 0, 0));
-      assertEquals(5, Bytes.findCommonPrefix(hello, hello, hello.length, hello.length, 0, 0));
-      assertEquals(3,
-        Bytes.findCommonPrefix(hello, hello, hello.length - 2, hello.length - 2, 2, 2));
-      assertEquals(0, Bytes.findCommonPrefix(hello, hello, 0, 0, 0, 0));
-
-      // tests for common prefixes greater than 8 bytes in length which may use the vectorized path
-      byte[] hellohello = Bytes.toBytes("hellohello");
-      byte[] hellohellohi = Bytes.toBytes("hellohellohi");
-
-      assertEquals(10, Bytes.findCommonPrefix(hellohello, hellohellohi, hellohello.length,
-        hellohellohi.length, 0, 0));
-      assertEquals(10, Bytes.findCommonPrefix(hellohellohi, hellohello, hellohellohi.length,
-        hellohello.length, 0, 0));
-      assertEquals(10,
-        Bytes.findCommonPrefix(hellohello, hellohello, hellohello.length, hellohello.length, 0, 0));
-
-      hellohello[2] = 0;
-      assertEquals(2, Bytes.findCommonPrefix(hellohello, hellohellohi, hellohello.length,
-        hellohellohi.length, 0, 0));
-    } finally {
-      setUnsafe(HBasePlatformDependent.unaligned());
-    }
-  }
 }
