@@ -17,7 +17,6 @@
  */
 package org.apache.hadoop.metrics2.lib;
 
-import com.google.errorprone.annotations.RestrictedApi;
 import java.util.Collection;
 import java.util.concurrent.ConcurrentMap;
 import org.apache.hadoop.hbase.metrics.Interns;
@@ -27,8 +26,6 @@ import org.apache.hadoop.metrics2.MetricsRecordBuilder;
 import org.apache.hadoop.metrics2.MetricsTag;
 import org.apache.hadoop.metrics2.impl.MsInfo;
 import org.apache.yetus.audience.InterfaceAudience;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import org.apache.hbase.thirdparty.com.google.common.base.MoreObjects;
 import org.apache.hbase.thirdparty.com.google.common.collect.Maps;
@@ -44,7 +41,6 @@ import org.apache.hbase.thirdparty.com.google.common.collect.Maps;
  */
 @InterfaceAudience.Private
 public class DynamicMetricsRegistry {
-  private static final Logger LOG = LoggerFactory.getLogger(DynamicMetricsRegistry.class);
 
   private final ConcurrentMap<String, MutableMetric> metricsMap = Maps.newConcurrentMap();
   private final ConcurrentMap<String, MetricsTag> tagsMap = Maps.newConcurrentMap();
@@ -392,9 +388,8 @@ public class DynamicMetricsRegistry {
 
   public void removeHistogramMetrics(String baseName) {
     for (String suffix : histogramSuffixes) {
-      helper.removeObjectName(baseName + suffix);
+      removeMetric(baseName + suffix);
     }
-    metricsMap.remove(baseName);
   }
 
   /**
@@ -537,10 +532,4 @@ public class DynamicMetricsRegistry {
     }
     metricsMap.clear();
   }
-
-  @RestrictedApi(explanation = "Should only be called in TestMetricsTableMetricsMap", link = "",
-      allowedOnPath = ".*/(DynamicMetricsRegistry|TestMetricsTableMetricsMap).java")
-  public ConcurrentMap<String, MutableMetric> getMetricsMap() {
-    return metricsMap;
-  }
 }
