@@ -17,6 +17,10 @@
  */
 package org.apache.hadoop.hbase.http.conf;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.StringReader;
 import java.io.StringWriter;
 import java.util.HashSet;
@@ -24,7 +28,6 @@ import java.util.Map;
 import java.util.Set;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
-import junit.framework.TestCase;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.testclassification.MiscTests;
@@ -45,7 +48,7 @@ import org.apache.hbase.thirdparty.org.eclipse.jetty.util.ajax.JSON;
  * format.
  */
 @Category({ MiscTests.class, SmallTests.class })
-public class TestConfServlet extends TestCase {
+public class TestConfServlet {
 
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE =
@@ -110,15 +113,6 @@ public class TestConfServlet extends TestCase {
     assertTrue(foundSetting);
   }
 
-  @Test
-  public void testMask() {
-    final String passwordKey = "hbase.rpc.tls.keystore.password";
-    Configuration conf = getTestConf();
-    conf.set(passwordKey, "MyPassword");
-    Configuration maskedConf = ConfServlet.mask(conf);
-    assertEquals(ConfServlet.MASKED, maskedConf.get(passwordKey));
-  }
-
   @Test
   public void testBadFormat() throws Exception {
     StringWriter sw = new StringWriter();
