@@ -34,6 +34,7 @@ import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.RegionLocator;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Threads;
 import org.apache.yetus.audience.InterfaceAudience;
 
@@ -56,7 +57,7 @@ public class DistributedHBaseCluster extends HBaseCluster {
    * restarted instances of the same server will have different ServerName and will not coincide
    * with past dead ones. So there's no need to cleanup this list.
    */
-  private final Set<ServerName> killedRegionServers = new HashSet<>();
+  private Set<ServerName> killedRegionServers = new HashSet<>();
 
   public DistributedHBaseCluster(Configuration conf, ClusterManager clusterManager)
     throws IOException {
@@ -76,7 +77,7 @@ public class DistributedHBaseCluster extends HBaseCluster {
   }
 
   /**
-   * Returns a ClusterStatus for this HBase cluster
+   * Returns a ClusterStatus for this HBase cluster n
    */
   @Override
   public ClusterMetrics getClusterMetrics() throws IOException {
@@ -247,43 +248,12 @@ public class DistributedHBaseCluster extends HBaseCluster {
     waitForServiceToStop(ServiceType.HADOOP_NAMENODE, serverName, timeout);
   }
 
-  @Override
-  public void startJournalNode(ServerName serverName) throws IOException {
-    LOG.info("Starting journal node on: {}", serverName.getServerName());
-    clusterManager.start(ServiceType.HADOOP_JOURNALNODE, serverName.getHostname(),
-      serverName.getPort());
-  }
-
-  @Override
-  public void killJournalNode(ServerName serverName) throws IOException {
-    LOG.info("Aborting journal node on: {}", serverName.getServerName());
-    clusterManager.kill(ServiceType.HADOOP_JOURNALNODE, serverName.getHostname(),
-      serverName.getPort());
-  }
-
-  @Override
-  public void stopJournalNode(ServerName serverName) throws IOException {
-    LOG.info("Stopping journal node on: {}", serverName.getServerName());
-    clusterManager.stop(ServiceType.HADOOP_JOURNALNODE, serverName.getHostname(),
-      serverName.getPort());
-  }
-
-  @Override
-  public void waitForJournalNodeToStart(ServerName serverName, long timeout) throws IOException {
-    waitForServiceToStart(ServiceType.HADOOP_JOURNALNODE, serverName, timeout);
-  }
-
-  @Override
-  public void waitForJournalNodeToStop(ServerName serverName, long timeout) throws IOException {
-    waitForServiceToStop(ServiceType.HADOOP_JOURNALNODE, serverName, timeout);
-  }
-
   private void waitForServiceToStop(ServiceType service, ServerName serverName, long timeout)
     throws IOException {
     LOG.info("Waiting for service: {} to stop: {}", service, serverName.getServerName());
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
 
-    while ((System.currentTimeMillis() - start) < timeout) {
+    while ((EnvironmentEdgeManager.currentTime() - start) < timeout) {
       if (!clusterManager.isRunning(service, serverName.getHostname(), serverName.getPort())) {
         return;
       }
@@ -294,10 +264,10 @@ public class DistributedHBaseCluster extends HBaseCluster {
 
   private void waitForServiceToStart(ServiceType service, ServerName serverName, long timeout)
     throws IOException {
-    LOG.info("Waiting for service: {} to start: {}", service, serverName.getServerName());
-    long start = System.currentTimeMillis();
+    LOG.info("Waiting for service: {} to start: ", service, serverName.getServerName());
+    long start = EnvironmentEdgeManager.currentTime();
 
-    while ((System.currentTimeMillis() - start) < timeout) {
+    while ((EnvironmentEdgeManager.currentTime() - start) < timeout) {
       if (clusterManager.isRunning(service, serverName.getHostname(), serverName.getPort())) {
         return;
       }
@@ -336,8 +306,8 @@ public class DistributedHBaseCluster extends HBaseCluster {
 
   @Override
   public boolean waitForActiveAndReadyMaster(long timeout) throws IOException {
-    long start = System.currentTimeMillis();
-    while (System.currentTimeMillis() - start < timeout) {
+    long start = EnvironmentEdgeManager.currentTime();
+    while (EnvironmentEdgeManager.currentTime() - start < timeout) {
       try {
         getMasterAdminService();
         return true;
@@ -389,9 +359,10 @@ public class DistributedHBaseCluster extends HBaseCluster {
     LOG.info("Restoring cluster - started");
 
     // do a best effort restore
-    boolean success = restoreMasters(initial, current);
-    success = restoreRegionServers(initial, current) & success;
-    success = restoreAdmin() & success;
+    boolean success = true;
+    success = restoreMasters(initial, current) && success;
+    success = restoreRegionServers(initial, current) && success;
+    success = restoreAdmin() && success;
 
     LOG.info("Restoring cluster - done");
     return success;
