@@ -30,6 +30,7 @@ import org.apache.hadoop.hbase.filter.Filter;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.mapreduce.TableInputFormat;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.util.StringUtils;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
@@ -86,7 +87,7 @@ public class TableRecordReaderImpl {
     }
     if (logScannerActivity) {
       LOG.info("Current scan=" + currentScan.toString());
-      timestamp = System.currentTimeMillis();
+      timestamp = EnvironmentEdgeManager.currentTime();
       rowcount = 0;
     }
   }
@@ -153,6 +154,7 @@ public class TableRecordReaderImpl {
   }
 
   /**
+   * n *
    * @see org.apache.hadoop.mapred.RecordReader#createKey()
    */
   public ImmutableBytesWritable createKey() {
@@ -160,6 +162,7 @@ public class TableRecordReaderImpl {
   }
 
   /**
+   * n *
    * @see org.apache.hadoop.mapred.RecordReader#createValue()
    */
   public Result createValue() {
@@ -190,7 +193,7 @@ public class TableRecordReaderImpl {
         if (logScannerActivity) {
           rowcount++;
           if (rowcount >= logPerRowCount) {
-            long now = System.currentTimeMillis();
+            long now = EnvironmentEdgeManager.currentTime();
             LOG.info("Mapper took " + (now - timestamp) + "ms to process " + rowcount + " rows");
             timestamp = now;
             rowcount = 0;
@@ -228,7 +231,7 @@ public class TableRecordReaderImpl {
       return false;
     } catch (IOException ioe) {
       if (logScannerActivity) {
-        long now = System.currentTimeMillis();
+        long now = EnvironmentEdgeManager.currentTime();
         LOG.info("Mapper took " + (now - timestamp) + "ms to process " + rowcount + " rows");
         LOG.info(ioe.toString(), ioe);
         String lastRow =
