@@ -734,9 +734,10 @@ public class TableMapReduceUtil {
       org.apache.hadoop.hbase.unsafe.HBasePlatformDependent.class, // hbase-unsafe
       org.apache.zookeeper.ZooKeeper.class, // zookeeper
       com.google.protobuf.Message.class, // protobuf
-      org.apache.htrace.core.Tracer.class, // htrace
       com.codahale.metrics.MetricRegistry.class, // metrics-core
-      org.apache.commons.lang3.ArrayUtils.class); // commons-lang
+      org.apache.commons.lang3.ArrayUtils.class, // commons-lang
+      io.opentelemetry.api.trace.Span.class, // opentelemetry-api
+      io.opentelemetry.semconv.trace.attributes.SemanticAttributes.class); // opentelemetry-semconv
   }
 
   /**
@@ -848,7 +849,7 @@ public class TableMapReduceUtil {
    * @param my_class        the class to find.
    * @param fs              the FileSystem with which to qualify the returned path.
    * @param packagedClasses a map of class name to path.
-   * @return a jar file that contains the class.
+   * @return a jar file that contains the class. n
    */
   private static Path findOrCreateJar(Class<?> my_class, FileSystem fs,
     Map<String, String> packagedClasses) throws IOException {
@@ -897,7 +898,7 @@ public class TableMapReduceUtil {
    * that is not the first thing on the class path that has a class with the same name. Looks first
    * on the classpath and then in the <code>packagedClasses</code> map.
    * @param my_class the class to find.
-   * @return a jar file that contains the class, or null.
+   * @return a jar file that contains the class, or null. n
    */
   private static String findContainingJar(Class<?> my_class, Map<String, String> packagedClasses)
     throws IOException {
