@@ -473,7 +473,7 @@ public class TestCellBasedHFileOutputFormat2 {
         LocatedFileStatus keyFileStatus = iterator.next();
         HFile.Reader reader =
           HFile.createReader(fs, keyFileStatus.getPath(), new CacheConfig(conf), true, conf);
-        HFileScanner scanner = reader.getScanner(false, false, false);
+        HFileScanner scanner = reader.getScanner(conf, false, false, false);
         scanner.seekTo();
         Cell cell = scanner.getCell();
         List<Tag> tagsFromCell =
@@ -776,7 +776,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureCompression(Configuration, HTableDescriptor)} and
    * {@link HFileOutputFormat2#createFamilyCompressionMap(Configuration)}. Tests that the
-   * compression map is correctly serialized into and deserialized from configuration
+   * compression map is correctly serialized into and deserialized from configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -839,7 +839,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureBloomType(HTableDescriptor, Configuration)} and
    * {@link HFileOutputFormat2#createFamilyBloomTypeMap(Configuration)}. Tests that the compression
-   * map is correctly serialized into and deserialized from configuration
+   * map is correctly serialized into and deserialized from configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -899,7 +899,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureBlockSize(HTableDescriptor, Configuration)} and
    * {@link HFileOutputFormat2#createFamilyBlockSizeMap(Configuration)}. Tests that the compression
-   * map is correctly serialized into and deserialized from configuration
+   * map is correctly serialized into and deserialized from configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -962,7 +962,7 @@ public class TestCellBasedHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#configureDataBlockEncoding(HTableDescriptor, Configuration)}
    * and {@link HFileOutputFormat2#createFamilyDataBlockEncodingMap(Configuration)}. Tests that the
-   * compression map is correctly serialized into and deserialized from configuration
+   * compression map is correctly serialized into and deserialized from configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
