@@ -67,6 +67,7 @@ import org.apache.hadoop.hbase.regionserver.wal.WALActionsListener;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.testclassification.VerySlowMapReduceTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.LauncherSecurityManager;
 import org.apache.hadoop.hbase.util.MapReduceExtendedCell;
 import org.apache.hadoop.hbase.wal.WAL;
@@ -114,7 +115,7 @@ public class TestCellBasedImportExport2 {
   private static String FQ_OUTPUT_DIR;
   private static final String EXPORT_BATCH_SIZE = "100";
 
-  private static final long now = System.currentTimeMillis();
+  private static final long now = EnvironmentEdgeManager.currentTime();
   private final TableName EXPORT_TABLE = TableName.valueOf("export_table");
   private final TableName IMPORT_TABLE = TableName.valueOf("import_table");
 
@@ -153,8 +154,8 @@ public class TestCellBasedImportExport2 {
   }
 
   /**
-   * Runs an export job with the specified command line args
-   * @return true if job completed successfully
+   * Runs an export job with the specified command line args n * @return true if job completed
+   * successfully nnn
    */
   protected boolean runExport(String[] args) throws Throwable {
     // need to make a copy of the configuration because to make sure different temp dirs are used.
@@ -167,8 +168,8 @@ public class TestCellBasedImportExport2 {
   }
 
   /**
-   * Runs an import job with the specified command line args
-   * @return true if job completed successfully
+   * Runs an import job with the specified command line args n * @return true if job completed
+   * successfully nnn
    */
   boolean runImport(String[] args) throws Throwable {
     // need to make a copy of the configuration because to make sure different temp dirs are used.
@@ -177,7 +178,7 @@ public class TestCellBasedImportExport2 {
   }
 
   /**
-   * Test simple replication case with column mapping
+   * Test simple replication case with column mapping n
    */
   @Test
   public void testSimpleCase() throws Throwable {
@@ -229,7 +230,7 @@ public class TestCellBasedImportExport2 {
   }
 
   /**
-   * Test export hbase:meta table
+   * Test export hbase:meta table n
    */
   @Test
   public void testMetaExport() throws Throwable {
@@ -239,7 +240,7 @@ public class TestCellBasedImportExport2 {
   }
 
   /**
-   * Test import data from 0.94 exported file
+   * Test import data from 0.94 exported file n
    */
   @Test
   public void testImport94Table() throws Throwable {
@@ -488,7 +489,7 @@ public class TestCellBasedImportExport2 {
   }
 
   /**
-   * Count the number of keyvalues in the specified table for the given timerange
+   * Count the number of keyvalues in the specified table for the given timerange nnn
    */
   private int getCount(Table table, Filter filter) throws IOException {
     Scan scan = new Scan();
@@ -534,7 +535,7 @@ public class TestCellBasedImportExport2 {
   @Test
   public void testExportScan() throws Exception {
     int version = 100;
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     long endTime = startTime + 1;
     String prefix = "row";
     String label_0 = "label_0";
@@ -728,7 +729,7 @@ public class TestCellBasedImportExport2 {
     }
 
     @Override
-    public void visitLogEntryBeforeWrite(WALKey logKey, WALEdit logEdit) {
+    public void visitLogEntryBeforeWrite(RegionInfo info, WALKey logKey, WALEdit logEdit) {
       if (
         logKey.getTableName().getNameAsString()
           .equalsIgnoreCase(this.regionInfo.getTable().getNameAsString()) && (!logEdit.isMetaEdit())
