@@ -111,12 +111,9 @@ import org.apache.hadoop.hdfs.protocol.HdfsFileStatus;
 import org.apache.hadoop.hdfs.server.blockmanagement.BlockStoragePolicySuite;
 import org.apache.hadoop.io.NullWritable;
 import org.apache.hadoop.mapreduce.Job;
-import org.apache.hadoop.mapreduce.JobContext;
 import org.apache.hadoop.mapreduce.Mapper;
-import org.apache.hadoop.mapreduce.OutputCommitter;
 import org.apache.hadoop.mapreduce.RecordWriter;
 import org.apache.hadoop.mapreduce.TaskAttemptContext;
-import org.apache.hadoop.mapreduce.lib.output.FileOutputCommitter;
 import org.apache.hadoop.mapreduce.lib.output.FileOutputFormat;
 import org.junit.ClassRule;
 import org.junit.Ignore;
@@ -464,7 +461,7 @@ public class TestHFileOutputFormat2 {
         LocatedFileStatus keyFileStatus = iterator.next();
         HFile.Reader reader =
           HFile.createReader(fs, keyFileStatus.getPath(), new CacheConfig(conf), true, conf);
-        HFileScanner scanner = reader.getScanner(false, false, false);
+        HFileScanner scanner = reader.getScanner(conf, false, false, false);
 
         kvCount += reader.getEntries();
         scanner.seekTo();
@@ -510,7 +507,7 @@ public class TestHFileOutputFormat2 {
         LocatedFileStatus keyFileStatus = iterator.next();
         HFile.Reader reader =
           HFile.createReader(fs, keyFileStatus.getPath(), new CacheConfig(conf), true, conf);
-        HFileScanner scanner = reader.getScanner(false, false, false);
+        HFileScanner scanner = reader.getScanner(conf, false, false, false);
         scanner.seekTo();
         Cell cell = scanner.getCell();
         List<Tag> tagsFromCell = PrivateCellUtil.getTags(cell);
@@ -813,7 +810,7 @@ public class TestHFileOutputFormat2 {
 
   /**
    * Test for {@link HFileOutputFormat2#createFamilyCompressionMap(Configuration)}. Tests that the
-   * family compression map is correctly serialized into and deserialized from configuration
+   * family compression map is correctly serialized into and deserialized from configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -875,7 +872,7 @@ public class TestHFileOutputFormat2 {
 
   /**
    * Test for {@link HFileOutputFormat2#createFamilyBloomTypeMap(Configuration)}. Tests that the
-   * family bloom type map is correctly serialized into and deserialized from configuration
+   * family bloom type map is correctly serialized into and deserialized from configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -934,7 +931,7 @@ public class TestHFileOutputFormat2 {
 
   /**
    * Test for {@link HFileOutputFormat2#createFamilyBlockSizeMap(Configuration)}. Tests that the
-   * family block size map is correctly serialized into and deserialized from configuration
+   * family block size map is correctly serialized into and deserialized from configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -997,7 +994,7 @@ public class TestHFileOutputFormat2 {
   /**
    * Test for {@link HFileOutputFormat2#createFamilyDataBlockEncodingMap(Configuration)}. Tests that
    * the family data block encoding map is correctly serialized into and deserialized from
-   * configuration
+   * configuration n
    */
   @Ignore("Goes zombie too frequently; needs work. See HBASE-14563")
   @Test
@@ -1586,59 +1583,6 @@ public class TestHFileOutputFormat2 {
     }
   }
 
-  @Test
-  public void itGetsWorkPathHadoop2() throws Exception {
-    Configuration conf = new Configuration(this.util.getConfiguration());
-    Job job = new Job(conf);
-    FileOutputCommitter committer =
-      new FileOutputCommitter(new Path("/test"), createTestTaskAttemptContext(job));
-    assertEquals(committer.getWorkPath(), HFileOutputFormat2.getWorkPath(committer));
-  }
-
-  @Test
-  public void itGetsWorkPathHadoo3() {
-    Hadoop3TestOutputCommitter committer = new Hadoop3TestOutputCommitter(new Path("/test"));
-    assertEquals(committer.getWorkPath(), HFileOutputFormat2.getWorkPath(committer));
-  }
-
-  static class Hadoop3TestOutputCommitter extends OutputCommitter {
-
-    Path path;
-
-    Hadoop3TestOutputCommitter(Path path) {
-      this.path = path;
-    }
-
-    public Path getWorkPath() {
-      return path;
-    }
-
-    @Override
-    public void setupJob(JobContext jobContext) throws IOException {
-
-    }
-
-    @Override
-    public void setupTask(TaskAttemptContext taskAttemptContext) throws IOException {
-
-    }
-
-    @Override
-    public boolean needsTaskCommit(TaskAttemptContext taskAttemptContext) throws IOException {
-      return false;
-    }
-
-    @Override
-    public void commitTask(TaskAttemptContext taskAttemptContext) throws IOException {
-
-    }
-
-    @Override
-    public void abortTask(TaskAttemptContext taskAttemptContext) throws IOException {
-
-    }
-  }
-
   private static class ConfigurationCaptorConnection implements Connection {
     private static final String UUID_KEY = "ConfigurationCaptorConnection.uuid";
 
