@@ -83,6 +83,7 @@ import org.apache.hadoop.hbase.regionserver.wal.WALActionsListener;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.testclassification.VerySlowMapReduceTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.LauncherSecurityManager;
 import org.apache.hadoop.hbase.wal.WAL;
 import org.apache.hadoop.hbase.wal.WALEdit;
@@ -130,7 +131,7 @@ public class TestImportExport {
   private static String FQ_OUTPUT_DIR;
   private static final String EXPORT_BATCH_SIZE = "100";
 
-  private static final long now = System.currentTimeMillis();
+  private static final long now = EnvironmentEdgeManager.currentTime();
   private final TableName EXPORT_TABLE = TableName.valueOf("export_table");
   private final TableName IMPORT_TABLE = TableName.valueOf("import_table");
   public static final byte TEST_TAG_TYPE = (byte) (Tag.CUSTOM_TAG_TYPE_RANGE + 1);
@@ -172,8 +173,8 @@ public class TestImportExport {
   }
 
   /**
-   * Runs an export job with the specified command line args
-   * @return true if job completed successfully
+   * Runs an export job with the specified command line args n * @return true if job completed
+   * successfully nnn
    */
   protected boolean runExport(String[] args) throws Throwable {
     // need to make a copy of the configuration because to make sure different temp dirs are used.
@@ -186,8 +187,8 @@ public class TestImportExport {
   }
 
   /**
-   * Runs an import job with the specified command line args
-   * @return true if job completed successfully
+   * Runs an import job with the specified command line args n * @return true if job completed
+   * successfully nnn
    */
   boolean runImport(String[] args) throws Throwable {
     // need to make a copy of the configuration because to make sure different temp dirs are used.
@@ -196,7 +197,7 @@ public class TestImportExport {
   }
 
   /**
-   * Test simple replication case with column mapping
+   * Test simple replication case with column mapping n
    */
   @Test
   public void testSimpleCase() throws Throwable {
@@ -248,7 +249,7 @@ public class TestImportExport {
   }
 
   /**
-   * Test export hbase:meta table
+   * Test export hbase:meta table n
    */
   @Test
   public void testMetaExport() throws Throwable {
@@ -258,7 +259,7 @@ public class TestImportExport {
   }
 
   /**
-   * Test import data from 0.94 exported file
+   * Test import data from 0.94 exported file n
    */
   @Test
   public void testImport94Table() throws Throwable {
@@ -509,7 +510,7 @@ public class TestImportExport {
   /**
    * Count the number of keyvalues in the specified table with the given filter
    * @param table the table to scan
-   * @return the number of keyvalues found
+   * @return the number of keyvalues found n
    */
   private int getCount(Table table, Filter filter) throws IOException {
     Scan scan = new Scan();
@@ -555,7 +556,7 @@ public class TestImportExport {
   @Test
   public void testExportScan() throws Exception {
     int version = 100;
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     long endTime = startTime + 1;
     String prefix = "row";
     String label_0 = "label_0";
@@ -749,7 +750,7 @@ public class TestImportExport {
     }
 
     @Override
-    public void visitLogEntryBeforeWrite(WALKey logKey, WALEdit logEdit) {
+    public void visitLogEntryBeforeWrite(RegionInfo info, WALKey logKey, WALEdit logEdit) {
       if (
         logKey.getTableName().getNameAsString()
           .equalsIgnoreCase(this.regionInfo.getTable().getNameAsString()) && (!logEdit.isMetaEdit())
