@@ -51,7 +51,6 @@ import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.io.hfile.CacheConfig;
 import org.apache.hadoop.hbase.io.hfile.HFile;
 import org.apache.hadoop.hbase.io.hfile.HFileScanner;
-import org.apache.hadoop.hbase.regionserver.NoSuchColumnFamilyException;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.VerySlowMapReduceTests;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -242,27 +241,6 @@ public class TestImportTsv implements Configurable {
       }, args));
   }
 
-  @Test
-  public void testMRNoMatchedColumnFamily() throws Exception {
-    util.createTable(tn, FAMILY);
-
-    String[] args = new String[] {
-      "-D" + ImportTsv.COLUMNS_CONF_KEY
-        + "=HBASE_ROW_KEY,FAM:A,FAM01_ERROR:A,FAM01_ERROR:B,FAM02_ERROR:C",
-      tn.getNameAsString(), "/inputFile" };
-    exception.expect(NoSuchColumnFamilyException.class);
-    assertEquals("running test job configuration failed.", 0,
-      ToolRunner.run(new Configuration(util.getConfiguration()), new ImportTsv() {
-        @Override
-        public int run(String[] args) throws Exception {
-          createSubmittableJob(getConf(), args);
-          return 0;
-        }
-      }, args));
-
-    util.deleteTable(tn);
-  }
-
   @Test
   public void testMRWithoutAnExistingTable() throws Exception {
     String[] args = new String[] { tn.getNameAsString(), "/inputFile" };
@@ -562,12 +540,12 @@ public class TestImportTsv implements Configurable {
    * Method returns the total KVs in given hfile
    * @param fs File System
    * @param p  HFile path
-   * @return KV count in the given hfile
+   * @return KV count in the given hfile n
    */
   private static int getKVCountFromHfile(FileSystem fs, Path p) throws IOException {
     Configuration conf = util.getConfiguration();
     HFile.Reader reader = HFile.createReader(fs, p, new CacheConfig(conf), true, conf);
-    HFileScanner scanner = reader.getScanner(false, false);
+    HFileScanner scanner = reader.getScanner(conf, false, false);
     scanner.seekTo();
     int count = 0;
     do {
