@@ -34,6 +34,7 @@ import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.MapReduceTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.LauncherSecurityManager;
 import org.apache.hadoop.mapreduce.Counter;
 import org.apache.hadoop.mapreduce.Job;
@@ -86,7 +87,7 @@ public class TestRowCounter {
   }
 
   /**
-   * Test a case when no column was specified in command line arguments.
+   * Test a case when no column was specified in command line arguments. n
    */
   @Test
   public void testRowCounterNoColumn() throws Exception {
@@ -95,7 +96,7 @@ public class TestRowCounter {
   }
 
   /**
-   * Test a case when the column specified in command line arguments is exclusive for few rows.
+   * Test a case when the column specified in command line arguments is exclusive for few rows. n
    */
   @Test
   public void testRowCounterExclusiveColumn() throws Exception {
@@ -105,7 +106,7 @@ public class TestRowCounter {
 
   /**
    * Test a case when the column specified in command line arguments is one for which the qualifier
-   * contains colons.
+   * contains colons. n
    */
   @Test
   public void testRowCounterColumnWithColonInQualifier() throws Exception {
@@ -115,7 +116,7 @@ public class TestRowCounter {
 
   /**
    * Test a case when the column specified in command line arguments is not part of first KV for a
-   * row.
+   * row. n
    */
   @Test
   public void testRowCounterHiddenColumn() throws Exception {
@@ -125,7 +126,7 @@ public class TestRowCounter {
 
   /**
    * Test a case when the column specified in command line arguments is exclusive for few rows and
-   * also a row range filter is specified
+   * also a row range filter is specified n
    */
   @Test
   public void testRowCounterColumnAndRowRange() throws Exception {
@@ -134,7 +135,7 @@ public class TestRowCounter {
   }
 
   /**
-   * Test a case when a range is specified with single range of start-end keys
+   * Test a case when a range is specified with single range of start-end keys n
    */
   @Test
   public void testRowCounterRowSingleRange() throws Exception {
@@ -143,7 +144,7 @@ public class TestRowCounter {
   }
 
   /**
-   * Test a case when a range is specified with single range with end key only
+   * Test a case when a range is specified with single range with end key only n
    */
   @Test
   public void testRowCounterRowSingleRangeUpperBound() throws Exception {
@@ -152,7 +153,7 @@ public class TestRowCounter {
   }
 
   /**
-   * Test a case when a range is specified with two ranges where one range is with end key only
+   * Test a case when a range is specified with two ranges where one range is with end key only n
    */
   @Test
   public void testRowCounterRowMultiRangeUpperBound() throws Exception {
@@ -161,7 +162,7 @@ public class TestRowCounter {
   }
 
   /**
-   * Test a case when a range is specified with multiple ranges of start-end keys
+   * Test a case when a range is specified with multiple ranges of start-end keys n
    */
   @Test
   public void testRowCounterRowMultiRange() throws Exception {
@@ -171,7 +172,7 @@ public class TestRowCounter {
 
   /**
    * Test a case when a range is specified with multiple ranges of start-end keys; one range is
-   * filled, another two are not
+   * filled, another two are not n
    */
   @Test
   public void testRowCounterRowMultiEmptyRange() throws Exception {
@@ -192,7 +193,7 @@ public class TestRowCounter {
   }
 
   /**
-   * Test a case when the timerange is specified with --starttime and --endtime options
+   * Test a case when the timerange is specified with --starttime and --endtime options n
    */
   @Test
   public void testRowCounterTimeRange() throws Exception {
@@ -208,12 +209,12 @@ public class TestRowCounter {
     Table table =
       TEST_UTIL.createTable(TableName.valueOf(TABLE_NAME_TS_RANGE), Bytes.toBytes(COL_FAM));
 
-    ts = System.currentTimeMillis();
+    ts = EnvironmentEdgeManager.currentTime();
     put1.addColumn(family, col1, ts, Bytes.toBytes("val1"));
     table.put(put1);
     Thread.sleep(100);
 
-    ts = System.currentTimeMillis();
+    ts = EnvironmentEdgeManager.currentTime();
     put2.addColumn(family, col1, ts, Bytes.toBytes("val2"));
     put3.addColumn(family, col1, ts, Bytes.toBytes("val3"));
     table.put(put2);
@@ -240,16 +241,16 @@ public class TestRowCounter {
   /**
    * Run the RowCounter map reduce job and verify the row count.
    * @param args          the command line arguments to be used for rowcounter job.
-   * @param expectedCount the expected row count (result of map reduce job).
+   * @param expectedCount the expected row count (result of map reduce job). n
    */
   private void runRowCount(String[] args, int expectedCount) throws Exception {
     RowCounter rowCounter = new RowCounter();
     rowCounter.setConf(TEST_UTIL.getConfiguration());
     args = Arrays.copyOf(args, args.length + 1);
     args[args.length - 1] = "--expectedCount=" + expectedCount;
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     int result = rowCounter.run(args);
-    long duration = System.currentTimeMillis() - start;
+    long duration = EnvironmentEdgeManager.currentTime() - start;
     LOG.debug("row count duration (ms): " + duration);
     assertTrue(result == 0);
   }
@@ -262,9 +263,9 @@ public class TestRowCounter {
    */
   private void runCreateSubmittableJobWithArgs(String[] args, int expectedCount) throws Exception {
     Job job = RowCounter.createSubmittableJob(TEST_UTIL.getConfiguration(), args);
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     job.waitForCompletion(true);
-    long duration = System.currentTimeMillis() - start;
+    long duration = EnvironmentEdgeManager.currentTime() - start;
     LOG.debug("row count duration (ms): " + duration);
     assertTrue(job.isSuccessful());
     Counter counter = job.getCounters().findCounter(RowCounter.RowCounterMapper.Counters.ROWS);
@@ -401,12 +402,12 @@ public class TestRowCounter {
     // clean up content of TABLE_NAME
     Table table = TEST_UTIL.createTable(TableName.valueOf(tableName), Bytes.toBytes(COL_FAM));
 
-    ts = System.currentTimeMillis();
+    ts = EnvironmentEdgeManager.currentTime();
     put1.addColumn(family, col1, ts, Bytes.toBytes("val1"));
     table.put(put1);
     Thread.sleep(100);
 
-    ts = System.currentTimeMillis();
+    ts = EnvironmentEdgeManager.currentTime();
     put2.addColumn(family, col1, ts, Bytes.toBytes("val2"));
     put3.addColumn(family, col1, ts, Bytes.toBytes("val3"));
     table.put(put2);
@@ -432,7 +433,7 @@ public class TestRowCounter {
 
   /**
    * Writes TOTAL_ROWS number of distinct rows in to the table. Few rows have two columns, Few have
-   * one.
+   * one. nn
    */
   private static void writeRows(Table table, int totalRows, int rowsWithOneCol) throws IOException {
     final byte[] family = Bytes.toBytes(COL_FAM);
