@@ -18,24 +18,18 @@
 package org.apache.hadoop.hbase.rest;
 
 import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Base64;
-import java.util.Base64.Decoder;
-import java.util.List;
-import org.apache.hadoop.hbase.client.Result;
-import org.apache.hadoop.hbase.filter.Filter;
-import org.apache.hadoop.hbase.filter.ParseFilter;
+import org.apache.hadoop.hbase.Cell;
+import org.apache.hadoop.hbase.CellUtil;
+import org.apache.hadoop.hbase.rest.model.CellModel;
 import org.apache.hadoop.hbase.rest.model.CellSetModel;
+import org.apache.hadoop.hbase.rest.model.RowModel;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.hbase.thirdparty.javax.ws.rs.Encoded;
 import org.apache.hbase.thirdparty.javax.ws.rs.GET;
-import org.apache.hbase.thirdparty.javax.ws.rs.HeaderParam;
 import org.apache.hbase.thirdparty.javax.ws.rs.Produces;
-import org.apache.hbase.thirdparty.javax.ws.rs.QueryParam;
 import org.apache.hbase.thirdparty.javax.ws.rs.core.Context;
 import org.apache.hbase.thirdparty.javax.ws.rs.core.MultivaluedMap;
 import org.apache.hbase.thirdparty.javax.ws.rs.core.Response;
@@ -45,14 +39,12 @@ import org.apache.hbase.thirdparty.javax.ws.rs.core.UriInfo;
 public class MultiRowResource extends ResourceBase implements Constants {
   private static final Logger LOG = LoggerFactory.getLogger(MultiRowResource.class);
 
-  private static final Decoder base64Urldecoder = Base64.getUrlDecoder();
-
   TableResource tableResource;
   Integer versions = null;
   String[] columns = null;
 
   /**
-   * Constructor
+   * Constructor nn * @throws java.io.IOException
    */
   public MultiRowResource(TableResource tableResource, String versions, String columnsStr)
     throws IOException {
@@ -71,35 +63,14 @@ public class MultiRowResource extends ResourceBase implements Constants {
 
   @GET
   @Produces({ MIMETYPE_XML, MIMETYPE_JSON, MIMETYPE_PROTOBUF, MIMETYPE_PROTOBUF_IETF })
-  public Response get(final @Context UriInfo uriInfo,
-    final @HeaderParam("Encoding") String keyEncodingHeader,
-    @QueryParam(Constants.FILTER_B64) @Encoded String paramFilterB64,
-    @QueryParam(Constants.FILTER) String paramFilter) {
+  public Response get(final @Context UriInfo uriInfo) {
     MultivaluedMap<String, String> params = uriInfo.getQueryParameters();
-    String keyEncoding = (keyEncodingHeader != null)
-      ? keyEncodingHeader
-      : params.getFirst(KEY_ENCODING_QUERY_PARAM_NAME);
 
     servlet.getMetrics().incrementRequests(1);
-
-    byte[] filterBytes = null;
-    if (paramFilterB64 != null) {
-      filterBytes = base64Urldecoder.decode(paramFilterB64);
-    } else if (paramFilter != null) {
-      filterBytes = paramFilter.getBytes();
-    }
-
     try {
-      Filter parsedParamFilter = null;
-      if (filterBytes != null) {
-        // Note that this is a completely different representation of the filters
-        // than the JSON one used in the /table/scanner endpoint
-        ParseFilter pf = new ParseFilter();
-        parsedParamFilter = pf.parseFilterString(filterBytes);
-      }
-      List<RowSpec> rowSpecs = new ArrayList<>();
+      CellSetModel model = new CellSetModel();
       for (String rk : params.get(ROW_KEYS_PARAM_NAME)) {
-        RowSpec rowSpec = new RowSpec(rk, keyEncoding);
+        RowSpec rowSpec = new RowSpec(rk);
 
         if (this.versions != null) {
           rowSpec.setMaxVersions(this.versions);
@@ -110,19 +81,24 @@ public class MultiRowResource extends ResourceBase implements Constants {
             rowSpec.addColumn(Bytes.toBytes(this.columns[i]));
           }
         }
-        rowSpecs.add(rowSpec);
-      }
 
-      MultiRowResultReader reader = new MultiRowResultReader(this.tableResource.getName(), rowSpecs,
-        parsedParamFilter, !params.containsKey(NOCACHE_PARAM_NAME));
-
-      CellSetModel model = new CellSetModel();
-      for (Result r : reader.getResults()) {
-        if (r.isEmpty()) {
-          continue;
+        ResultGenerator generator = ResultGenerator.fromRowSpec(this.tableResource.getName(),
+          rowSpec, null, !params.containsKey(NOCACHE_PARAM_NAME));
+        Cell value = null;
+        RowModel rowModel = new RowModel(rowSpec.getRow());
+        if (generator.hasNext()) {
+          while ((value = generator.next()) != null) {
+            rowModel.addCell(new CellModel(CellUtil.cloneFamily(value),
+              CellUtil.cloneQualifier(value), value.getTimestamp(), CellUtil.cloneValue(value)));
+          }
+          model.addRow(rowModel);
+        } else {
+          if (LOG.isTraceEnabled()) {
+            LOG.trace("The row : " + rk + " not found in the table.");
+          }
         }
-        model.addRow(RestUtil.createRowModelFromResult(r));
       }
+
       if (model.getRows().isEmpty()) {
         // If no rows found.
         servlet.getMetrics().incrementFailedGetRequests(1);
