@@ -53,8 +53,6 @@ public class RESTServlet implements Constants {
   }
 
   /** Returns the RESTServlet singleton instance */
-  @edu.umd.cs.findbugs.annotations.SuppressWarnings(value = "MS_EXPOSE_REP",
-      justification = "singleton pattern")
   public synchronized static RESTServlet getInstance() {
     assert (INSTANCE != null);
     return INSTANCE;
@@ -68,10 +66,8 @@ public class RESTServlet implements Constants {
   /**
    * @param conf         Existing configuration to use in rest servlet
    * @param userProvider the login user provider
-   * @return the RESTServlet singleton instance
+   * @return the RESTServlet singleton instance n
    */
-  @edu.umd.cs.findbugs.annotations.SuppressWarnings(value = "MS_EXPOSE_REP",
-      justification = "singleton pattern")
   public synchronized static RESTServlet getInstance(Configuration conf, UserProvider userProvider)
     throws IOException {
     if (INSTANCE == null) {
@@ -90,7 +86,7 @@ public class RESTServlet implements Constants {
   /**
    * Constructor with existing configuration
    * @param conf         existing configuration
-   * @param userProvider the login user provider
+   * @param userProvider the login user provider n
    */
   RESTServlet(final Configuration conf, final UserProvider userProvider) throws IOException {
     this.realUser = userProvider.getCurrent().getUGI();
