@@ -18,16 +18,15 @@
 package org.apache.hadoop.hbase.rest.client;
 
 import java.io.BufferedInputStream;
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.nio.file.Files;
-import java.nio.file.Path;
-import java.security.GeneralSecurityException;
 import java.security.KeyManagementException;
 import java.security.KeyStore;
 import java.security.KeyStoreException;
@@ -37,22 +36,17 @@ import java.util.Collections;
 import java.util.Map;
 import java.util.Optional;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ThreadLocalRandom;
 import javax.net.ssl.SSLContext;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.rest.Constants;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.security.authentication.client.AuthenticatedURL;
 import org.apache.hadoop.security.authentication.client.AuthenticationException;
 import org.apache.hadoop.security.authentication.client.KerberosAuthenticator;
-import org.apache.hadoop.security.ssl.SSLFactory;
-import org.apache.hadoop.security.ssl.SSLFactory.Mode;
 import org.apache.http.Header;
-import org.apache.http.HttpHeaders;
 import org.apache.http.HttpResponse;
 import org.apache.http.HttpStatus;
-import org.apache.http.auth.AuthScope;
-import org.apache.http.auth.UsernamePasswordCredentials;
 import org.apache.http.client.HttpClient;
 import org.apache.http.client.config.RequestConfig;
 import org.apache.http.client.methods.HttpDelete;
@@ -61,12 +55,9 @@ import org.apache.http.client.methods.HttpHead;
 import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpPut;
 import org.apache.http.client.methods.HttpUriRequest;
-import org.apache.http.client.protocol.HttpClientContext;
-import org.apache.http.entity.ByteArrayEntity;
-import org.apache.http.impl.client.BasicCredentialsProvider;
+import org.apache.http.entity.InputStreamEntity;
 import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.impl.client.HttpClients;
-import org.apache.http.impl.cookie.BasicClientCookie;
 import org.apache.http.message.BasicHeader;
 import org.apache.http.ssl.SSLContexts;
 import org.apache.http.util.EntityUtils;
@@ -74,9 +65,6 @@ import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.hbase.thirdparty.com.google.common.io.ByteStreams;
-import org.apache.hbase.thirdparty.com.google.common.io.Closeables;
-
 /**
  * A wrapper around HttpClient which provides some useful function and semantics for interacting
  * with the REST gateway.
@@ -89,17 +77,12 @@ public class Client {
 
   private HttpClient httpClient;
   private Cluster cluster;
-  private Integer lastNodeId;
-  private boolean sticky = false;
   private Configuration conf;
   private boolean sslEnabled;
   private HttpResponse resp;
   private HttpGet httpGet = null;
-  private HttpClientContext stickyContext = null;
-  private BasicCredentialsProvider provider;
-  private Optional<KeyStore> trustStore;
+
   private Map<String, String> extraHeaders;
-  private KerberosAuthenticator authenticator;
 
   private static final String AUTH_COOKIE = "hadoop.auth";
   private static final String AUTH_COOKIE_EQ = AUTH_COOKIE + "=";
@@ -112,13 +95,11 @@ public class Client {
     this(null);
   }
 
-  private void initialize(Cluster cluster, Configuration conf, boolean sslEnabled, boolean sticky,
-    Optional<KeyStore> trustStore, Optional<String> userName, Optional<String> password,
-    Optional<String> bearerToken) {
+  private void initialize(Cluster cluster, Configuration conf, boolean sslEnabled,
+    Optional<KeyStore> trustStore) {
     this.cluster = cluster;
     this.conf = conf;
     this.sslEnabled = sslEnabled;
-    this.trustStore = trustStore;
     extraHeaders = new ConcurrentHashMap<>();
     String clspath = System.getProperty("java.class.path");
     LOG.debug("classpath " + clspath);
@@ -150,41 +131,11 @@ public class Client {
       }
     }
 
-    if (userName.isPresent() && password.isPresent()) {
-      // We want to stick to the old very limited authentication and session handling when sticky is
-      // not set
-      // to preserve backwards compatibility
-      if (!sticky) {
-        throw new IllegalArgumentException("BASIC auth is only implemented when sticky is set");
-      }
-      provider = new BasicCredentialsProvider();
-      // AuthScope.ANY is required for pre-emptive auth. We only ever use a single auth method
-      // anyway.
-      AuthScope anyAuthScope = AuthScope.ANY;
-      this.provider.setCredentials(anyAuthScope,
-        new UsernamePasswordCredentials(userName.get(), password.get()));
-    }
-
-    if (bearerToken.isPresent()) {
-      // We want to stick to the old very limited authentication and session handling when sticky is
-      // not set
-      // to preserve backwards compatibility
-      if (!sticky) {
-        throw new IllegalArgumentException("BEARER auth is only implemented when sticky is set");
-      }
-      // We could also put the header into the context or connection, but that would have the same
-      // effect.
-      extraHeaders.put(HttpHeaders.AUTHORIZATION, "Bearer " + bearerToken.get());
-    }
-
     this.httpClient = httpClientBuilder.build();
-    setSticky(sticky);
   }
 
   /**
-   * Constructor This constructor will create an object using the old faulty load balancing logic.
-   * When specifying multiple servers in the cluster object, it is highly recommended to call
-   * setSticky() on the created client, or use the preferred constructor instead.
+   * Constructor
    * @param cluster the cluster definition
    */
   public Client(Cluster cluster) {
@@ -192,35 +143,26 @@ public class Client {
   }
 
   /**
-   * Constructor This constructor will create an object using the old faulty load balancing logic.
-   * When specifying multiple servers in the cluster object, it is highly recommended to call
-   * setSticky() on the created client, or use the preferred constructor instead.
+   * Constructor
    * @param cluster    the cluster definition
    * @param sslEnabled enable SSL or not
    */
   public Client(Cluster cluster, boolean sslEnabled) {
-    initialize(cluster, HBaseConfiguration.create(), sslEnabled, false, Optional.empty(),
-      Optional.empty(), Optional.empty(), Optional.empty());
+    initialize(cluster, HBaseConfiguration.create(), sslEnabled, Optional.empty());
   }
 
   /**
-   * Constructor This constructor will create an object using the old faulty load balancing logic.
-   * When specifying multiple servers in the cluster object, it is highly recommended to call
-   * setSticky() on the created client, or use the preferred constructor instead.
+   * Constructor
    * @param cluster    the cluster definition
    * @param conf       Configuration
    * @param sslEnabled enable SSL or not
    */
   public Client(Cluster cluster, Configuration conf, boolean sslEnabled) {
-    initialize(cluster, conf, sslEnabled, false, Optional.empty(), Optional.empty(),
-      Optional.empty(), Optional.empty());
+    initialize(cluster, conf, sslEnabled, Optional.empty());
   }
 
   /**
-   * Constructor, allowing to define custom trust store (only for SSL connections) This constructor
-   * will create an object using the old faulty load balancing logic. When specifying multiple
-   * servers in the cluster object, it is highly recommended to call setSticky() on the created
-   * client, or use the preferred constructor instead.
+   * Constructor, allowing to define custom trust store (only for SSL connections)
    * @param cluster            the cluster definition
    * @param trustStorePath     custom trust store to use for SSL connections
    * @param trustStorePassword password to use for custom trust store
@@ -233,32 +175,9 @@ public class Client {
   }
 
   /**
-   * Constructor that accepts an optional trustStore and authentication information for either BASIC
-   * or BEARER authentication in sticky mode, which does not use the old faulty load balancing
-   * logic, and enables correct session handling. If neither userName/password, nor the bearer token
-   * is specified, the client falls back to SPNEGO auth. The loadTrustsore static method can be used
-   * to load a local trustStore file. This is the preferred constructor to use.
-   * @param cluster     the cluster definition
-   * @param conf        HBase/Hadoop configuration
-   * @param sslEnabled  use HTTPS
-   * @param trustStore  the optional trustStore object
-   * @param userName    for BASIC auth
-   * @param password    for BASIC auth
-   * @param bearerToken for BEAERER auth
-   */
-  public Client(Cluster cluster, Configuration conf, boolean sslEnabled,
-    Optional<KeyStore> trustStore, Optional<String> userName, Optional<String> password,
-    Optional<String> bearerToken) {
-    initialize(cluster, conf, sslEnabled, true, trustStore, userName, password, bearerToken);
-  }
-
-  /**
-   * Constructor, allowing to define custom trust store (only for SSL connections). This constructor
-   * will create an object using the old faulty load balancing logic. When specifying multiple
-   * servers in the cluster object, it is highly recommended to call setSticky() on the created
-   * client, or use the preferred constructor instead.
+   * Constructor, allowing to define custom trust store (only for SSL connections)
    * @param cluster            the cluster definition
-   * @param conf               HBase/Hadoop Configuration
+   * @param conf               Configuration
    * @param trustStorePath     custom trust store to use for SSL connections
    * @param trustStorePassword password to use for custom trust store
    * @param trustStoreType     type of custom trust store
@@ -266,19 +185,8 @@ public class Client {
    */
   public Client(Cluster cluster, Configuration conf, String trustStorePath,
     Optional<String> trustStorePassword, Optional<String> trustStoreType) {
-    KeyStore trustStore = loadTruststore(trustStorePath, trustStorePassword, trustStoreType);
-    initialize(cluster, conf, true, false, Optional.of(trustStore), Optional.empty(),
-      Optional.empty(), Optional.empty());
-  }
 
-  /**
-   * Loads a trustStore from the local fileSystem. Can be used to load the trustStore for the
-   * preferred constructor.
-   */
-  public static KeyStore loadTruststore(String trustStorePath, Optional<String> trustStorePassword,
-    Optional<String> trustStoreType) {
-
-    char[] truststorePassword = trustStorePassword.map(String::toCharArray).orElse(null);
+    char[] password = trustStorePassword.map(String::toCharArray).orElse(null);
     String type = trustStoreType.orElse(KeyStore.getDefaultType());
 
     KeyStore trustStore;
@@ -289,12 +197,13 @@ public class Client {
     }
     try (InputStream inputStream =
       new BufferedInputStream(Files.newInputStream(new File(trustStorePath).toPath()))) {
-      trustStore.load(inputStream, truststorePassword);
+      trustStore.load(inputStream, password);
     } catch (CertificateException | NoSuchAlgorithmException | IOException e) {
       throw new ClientTrustStoreInitializationException("Trust store load error: " + trustStorePath,
         e);
     }
-    return trustStore;
+
+    initialize(cluster, conf, true, Optional.of(trustStore));
   }
 
   /**
@@ -338,17 +247,15 @@ public class Client {
   }
 
   /**
-   * Execute a transaction method given only the path. If sticky is false: Will select at random one
-   * of the members of the supplied cluster definition and iterate through the list until a
-   * transaction can be successfully completed. The definition of success here is a complete HTTP
-   * transaction, irrespective of result code. If sticky is true: For the first request it will
-   * select a random one of the members of the supplied cluster definition. For subsequent requests
-   * it will use the same member, and it will not automatically re-try if the call fails.
+   * Execute a transaction method given only the path. Will select at random one of the members of
+   * the supplied cluster definition and iterate through the list until a transaction can be
+   * successfully completed. The definition of success here is a complete HTTP transaction,
+   * irrespective of result code.
    * @param cluster the cluster definition
    * @param method  the transaction method
    * @param headers HTTP header values to send
    * @param path    the properly urlencoded path
-   * @return the HTTP response code
+   * @return the HTTP response code n
    */
   public HttpResponse executePathOnly(Cluster cluster, HttpUriRequest method, Header[] headers,
     String path) throws IOException {
@@ -356,12 +263,10 @@ public class Client {
     if (cluster.nodes.size() < 1) {
       throw new IOException("Cluster is empty");
     }
-    if (lastNodeId == null || !sticky) {
-      lastNodeId = ThreadLocalRandom.current().nextInt(cluster.nodes.size());
-    }
-    int start = lastNodeId;
+    int start = (int) Math.round((cluster.nodes.size() - 1) * Math.random());
+    int i = start;
     do {
-      cluster.lastHost = cluster.nodes.get(lastNodeId);
+      cluster.lastHost = cluster.nodes.get(i);
       try {
         StringBuilder sb = new StringBuilder();
         if (sslEnabled) {
@@ -395,11 +300,7 @@ public class Client {
       } catch (URISyntaxException use) {
         lastException = new IOException(use);
       }
-      if (!sticky) {
-        lastNodeId = (++lastNodeId) % cluster.nodes.size();
-      }
-      // Do not retry if sticky. Let the caller handle the error.
-    } while (!sticky && lastNodeId != start);
+    } while (++i != start && i < cluster.nodes.size());
     throw lastException;
   }
 
@@ -408,7 +309,7 @@ public class Client {
    * @param method  the transaction method
    * @param headers HTTP header values to send
    * @param uri     a properly urlencoded URI
-   * @return the HTTP response code
+   * @return the HTTP response code n
    */
   public HttpResponse executeURI(HttpUriRequest method, Header[] headers, String uri)
     throws IOException {
@@ -421,29 +322,17 @@ public class Client {
         method.addHeader(header);
       }
     }
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     if (resp != null) EntityUtils.consumeQuietly(resp.getEntity());
-    if (stickyContext != null) {
-      resp = httpClient.execute(method, stickyContext);
-    } else {
-      resp = httpClient.execute(method);
-    }
+    resp = httpClient.execute(method);
     if (resp.getStatusLine().getStatusCode() == HttpStatus.SC_UNAUTHORIZED) {
       // Authentication error
       LOG.debug("Performing negotiation with the server.");
-      try {
-        negotiate(method, uri);
-      } catch (GeneralSecurityException e) {
-        throw new IOException(e);
-      }
-      if (stickyContext != null) {
-        resp = httpClient.execute(method, stickyContext);
-      } else {
-        resp = httpClient.execute(method);
-      }
+      negotiate(method, uri);
+      resp = httpClient.execute(method);
     }
 
-    long endTime = System.currentTimeMillis();
+    long endTime = EnvironmentEdgeManager.currentTime();
     if (LOG.isTraceEnabled()) {
       LOG.trace(method.getMethod() + " " + uri + " " + resp.getStatusLine().getStatusCode() + " "
         + resp.getStatusLine().getReasonPhrase() + " in " + (endTime - startTime) + " ms");
@@ -459,7 +348,7 @@ public class Client {
    * @param method  the HTTP method
    * @param headers HTTP header values to send
    * @param path    the properly urlencoded path or URI
-   * @return the HTTP response code
+   * @return the HTTP response code n
    */
   public HttpResponse execute(Cluster cluster, HttpUriRequest method, Header[] headers, String path)
     throws IOException {
@@ -475,58 +364,19 @@ public class Client {
    * @param uri    the String to parse as a URL.
    * @throws IOException if unknown protocol is found.
    */
-  private void negotiate(HttpUriRequest method, String uri)
-    throws IOException, GeneralSecurityException {
+  private void negotiate(HttpUriRequest method, String uri) throws IOException {
     try {
       AuthenticatedURL.Token token = new AuthenticatedURL.Token();
-      if (authenticator == null) {
-        authenticator = new KerberosAuthenticator();
-        if (trustStore.isPresent()) {
-          // The authenticator does not use Apache HttpClient, so we need to
-          // configure it separately to use the specified trustStore
-          Configuration sslConf = setupTrustStoreForHadoop(trustStore.get());
-          SSLFactory sslFactory = new SSLFactory(Mode.CLIENT, sslConf);
-          sslFactory.init();
-          authenticator.setConnectionConfigurator(sslFactory);
-        }
-      }
-      URL url = new URL(uri);
-      authenticator.authenticate(url, token);
-      if (sticky) {
-        BasicClientCookie authCookie = new BasicClientCookie("hadoop.auth", token.toString());
-        // Hadoop eats the domain even if set by server
-        authCookie.setDomain(url.getHost());
-        stickyContext.getCookieStore().addCookie(authCookie);
-      } else {
-        // session cookie is NOT set for backwards compatibility for non-sticky mode
-        // Inject the obtained negotiated token in the method cookie
-        // This is only done for this single request, the next one will trigger a new SPENGO
-        // handshake
-        injectToken(method, token);
-      }
+      KerberosAuthenticator authenticator = new KerberosAuthenticator();
+      authenticator.authenticate(new URL(uri), token);
+      // Inject the obtained negotiated token in the method cookie
+      injectToken(method, token);
     } catch (AuthenticationException e) {
       LOG.error("Failed to negotiate with the server.", e);
       throw new IOException(e);
     }
   }
 
-  private Configuration setupTrustStoreForHadoop(KeyStore trustStore)
-    throws IOException, KeyStoreException, NoSuchAlgorithmException, CertificateException {
-    Path tmpDirPath = Files.createTempDirectory("hbase_rest_client_truststore");
-    File trustStoreFile = tmpDirPath.resolve("truststore.jks").toFile();
-    // Shouldn't be needed with the secure temp dir, but let's generate a password anyway
-    String password = Double.toString(Math.random());
-    try (FileOutputStream fos = new FileOutputStream(trustStoreFile)) {
-      trustStore.store(fos, password.toCharArray());
-    }
-
-    Configuration sslConf = new Configuration();
-    // Type is the Java default, we use the same JVM to read this back
-    sslConf.set("ssl.client.keystore.location", trustStoreFile.getAbsolutePath());
-    sslConf.set("ssl.client.keystore.password", password);
-    return sslConf;
-  }
-
   /**
    * Helper method that injects an authentication token to send with the method.
    * @param method method to inject the authentication token into.
@@ -554,42 +404,10 @@ public class Client {
     this.cluster = cluster;
   }
 
-  /**
-   * The default behaviour is load balancing by sending each request to a random host. This DOES NOT
-   * work with scans, which have state on the REST servers. Make sure sticky is set to true before
-   * attempting Scan related operations if more than one host is defined in the cluster.
-   * @return whether subsequent requests will use the same host
-   */
-  public boolean isSticky() {
-    return sticky;
-  }
-
-  /**
-   * The default behaviour is load balancing by sending each request to a random host. This DOES NOT
-   * work with scans, which have state on the REST servers. Set sticky to true before attempting
-   * Scan related operations if more than one host is defined in the cluster. Nodes must not be
-   * added or removed from the Cluster object while sticky is true. Setting the sticky flag also
-   * enables session handling, which eliminates the need to re-authenticate each request, and lets
-   * the client handle any other cookies (like the sticky cookie set by load balancers) correctly.
-   * @param sticky whether subsequent requests will use the same host
-   */
-  public void setSticky(boolean sticky) {
-    lastNodeId = null;
-    if (sticky) {
-      stickyContext = new HttpClientContext();
-      if (provider != null) {
-        stickyContext.setCredentialsProvider(provider);
-      }
-    } else {
-      stickyContext = null;
-    }
-    this.sticky = sticky;
-  }
-
   /**
    * Send a HEAD request
    * @param path the path or URI
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response head(String path) throws IOException {
     return head(cluster, path, null);
@@ -600,7 +418,7 @@ public class Client {
    * @param cluster the cluster definition
    * @param path    the path or URI
    * @param headers the HTTP headers to include in the request
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response head(Cluster cluster, String path, Header[] headers) throws IOException {
     HttpHead method = new HttpHead(path);
@@ -615,7 +433,7 @@ public class Client {
   /**
    * Send a GET request
    * @param path the path or URI
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response get(String path) throws IOException {
     return get(cluster, path);
@@ -625,7 +443,7 @@ public class Client {
    * Send a GET request
    * @param cluster the cluster definition
    * @param path    the path or URI
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response get(Cluster cluster, String path) throws IOException {
     return get(cluster, path, EMPTY_HEADER_ARRAY);
@@ -635,7 +453,7 @@ public class Client {
    * Send a GET request
    * @param path   the path or URI
    * @param accept Accept header value
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response get(String path, String accept) throws IOException {
     return get(cluster, path, accept);
@@ -646,7 +464,7 @@ public class Client {
    * @param cluster the cluster definition
    * @param path    the path or URI
    * @param accept  Accept header value
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response get(Cluster cluster, String path, String accept) throws IOException {
     Header[] headers = new Header[1];
@@ -658,7 +476,7 @@ public class Client {
    * Send a GET request
    * @param path    the path or URI
    * @param headers the HTTP headers to include in the request, <tt>Accept</tt> must be supplied
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response get(String path, Header[] headers) throws IOException {
     return get(cluster, path, headers);
@@ -674,29 +492,28 @@ public class Client {
    * @return The response body, null if body is empty
    * @throws IOException If an I/O (transport) problem occurs while obtaining the response body.
    */
+  @edu.umd.cs.findbugs.annotations.SuppressWarnings(value = "NP_LOAD_OF_KNOWN_NULL_VALUE",
+      justification = "null is possible return value")
   public static byte[] getResponseBody(HttpResponse resp) throws IOException {
-    if (resp.getEntity() == null) {
-      return null;
-    }
-    InputStream instream = resp.getEntity().getContent();
-    if (instream == null) {
-      return null;
-    }
-    try {
-      long contentLength = resp.getEntity().getContentLength();
-      if (contentLength > Integer.MAX_VALUE) {
-        // guard integer cast from overflow
-        throw new IOException("Content too large to be buffered: " + contentLength + " bytes");
+    if (resp.getEntity() == null) return null;
+    try (InputStream instream = resp.getEntity().getContent()) {
+      if (instream != null) {
+        long contentLength = resp.getEntity().getContentLength();
+        if (contentLength > Integer.MAX_VALUE) {
+          // guard integer cast from overflow
+          throw new IOException("Content too large to be buffered: " + contentLength + " bytes");
+        }
+        ByteArrayOutputStream outstream =
+          new ByteArrayOutputStream(contentLength > 0 ? (int) contentLength : 4 * 1024);
+        byte[] buffer = new byte[4096];
+        int len;
+        while ((len = instream.read(buffer)) > 0) {
+          outstream.write(buffer, 0, len);
+        }
+        outstream.close();
+        return outstream.toByteArray();
       }
-      if (contentLength > 0) {
-        byte[] content = new byte[(int) contentLength];
-        ByteStreams.readFully(instream, content);
-        return content;
-      } else {
-        return ByteStreams.toByteArray(instream);
-      }
-    } finally {
-      Closeables.closeQuietly(instream);
+      return null;
     }
   }
 
@@ -705,7 +522,7 @@ public class Client {
    * @param c       the cluster definition
    * @param path    the path or URI
    * @param headers the HTTP headers to include in the request
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response get(Cluster c, String path, Header[] headers) throws IOException {
     if (httpGet != null) {
@@ -722,7 +539,7 @@ public class Client {
    * @param path        the path or URI
    * @param contentType the content MIME type
    * @param content     the content bytes
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response put(String path, String contentType, byte[] content) throws IOException {
     return put(cluster, path, contentType, content);
@@ -734,7 +551,7 @@ public class Client {
    * @param contentType the content MIME type
    * @param content     the content bytes
    * @param extraHdr    extra Header to send
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response put(String path, String contentType, byte[] content, Header extraHdr)
     throws IOException {
@@ -783,7 +600,7 @@ public class Client {
    * @param path    the path or URI
    * @param headers the HTTP headers to include, <tt>Content-Type</tt> must be supplied
    * @param content the content bytes
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response put(String path, Header[] headers, byte[] content) throws IOException {
     return put(cluster, path, headers, content);
@@ -795,13 +612,13 @@ public class Client {
    * @param path    the path or URI
    * @param headers the HTTP headers to include, <tt>Content-Type</tt> must be supplied
    * @param content the content bytes
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response put(Cluster cluster, String path, Header[] headers, byte[] content)
     throws IOException {
     HttpPut method = new HttpPut(path);
     try {
-      method.setEntity(new ByteArrayEntity(content));
+      method.setEntity(new InputStreamEntity(new ByteArrayInputStream(content), content.length));
       HttpResponse resp = execute(cluster, method, headers, path);
       headers = resp.getAllHeaders();
       content = getResponseBody(resp);
@@ -816,7 +633,7 @@ public class Client {
    * @param path        the path or URI
    * @param contentType the content MIME type
    * @param content     the content bytes
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response post(String path, String contentType, byte[] content) throws IOException {
     return post(cluster, path, contentType, content);
@@ -828,7 +645,7 @@ public class Client {
    * @param contentType the content MIME type
    * @param content     the content bytes
    * @param extraHdr    additional Header to send
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response post(String path, String contentType, byte[] content, Header extraHdr)
     throws IOException {
@@ -877,7 +694,7 @@ public class Client {
    * @param path    the path or URI
    * @param headers the HTTP headers to include, <tt>Content-Type</tt> must be supplied
    * @param content the content bytes
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response post(String path, Header[] headers, byte[] content) throws IOException {
     return post(cluster, path, headers, content);
@@ -889,13 +706,13 @@ public class Client {
    * @param path    the path or URI
    * @param headers the HTTP headers to include, <tt>Content-Type</tt> must be supplied
    * @param content the content bytes
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response post(Cluster cluster, String path, Header[] headers, byte[] content)
     throws IOException {
     HttpPost method = new HttpPost(path);
     try {
-      method.setEntity(new ByteArrayEntity(content));
+      method.setEntity(new InputStreamEntity(new ByteArrayInputStream(content), content.length));
       HttpResponse resp = execute(cluster, method, headers, path);
       headers = resp.getAllHeaders();
       content = getResponseBody(resp);
@@ -908,7 +725,7 @@ public class Client {
   /**
    * Send a DELETE request
    * @param path the path or URI
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response delete(String path) throws IOException {
     return delete(cluster, path);
@@ -918,7 +735,7 @@ public class Client {
    * Send a DELETE request
    * @param path     the path or URI
    * @param extraHdr additional Header to send
-   * @return a Response object with response detail
+   * @return a Response object with response detail n
    */
   public Response delete(String path, Header extraHdr) throws IOException {
     return delete(cluster, path, extraHdr);
