@@ -17,9 +17,6 @@
  */
 package org.apache.hadoop.hbase.rest.model;
 
-import static org.apache.hadoop.hbase.KeyValue.COLUMN_FAMILY_DELIMITER;
-
-import com.fasterxml.jackson.annotation.JsonIgnore;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import java.io.IOException;
 import java.io.Serializable;
@@ -59,11 +56,10 @@ import org.apache.yetus.audience.InterfaceAudience;
  * </pre>
  */
 @XmlRootElement(name = "Cell")
-@XmlAccessorType(XmlAccessType.NONE)
+@XmlAccessorType(XmlAccessType.FIELD)
 @InterfaceAudience.Private
 public class CellModel implements ProtobufMessageHandler, Serializable {
   private static final long serialVersionUID = 1L;
-  public static final int MAGIC_LENGTH = -1;
 
   @JsonProperty("column")
   @XmlAttribute
@@ -73,17 +69,10 @@ public class CellModel implements ProtobufMessageHandler, Serializable {
   @XmlAttribute
   private long timestamp = HConstants.LATEST_TIMESTAMP;
 
-  // If valueLength = -1, this represents the cell's value.
-  // If valueLength <> 1, this represents an array containing the cell's value as determined by
-  // offset and length.
+  @JsonProperty("$")
+  @XmlValue
   private byte[] value;
 
-  @JsonIgnore
-  private int valueOffset;
-
-  @JsonIgnore
-  private int valueLength = MAGIC_LENGTH;
-
   /**
    * Default constructor
    */
@@ -91,48 +80,43 @@ public class CellModel implements ProtobufMessageHandler, Serializable {
   }
 
   /**
-   * Constructor
+   * Constructor nn
    */
   public CellModel(byte[] column, byte[] value) {
     this(column, HConstants.LATEST_TIMESTAMP, value);
   }
 
   /**
-   * Constructor
+   * Constructor nnn
    */
   public CellModel(byte[] column, byte[] qualifier, byte[] value) {
     this(column, qualifier, HConstants.LATEST_TIMESTAMP, value);
   }
 
   /**
-   * Constructor from KeyValue This avoids copying the value from the cell, and tries to optimize
-   * generating the column value.
+   * Constructor from KeyValue n
    */
   public CellModel(org.apache.hadoop.hbase.Cell cell) {
-    this.column = makeColumn(cell.getFamilyArray(), cell.getFamilyOffset(), cell.getFamilyLength(),
-      cell.getQualifierArray(), cell.getQualifierOffset(), cell.getQualifierLength());
-    this.timestamp = cell.getTimestamp();
-    this.value = cell.getValueArray();
-    this.valueOffset = cell.getValueOffset();
-    this.valueLength = cell.getValueLength();
+    this(CellUtil.cloneFamily(cell), CellUtil.cloneQualifier(cell), cell.getTimestamp(),
+      CellUtil.cloneValue(cell));
   }
 
   /**
-   * Constructor
+   * Constructor nnn
    */
   public CellModel(byte[] column, long timestamp, byte[] value) {
     this.column = column;
     this.timestamp = timestamp;
-    setValue(value);
+    this.value = value;
   }
 
   /**
-   * Constructor
+   * Constructor nnnn
    */
-  public CellModel(byte[] family, byte[] qualifier, long timestamp, byte[] value) {
-    this.column = CellUtil.makeColumn(family, qualifier);
+  public CellModel(byte[] column, byte[] qualifier, long timestamp, byte[] value) {
+    this.column = CellUtil.makeColumn(column, qualifier);
     this.timestamp = timestamp;
-    setValue(value);
+    this.value = value;
   }
 
   /** Returns the column */
@@ -165,49 +149,22 @@ public class CellModel implements ProtobufMessageHandler, Serializable {
   }
 
   /** Returns the value */
-  @JsonProperty("$")
-  @XmlValue
   public byte[] getValue() {
-    if (valueLength == MAGIC_LENGTH) {
-      return value;
-    } else {
-      byte[] retValue = new byte[valueLength];
-      System.arraycopy(value, valueOffset, retValue, 0, valueLength);
-      return retValue;
-    }
-  }
-
-  /** Returns the backing array for value (may be the same as value) */
-  public byte[] getValueArray() {
     return value;
   }
 
   /**
    * @param value the value to set
    */
-  @JsonProperty("$")
   public void setValue(byte[] value) {
     this.value = value;
-    this.valueLength = MAGIC_LENGTH;
-  }
-
-  public int getValueOffset() {
-    return valueOffset;
-  }
-
-  public int getValueLength() {
-    return valueLength;
   }
 
   @Override
   public byte[] createProtobufOutput() {
     Cell.Builder builder = Cell.newBuilder();
     builder.setColumn(ByteStringer.wrap(getColumn()));
-    if (valueLength == MAGIC_LENGTH) {
-      builder.setData(ByteStringer.wrap(getValue()));
-    } else {
-      builder.setData(ByteStringer.wrap(value, valueOffset, valueLength));
-    }
+    builder.setData(ByteStringer.wrap(getValue()));
     if (hasUserTimestamp()) {
       builder.setTimestamp(getTimestamp());
     }
@@ -226,21 +183,6 @@ public class CellModel implements ProtobufMessageHandler, Serializable {
     return this;
   }
 
-  /**
-   * Makes a column in family:qualifier form from separate byte arrays with offset and length.
-   * <p>
-   * Not recommended for usage as this is old-style API.
-   * @return family:qualifier
-   */
-  public static byte[] makeColumn(byte[] family, int familyOffset, int familyLength,
-    byte[] qualifier, int qualifierOffset, int qualifierLength) {
-    byte[] column = new byte[familyLength + qualifierLength + 1];
-    System.arraycopy(family, familyOffset, column, 0, familyLength);
-    column[familyLength] = COLUMN_FAMILY_DELIMITER;
-    System.arraycopy(qualifier, qualifierOffset, column, familyLength + 1, qualifierLength);
-    return column;
-  }
-
   @Override
   public boolean equals(Object obj) {
     if (obj == null) {
@@ -254,17 +196,17 @@ public class CellModel implements ProtobufMessageHandler, Serializable {
     }
     CellModel cellModel = (CellModel) obj;
     return new EqualsBuilder().append(column, cellModel.column)
-      .append(timestamp, cellModel.timestamp).append(getValue(), cellModel.getValue()).isEquals();
+      .append(timestamp, cellModel.timestamp).append(value, cellModel.value).isEquals();
   }
 
   @Override
   public int hashCode() {
-    return new HashCodeBuilder().append(column).append(timestamp).append(getValue()).toHashCode();
+    return new HashCodeBuilder().append(column).append(timestamp).append(value).toHashCode();
   }
 
   @Override
   public String toString() {
     return new ToStringBuilder(this).append("column", column).append("timestamp", timestamp)
-      .append("value", getValue()).toString();
+      .append("value", value).toString();
   }
 }
