@@ -27,6 +27,8 @@ import org.apache.hadoop.hbase.MetaMutationAnnotation;
 import org.apache.hadoop.hbase.NamespaceDescriptor;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.BalanceRequest;
+import org.apache.hadoop.hbase.client.BalanceResponse;
 import org.apache.hadoop.hbase.client.MasterSwitchType;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.RegionInfo;
@@ -275,6 +277,60 @@ public interface MasterObserver {
     final TableName tableName, final TableDescriptor newDescriptor) throws IOException {
   }
 
+  /**
+   * Called prior to modifying a table's store file tracker. Called as part of modify table store
+   * file tracker RPC call.
+   * @param ctx       the environment to interact with the framework and master
+   * @param tableName the name of the table
+   * @param dstSFT    the store file tracker
+   * @return the store file tracker
+   */
+  default String preModifyTableStoreFileTracker(
+    final ObserverContext<MasterCoprocessorEnvironment> ctx, final TableName tableName,
+    String dstSFT) throws IOException {
+    return dstSFT;
+  }
+
+  /**
+   * Called after modifying a table's store file tracker. Called as part of modify table store file
+   * tracker RPC call.
+   * @param ctx       the environment to interact with the framework and master
+   * @param tableName the name of the table
+   * @param dstSFT    the store file tracker
+   */
+  default void postModifyTableStoreFileTracker(
+    final ObserverContext<MasterCoprocessorEnvironment> ctx, final TableName tableName,
+    String dstSFT) throws IOException {
+  }
+
+  /**
+   * Called prior to modifying a family's store file tracker. Called as part of modify family store
+   * file tracker RPC call.
+   * @param ctx       the environment to interact with the framework and master
+   * @param tableName the name of the table
+   * @param family    the column family
+   * @param dstSFT    the store file tracker
+   * @return the store file tracker
+   */
+  default String preModifyColumnFamilyStoreFileTracker(
+    final ObserverContext<MasterCoprocessorEnvironment> ctx, final TableName tableName,
+    final byte[] family, String dstSFT) throws IOException {
+    return dstSFT;
+  }
+
+  /**
+   * Called after modifying a family store file tracker. Called as part of modify family store file
+   * tracker RPC call.
+   * @param ctx       the environment to interact with the framework and master
+   * @param tableName the name of the table
+   * @param family    the column family
+   * @param dstSFT    the store file tracker
+   */
+  default void postModifyColumnFamilyStoreFileTracker(
+    final ObserverContext<MasterCoprocessorEnvironment> ctx, final TableName tableName,
+    final byte[] family, String dstSFT) throws IOException {
+  }
+
   /**
    * Called prior to modifying a table's properties. Called as part of modify table procedure and it
    * is async to the modify table RPC call.
@@ -491,8 +547,8 @@ public interface MasterObserver {
 
   /**
    * Called prior to unassigning a given region.
-   * @param ctx   the environment to interact with the framework and master
-   * @param force whether to force unassignment or not
+   * @param ctx the environment to interact with the framework and master n * @param force whether
+   *            to force unassignment or not
    * @deprecated in 2.4.0. replaced by preUnassign(ctx, regionInfo). removed in hbase 3. until then
    *             safe to either leave implementation here or move it to the new method. default impl
    *             of that method calls this one.
@@ -503,7 +559,7 @@ public interface MasterObserver {
 
   /**
    * Called prior to unassigning a given region.
-   * @param ctx the environment to interact with the framework and master
+   * @param ctx the environment to interact with the framework and master n
    */
   default void preUnassign(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     final RegionInfo regionInfo) throws IOException {
@@ -512,8 +568,8 @@ public interface MasterObserver {
 
   /**
    * Called after the region unassignment has been requested.
-   * @param ctx   the environment to interact with the framework and master
-   * @param force whether to force unassignment or not
+   * @param ctx the environment to interact with the framework and master n * @param force whether
+   *            to force unassignment or not
    * @deprecated in 2.4.0. replaced by postUnassign(ctx, regionInfo). removed in hbase 3. until then
    *             safe to either leave implementation here or move it to the new method. default impl
    *             of that method calls this one.
@@ -524,7 +580,7 @@ public interface MasterObserver {
 
   /**
    * Called after the region unassignment has been requested.
-   * @param ctx the environment to interact with the framework and master
+   * @param ctx the environment to interact with the framework and master n
    */
   default void postUnassign(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     final RegionInfo regionInfo) throws IOException {
@@ -533,7 +589,7 @@ public interface MasterObserver {
 
   /**
    * Called prior to marking a given region as offline.
-   * @param ctx the environment to interact with the framework and master
+   * @param ctx the environment to interact with the framework and master n
    */
   default void preRegionOffline(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     final RegionInfo regionInfo) throws IOException {
@@ -541,7 +597,7 @@ public interface MasterObserver {
 
   /**
    * Called after the region has been marked offline.
-   * @param ctx the environment to interact with the framework and master
+   * @param ctx the environment to interact with the framework and master n
    */
   default void postRegionOffline(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     final RegionInfo regionInfo) throws IOException {
@@ -550,21 +606,23 @@ public interface MasterObserver {
   /**
    * Called prior to requesting rebalancing of the cluster regions, though after the initial checks
    * for regions in transition and the balance switch flag.
-   * @param ctx the environment to interact with the framework and master
+   * @param ctx     the environment to interact with the framework and master
+   * @param request the request used to trigger the balancer
    */
-  default void preBalance(final ObserverContext<MasterCoprocessorEnvironment> ctx)
-    throws IOException {
+  default void preBalance(final ObserverContext<MasterCoprocessorEnvironment> ctx,
+    BalanceRequest request) throws IOException {
   }
 
   /**
    * Called after the balancing plan has been submitted.
-   * @param ctx   the environment to interact with the framework and master
-   * @param plans the RegionPlans which master has executed. RegionPlan serves as hint as for the
-   *              final destination for the underlying region but may not represent the final state
-   *              of assignment
+   * @param ctx     the environment to interact with the framework and master
+   * @param request the request used to trigger the balance
+   * @param plans   the RegionPlans which master has executed. RegionPlan serves as hint as for the
+   *                final destination for the underlying region but may not represent the final
+   *                state of assignment
    */
   default void postBalance(final ObserverContext<MasterCoprocessorEnvironment> ctx,
-    List<RegionPlan> plans) throws IOException {
+    BalanceRequest request, List<RegionPlan> plans) throws IOException {
   }
 
   /**
@@ -619,7 +677,7 @@ public interface MasterObserver {
 
   /**
    * This will be called before update META step as part of split transaction.
-   * @param ctx the environment to interact with the framework and master
+   * @param ctx the environment to interact with the framework and master nn
    */
   default void preSplitRegionBeforeMETAAction(
     final ObserverContext<MasterCoprocessorEnvironment> ctx, final byte[] splitKey,
@@ -1046,6 +1104,22 @@ public interface MasterObserver {
     final TableName tableName) throws IOException {
   }
 
+  /**
+   * Called before the master local region memstore is flushed to disk.
+   * @param ctx the environment to interact with the framework and master
+   */
+  default void preMasterStoreFlush(final ObserverContext<MasterCoprocessorEnvironment> ctx)
+    throws IOException {
+  }
+
+  /**
+   * Called after the master local region memstore is flushed to disk.
+   * @param ctx the environment to interact with the framework and master
+   */
+  default void postMasterStoreFlush(final ObserverContext<MasterCoprocessorEnvironment> ctx)
+    throws IOException {
+  }
+
   /**
    * Called before the quota for the user is stored.
    * @param ctx      the environment to interact with the framework and master
@@ -1294,16 +1368,18 @@ public interface MasterObserver {
    * @param groupName group name
    */
   default void preBalanceRSGroup(final ObserverContext<MasterCoprocessorEnvironment> ctx,
-    String groupName) throws IOException {
+    String groupName, BalanceRequest request) throws IOException {
   }
 
   /**
    * Called after a region server group is removed
    * @param ctx       the environment to interact with the framework and master
    * @param groupName group name
+   * @param request   the request sent to the balancer
+   * @param response  the response returned by the balancer
    */
   default void postBalanceRSGroup(final ObserverContext<MasterCoprocessorEnvironment> ctx,
-    String groupName, boolean balancerRan) throws IOException {
+    String groupName, BalanceRequest request, BalanceResponse response) throws IOException {
   }
 
   /**
@@ -1345,72 +1421,67 @@ public interface MasterObserver {
   }
 
   /**
-   * Called before remove a replication peer
-   * @param peerId a short name that identifies the peer
+   * Called before remove a replication peer n * @param peerId a short name that identifies the peer
    */
   default void preRemoveReplicationPeer(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called after remove a replication peer
-   * @param peerId a short name that identifies the peer
+   * Called after remove a replication peer n * @param peerId a short name that identifies the peer
    */
   default void postRemoveReplicationPeer(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called before enable a replication peer
-   * @param peerId a short name that identifies the peer
+   * Called before enable a replication peer n * @param peerId a short name that identifies the peer
    */
   default void preEnableReplicationPeer(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called after enable a replication peer
-   * @param peerId a short name that identifies the peer
+   * Called after enable a replication peer n * @param peerId a short name that identifies the peer
    */
   default void postEnableReplicationPeer(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called before disable a replication peer
-   * @param peerId a short name that identifies the peer
+   * Called before disable a replication peer n * @param peerId a short name that identifies the
+   * peer
    */
   default void preDisableReplicationPeer(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called after disable a replication peer
-   * @param peerId a short name that identifies the peer
+   * Called after disable a replication peer n * @param peerId a short name that identifies the peer
    */
   default void postDisableReplicationPeer(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called before get the configured ReplicationPeerConfig for the specified peer
-   * @param peerId a short name that identifies the peer
+   * Called before get the configured ReplicationPeerConfig for the specified peer n * @param peerId
+   * a short name that identifies the peer
    */
   default void preGetReplicationPeerConfig(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called after get the configured ReplicationPeerConfig for the specified peer
-   * @param peerId a short name that identifies the peer
+   * Called after get the configured ReplicationPeerConfig for the specified peer n * @param peerId
+   * a short name that identifies the peer
    */
   default void postGetReplicationPeerConfig(final ObserverContext<MasterCoprocessorEnvironment> ctx,
     String peerId) throws IOException {
   }
 
   /**
-   * Called before update peerConfig for the specified peer
-   * @param peerId a short name that identifies the peer
+   * Called before update peerConfig for the specified peer n * @param peerId a short name that
+   * identifies the peer
    */
   default void preUpdateReplicationPeerConfig(
     final ObserverContext<MasterCoprocessorEnvironment> ctx, String peerId,
