@@ -17,17 +17,16 @@
  */
 package org.apache.hadoop.hbase.executor;
 
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.context.Context;
+import io.opentelemetry.context.Scope;
 import java.io.IOException;
 import java.util.concurrent.atomic.AtomicLong;
 import org.apache.hadoop.hbase.Server;
 import org.apache.hadoop.hbase.trace.TraceUtil;
-import org.apache.htrace.core.Span;
-import org.apache.htrace.core.TraceScope;
-import org.apache.htrace.core.Tracer;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.slf4j.MDC;
 
 /**
  * Abstract base class for all HBase event handlers. Subclasses should implement the
@@ -70,7 +69,7 @@ public abstract class EventHandler implements Runnable, Comparable<EventHandler>
    * Default base class constructor.
    */
   public EventHandler(Server server, EventType eventType) {
-    this.parent = Tracer.getCurrentSpan();
+    this.parent = Span.current();
     this.server = server;
     this.eventType = eventType;
     seqid = seqids.incrementAndGet();
@@ -95,20 +94,19 @@ public abstract class EventHandler implements Runnable, Comparable<EventHandler>
 
   @Override
   public void run() {
-    // assume that this is the top of an execution on a new or reused thread, that we're safe to
-    // blast any existing MDC state.
-    try (TraceScope scope = TraceUtil.createTrace(this.getClass().getSimpleName(), parent)) {
-      MDC.put("event_type", eventType.toString());
+    Span span = TraceUtil.getGlobalTracer().spanBuilder(getClass().getSimpleName())
+      .setParent(Context.current().with(parent)).startSpan();
+    try (Scope scope = span.makeCurrent()) {
       process();
     } catch (Throwable t) {
       handleException(t);
     } finally {
-      MDC.clear();
+      span.end();
     }
   }
 
   /**
-   * This method is the main processing loop to be implemented by the various subclasses.
+   * This method is the main processing loop to be implemented by the various subclasses. n
    */
   public abstract void process() throws IOException;
 
