@@ -26,11 +26,11 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Random;
 import java.util.Set;
+import java.util.concurrent.ThreadLocalRandom;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.hbase.Cell.Type;
+import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellBuilderFactory;
 import org.apache.hadoop.hbase.CellBuilderType;
 import org.apache.hadoop.hbase.HBaseIOException;
@@ -52,6 +52,7 @@ import org.slf4j.LoggerFactory;
 
 import org.apache.hbase.thirdparty.com.google.common.collect.Lists;
 import org.apache.hbase.thirdparty.com.google.common.collect.Sets;
+import org.apache.hbase.thirdparty.org.apache.commons.collections4.CollectionUtils;
 
 import org.apache.hadoop.hbase.shaded.protobuf.ProtobufUtil;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.HBaseProtos;
@@ -73,7 +74,6 @@ public class FavoredNodeAssignmentHelper {
   // This map serves as a cache for rack to sn lookups. The num of
   // region server entries might not match with that is in servers.
   private Map<String, String> regionServerToRackMap;
-  private Random random;
   private List<ServerName> servers;
   public static final byte[] FAVOREDNODES_QUALIFIER = Bytes.toBytes("fn");
   public final static short FAVORED_NODES_NUM = 3;
@@ -90,7 +90,6 @@ public class FavoredNodeAssignmentHelper {
     this.rackToRegionServerMap = new HashMap<>();
     this.regionServerToRackMap = new HashMap<>();
     this.uniqueRackList = new ArrayList<>();
-    this.random = new Random();
   }
 
   // Always initialize() when FavoredNodeAssignmentHelper is constructed.
@@ -110,7 +109,7 @@ public class FavoredNodeAssignmentHelper {
           break;
         }
       }
-      serverList.add((sn));
+      serverList.add(sn);
       this.regionServerToRackMap.put(sn.getHostname(), rackName);
     }
   }
@@ -125,13 +124,15 @@ public class FavoredNodeAssignmentHelper {
     throws IOException {
     List<Put> puts = new ArrayList<>();
     for (Map.Entry<RegionInfo, List<ServerName>> entry : regionToFavoredNodes.entrySet()) {
-      Put put = makePutFromRegionInfo(entry.getKey(), entry.getValue());
+      Put put = makePut(entry.getKey(), entry.getValue());
       if (put != null) {
         puts.add(put);
       }
     }
-    MetaTableAccessor.putsToMetaTable(connection, puts);
-    LOG.info("Added " + puts.size() + " regions in META");
+    try (Table table = connection.getTable(TableName.META_TABLE_NAME)) {
+      table.put(puts);
+    }
+    LOG.info("Added " + puts.size() + " region favored nodes in META");
   }
 
   /**
@@ -139,47 +140,34 @@ public class FavoredNodeAssignmentHelper {
    */
   public static void updateMetaWithFavoredNodesInfo(
     Map<RegionInfo, List<ServerName>> regionToFavoredNodes, Configuration conf) throws IOException {
-    List<Put> puts = new ArrayList<>();
-    for (Map.Entry<RegionInfo, List<ServerName>> entry : regionToFavoredNodes.entrySet()) {
-      Put put = makePutFromRegionInfo(entry.getKey(), entry.getValue());
-      if (put != null) {
-        puts.add(put);
-      }
-    }
     // Write the region assignments to the meta table.
     // TODO: See above overrides take a Connection rather than a Configuration only the
     // Connection is a short circuit connection. That is not going to good in all cases, when
     // master and meta are not colocated. Fix when this favored nodes feature is actually used
     // someday.
-    try (Connection connection = ConnectionFactory.createConnection(conf)) {
-      try (Table metaTable = connection.getTable(TableName.META_TABLE_NAME)) {
-        metaTable.put(puts);
-      }
+    try (Connection conn = ConnectionFactory.createConnection(conf)) {
+      updateMetaWithFavoredNodesInfo(regionToFavoredNodes, conn);
     }
-    LOG.info("Added " + puts.size() + " regions in META");
   }
 
-  /**
-   * Generates and returns a Put containing the region info for the catalog table and the servers
-   * @return Put object
-   */
-  private static Put makePutFromRegionInfo(RegionInfo regionInfo, List<ServerName> favoredNodeList)
+  private static Put makePut(RegionInfo regionInfo, List<ServerName> favoredNodeList)
     throws IOException {
-    Put put = null;
-    if (favoredNodeList != null) {
-      long time = EnvironmentEdgeManager.currentTime();
-      put = MetaTableAccessor.makePutFromRegionInfo(regionInfo, time);
-      byte[] favoredNodes = getFavoredNodes(favoredNodeList);
-      put.add(CellBuilderFactory.create(CellBuilderType.SHALLOW_COPY).setRow(put.getRow())
-        .setFamily(HConstants.CATALOG_FAMILY).setQualifier(FAVOREDNODES_QUALIFIER)
-        .setTimestamp(time).setType(Type.Put).setValue(favoredNodes).build());
-      LOG.debug("Create the region {} with favored nodes {}", regionInfo.getRegionNameAsString(),
-        favoredNodeList);
+    if (CollectionUtils.isEmpty(favoredNodeList)) {
+      return null;
     }
+    long time = EnvironmentEdgeManager.currentTime();
+    Put put = new Put(MetaTableAccessor.getMetaKeyForRegion(regionInfo), time);
+    byte[] favoredNodes = getFavoredNodes(favoredNodeList);
+    put.add(CellBuilderFactory.create(CellBuilderType.SHALLOW_COPY).setRow(put.getRow())
+      .setFamily(HConstants.CATALOG_FAMILY).setQualifier(FAVOREDNODES_QUALIFIER).setTimestamp(time)
+      .setType(Cell.Type.Put).setValue(favoredNodes).build());
+    LOG.debug("Create the region {} with favored nodes {}", regionInfo.getRegionNameAsString(),
+      favoredNodeList);
     return put;
   }
 
   /**
+   * Convert PB bytes to ServerName.
    * @param favoredNodes The PB'ed bytes of favored nodes
    * @return the array of {@link ServerName} for the byte array of favored nodes.
    */
@@ -194,7 +182,9 @@ public class FavoredNodeAssignmentHelper {
     return servers;
   }
 
-  /** Returns PB'ed bytes of {@link FavoredNodes} generated by the server list. */
+  /**
+   * n * @return PB'ed bytes of {@link FavoredNodes} generated by the server list.
+   */
   public static byte[] getFavoredNodes(List<ServerName> serverAddrList) {
     FavoredNodes.Builder f = FavoredNodes.newBuilder();
     for (ServerName s : serverAddrList) {
@@ -220,7 +210,7 @@ public class FavoredNodeAssignmentHelper {
     Map<RegionInfo, ServerName> primaryRSMap, List<RegionInfo> regions) {
     List<String> rackList = new ArrayList<>(rackToRegionServerMap.size());
     rackList.addAll(rackToRegionServerMap.keySet());
-    int rackIndex = random.nextInt(rackList.size());
+    int rackIndex = ThreadLocalRandom.current().nextInt(rackList.size());
     int maxRackSize = 0;
     for (Map.Entry<String, List<ServerName>> r : rackToRegionServerMap.entrySet()) {
       if (r.getValue().size() > maxRackSize) {
@@ -229,7 +219,7 @@ public class FavoredNodeAssignmentHelper {
     }
     int numIterations = 0;
     // Initialize the current processing host index.
-    int serverIndex = random.nextInt(maxRackSize);
+    int serverIndex = ThreadLocalRandom.current().nextInt(maxRackSize);
     for (RegionInfo regionInfo : regions) {
       List<ServerName> currentServerList;
       String rackName;
@@ -243,7 +233,7 @@ public class FavoredNodeAssignmentHelper {
           if (numIterations % rackList.size() == 0) {
             if (++serverIndex >= maxRackSize) serverIndex = 0;
           }
-          if ((++rackIndex) >= rackList.size()) {
+          if (++rackIndex >= rackList.size()) {
             rackIndex = 0; // reset the rack index to 0
           }
         } else break;
@@ -267,7 +257,7 @@ public class FavoredNodeAssignmentHelper {
       if (numIterations % rackList.size() == 0) {
         ++serverIndex;
       }
-      if ((++rackIndex) >= rackList.size()) {
+      if (++rackIndex >= rackList.size()) {
         rackIndex = 0; // reset the rack index to 0
       }
     }
@@ -306,7 +296,7 @@ public class FavoredNodeAssignmentHelper {
     if (getTotalNumberOfRacks() == 1) {
       favoredNodes = singleRackCase(regionInfo, primaryRS, primaryRack);
     } else {
-      favoredNodes = multiRackCase(regionInfo, primaryRS, primaryRack);
+      favoredNodes = multiRackCase(primaryRS, primaryRack);
     }
     return favoredNodes;
   }
@@ -327,8 +317,8 @@ public class FavoredNodeAssignmentHelper {
 
   /**
    * For regions that share the primary, avoid placing the secondary and tertiary on a same RS. Used
-   * for generating new assignments for the primary/secondary/tertiary RegionServers
-   * @return the map of regions to the servers the region-files should be hosted on
+   * for generating new assignments for the primary/secondary/tertiary RegionServers n * @return the
+   * map of regions to the servers the region-files should be hosted on
    */
   public Map<RegionInfo, ServerName[]>
     placeSecondaryAndTertiaryWithRestrictions(Map<RegionInfo, ServerName> primaryRSMap) {
@@ -491,14 +481,12 @@ public class FavoredNodeAssignmentHelper {
    * has only one region server, then we place primary and tertiary on one rack and secondary on
    * another. The aim is two distribute the three favored nodes on >= 2 racks. TODO: see how we can
    * use generateMissingFavoredNodeMultiRack API here
-   * @param regionInfo  Region for which we are trying to generate FN
    * @param primaryRS   The primary favored node.
    * @param primaryRack The rack of the primary favored node.
    * @return Array containing secondary and tertiary favored nodes.
    * @throws IOException Signals that an I/O exception has occurred.
    */
-  private ServerName[] multiRackCase(RegionInfo regionInfo, ServerName primaryRS,
-    String primaryRack) throws IOException {
+  private ServerName[] multiRackCase(ServerName primaryRS, String primaryRack) throws IOException {
 
     List<ServerName> favoredNodes = Lists.newArrayList(primaryRS);
     // Create the secondary and tertiary pair
@@ -564,7 +552,7 @@ public class FavoredNodeAssignmentHelper {
     }
 
     ServerName randomServer = null;
-    int randomIndex = random.nextInt(serversToChooseFrom.size());
+    int randomIndex = ThreadLocalRandom.current().nextInt(serversToChooseFrom.size());
     int j = 0;
     for (StartcodeAgnosticServerName sn : serversToChooseFrom) {
       if (j == randomIndex) {
@@ -585,14 +573,14 @@ public class FavoredNodeAssignmentHelper {
     return this.getOneRandomServer(rack, null);
   }
 
-  protected String getOneRandomRack(Set<String> skipRackSet) throws IOException {
+  String getOneRandomRack(Set<String> skipRackSet) throws IOException {
     if (skipRackSet == null || uniqueRackList.size() <= skipRackSet.size()) {
       throw new IOException("Cannot randomly pick another random server");
     }
 
     String randomRack;
     do {
-      int randomIndex = random.nextInt(this.uniqueRackList.size());
+      int randomIndex = ThreadLocalRandom.current().nextInt(this.uniqueRackList.size());
       randomRack = this.uniqueRackList.get(randomIndex);
     } while (skipRackSet.contains(randomRack));
 
@@ -746,7 +734,7 @@ public class FavoredNodeAssignmentHelper {
   public List<ServerName> generateFavoredNodes(RegionInfo hri) throws IOException {
 
     List<ServerName> favoredNodesForRegion = new ArrayList<>(FAVORED_NODES_NUM);
-    ServerName primary = servers.get(random.nextInt(servers.size()));
+    ServerName primary = servers.get(ThreadLocalRandom.current().nextInt(servers.size()));
     favoredNodesForRegion.add(ServerName.valueOf(primary.getAddress(), ServerName.NON_STARTCODE));
 
     Map<RegionInfo, ServerName> primaryRSMap = new HashMap<>(1);
