@@ -106,6 +106,10 @@ public class FileLink {
       this.in = tryOpen();
     }
 
+    private FSDataInputStream getUnderlyingInputStream() {
+      return in;
+    }
+
     @Override
     public int read() throws IOException {
       int res;
@@ -113,10 +117,12 @@ public class FileLink {
         res = in.read();
       } catch (FileNotFoundException e) {
         res = tryOpen().read();
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        res = tryOpen().read();
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        res = tryOpen().read();
       }
-      if (res > 0) {
-        pos += 1;
-      }
+      if (res > 0) pos += 1;
       return res;
     }
 
@@ -132,10 +138,12 @@ public class FileLink {
         n = in.read(b, off, len);
       } catch (FileNotFoundException e) {
         n = tryOpen().read(b, off, len);
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        n = tryOpen().read(b, off, len);
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        n = tryOpen().read(b, off, len);
       }
-      if (n > 0) {
-        pos += n;
-      }
+      if (n > 0) pos += n;
       assert (in.getPos() == pos);
       return n;
     }
@@ -147,6 +155,10 @@ public class FileLink {
         n = in.read(position, buffer, offset, length);
       } catch (FileNotFoundException e) {
         n = tryOpen().read(position, buffer, offset, length);
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        n = tryOpen().read(position, buffer, offset, length);
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        n = tryOpen().read(position, buffer, offset, length);
       }
       return n;
     }
@@ -162,6 +174,10 @@ public class FileLink {
         in.readFully(position, buffer, offset, length);
       } catch (FileNotFoundException e) {
         tryOpen().readFully(position, buffer, offset, length);
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        tryOpen().readFully(position, buffer, offset, length);
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        tryOpen().readFully(position, buffer, offset, length);
       }
     }
 
@@ -173,11 +189,13 @@ public class FileLink {
         skipped = in.skip(n);
       } catch (FileNotFoundException e) {
         skipped = tryOpen().skip(n);
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        skipped = tryOpen().skip(n);
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        skipped = tryOpen().skip(n);
       }
 
-      if (skipped > 0) {
-        pos += skipped;
-      }
+      if (skipped > 0) pos += skipped;
       return skipped;
     }
 
@@ -187,6 +205,10 @@ public class FileLink {
         return in.available();
       } catch (FileNotFoundException e) {
         return tryOpen().available();
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        return tryOpen().available();
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        return tryOpen().available();
       }
     }
 
@@ -196,6 +218,10 @@ public class FileLink {
         in.seek(pos);
       } catch (FileNotFoundException e) {
         tryOpen().seek(pos);
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        tryOpen().seek(pos);
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        tryOpen().seek(pos);
       }
       this.pos = pos;
     }
@@ -212,6 +238,10 @@ public class FileLink {
         res = in.seekToNewSource(targetPos);
       } catch (FileNotFoundException e) {
         res = tryOpen().seekToNewSource(targetPos);
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        res = tryOpen().seekToNewSource(targetPos);
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        res = tryOpen().seekToNewSource(targetPos);
       }
       if (res) pos = targetPos;
       return res;
@@ -419,6 +449,17 @@ public class FileLink {
     return new FSDataInputStream(new FileLinkInputStream(fs, this, bufferSize));
   }
 
+  /**
+   * If the passed FSDataInputStream is backed by a FileLink, returns the underlying InputStream for
+   * the resolved link target. Otherwise, returns null.
+   */
+  public static FSDataInputStream getUnderlyingFileLinkInputStream(FSDataInputStream stream) {
+    if (stream.getWrappedStream() instanceof FileLinkInputStream) {
+      return ((FileLinkInputStream) stream.getWrappedStream()).getUnderlyingInputStream();
+    }
+    return null;
+  }
+
   /**
    * NOTE: This method must be used only in the constructor! It creates a List with the specified
    * locations for the link.
