@@ -373,10 +373,6 @@ public final class HFile {
     HFileBlock readBlock(long offset, long onDiskBlockSize, boolean cacheBlock, final boolean pread,
       final boolean isCompaction, final boolean updateCacheMetrics, BlockType expectedBlockType,
       DataBlockEncoding expectedDataBlockEncoding) throws IOException;
-
-    HFileBlock readBlock(long offset, long onDiskBlockSize, boolean cacheBlock, final boolean pread,
-      final boolean isCompaction, final boolean updateCacheMetrics, BlockType expectedBlockType,
-      DataBlockEncoding expectedDataBlockEncoding, boolean cacheOnly) throws IOException;
   }
 
   /** An interface used by clients to open and iterate an {@link HFile}. */
@@ -389,7 +385,8 @@ public final class HFile {
 
     CellComparator getComparator();
 
-    HFileScanner getScanner(boolean cacheBlocks, final boolean pread, final boolean isCompaction);
+    HFileScanner getScanner(Configuration conf, boolean cacheBlocks, boolean pread,
+      boolean isCompaction);
 
     HFileBlock getMetaBlock(String metaBlockName, boolean cacheBlock) throws IOException;
 
@@ -419,7 +416,7 @@ public final class HFile {
 
     HFileBlockIndex.ByteArrayKeyBlockIndexReader getMetaBlockIndexReader();
 
-    HFileScanner getScanner(boolean cacheBlocks, boolean pread);
+    HFileScanner getScanner(Configuration conf, boolean cacheBlocks, boolean pread);
 
     /**
      * Retrieves general Bloom filter metadata as appropriate for each {@link HFile} version. Knows
@@ -455,8 +452,6 @@ public final class HFile {
 
     boolean prefetchComplete();
 
-    boolean prefetchStarted();
-
     /**
      * To close the stream's socket. Note: This can be concurrently called from multiple threads and
      * implementation should take care of thread safety.
