@@ -18,7 +18,13 @@
 package org.apache.hadoop.hbase.io.hfile;
 
 import static org.apache.hadoop.hbase.io.ByteBuffAllocator.HEAP;
+import static org.apache.hadoop.hbase.io.hfile.trace.HFileContextAttributesBuilderConsumer.CONTEXT_KEY;
 
+import io.opentelemetry.api.common.Attributes;
+import io.opentelemetry.api.common.AttributesBuilder;
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.context.Context;
+import io.opentelemetry.context.Scope;
 import java.io.DataInputStream;
 import java.io.DataOutput;
 import java.io.DataOutputStream;
@@ -26,9 +32,11 @@ import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Optional;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
+import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.hbase.Cell;
@@ -45,14 +53,17 @@ import org.apache.hadoop.hbase.io.encoding.HFileBlockDecodingContext;
 import org.apache.hadoop.hbase.io.encoding.HFileBlockDefaultDecodingContext;
 import org.apache.hadoop.hbase.io.encoding.HFileBlockDefaultEncodingContext;
 import org.apache.hadoop.hbase.io.encoding.HFileBlockEncodingContext;
+import org.apache.hadoop.hbase.io.hfile.trace.HFileContextAttributesBuilderConsumer;
 import org.apache.hadoop.hbase.io.util.BlockIOUtils;
 import org.apache.hadoop.hbase.nio.ByteBuff;
 import org.apache.hadoop.hbase.nio.MultiByteBuff;
 import org.apache.hadoop.hbase.nio.SingleByteBuff;
 import org.apache.hadoop.hbase.regionserver.ShipperListener;
+import org.apache.hadoop.hbase.trace.HBaseSemanticAttributes.ReadType;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.ChecksumType;
 import org.apache.hadoop.hbase.util.ClassSize;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -159,7 +170,7 @@ public class HFileBlock implements Cacheable {
    * {@link #onDiskSizeWithoutHeader} when using HDFS checksum.
    * @see Writer#putHeader(byte[], int, int, int, int)
    */
-  private final int onDiskDataSizeWithHeader;
+  private int onDiskDataSizeWithHeader;
   // End of Block Header fields.
 
   /**
@@ -175,15 +186,13 @@ public class HFileBlock implements Cacheable {
    * ByteBuffer-like API across multiple ByteBuffers reading from a cache such as BucketCache. So,
    * we have this ByteBuff type. Unfortunately, it is spread all about HFileBlock. Would be good if
    * could be confined to cache-use only but hard-to-do.
-   * <p>
-   * NOTE: this byteBuff including HFileBlock header and data, but excluding checksum.
    */
-  private ByteBuff bufWithoutChecksum;
+  private ByteBuff buf;
 
   /**
    * Meta data that holds meta information on the hfileblock.
    */
-  private final HFileContext fileContext;
+  private HFileContext fileContext;
 
   /**
    * The offset of this block in the file. Populated by the reader for convenience of access. This
@@ -228,7 +237,8 @@ public class HFileBlock implements Cacheable {
    * (This EXTRA info came in with original commit of the bucketcache, HBASE-7404. It was formerly
    * known as EXTRA_SERIALIZATION_SPACE).
    */
-  static final int BLOCK_METADATA_SPACE = Bytes.SIZEOF_BYTE + Bytes.SIZEOF_LONG + Bytes.SIZEOF_INT;
+  public static final int BLOCK_METADATA_SPACE =
+    Bytes.SIZEOF_BYTE + Bytes.SIZEOF_LONG + Bytes.SIZEOF_INT;
 
   /**
    * Each checksum value is an integer that can be stored in 4 bytes.
@@ -284,8 +294,6 @@ public class HFileBlock implements Cacheable {
       CacheableDeserializerIdManager.registerDeserializer(BLOCK_DESERIALIZER);
   }
 
-  private final int totalChecksumBytes;
-
   /**
    * Creates a new {@link HFile} block from the given fields. This constructor is used only while
    * writing blocks and caching, and is sitting in a byte buffer and we want to stuff the block into
@@ -322,12 +330,11 @@ public class HFileBlock implements Cacheable {
     this.nextBlockOnDiskSize = nextBlockOnDiskSize;
     this.fileContext = fileContext;
     this.allocator = allocator;
-    this.bufWithoutChecksum = buf;
+    this.buf = buf;
     if (fillHeader) {
       overwriteHeader();
     }
-    this.bufWithoutChecksum.rewind();
-    this.totalChecksumBytes = computeTotalChecksumBytes();
+    this.buf.rewind();
   }
 
   /**
@@ -378,12 +385,12 @@ public class HFileBlock implements Cacheable {
 
   /**
    * Parse total on disk size including header and checksum.
-   * @param headerBuf       Header ByteBuffer. Presumed exact size of header.
-   * @param checksumSupport true if checksum verification is in use.
+   * @param headerBuf      Header ByteBuffer. Presumed exact size of header.
+   * @param verifyChecksum true if checksum verification is in use.
    * @return Size of the block with header included.
    */
-  private static int getOnDiskSizeWithHeader(final ByteBuff headerBuf, boolean checksumSupport) {
-    return headerBuf.getInt(Header.ON_DISK_SIZE_WITHOUT_HEADER_INDEX) + headerSize(checksumSupport);
+  private static int getOnDiskSizeWithHeader(final ByteBuff headerBuf, boolean verifyChecksum) {
+    return headerBuf.getInt(Header.ON_DISK_SIZE_WITHOUT_HEADER_INDEX) + headerSize(verifyChecksum);
   }
 
   /**
@@ -402,12 +409,12 @@ public class HFileBlock implements Cacheable {
 
   @Override
   public int refCnt() {
-    return bufWithoutChecksum.refCnt();
+    return buf.refCnt();
   }
 
   @Override
   public HFileBlock retain() {
-    bufWithoutChecksum.retain();
+    buf.retain();
     return this;
   }
 
@@ -417,7 +424,7 @@ public class HFileBlock implements Cacheable {
    */
   @Override
   public boolean release() {
-    return bufWithoutChecksum.release();
+    return buf.release();
   }
 
   /**
@@ -432,7 +439,7 @@ public class HFileBlock implements Cacheable {
 
   @Override
   public HFileBlock touch(Object hint) {
-    bufWithoutChecksum.touch(hint);
+    buf.touch(hint);
     return this;
   }
 
@@ -442,7 +449,7 @@ public class HFileBlock implements Cacheable {
       throw new IllegalArgumentException("Querying encoder ID of a block " + "of type other than "
         + BlockType.ENCODED_DATA + ": " + blockType);
     }
-    return bufWithoutChecksum.getShort(headerSize());
+    return buf.getShort(headerSize());
   }
 
   /** Returns the on-disk size of header + data part + checksum. */
@@ -470,15 +477,15 @@ public class HFileBlock implements Cacheable {
    * side-effect.
    */
   private void overwriteHeader() {
-    bufWithoutChecksum.rewind();
-    blockType.write(bufWithoutChecksum);
-    bufWithoutChecksum.putInt(onDiskSizeWithoutHeader);
-    bufWithoutChecksum.putInt(uncompressedSizeWithoutHeader);
-    bufWithoutChecksum.putLong(prevBlockOffset);
+    buf.rewind();
+    blockType.write(buf);
+    buf.putInt(onDiskSizeWithoutHeader);
+    buf.putInt(uncompressedSizeWithoutHeader);
+    buf.putLong(prevBlockOffset);
     if (this.fileContext.isUseHBaseChecksum()) {
-      bufWithoutChecksum.put(fileContext.getChecksumType().getCode());
-      bufWithoutChecksum.putInt(fileContext.getBytesPerChecksum());
-      bufWithoutChecksum.putInt(onDiskDataSizeWithHeader);
+      buf.put(fileContext.getChecksumType().getCode());
+      buf.putInt(fileContext.getBytesPerChecksum());
+      buf.putInt(onDiskDataSizeWithHeader);
     }
   }
 
@@ -498,12 +505,11 @@ public class HFileBlock implements Cacheable {
    * in {@link CompoundBloomFilter} to avoid object creation on every Bloom filter lookup, but has
    * to be used with caution. Buffer holds header, block content, and any follow-on checksums if
    * present.
-   * @return the buffer of this block for read-only operations,the buffer includes header,but not
-   *         checksum.
+   * @return the buffer of this block for read-only operations
    */
   public ByteBuff getBufferReadOnly() {
     // TODO: ByteBuf does not support asReadOnlyBuffer(). Fix.
-    ByteBuff dup = this.bufWithoutChecksum.duplicate();
+    ByteBuff dup = this.buf.duplicate();
     assert dup.position() == 0;
     return dup;
   }
@@ -537,7 +543,7 @@ public class HFileBlock implements Cacheable {
    */
   void sanityCheck() throws IOException {
     // Duplicate so no side-effects
-    ByteBuff dup = this.bufWithoutChecksum.duplicate().rewind();
+    ByteBuff dup = this.buf.duplicate().rewind();
     sanityCheckAssertion(BlockType.read(dup), blockType);
 
     sanityCheckAssertion(dup.getInt(), onDiskSizeWithoutHeader, "onDiskSizeWithoutHeader");
@@ -580,8 +586,8 @@ public class HFileBlock implements Cacheable {
       .append(", prevBlockOffset=").append(prevBlockOffset).append(", isUseHBaseChecksum=")
       .append(fileContext.isUseHBaseChecksum());
     if (fileContext.isUseHBaseChecksum()) {
-      sb.append(", checksumType=").append(ChecksumType.codeToType(this.bufWithoutChecksum.get(24)))
-        .append(", bytesPerChecksum=").append(this.bufWithoutChecksum.getInt(24 + 1))
+      sb.append(", checksumType=").append(ChecksumType.codeToType(this.buf.get(24)))
+        .append(", bytesPerChecksum=").append(this.buf.getInt(24 + 1))
         .append(", onDiskDataSizeWithHeader=").append(onDiskDataSizeWithHeader);
     } else {
       sb.append(", onDiskDataSizeWithHeader=").append(onDiskDataSizeWithHeader).append("(")
@@ -589,10 +595,9 @@ public class HFileBlock implements Cacheable {
         .append(HConstants.HFILEBLOCK_HEADER_SIZE_NO_CHECKSUM).append(")");
     }
     String dataBegin;
-    if (bufWithoutChecksum.hasArray()) {
-      dataBegin = Bytes.toStringBinary(bufWithoutChecksum.array(),
-        bufWithoutChecksum.arrayOffset() + headerSize(),
-        Math.min(32, bufWithoutChecksum.limit() - bufWithoutChecksum.arrayOffset() - headerSize()));
+    if (buf.hasArray()) {
+      dataBegin = Bytes.toStringBinary(buf.array(), buf.arrayOffset() + headerSize(),
+        Math.min(32, buf.limit() - buf.arrayOffset() - headerSize()));
     } else {
       ByteBuff bufWithoutHeader = getBufferWithoutHeader();
       byte[] dataBeginBytes =
@@ -602,8 +607,8 @@ public class HFileBlock implements Cacheable {
     }
     sb.append(", getOnDiskSizeWithHeader=").append(getOnDiskSizeWithHeader())
       .append(", totalChecksumBytes=").append(totalChecksumBytes()).append(", isUnpacked=")
-      .append(isUnpacked()).append(", buf=[").append(bufWithoutChecksum).append("]")
-      .append(", dataBeginsWith=").append(dataBegin).append(", fileContext=").append(fileContext)
+      .append(isUnpacked()).append(", buf=[").append(buf).append("]").append(", dataBeginsWith=")
+      .append(dataBegin).append(", fileContext=").append(fileContext)
       .append(", nextBlockOnDiskSize=").append(nextBlockOnDiskSize).append("]");
     return sb.toString();
   }
@@ -624,13 +629,15 @@ public class HFileBlock implements Cacheable {
     HFileBlock unpacked = shallowClone(this, newBuf);
 
     boolean succ = false;
-    try {
+    final Context context =
+      Context.current().with(CONTEXT_KEY, new HFileContextAttributesBuilderConsumer(fileContext));
+    try (Scope ignored = context.makeCurrent()) {
       HFileBlockDecodingContext ctx = blockType == BlockType.ENCODED_DATA
         ? reader.getBlockDecodingContext()
         : reader.getDefaultBlockDecodingContext();
       // Create a duplicated buffer without the header part.
       int headerSize = this.headerSize();
-      ByteBuff dup = this.bufWithoutChecksum.duplicate();
+      ByteBuff dup = this.buf.duplicate();
       dup.position(headerSize);
       dup = dup.slice();
       // Decode the dup into unpacked#buf
@@ -653,7 +660,7 @@ public class HFileBlock implements Cacheable {
     int headerSize = headerSize();
     int capacityNeeded = headerSize + uncompressedSizeWithoutHeader;
 
-    ByteBuff source = bufWithoutChecksum.duplicate();
+    ByteBuff source = buf.duplicate();
     ByteBuff newBuf = allocator.allocate(capacityNeeded);
 
     // Copy header bytes into newBuf.
@@ -672,7 +679,7 @@ public class HFileBlock implements Cacheable {
   public boolean isUnpacked() {
     final int headerSize = headerSize();
     final int expectedCapacity = headerSize + uncompressedSizeWithoutHeader;
-    final int bufCapacity = bufWithoutChecksum.remaining();
+    final int bufCapacity = buf.remaining();
     return bufCapacity == expectedCapacity || bufCapacity == expectedCapacity + headerSize;
   }
 
@@ -688,9 +695,9 @@ public class HFileBlock implements Cacheable {
     return offset;
   }
 
-  /** Returns a byte stream reading the data(excluding header and checksum) of this block */
+  /** Returns a byte stream reading the data + checksum of this block */
   DataInputStream getByteStream() {
-    ByteBuff dup = this.bufWithoutChecksum.duplicate();
+    ByteBuff dup = this.buf.duplicate();
     dup.position(this.headerSize());
     return new DataInputStream(new ByteBuffInputStream(dup));
   }
@@ -699,9 +706,9 @@ public class HFileBlock implements Cacheable {
   public long heapSize() {
     long size = FIXED_OVERHEAD;
     size += fileContext.heapSize();
-    if (bufWithoutChecksum != null) {
+    if (buf != null) {
       // Deep overhead of the byte buffer. Needs to be aligned separately.
-      size += ClassSize.align(bufWithoutChecksum.capacity() + MULTI_BYTE_BUFFER_HEAP_SIZE);
+      size += ClassSize.align(buf.capacity() + MULTI_BYTE_BUFFER_HEAP_SIZE);
     }
     return ClassSize.align(size);
   }
@@ -809,12 +816,13 @@ public class HFileBlock implements Cacheable {
     /**
      * @param dataBlockEncoder data block encoding algorithm to use
      */
-    public Writer(HFileDataBlockEncoder dataBlockEncoder, HFileContext fileContext) {
-      this(dataBlockEncoder, fileContext, ByteBuffAllocator.HEAP);
+    public Writer(Configuration conf, HFileDataBlockEncoder dataBlockEncoder,
+      HFileContext fileContext) {
+      this(conf, dataBlockEncoder, fileContext, ByteBuffAllocator.HEAP);
     }
 
-    public Writer(HFileDataBlockEncoder dataBlockEncoder, HFileContext fileContext,
-      ByteBuffAllocator allocator) {
+    public Writer(Configuration conf, HFileDataBlockEncoder dataBlockEncoder,
+      HFileContext fileContext, ByteBuffAllocator allocator) {
       if (fileContext.getBytesPerChecksum() < HConstants.HFILEBLOCK_HEADER_SIZE) {
         throw new RuntimeException("Unsupported value of bytesPerChecksum. " + " Minimum is "
           + HConstants.HFILEBLOCK_HEADER_SIZE + " but the configured value is "
@@ -823,11 +831,11 @@ public class HFileBlock implements Cacheable {
       this.allocator = allocator;
       this.dataBlockEncoder =
         dataBlockEncoder != null ? dataBlockEncoder : NoOpDataBlockEncoder.INSTANCE;
-      this.dataBlockEncodingCtx = this.dataBlockEncoder
-        .newDataBlockEncodingContext(HConstants.HFILEBLOCK_DUMMY_HEADER, fileContext);
-      // TODO: This should be lazily instantiated since we usually do NOT need this default encoder
-      this.defaultBlockEncodingCtx =
-        new HFileBlockDefaultEncodingContext(null, HConstants.HFILEBLOCK_DUMMY_HEADER, fileContext);
+      this.dataBlockEncodingCtx = this.dataBlockEncoder.newDataBlockEncodingContext(conf,
+        HConstants.HFILEBLOCK_DUMMY_HEADER, fileContext);
+      // TODO: This should be lazily instantiated
+      this.defaultBlockEncodingCtx = new HFileBlockDefaultEncodingContext(conf, null,
+        HConstants.HFILEBLOCK_DUMMY_HEADER, fileContext);
       // TODO: Set BAOS initial size. Use fileContext.getBlocksize() and add for header/checksum
       baosInMemory = new ByteArrayOutputStream();
       prevOffsetByType = new long[BlockType.values().length];
@@ -997,10 +1005,10 @@ public class HFileBlock implements Cacheable {
      */
     protected void finishBlockAndWriteHeaderAndData(DataOutputStream out) throws IOException {
       ensureBlockReady();
-      long startTime = System.currentTimeMillis();
+      long startTime = EnvironmentEdgeManager.currentTime();
       out.write(onDiskBlockBytesWithHeader.getBuffer(), 0, onDiskBlockBytesWithHeader.size());
       out.write(onDiskChecksum);
-      HFile.updateWriteLatency(System.currentTimeMillis() - startTime);
+      HFile.updateWriteLatency(EnvironmentEdgeManager.currentTime() - startTime);
     }
 
     /**
@@ -1280,7 +1288,7 @@ public class HFileBlock implements Cacheable {
 
     void setIncludesMemStoreTS(boolean includesMemstoreTS);
 
-    void setDataBlockEncoder(HFileDataBlockEncoder encoder);
+    void setDataBlockEncoder(HFileDataBlockEncoder encoder, Configuration conf);
 
     /**
      * To close the stream's socket. Note: This can be concurrently called from multiple threads and
@@ -1348,8 +1356,8 @@ public class HFileBlock implements Cacheable {
 
     private final boolean isPreadAllBytes;
 
-    FSReaderImpl(ReaderContext readerContext, HFileContext fileContext, ByteBuffAllocator allocator)
-      throws IOException {
+    FSReaderImpl(ReaderContext readerContext, HFileContext fileContext, ByteBuffAllocator allocator,
+      Configuration conf) throws IOException {
       this.fileSize = readerContext.getFileSize();
       this.hfs = readerContext.getFileSystem();
       if (readerContext.getFilePath() != null) {
@@ -1362,7 +1370,7 @@ public class HFileBlock implements Cacheable {
       this.streamWrapper = readerContext.getInputStreamWrapper();
       // Older versions of HBase didn't support checksum.
       this.streamWrapper.prepareForBlockReader(!fileContext.isUseHBaseChecksum());
-      defaultDecodingCtx = new HFileBlockDefaultDecodingContext(fileContext);
+      defaultDecodingCtx = new HFileBlockDefaultDecodingContext(conf, fileContext);
       encodedBlockDecodingCtx = defaultDecodingCtx;
       isPreadAllBytes = readerContext.isPreadAllBytes();
     }
@@ -1434,7 +1442,7 @@ public class HFileBlock implements Cacheable {
       boolean peekIntoNextBlock, long fileOffset, boolean pread) throws IOException {
       if (!pread) {
         // Seek + read. Better for scanning.
-        istream.seek(fileOffset);
+        HFileUtil.seekOnMultipleSources(istream, fileOffset);
         long realOffset = istream.getPos();
         if (realOffset != fileOffset) {
           throw new IOException("Tried to seek to " + fileOffset + " to read " + size
@@ -1482,104 +1490,95 @@ public class HFileBlock implements Cacheable {
       boolean updateMetrics, boolean intoHeap) throws IOException {
       // Get a copy of the current state of whether to validate
       // hbase checksums or not for this read call. This is not
-      // thread-safe but the one constaint is that if we decide
+      // thread-safe but the one constraint is that if we decide
       // to skip hbase checksum verification then we are
       // guaranteed to use hdfs checksum verification.
       boolean doVerificationThruHBaseChecksum = streamWrapper.shouldUseHBaseChecksum();
       FSDataInputStream is = streamWrapper.getStream(doVerificationThruHBaseChecksum);
-
-      HFileBlock blk = readBlockDataInternal(is, offset, onDiskSizeWithHeaderL, pread,
-        doVerificationThruHBaseChecksum, updateMetrics, intoHeap);
-      if (blk == null) {
-        HFile.LOG.warn("HBase checksum verification failed for file " + pathName + " at offset "
-          + offset + " filesize " + fileSize + ". Retrying read with HDFS checksums turned on...");
-
-        if (!doVerificationThruHBaseChecksum) {
-          String msg = "HBase checksum verification failed for file " + pathName + " at offset "
-            + offset + " filesize " + fileSize + " but this cannot happen because doVerify is "
-            + doVerificationThruHBaseChecksum;
-          HFile.LOG.warn(msg);
-          throw new IOException(msg); // cannot happen case here
-        }
-        HFile.CHECKSUM_FAILURES.increment(); // update metrics
-
-        // If we have a checksum failure, we fall back into a mode where
-        // the next few reads use HDFS level checksums. We aim to make the
-        // next CHECKSUM_VERIFICATION_NUM_IO_THRESHOLD reads avoid
-        // hbase checksum verification, but since this value is set without
-        // holding any locks, it can so happen that we might actually do
-        // a few more than precisely this number.
-        is = this.streamWrapper.fallbackToFsChecksum(CHECKSUM_VERIFICATION_NUM_IO_THRESHOLD);
-        doVerificationThruHBaseChecksum = false;
-        blk = readBlockDataInternal(is, offset, onDiskSizeWithHeaderL, pread,
+      final Context context = Context.current().with(CONTEXT_KEY,
+        new HFileContextAttributesBuilderConsumer(fileContext)
+          .setSkipChecksum(doVerificationThruHBaseChecksum)
+          .setReadType(pread ? ReadType.POSITIONAL_READ : ReadType.SEEK_PLUS_READ));
+      try (Scope ignored = context.makeCurrent()) {
+        HFileBlock blk = readBlockDataInternal(is, offset, onDiskSizeWithHeaderL, pread,
           doVerificationThruHBaseChecksum, updateMetrics, intoHeap);
-        if (blk != null) {
-          HFile.LOG.warn("HDFS checksum verification succeeded for file " + pathName + " at offset "
-            + offset + " filesize " + fileSize);
-        }
-      }
-      if (blk == null && !doVerificationThruHBaseChecksum) {
-        String msg =
-          "readBlockData failed, possibly due to " + "checksum verification failed for file "
-            + pathName + " at offset " + offset + " filesize " + fileSize;
-        HFile.LOG.warn(msg);
-        throw new IOException(msg);
-      }
+        if (blk == null) {
+          HFile.LOG.warn("HBase checksum verification failed for file {} at offset {} filesize {}."
+            + " Retrying read with HDFS checksums turned on...", pathName, offset, fileSize);
 
-      // If there is a checksum mismatch earlier, then retry with
-      // HBase checksums switched off and use HDFS checksum verification.
-      // This triggers HDFS to detect and fix corrupt replicas. The
-      // next checksumOffCount read requests will use HDFS checksums.
-      // The decrementing of this.checksumOffCount is not thread-safe,
-      // but it is harmless because eventually checksumOffCount will be
-      // a negative number.
-      streamWrapper.checksumOk();
-      return blk;
+          if (!doVerificationThruHBaseChecksum) {
+            String msg = "HBase checksum verification failed for file " + pathName + " at offset "
+              + offset + " filesize " + fileSize + " but this cannot happen because doVerify is "
+              + doVerificationThruHBaseChecksum;
+            HFile.LOG.warn(msg);
+            throw new IOException(msg); // cannot happen case here
+          }
+          HFile.CHECKSUM_FAILURES.increment(); // update metrics
+
+          // If we have a checksum failure, we fall back into a mode where
+          // the next few reads use HDFS level checksums. We aim to make the
+          // next CHECKSUM_VERIFICATION_NUM_IO_THRESHOLD reads avoid
+          // hbase checksum verification, but since this value is set without
+          // holding any locks, it can so happen that we might actually do
+          // a few more than precisely this number.
+          is = this.streamWrapper.fallbackToFsChecksum(CHECKSUM_VERIFICATION_NUM_IO_THRESHOLD);
+          doVerificationThruHBaseChecksum = false;
+          blk = readBlockDataInternal(is, offset, onDiskSizeWithHeaderL, pread,
+            doVerificationThruHBaseChecksum, updateMetrics, intoHeap);
+          if (blk != null) {
+            HFile.LOG.warn(
+              "HDFS checksum verification succeeded for file {} at offset {} filesize" + " {}",
+              pathName, offset, fileSize);
+          }
+        }
+        if (blk == null && !doVerificationThruHBaseChecksum) {
+          String msg =
+            "readBlockData failed, possibly due to " + "checksum verification failed for file "
+              + pathName + " at offset " + offset + " filesize " + fileSize;
+          HFile.LOG.warn(msg);
+          throw new IOException(msg);
+        }
+
+        // If there is a checksum mismatch earlier, then retry with
+        // HBase checksums switched off and use HDFS checksum verification.
+        // This triggers HDFS to detect and fix corrupt replicas. The
+        // next checksumOffCount read requests will use HDFS checksums.
+        // The decrementing of this.checksumOffCount is not thread-safe,
+        // but it is harmless because eventually checksumOffCount will be
+        // a negative number.
+        streamWrapper.checksumOk();
+        return blk;
+      }
     }
 
     /**
-     * Check that {@code value} read from a block header seems reasonable, within a large margin of
-     * error.
-     * @return {@code true} if the value is safe to proceed, {@code false} otherwise.
+     * Returns Check <code>onDiskSizeWithHeaderL</code> size is healthy and then return it as an int
      */
-    private boolean checkOnDiskSizeWithHeader(int value) {
-      if (value < 0) {
-        if (LOG.isTraceEnabled()) {
-          LOG.trace(
-            "onDiskSizeWithHeader={}; value represents a size, so it should never be negative.",
-            value);
-        }
-        return false;
+    private static int checkAndGetSizeAsInt(final long onDiskSizeWithHeaderL, final int hdrSize)
+      throws IOException {
+      if (
+        (onDiskSizeWithHeaderL < hdrSize && onDiskSizeWithHeaderL != -1)
+          || onDiskSizeWithHeaderL >= Integer.MAX_VALUE
+      ) {
+        throw new IOException(
+          "Invalid onDisksize=" + onDiskSizeWithHeaderL + ": expected to be at least " + hdrSize
+            + " and at most " + Integer.MAX_VALUE + ", or -1");
       }
-      if (value - hdrSize < 0) {
-        if (LOG.isTraceEnabled()) {
-          LOG.trace("onDiskSizeWithHeader={}, hdrSize={}; don't accept a value that is negative"
-            + " after the header size is excluded.", value, hdrSize);
-        }
-        return false;
-      }
-      return true;
+      return (int) onDiskSizeWithHeaderL;
     }
 
     /**
-     * Check that {@code value} provided by the calling context seems reasonable, within a large
-     * margin of error.
-     * @return {@code true} if the value is safe to proceed, {@code false} otherwise.
+     * Verify the passed in onDiskSizeWithHeader aligns with what is in the header else something is
+     * not right.
      */
-    private boolean checkCallerProvidedOnDiskSizeWithHeader(long value) {
-      // same validation logic as is used by Math.toIntExact(long)
-      int intValue = (int) value;
-      if (intValue != value) {
-        if (LOG.isTraceEnabled()) {
-          LOG.trace("onDiskSizeWithHeaderL={}; value exceeds int size limits.", value);
-        }
-        return false;
+    private void verifyOnDiskSizeMatchesHeader(final int passedIn, final ByteBuff headerBuf,
+      final long offset, boolean verifyChecksum) throws IOException {
+      // Assert size provided aligns with what is in the header
+      int fromHeader = getOnDiskSizeWithHeader(headerBuf, verifyChecksum);
+      if (passedIn != fromHeader) {
+        throw new IOException("Passed in onDiskSizeWithHeader=" + passedIn + " != " + fromHeader
+          + ", offset=" + offset + ", fileContext=" + this.fileContext);
       }
-      if (intValue == -1) {
-        // a magic value we expect to see.
-        return true;
-      }
-      return checkOnDiskSizeWithHeader(intValue);
     }
 
     /**
@@ -1610,16 +1609,14 @@ public class HFileBlock implements Cacheable {
       this.prefetchedHeader.set(ph);
     }
 
-    /**
-     * Clear the cached value when its integrity is suspect.
-     */
-    private void invalidateNextBlockHeader() {
-      prefetchedHeader.set(null);
-    }
-
-    private int getNextBlockOnDiskSize(ByteBuff onDiskBlock, int onDiskSizeWithHeader) {
-      return onDiskBlock.getIntAfterPosition(onDiskSizeWithHeader + BlockType.MAGIC_LENGTH)
-        + hdrSize;
+    private int getNextBlockOnDiskSize(boolean readNextHeader, ByteBuff onDiskBlock,
+      int onDiskSizeWithHeader) {
+      int nextBlockOnDiskSize = -1;
+      if (readNextHeader) {
+        nextBlockOnDiskSize =
+          onDiskBlock.getIntAfterPosition(onDiskSizeWithHeader + BlockType.MAGIC_LENGTH) + hdrSize;
+      }
+      return nextBlockOnDiskSize;
     }
 
     private ByteBuff allocate(int size, boolean intoHeap) {
@@ -1649,13 +1646,13 @@ public class HFileBlock implements Cacheable {
         throw new IOException("Invalid offset=" + offset + " trying to read " + "block (onDiskSize="
           + onDiskSizeWithHeaderL + ")");
       }
-      if (!checkCallerProvidedOnDiskSizeWithHeader(onDiskSizeWithHeaderL)) {
-        LOG.trace("Caller provided invalid onDiskSizeWithHeaderL={}", onDiskSizeWithHeaderL);
-        onDiskSizeWithHeaderL = -1;
-      }
-      int onDiskSizeWithHeader = (int) onDiskSizeWithHeaderL;
 
-      // Try to use the cached header. Will serve us in rare case where onDiskSizeWithHeaderL==-1
+      final Span span = Span.current();
+      final AttributesBuilder attributesBuilder = Attributes.builder();
+      Optional.of(Context.current()).map(val -> val.get(CONTEXT_KEY))
+        .ifPresent(c -> c.accept(attributesBuilder));
+      int onDiskSizeWithHeader = checkAndGetSizeAsInt(onDiskSizeWithHeaderL, hdrSize);
+      // Try and get cached header. Will serve us in rare case where onDiskSizeWithHeaderL is -1
       // and will save us having to seek the stream backwards to reread the header we
       // read the last time through here.
       ByteBuff headerBuf = getCachedHeader(offset);
@@ -1668,9 +1665,9 @@ public class HFileBlock implements Cacheable {
       // checksums. Can change with circumstances. The below flag is whether the
       // file has support for checksums (version 2+).
       boolean checksumSupport = this.fileContext.isUseHBaseChecksum();
-      long startTime = System.currentTimeMillis();
-      if (onDiskSizeWithHeader == -1) {
-        // The caller does not know the block size. Need to get it from the header. If header was
+      long startTime = EnvironmentEdgeManager.currentTime();
+      if (onDiskSizeWithHeader <= 0) {
+        // We were not passed the block size. Need to get it from the header. If header was
         // not cached (see getCachedHeader above), need to seek to pull it in. This is costly
         // and should happen very rarely. Currently happens on open of a hfile reader where we
         // read the trailer blocks to pull in the indices. Otherwise, we are reading block sizes
@@ -1678,26 +1675,15 @@ public class HFileBlock implements Cacheable {
         // in a LOG every time we seek. See HBASE-17072 for more detail.
         if (headerBuf == null) {
           if (LOG.isTraceEnabled()) {
-            LOG.trace("Extra see to get block size!", new RuntimeException());
+            LOG.trace("Extra seek to get block size!", new RuntimeException());
           }
+          span.addEvent("Extra seek to get block size!", attributesBuilder.build());
           headerBuf = HEAP.allocate(hdrSize);
           readAtOffset(is, headerBuf, hdrSize, false, offset, pread);
           headerBuf.rewind();
         }
         onDiskSizeWithHeader = getOnDiskSizeWithHeader(headerBuf, checksumSupport);
       }
-
-      // The common case is that onDiskSizeWithHeader was produced by a read without checksum
-      // validation, so give it a sanity check before trying to use it.
-      if (!checkOnDiskSizeWithHeader(onDiskSizeWithHeader)) {
-        if (verifyChecksum) {
-          invalidateNextBlockHeader();
-          return null;
-        } else {
-          throw new IOException("Invalid onDiskSizeWithHeader=" + onDiskSizeWithHeader);
-        }
-      }
-
       int preReadHeaderSize = headerBuf == null ? 0 : hdrSize;
       // Allocate enough space to fit the next block's header too; saves a seek next time through.
       // onDiskBlock is whole block + header + checksums then extra hdrSize to read next header;
@@ -1714,51 +1700,23 @@ public class HFileBlock implements Cacheable {
         boolean readNextHeader = readAtOffset(is, onDiskBlock,
           onDiskSizeWithHeader - preReadHeaderSize, true, offset + preReadHeaderSize, pread);
         onDiskBlock.rewind(); // in case of moving position when copying a cached header
-
-        // the call to validateChecksum for this block excludes the next block header over-read, so
-        // no reason to delay extracting this value.
-        int nextBlockOnDiskSize = -1;
-        if (readNextHeader) {
-          int parsedVal = getNextBlockOnDiskSize(onDiskBlock, onDiskSizeWithHeader);
-          if (checkOnDiskSizeWithHeader(parsedVal)) {
-            nextBlockOnDiskSize = parsedVal;
-          }
-        }
+        int nextBlockOnDiskSize =
+          getNextBlockOnDiskSize(readNextHeader, onDiskBlock, onDiskSizeWithHeader);
         if (headerBuf == null) {
           headerBuf = onDiskBlock.duplicate().position(0).limit(hdrSize);
         }
-
+        // Do a few checks before we go instantiate HFileBlock.
+        assert onDiskSizeWithHeader > this.hdrSize;
+        verifyOnDiskSizeMatchesHeader(onDiskSizeWithHeader, headerBuf, offset, checksumSupport);
         ByteBuff curBlock = onDiskBlock.duplicate().position(0).limit(onDiskSizeWithHeader);
         // Verify checksum of the data before using it for building HFileBlock.
         if (verifyChecksum && !validateChecksum(offset, curBlock, hdrSize)) {
-          invalidateNextBlockHeader();
           return null;
         }
-
-        // TODO: is this check necessary or can we proceed with a provided value regardless of
-        // what is in the header?
-        int fromHeader = getOnDiskSizeWithHeader(headerBuf, checksumSupport);
-        if (onDiskSizeWithHeader != fromHeader) {
-          if (LOG.isTraceEnabled()) {
-            LOG.trace("Passed in onDiskSizeWithHeader={} != {}, offset={}, fileContext={}",
-              onDiskSizeWithHeader, fromHeader, offset, this.fileContext);
-          }
-          if (checksumSupport && verifyChecksum) {
-            // This file supports HBase checksums and verification of those checksums was
-            // requested. The block size provided by the caller (presumably from the block index)
-            // does not match the block size written to the block header. treat this as
-            // HBase-checksum failure.
-            invalidateNextBlockHeader();
-            return null;
-          }
-          throw new IOException("Passed in onDiskSizeWithHeader=" + onDiskSizeWithHeader + " != "
-            + fromHeader + ", offset=" + offset + ", fileContext=" + this.fileContext);
-        }
-
         // remove checksum from buffer now that it's verified
         int sizeWithoutChecksum = curBlock.getInt(Header.ON_DISK_DATA_SIZE_WITH_HEADER_INDEX);
         curBlock.limit(sizeWithoutChecksum);
-        long duration = System.currentTimeMillis() - startTime;
+        long duration = EnvironmentEdgeManager.currentTime() - startTime;
         if (updateMetrics) {
           HFile.updateReadLatency(duration, pread);
         }
@@ -1772,6 +1730,7 @@ public class HFileBlock implements Cacheable {
           hFileBlock.sanityCheckUncompressed();
         }
         LOG.trace("Read {} in {} ms", hFileBlock, duration);
+        span.addEvent("Read block", attributesBuilder.build());
         // Cache next block header if we read it for the next time through here.
         if (nextBlockOnDiskSize != -1) {
           cacheNextBlockHeader(offset + hFileBlock.getOnDiskSizeWithHeader(), onDiskBlock,
@@ -1793,8 +1752,8 @@ public class HFileBlock implements Cacheable {
     }
 
     @Override
-    public void setDataBlockEncoder(HFileDataBlockEncoder encoder) {
-      encodedBlockDecodingCtx = encoder.newDataBlockDecodingContext(this.fileContext);
+    public void setDataBlockEncoder(HFileDataBlockEncoder encoder, Configuration conf) {
+      encodedBlockDecodingCtx = encoder.newDataBlockDecodingContext(conf, fileContext);
     }
 
     @Override
@@ -1860,9 +1819,9 @@ public class HFileBlock implements Cacheable {
   // Cacheable implementation
   @Override
   public int getSerializedLength() {
-    if (bufWithoutChecksum != null) {
+    if (buf != null) {
       // Include extra bytes for block metadata.
-      return this.bufWithoutChecksum.limit() + BLOCK_METADATA_SPACE;
+      return this.buf.limit() + BLOCK_METADATA_SPACE;
     }
     return 0;
   }
@@ -1870,7 +1829,7 @@ public class HFileBlock implements Cacheable {
   // Cacheable implementation
   @Override
   public void serialize(ByteBuffer destination, boolean includeNextBlockMetadata) {
-    this.bufWithoutChecksum.get(destination, 0, getSerializedLength() - BLOCK_METADATA_SPACE);
+    this.buf.get(destination, 0, getSerializedLength() - BLOCK_METADATA_SPACE);
     destination = addMetaData(destination, includeNextBlockMetadata);
 
     // Make it ready for reading. flip sets position to zero and limit to current position which
@@ -1882,8 +1841,7 @@ public class HFileBlock implements Cacheable {
   /**
    * For use by bucketcache. This exposes internals.
    */
-  public ByteBuffer getMetaData() {
-    ByteBuffer bb = ByteBuffer.allocate(BLOCK_METADATA_SPACE);
+  public ByteBuffer getMetaData(ByteBuffer bb) {
     bb = addMetaData(bb, true);
     bb.flip();
     return bb;
@@ -1917,7 +1875,7 @@ public class HFileBlock implements Cacheable {
     result = result * 31 + onDiskSizeWithoutHeader;
     result = result * 31 + (int) (prevBlockOffset ^ (prevBlockOffset >>> 32));
     result = result * 31 + uncompressedSizeWithoutHeader;
-    result = result * 31 + bufWithoutChecksum.hashCode();
+    result = result * 31 + buf.hashCode();
     return result;
   }
 
@@ -1955,8 +1913,8 @@ public class HFileBlock implements Cacheable {
       return false;
     }
     if (
-      ByteBuff.compareTo(this.bufWithoutChecksum, 0, this.bufWithoutChecksum.limit(),
-        castedComparison.bufWithoutChecksum, 0, castedComparison.bufWithoutChecksum.limit()) != 0
+      ByteBuff.compareTo(this.buf, 0, this.buf.limit(), castedComparison.buf, 0,
+        castedComparison.buf.limit()) != 0
     ) {
       return false;
     }
@@ -1984,17 +1942,10 @@ public class HFileBlock implements Cacheable {
   }
 
   /**
-   * Return the number of bytes required to store all the checksums for this block. Each checksum
-   * value is a 4 byte integer. <br/>
-   * NOTE: ByteBuff returned by {@link HFileBlock#getBufferWithoutHeader()} and
-   * {@link HFileBlock#getBufferReadOnly} or DataInputStream returned by
-   * {@link HFileBlock#getByteStream()} does not include checksum.
+   * Calculate the number of bytes required to store all the checksums for this block. Each checksum
+   * value is a 4 byte integer.
    */
   int totalChecksumBytes() {
-    return totalChecksumBytes;
-  }
-
-  private int computeTotalChecksumBytes() {
     // If the hfile block has minorVersion 0, then there are no checksum
     // data to validate. Similarly, a zero value in this.bytesPerChecksum
     // indicates that cached blocks do not have checksum data because
@@ -2091,8 +2042,7 @@ public class HFileBlock implements Cacheable {
   }
 
   static HFileBlock deepCloneOnHeap(HFileBlock blk) {
-    ByteBuff deepCloned = ByteBuff
-      .wrap(ByteBuffer.wrap(blk.bufWithoutChecksum.toBytes(0, blk.bufWithoutChecksum.limit())));
+    ByteBuff deepCloned = ByteBuff.wrap(ByteBuffer.wrap(blk.buf.toBytes(0, blk.buf.limit())));
     return createBuilder(blk, deepCloned).build();
   }
 }
