@@ -17,6 +17,10 @@
  */
 package org.apache.hadoop.hbase.io.hfile;
 
+import static org.apache.hadoop.hbase.trace.HBaseSemanticAttributes.BLOCK_CACHE_KEY_KEY;
+
+import io.opentelemetry.api.common.Attributes;
+import io.opentelemetry.api.trace.Span;
 import java.io.DataInput;
 import java.io.IOException;
 import java.nio.ByteBuffer;
@@ -42,13 +46,11 @@ import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
 import org.apache.hadoop.hbase.io.encoding.HFileBlockDecodingContext;
 import org.apache.hadoop.hbase.nio.ByteBuff;
 import org.apache.hadoop.hbase.regionserver.KeyValueScanner;
-import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.hadoop.hbase.util.ByteBufferUtils;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.IdLock;
 import org.apache.hadoop.hbase.util.ObjectIntPair;
 import org.apache.hadoop.io.WritableUtils;
-import org.apache.htrace.core.TraceScope;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -138,9 +140,9 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
     this.trailer = fileInfo.getTrailer();
     this.hfileContext = fileInfo.getHFileContext();
     this.fsBlockReader =
-      new HFileBlock.FSReaderImpl(context, hfileContext, cacheConf.getByteBuffAllocator());
+      new HFileBlock.FSReaderImpl(context, hfileContext, cacheConf.getByteBuffAllocator(), conf);
     this.dataBlockEncoder = HFileDataBlockEncoderImpl.createFromFileInfo(fileInfo);
-    fsBlockReader.setDataBlockEncoder(dataBlockEncoder);
+    fsBlockReader.setDataBlockEncoder(dataBlockEncoder, conf);
     dataBlockIndexReader = fileInfo.getDataBlockIndexReader();
     metaBlockIndexReader = fileInfo.getMetaBlockIndexReader();
   }
@@ -247,7 +249,7 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
   @Override
   public void setDataBlockEncoder(HFileDataBlockEncoder dataBlockEncoder) {
     this.dataBlockEncoder = dataBlockEncoder;
-    this.fsBlockReader.setDataBlockEncoder(dataBlockEncoder);
+    this.fsBlockReader.setDataBlockEncoder(dataBlockEncoder, conf);
   }
 
   @Override
@@ -514,8 +516,8 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
      * Within a loaded block, seek looking for the last key that is smaller than (or equal to?) the
      * key we are interested in. A note on the seekBefore: if you have seekBefore = true, AND the
      * first key in the block = key, then you'll get thrown exceptions. The caller has to check for
-     * that case and load the previous block as appropriate. the key to find find the key before the
-     * given key in case of exact match.
+     * that case and load the previous block as appropriate. n * the key to find n * find the key
+     * before the given key in case of exact match.
      * @return 0 in case of an exact key match, 1 in case of an inexact match, -2 in case of an
      *         inexact match and furthermore, the input key less than the first key of current
      *         block(e.g. using a faked index key)
@@ -1082,7 +1084,7 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
    * and its encoding vs. {@code expectedDataBlockEncoding}. Unpacks the block as necessary.
    */
   private HFileBlock getCachedBlock(BlockCacheKey cacheKey, boolean cacheBlock, boolean useLock,
-    boolean updateCacheMetrics, BlockType expectedBlockType,
+    boolean isCompaction, boolean updateCacheMetrics, BlockType expectedBlockType,
     DataBlockEncoding expectedDataBlockEncoding) throws IOException {
     // Check cache for block. If found return.
     BlockCache cache = cacheConf.getBlockCache().orElse(null);
@@ -1187,7 +1189,7 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
 
       cacheBlock &= cacheConf.shouldCacheBlockOnRead(BlockType.META.getCategory());
       HFileBlock cachedBlock =
-        getCachedBlock(cacheKey, cacheBlock, false, true, BlockType.META, null);
+        getCachedBlock(cacheKey, cacheBlock, false, true, true, BlockType.META, null);
       if (cachedBlock != null) {
         assert cachedBlock.isUnpacked() : "Packed block leak.";
         // Return a distinct 'shallow copy' of the block,
@@ -1234,15 +1236,6 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
   public HFileBlock readBlock(long dataBlockOffset, long onDiskBlockSize, final boolean cacheBlock,
     boolean pread, final boolean isCompaction, boolean updateCacheMetrics,
     BlockType expectedBlockType, DataBlockEncoding expectedDataBlockEncoding) throws IOException {
-    return readBlock(dataBlockOffset, onDiskBlockSize, cacheBlock, pread, isCompaction,
-      updateCacheMetrics, expectedBlockType, expectedDataBlockEncoding, false);
-  }
-
-  @Override
-  public HFileBlock readBlock(long dataBlockOffset, long onDiskBlockSize, final boolean cacheBlock,
-    boolean pread, final boolean isCompaction, boolean updateCacheMetrics,
-    BlockType expectedBlockType, DataBlockEncoding expectedDataBlockEncoding, boolean cacheOnly)
-    throws IOException {
     if (dataBlockIndexReader == null) {
       throw new IOException(path + " block index not loaded");
     }
@@ -1260,26 +1253,27 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
 
     BlockCacheKey cacheKey =
       new BlockCacheKey(name, dataBlockOffset, this.isPrimaryReplicaReader(), expectedBlockType);
+    Attributes attributes = Attributes.of(BLOCK_CACHE_KEY_KEY, cacheKey.toString());
 
     boolean useLock = false;
     IdLock.Entry lockEntry = null;
-    try (TraceScope traceScope = TraceUtil.createTrace("HFileReaderImpl.readBlock")) {
+    final Span span = Span.current();
+    try {
       while (true) {
         // Check cache for block. If found return.
-        if (cacheConf.shouldReadBlockFromCache(expectedBlockType) && !cacheOnly) {
+        if (cacheConf.shouldReadBlockFromCache(expectedBlockType)) {
           if (useLock) {
             lockEntry = offsetLock.getLockEntry(dataBlockOffset);
           }
           // Try and get the block from the block cache. If the useLock variable is true then this
           // is the second time through the loop and it should not be counted as a block cache miss.
-          HFileBlock cachedBlock = getCachedBlock(cacheKey, cacheBlock, useLock, updateCacheMetrics,
-            expectedBlockType, expectedDataBlockEncoding);
+          HFileBlock cachedBlock = getCachedBlock(cacheKey, cacheBlock, useLock, isCompaction,
+            updateCacheMetrics, expectedBlockType, expectedDataBlockEncoding);
           if (cachedBlock != null) {
             if (LOG.isTraceEnabled()) {
-              LOG.trace("Block for file {} is coming from Cache {}",
-                Bytes.toString(cachedBlock.getHFileContext().getTableName()), cachedBlock);
+              LOG.trace("From Cache {}", cachedBlock);
             }
-            TraceUtil.addTimelineAnnotation("blockCacheHit");
+            span.addEvent("block cache hit", attributes);
             assert cachedBlock.isUnpacked() : "Packed block leak.";
             if (cachedBlock.getBlockType().isData()) {
               if (updateCacheMetrics) {
@@ -1309,37 +1303,20 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
           // Carry on, please load.
         }
 
-        TraceUtil.addTimelineAnnotation("blockCacheMiss");
+        span.addEvent("block cache miss", attributes);
         // Load block from filesystem.
         HFileBlock hfileBlock = fsBlockReader.readBlockData(dataBlockOffset, onDiskBlockSize, pread,
           !isCompaction, shouldUseHeap(expectedBlockType));
         validateBlockType(hfileBlock, expectedBlockType);
-        BlockType.BlockCategory category = hfileBlock.getBlockType().getCategory();
-        final boolean cacheCompressed = cacheConf.shouldCacheCompressed(category);
-        final boolean cacheOnRead = cacheConf.shouldCacheBlockOnRead(category);
-
-        // Don't need the unpacked block back and we're storing the block in the cache compressed
-        if (cacheOnly && cacheCompressed && cacheOnRead) {
-          LOG.debug("Skipping decompression of block in prefetch");
-          // Cache the block if necessary
-          cacheConf.getBlockCache().ifPresent(cache -> {
-            if (cacheBlock && cacheConf.shouldCacheBlockOnRead(category)) {
-              cache.cacheBlock(cacheKey, hfileBlock, cacheConf.isInMemory(), cacheOnly);
-            }
-          });
-
-          if (updateCacheMetrics && hfileBlock.getBlockType().isData()) {
-            HFile.DATABLOCK_READ_COUNT.increment();
-          }
-          return hfileBlock;
-        }
         HFileBlock unpacked = hfileBlock.unpack(hfileContext, fsBlockReader);
+        BlockType.BlockCategory category = hfileBlock.getBlockType().getCategory();
+
         // Cache the block if necessary
         cacheConf.getBlockCache().ifPresent(cache -> {
           if (cacheBlock && cacheConf.shouldCacheBlockOnRead(category)) {
-            // Using the wait on cache during compaction and prefetching.
-            cache.cacheBlock(cacheKey, cacheCompressed ? hfileBlock : unpacked,
-              cacheConf.isInMemory(), cacheOnly);
+            cache.cacheBlock(cacheKey,
+              cacheConf.shouldCacheCompressed(category) ? hfileBlock : unpacked,
+              cacheConf.isInMemory());
           }
         });
         if (unpacked != hfileBlock) {
@@ -1432,11 +1409,11 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
     private final DataBlockEncoder dataBlockEncoder;
 
     public EncodedScanner(HFile.Reader reader, boolean cacheBlocks, boolean pread,
-      boolean isCompaction, HFileContext meta) {
+      boolean isCompaction, HFileContext meta, Configuration conf) {
       super(reader, cacheBlocks, pread, isCompaction);
       DataBlockEncoding encoding = reader.getDataBlockEncoding();
       dataBlockEncoder = encoding.getEncoder();
-      decodingCtx = dataBlockEncoder.newDataBlockDecodingContext(meta);
+      decodingCtx = dataBlockEncoder.newDataBlockDecodingContext(conf, meta);
       seeker = dataBlockEncoder.createSeeker(decodingCtx);
     }
 
@@ -1618,45 +1595,37 @@ public abstract class HFileReaderImpl implements HFile.Reader, Configurable {
     return PrefetchExecutor.isCompleted(path);
   }
 
-  /**
-   * Returns true if block prefetching was started after waiting for specified delay, false
-   * otherwise
-   */
-  @Override
-  public boolean prefetchStarted() {
-    return PrefetchExecutor.isPrefetchStarted();
-  }
-
   /**
    * Create a Scanner on this file. No seeks or reads are done on creation. Call
    * {@link HFileScanner#seekTo(Cell)} to position an start the read. There is nothing to clean up
    * in a Scanner. Letting go of your references to the scanner is sufficient. NOTE: Do not use this
-   * overload of getScanner for compactions. See {@link #getScanner(boolean, boolean, boolean)}
+   * overload of getScanner for compactions. See
+   * {@link #getScanner(Configuration, boolean, boolean, boolean)}
+   * @param conf        Store configuration.
    * @param cacheBlocks True if we should cache blocks read in by this scanner.
    * @param pread       Use positional read rather than seek+read if true (pread is better for
    *                    random reads, seek+read is better scanning).
    * @return Scanner on this file.
    */
   @Override
-  public HFileScanner getScanner(boolean cacheBlocks, final boolean pread) {
-    return getScanner(cacheBlocks, pread, false);
+  public HFileScanner getScanner(Configuration conf, boolean cacheBlocks, final boolean pread) {
+    return getScanner(conf, cacheBlocks, pread, false);
   }
 
   /**
    * Create a Scanner on this file. No seeks or reads are done on creation. Call
    * {@link HFileScanner#seekTo(Cell)} to position an start the read. There is nothing to clean up
-   * in a Scanner. Letting go of your references to the scanner is sufficient.
-   * @param cacheBlocks  True if we should cache blocks read in by this scanner.
-   * @param pread        Use positional read rather than seek+read if true (pread is better for
-   *                     random reads, seek+read is better scanning).
-   * @param isCompaction is scanner being used for a compaction?
+   * in a Scanner. Letting go of your references to the scanner is sufficient. n * Store
+   * configuration. n * True if we should cache blocks read in by this scanner. n * Use positional
+   * read rather than seek+read if true (pread is better for random reads, seek+read is better
+   * scanning). n * is scanner being used for a compaction?
    * @return Scanner on this file.
    */
   @Override
-  public HFileScanner getScanner(boolean cacheBlocks, final boolean pread,
+  public HFileScanner getScanner(Configuration conf, boolean cacheBlocks, final boolean pread,
     final boolean isCompaction) {
     if (dataBlockEncoder.useEncodedScanner()) {
-      return new EncodedScanner(this, cacheBlocks, pread, isCompaction, this.hfileContext);
+      return new EncodedScanner(this, cacheBlocks, pread, isCompaction, this.hfileContext, conf);
     }
     return new HFileScannerImpl(this, cacheBlocks, pread, isCompaction);
   }
