@@ -19,6 +19,11 @@ package org.apache.hadoop.hbase.ipc;
 
 import static org.apache.hadoop.hbase.HConstants.RPC_HEADER;
 
+import io.opentelemetry.api.GlobalOpenTelemetry;
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.context.Context;
+import io.opentelemetry.context.Scope;
+import io.opentelemetry.context.propagation.TextMapGetter;
 import java.io.ByteArrayInputStream;
 import java.io.Closeable;
 import java.io.DataOutputStream;
@@ -51,6 +56,7 @@ import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.security.provider.SaslServerAuthenticationProvider;
 import org.apache.hadoop.hbase.security.provider.SaslServerAuthenticationProviders;
 import org.apache.hadoop.hbase.security.provider.SimpleSaslServerAuthenticationProvider;
+import org.apache.hadoop.hbase.trace.TraceUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.io.BytesWritable;
 import org.apache.hadoop.io.IntWritable;
@@ -80,13 +86,16 @@ import org.apache.hadoop.hbase.shaded.protobuf.generated.RPCProtos.ConnectionHea
 import org.apache.hadoop.hbase.shaded.protobuf.generated.RPCProtos.RequestHeader;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.RPCProtos.ResponseHeader;
 import org.apache.hadoop.hbase.shaded.protobuf.generated.RPCProtos.UserInformation;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.TracingProtos.RPCTInfo;
 
 /** Reads calls from a connection and queues them for handling. */
 @edu.umd.cs.findbugs.annotations.SuppressWarnings(value = "VO_VOLATILE_INCREMENT",
     justification = "False positive according to http://sourceforge.net/p/findbugs/bugs/1032/")
 @InterfaceAudience.Private
 abstract class ServerRpcConnection implements Closeable {
-  /**  */
+
+  private static final TextMapGetter<RPCTInfo> getter = new RPCTInfoGetter();
+
   protected final RpcServer rpcServer;
   // If the connection header has been read or not.
   protected boolean connectionHeaderRead = false;
@@ -170,7 +179,7 @@ abstract class ServerRpcConnection implements Closeable {
   }
 
   /**
-   * Set up cell block codecs
+   * Set up cell block codecs n
    */
   private void setupCellBlockCodecs(final ConnectionHeader header) throws FatalConnectionException {
     // TODO: Plug in other supported decoders.
@@ -193,7 +202,7 @@ abstract class ServerRpcConnection implements Closeable {
   }
 
   /**
-   * Set up cipher for rpc encryption with Apache Commons Crypto
+   * Set up cipher for rpc encryption with Apache Commons Crypto n
    */
   private void setupCryptoCipher(final ConnectionHeader header,
     RPCProtos.ConnectionHeaderResponse.Builder chrBuilder) throws FatalConnectionException {
@@ -571,10 +580,8 @@ abstract class ServerRpcConnection implements Closeable {
   protected abstract void doRespond(RpcResponse resp) throws IOException;
 
   /**
-   * Has the request header and the request param and optionally encoded data buffer all in this one
-   * array.
-   * <p/>
-   * Will be overridden in tests.
+   * n * Has the request header and the request param and optionally encoded data buffer all in this
+   * one array. nn
    */
   protected void processRequest(ByteBuff buf) throws IOException, InterruptedException {
     long totalRequestSize = buf.limit();
@@ -596,96 +603,123 @@ abstract class ServerRpcConnection implements Closeable {
     ProtobufUtil.mergeFrom(builder, cis, headerSize);
     RequestHeader header = (RequestHeader) builder.build();
     offset += headerSize;
-    int id = header.getCallId();
-    if (RpcServer.LOG.isTraceEnabled()) {
-      RpcServer.LOG.trace("RequestHeader " + TextFormat.shortDebugString(header)
-        + " totalRequestSize: " + totalRequestSize + " bytes");
-    }
-    // Enforcing the call queue size, this triggers a retry in the client
-    // This is a bit late to be doing this check - we have already read in the
-    // total request.
-    if (
-      (totalRequestSize + this.rpcServer.callQueueSizeInBytes.sum())
-          > this.rpcServer.maxQueueSizeInBytes
-    ) {
-      final ServerCall<?> callTooBig = createCall(id, this.service, null, null, null, null,
-        totalRequestSize, null, 0, this.callCleanup);
-      this.rpcServer.metrics.exception(RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION);
-      callTooBig.setResponse(null, null, RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION,
-        "Call queue is full on " + this.rpcServer.server.getServerName()
-          + ", is hbase.ipc.server.max.callqueue.size too small?");
-      callTooBig.sendResponseIfReady();
-      return;
-    }
-    MethodDescriptor md = null;
-    Message param = null;
-    CellScanner cellScanner = null;
-    try {
-      if (header.hasRequestParam() && header.getRequestParam()) {
-        md = this.service.getDescriptorForType().findMethodByName(header.getMethodName());
-        if (md == null) throw new UnsupportedOperationException(header.getMethodName());
-        builder = this.service.getRequestPrototype(md).newBuilderForType();
-        cis.resetSizeCounter();
-        int paramSize = cis.readRawVarint32();
-        offset += cis.getTotalBytesRead();
-        if (builder != null) {
-          ProtobufUtil.mergeFrom(builder, cis, paramSize);
-          param = builder.build();
+    Context traceCtx = GlobalOpenTelemetry.getPropagators().getTextMapPropagator()
+      .extract(Context.current(), header.getTraceInfo(), getter);
+
+    // n.b. Management of this Span instance is a little odd. Most exit paths from this try scope
+    // are early-exits due to error cases. There's only one success path, the asynchronous call to
+    // RpcScheduler#dispatch. The success path assumes ownership of the span, which is represented
+    // by null-ing out the reference in this scope. All other paths end the span. Thus, and in
+    // order to avoid accidentally orphaning the span, the call to Span#end happens in a finally
+    // block iff the span is non-null.
+    Span span = TraceUtil.createRemoteSpan("RpcServer.process", traceCtx);
+    try (Scope ignored = span.makeCurrent()) {
+      int id = header.getCallId();
+      if (RpcServer.LOG.isTraceEnabled()) {
+        RpcServer.LOG.trace("RequestHeader " + TextFormat.shortDebugString(header)
+          + " totalRequestSize: " + totalRequestSize + " bytes");
+      }
+      // Enforcing the call queue size, this triggers a retry in the client
+      // This is a bit late to be doing this check - we have already read in the
+      // total request.
+      if (
+        (totalRequestSize + this.rpcServer.callQueueSizeInBytes.sum())
+            > this.rpcServer.maxQueueSizeInBytes
+      ) {
+        final ServerCall<?> callTooBig = createCall(id, this.service, null, null, null, null,
+          totalRequestSize, null, 0, this.callCleanup);
+        this.rpcServer.metrics.exception(RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION);
+        callTooBig.setResponse(null, null, RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION,
+          "Call queue is full on " + this.rpcServer.server.getServerName()
+            + ", is hbase.ipc.server.max.callqueue.size too small?");
+        TraceUtil.setError(span, RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION);
+        callTooBig.sendResponseIfReady();
+        return;
+      }
+      MethodDescriptor md = null;
+      Message param = null;
+      CellScanner cellScanner = null;
+      try {
+        if (header.hasRequestParam() && header.getRequestParam()) {
+          md = this.service.getDescriptorForType().findMethodByName(header.getMethodName());
+          if (md == null) {
+            throw new UnsupportedOperationException(header.getMethodName());
+          }
+          builder = this.service.getRequestPrototype(md).newBuilderForType();
+          cis.resetSizeCounter();
+          int paramSize = cis.readRawVarint32();
+          offset += cis.getTotalBytesRead();
+          if (builder != null) {
+            ProtobufUtil.mergeFrom(builder, cis, paramSize);
+            param = builder.build();
+          }
+          offset += paramSize;
+        } else {
+          // currently header must have request param, so we directly throw
+          // exception here
+          String msg = "Invalid request header: " + TextFormat.shortDebugString(header)
+            + ", should have param set in it";
+          RpcServer.LOG.warn(msg);
+          throw new DoNotRetryIOException(msg);
         }
-        offset += paramSize;
+        if (header.hasCellBlockMeta()) {
+          buf.position(offset);
+          ByteBuff dup = buf.duplicate();
+          dup.limit(offset + header.getCellBlockMeta().getLength());
+          cellScanner = this.rpcServer.cellBlockBuilder.createCellScannerReusingBuffers(this.codec,
+            this.compressionCodec, dup);
+        }
+      } catch (Throwable thrown) {
+        InetSocketAddress address = this.rpcServer.getListenerAddress();
+        String msg = (address != null ? address : "(channel closed)")
+          + " is unable to read call parameter from client " + getHostAddress();
+        RpcServer.LOG.warn(msg, thrown);
+
+        this.rpcServer.metrics.exception(thrown);
+
+        final Throwable responseThrowable;
+        if (thrown instanceof LinkageError) {
+          // probably the hbase hadoop version does not match the running hadoop version
+          responseThrowable = new DoNotRetryIOException(thrown);
+        } else if (thrown instanceof UnsupportedOperationException) {
+          // If the method is not present on the server, do not retry.
+          responseThrowable = new DoNotRetryIOException(thrown);
+        } else {
+          responseThrowable = thrown;
+        }
+
+        ServerCall<?> readParamsFailedCall = createCall(id, this.service, null, null, null, null,
+          totalRequestSize, null, 0, this.callCleanup);
+        readParamsFailedCall.setResponse(null, null, responseThrowable,
+          msg + "; " + responseThrowable.getMessage());
+        TraceUtil.setError(span, responseThrowable);
+        readParamsFailedCall.sendResponseIfReady();
+        return;
+      }
+
+      int timeout = 0;
+      if (header.hasTimeout() && header.getTimeout() > 0) {
+        timeout = Math.max(this.rpcServer.minClientRequestTimeout, header.getTimeout());
+      }
+      ServerCall<?> call = createCall(id, this.service, md, header, param, cellScanner,
+        totalRequestSize, this.addr, timeout, this.callCleanup);
+
+      if (this.rpcServer.scheduler.dispatch(new CallRunner(this.rpcServer, call))) {
+        // unset span do that it's not closed in the finally block
+        span = null;
       } else {
-        // currently header must have request param, so we directly throw
-        // exception here
-        String msg = "Invalid request header: " + TextFormat.shortDebugString(header)
-          + ", should have param set in it";
-        RpcServer.LOG.warn(msg);
-        throw new DoNotRetryIOException(msg);
+        this.rpcServer.callQueueSizeInBytes.add(-1 * call.getSize());
+        this.rpcServer.metrics.exception(RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION);
+        call.setResponse(null, null, RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION,
+          "Call queue is full on " + this.rpcServer.server.getServerName()
+            + ", too many items queued ?");
+        TraceUtil.setError(span, RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION);
+        call.sendResponseIfReady();
       }
-      if (header.hasCellBlockMeta()) {
-        buf.position(offset);
-        ByteBuff dup = buf.duplicate();
-        dup.limit(offset + header.getCellBlockMeta().getLength());
-        cellScanner = this.rpcServer.cellBlockBuilder.createCellScannerReusingBuffers(this.codec,
-          this.compressionCodec, dup);
+    } finally {
+      if (span != null) {
+        span.end();
       }
-    } catch (Throwable t) {
-      InetSocketAddress address = this.rpcServer.getListenerAddress();
-      String msg = (address != null ? address : "(channel closed)")
-        + " is unable to read call parameter from client " + getHostAddress();
-      RpcServer.LOG.warn(msg, t);
-
-      this.rpcServer.metrics.exception(t);
-
-      // probably the hbase hadoop version does not match the running hadoop
-      // version
-      if (t instanceof LinkageError) {
-        t = new DoNotRetryIOException(t);
-      }
-      // If the method is not present on the server, do not retry.
-      if (t instanceof UnsupportedOperationException) {
-        t = new DoNotRetryIOException(t);
-      }
-
-      ServerCall<?> readParamsFailedCall = createCall(id, this.service, null, null, null, null,
-        totalRequestSize, null, 0, this.callCleanup);
-      readParamsFailedCall.setResponse(null, null, t, msg + "; " + t.getMessage());
-      readParamsFailedCall.sendResponseIfReady();
-      return;
-    }
-
-    int timeout = 0;
-    if (header.hasTimeout() && header.getTimeout() > 0) {
-      timeout = Math.max(this.rpcServer.minClientRequestTimeout, header.getTimeout());
-    }
-    ServerCall<?> call = createCall(id, this.service, md, header, param, cellScanner,
-      totalRequestSize, this.addr, timeout, this.callCleanup);
-
-    if (!this.rpcServer.scheduler.dispatch(new CallRunner(this.rpcServer, call))) {
-      this.rpcServer.callQueueSizeInBytes.add(-1 * call.getSize());
-      this.rpcServer.metrics.exception(RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION);
-      call.setResponse(null, null, RpcServer.CALL_QUEUE_TOO_BIG_EXCEPTION, "Call queue is full on "
-        + this.rpcServer.server.getServerName() + ", too many items queued ?");
-      call.sendResponseIfReady();
     }
   }
 
