@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -21,19 +21,21 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Abortable;
 import org.apache.hadoop.hbase.HBaseInterfaceAudience;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.yetus.audience.InterfaceAudience;
-import org.apache.yetus.audience.InterfaceStability;
 import org.apache.hadoop.hbase.conf.ConfigurationObserver;
 import org.apache.hadoop.hbase.master.MasterAnnotationReadingPriorityFunction;
+import org.apache.yetus.audience.InterfaceAudience;
+import org.apache.yetus.audience.InterfaceStability;
 
 /**
  * The default scheduler. Configurable. Maintains isolated handler pools for general ('default'),
  * high-priority ('priority'), and replication ('replication') requests. Default behavior is to
- * balance the requests across handlers. Add configs to enable balancing by read vs writes, etc.
- * See below article for explanation of options.
- * @see <a href="http://blog.cloudera.com/blog/2014/12/new-in-cdh-5-2-improvements-for-running-multiple-workloads-on-a-single-hbase-cluster/">Overview on Request Queuing</a>
+ * balance the requests across handlers. Add configs to enable balancing by read vs writes, etc. See
+ * below article for explanation of options.
+ * @see <a href=
+ *      "http://blog.cloudera.com/blog/2014/12/new-in-cdh-5-2-improvements-for-running-multiple-workloads-on-a-single-hbase-cluster/">Overview
+ *      on Request Queuing</a>
  */
-@InterfaceAudience.LimitedPrivate({HBaseInterfaceAudience.COPROC, HBaseInterfaceAudience.PHOENIX})
+@InterfaceAudience.LimitedPrivate({ HBaseInterfaceAudience.COPROC, HBaseInterfaceAudience.PHOENIX })
 @InterfaceStability.Evolving
 public class SimpleRpcScheduler extends RpcScheduler implements ConfigurationObserver {
   private int port;
@@ -53,83 +55,80 @@ public class SimpleRpcScheduler extends RpcScheduler implements ConfigurationObs
   private Abortable abortable = null;
 
   /**
-   * @param conf
-   * @param handlerCount the number of handler threads that will be used to process calls
-   * @param priorityHandlerCount How many threads for priority handling.
-   * @param replicationHandlerCount How many threads for replication handling.
-   * @param highPriorityLevel
-   * @param priority Function to extract request priority.
+   * n * @param handlerCount the number of handler threads that will be used to process calls
+   * @param priorityHandlerCount    How many threads for priority handling.
+   * @param replicationHandlerCount How many threads for replication handling. n * @param priority
+   *                                Function to extract request priority.
    */
-  public SimpleRpcScheduler(
-      Configuration conf,
-      int handlerCount,
-      int priorityHandlerCount,
-      int replicationHandlerCount,
-      int metaTransitionHandler,
-      PriorityFunction priority,
-      Abortable server,
-      int highPriorityLevel) {
+  public SimpleRpcScheduler(Configuration conf, int handlerCount, int priorityHandlerCount,
+    int replicationHandlerCount, int metaTransitionHandler, PriorityFunction priority,
+    Abortable server, int highPriorityLevel) {
 
     int maxQueueLength = conf.getInt(RpcScheduler.IPC_SERVER_MAX_CALLQUEUE_LENGTH,
-        handlerCount * RpcServer.DEFAULT_MAX_CALLQUEUE_LENGTH_PER_HANDLER);
-    int maxPriorityQueueLength =
-        conf.getInt(RpcScheduler.IPC_SERVER_PRIORITY_MAX_CALLQUEUE_LENGTH, maxQueueLength);
+      handlerCount * RpcServer.DEFAULT_MAX_CALLQUEUE_LENGTH_PER_HANDLER);
+    int maxPriorityQueueLength = conf.getInt(RpcScheduler.IPC_SERVER_PRIORITY_MAX_CALLQUEUE_LENGTH,
+      priorityHandlerCount * RpcServer.DEFAULT_MAX_CALLQUEUE_LENGTH_PER_HANDLER);
+    int maxReplicationQueueLength =
+      conf.getInt(RpcScheduler.IPC_SERVER_REPLICATION_MAX_CALLQUEUE_LENGTH,
+        replicationHandlerCount * RpcServer.DEFAULT_MAX_CALLQUEUE_LENGTH_PER_HANDLER);
 
     this.priority = priority;
     this.highPriorityLevel = highPriorityLevel;
     this.abortable = server;
 
-    String callQueueType = conf.get(RpcExecutor.CALL_QUEUE_TYPE_CONF_KEY,
-      RpcExecutor.CALL_QUEUE_TYPE_CONF_DEFAULT);
+    String callQueueType =
+      conf.get(RpcExecutor.CALL_QUEUE_TYPE_CONF_KEY, RpcExecutor.CALL_QUEUE_TYPE_CONF_DEFAULT);
     float callqReadShare = conf.getFloat(RWQueueRpcExecutor.CALL_QUEUE_READ_SHARE_CONF_KEY, 0);
 
     if (callqReadShare > 0) {
       // at least 1 read handler and 1 write handler
-      callExecutor = new RWQueueRpcExecutor("default.RWQ", Math.max(2, handlerCount),
+      callExecutor = new FastPathRWQueueRpcExecutor("default.FPRWQ", Math.max(2, handlerCount),
         maxQueueLength, priority, conf, server);
     } else {
-      if (RpcExecutor.isFifoQueueType(callQueueType) ||
-        RpcExecutor.isCodelQueueType(callQueueType) ||
-        RpcExecutor.isPluggableQueueWithFastPath(callQueueType, conf)) {
+      if (
+        RpcExecutor.isFifoQueueType(callQueueType) || RpcExecutor.isCodelQueueType(callQueueType)
+          || RpcExecutor.isPluggableQueueWithFastPath(callQueueType, conf)
+      ) {
         callExecutor = new FastPathBalancedQueueRpcExecutor("default.FPBQ", handlerCount,
-            maxQueueLength, priority, conf, server);
+          maxQueueLength, priority, conf, server);
       } else {
         callExecutor = new BalancedQueueRpcExecutor("default.BQ", handlerCount, maxQueueLength,
-            priority, conf, server);
+          priority, conf, server);
       }
     }
 
     float metaCallqReadShare =
-        conf.getFloat(MetaRWQueueRpcExecutor.META_CALL_QUEUE_READ_SHARE_CONF_KEY,
-            MetaRWQueueRpcExecutor.DEFAULT_META_CALL_QUEUE_READ_SHARE);
+      conf.getFloat(MetaRWQueueRpcExecutor.META_CALL_QUEUE_READ_SHARE_CONF_KEY,
+        MetaRWQueueRpcExecutor.DEFAULT_META_CALL_QUEUE_READ_SHARE);
     if (metaCallqReadShare > 0) {
       // different read/write handler for meta, at least 1 read handler and 1 write handler
-      this.priorityExecutor =
-          new MetaRWQueueRpcExecutor("priority.RWQ", Math.max(2, priorityHandlerCount),
-              maxPriorityQueueLength, priority, conf, server);
+      this.priorityExecutor = new MetaRWQueueRpcExecutor("priority.RWQ",
+        Math.max(2, priorityHandlerCount), maxPriorityQueueLength, priority, conf, server);
     } else {
       // Create 2 queues to help priorityExecutor be more scalable.
-      this.priorityExecutor = priorityHandlerCount > 0 ?
-          new FastPathBalancedQueueRpcExecutor("priority.FPBQ", priorityHandlerCount,
-              RpcExecutor.CALL_QUEUE_TYPE_FIFO_CONF_VALUE, maxPriorityQueueLength, priority, conf,
-              abortable) :
-          null;
+      this.priorityExecutor = priorityHandlerCount > 0
+        ? new FastPathBalancedQueueRpcExecutor("priority.FPBQ", priorityHandlerCount,
+          RpcExecutor.CALL_QUEUE_TYPE_FIFO_CONF_VALUE, maxPriorityQueueLength, priority, conf,
+          abortable)
+        : null;
     }
-    this.replicationExecutor = replicationHandlerCount > 0 ? new FastPathBalancedQueueRpcExecutor(
-        "replication.FPBQ", replicationHandlerCount, RpcExecutor.CALL_QUEUE_TYPE_FIFO_CONF_VALUE,
-        maxQueueLength, priority, conf, abortable) : null;
+    this.replicationExecutor = replicationHandlerCount > 0
+      ? new FastPathBalancedQueueRpcExecutor("replication.FPBQ", replicationHandlerCount,
+        RpcExecutor.CALL_QUEUE_TYPE_FIFO_CONF_VALUE, maxReplicationQueueLength, priority, conf,
+        abortable)
+      : null;
 
-    this.metaTransitionExecutor = metaTransitionHandler > 0 ?
-        new FastPathBalancedQueueRpcExecutor("metaPriority.FPBQ", metaTransitionHandler,
-            RpcExecutor.CALL_QUEUE_TYPE_FIFO_CONF_VALUE, maxPriorityQueueLength, priority, conf,
-            abortable) :
-        null;
+    this.metaTransitionExecutor = metaTransitionHandler > 0
+      ? new FastPathBalancedQueueRpcExecutor("metaPriority.FPBQ", metaTransitionHandler,
+        RpcExecutor.CALL_QUEUE_TYPE_FIFO_CONF_VALUE, maxPriorityQueueLength, priority, conf,
+        abortable)
+      : null;
   }
 
   public SimpleRpcScheduler(Configuration conf, int handlerCount, int priorityHandlerCount,
-      int replicationHandlerCount, PriorityFunction priority, int highPriorityLevel) {
+    int replicationHandlerCount, PriorityFunction priority, int highPriorityLevel) {
     this(conf, handlerCount, priorityHandlerCount, replicationHandlerCount, 0, priority, null,
-        highPriorityLevel);
+      highPriorityLevel);
   }
 
   /**
@@ -149,10 +148,11 @@ public class SimpleRpcScheduler extends RpcScheduler implements ConfigurationObs
       metaTransitionExecutor.resizeQueues(conf);
     }
 
-    String callQueueType = conf.get(RpcExecutor.CALL_QUEUE_TYPE_CONF_KEY,
-      RpcExecutor.CALL_QUEUE_TYPE_CONF_DEFAULT);
-    if (RpcExecutor.isCodelQueueType(callQueueType) ||
-      RpcExecutor.isPluggableQueueType(callQueueType)) {
+    String callQueueType =
+      conf.get(RpcExecutor.CALL_QUEUE_TYPE_CONF_KEY, RpcExecutor.CALL_QUEUE_TYPE_CONF_DEFAULT);
+    if (
+      RpcExecutor.isCodelQueueType(callQueueType) || RpcExecutor.isPluggableQueueType(callQueueType)
+    ) {
       callExecutor.onConfigurationChange(conf);
     }
   }
@@ -193,15 +193,17 @@ public class SimpleRpcScheduler extends RpcScheduler implements ConfigurationObs
   }
 
   @Override
-  public boolean dispatch(CallRunner callTask) throws InterruptedException {
+  public boolean dispatch(CallRunner callTask) {
     RpcCall call = callTask.getRpcCall();
-    int level = priority.getPriority(call.getHeader(), call.getParam(),
-        call.getRequestUser().orElse(null));
+    int level =
+      priority.getPriority(call.getHeader(), call.getParam(), call.getRequestUser().orElse(null));
     if (level == HConstants.PRIORITY_UNSET) {
       level = HConstants.NORMAL_QOS;
     }
-    if (metaTransitionExecutor != null &&
-      level == MasterAnnotationReadingPriorityFunction.META_TRANSITION_QOS) {
+    if (
+      metaTransitionExecutor != null
+        && level == MasterAnnotationReadingPriorityFunction.META_TRANSITION_QOS
+    ) {
       return metaTransitionExecutor.dispatch(callTask);
     } else if (priorityExecutor != null && level > highPriorityLevel) {
       return priorityExecutor.dispatch(callTask);
@@ -235,7 +237,7 @@ public class SimpleRpcScheduler extends RpcScheduler implements ConfigurationObs
   @Override
   public int getActiveRpcHandlerCount() {
     return callExecutor.getActiveHandlerCount() + getActivePriorityRpcHandlerCount()
-        + getActiveReplicationRpcHandlerCount() + getActiveMetaPriorityRpcHandlerCount();
+      + getActiveReplicationRpcHandlerCount() + getActiveMetaPriorityRpcHandlerCount();
   }
 
   @Override
@@ -325,7 +327,7 @@ public class SimpleRpcScheduler extends RpcScheduler implements ConfigurationObs
     if (null != metaTransitionExecutor) {
       queueName = "Meta Transition Queue";
       callQueueInfo.setCallMethodCount(queueName,
-          metaTransitionExecutor.getCallQueueCountsSummary());
+        metaTransitionExecutor.getCallQueueCountsSummary());
       callQueueInfo.setCallMethodSize(queueName, metaTransitionExecutor.getCallQueueSizeSummary());
     }
 
@@ -333,4 +335,3 @@ public class SimpleRpcScheduler extends RpcScheduler implements ConfigurationObs
   }
 
 }
-
