@@ -295,7 +295,7 @@ public class AssignmentVerificationReport {
   }
 
   /**
-   * Use this to project the dispersion scores
+   * Use this to project the dispersion scores nnn
    */
   public void fillUpDispersion(TableName tableName, SnapshotOfRegionAssignmentFromMeta snapshot,
     FavoredNodesPlan newPlan) {
@@ -410,8 +410,8 @@ public class AssignmentVerificationReport {
   }
 
   /**
-   * @return list which contains just 3 elements: average dispersion score, max dispersion score and
-   *         min dispersion score as first, second and third element respectively.
+   * Return a list which contains 3 elements: average dispersion score, max dispersion score and min
+   * dispersion score as first, second and third elements, respectively.
    */
   public List<Float> getDispersionInformation() {
     List<Float> dispersion = new ArrayList<>();
@@ -567,8 +567,7 @@ public class AssignmentVerificationReport {
 
   /**
    * Return the number of regions based on the position (primary/secondary/ tertiary) assigned to
-   * their favored nodes
-   * @return the number of regions
+   * their favored nodes n * @return the number of regions
    */
   int getNumRegionsOnFavoredNodeByPosition(FavoredNodesPlan.Position position) {
     return favoredNodes[position.ordinal()];
@@ -580,7 +579,7 @@ public class AssignmentVerificationReport {
     }
     int i = 0;
     for (ServerName addr : serverSet) {
-      if ((i++) % 3 == 0) {
+      if (i++ % 3 == 0) {
         System.out.print("\n\t\t\t");
       }
       System.out.print(addr.getAddress() + " ; ");
