@@ -30,6 +30,8 @@ import org.apache.hadoop.hbase.NamespaceDescriptor;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.SharedConnection;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.BalanceRequest;
+import org.apache.hadoop.hbase.client.BalanceResponse;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.MasterSwitchType;
 import org.apache.hadoop.hbase.client.Mutation;
@@ -483,6 +485,55 @@ public class MasterCoprocessorHost
     });
   }
 
+  public String preModifyTableStoreFileTracker(final TableName tableName, final String dstSFT)
+    throws IOException {
+    if (coprocEnvironments.isEmpty()) {
+      return dstSFT;
+    }
+    return execOperationWithResult(
+      new ObserverOperationWithResult<MasterObserver, String>(masterObserverGetter, dstSFT) {
+        @Override
+        protected String call(MasterObserver observer) throws IOException {
+          return observer.preModifyTableStoreFileTracker(this, tableName, getResult());
+        }
+      });
+  }
+
+  public void postModifyTableStoreFileTracker(final TableName tableName, final String dstSFT)
+    throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.postModifyTableStoreFileTracker(this, tableName, dstSFT);
+      }
+    });
+  }
+
+  public String preModifyColumnFamilyStoreFileTracker(final TableName tableName,
+    final byte[] family, final String dstSFT) throws IOException {
+    if (coprocEnvironments.isEmpty()) {
+      return dstSFT;
+    }
+    return execOperationWithResult(
+      new ObserverOperationWithResult<MasterObserver, String>(masterObserverGetter, dstSFT) {
+        @Override
+        protected String call(MasterObserver observer) throws IOException {
+          return observer.preModifyColumnFamilyStoreFileTracker(this, tableName, family,
+            getResult());
+        }
+      });
+  }
+
+  public void postModifyColumnFamilyStoreFileTracker(final TableName tableName, final byte[] family,
+    final String dstSFT) throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.postModifyColumnFamilyStoreFileTracker(this, tableName, family, dstSFT);
+      }
+    });
+  }
+
   public void preModifyTableAction(final TableName tableName,
     final TableDescriptor currentDescriptor, final TableDescriptor newDescriptor, final User user)
     throws IOException {
@@ -726,20 +777,21 @@ public class MasterCoprocessorHost
     });
   }
 
-  public boolean preBalance() throws IOException {
+  public boolean preBalance(final BalanceRequest request) throws IOException {
     return execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
       @Override
       public void call(MasterObserver observer) throws IOException {
-        observer.preBalance(this);
+        observer.preBalance(this, request);
       }
     });
   }
 
-  public void postBalance(final List<RegionPlan> plans) throws IOException {
+  public void postBalance(final BalanceRequest request, final List<RegionPlan> plans)
+    throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
       @Override
       public void call(MasterObserver observer) throws IOException {
-        observer.postBalance(this, plans);
+        observer.postBalance(this, request, plans);
       }
     });
   }
@@ -767,7 +819,7 @@ public class MasterCoprocessorHost
   /**
    * Invoked just before calling the split region procedure
    * @param tableName the table where the region belongs to
-   * @param splitRow  the split point
+   * @param splitRow  the split point n
    */
   public void preSplitRegion(final TableName tableName, final byte[] splitRow) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
@@ -782,7 +834,7 @@ public class MasterCoprocessorHost
    * Invoked just before a split
    * @param tableName the table where the region belongs to
    * @param splitRow  the split point
-   * @param user      the user
+   * @param user      the user n
    */
   public void preSplitRegionAction(final TableName tableName, final byte[] splitRow,
     final User user) throws IOException {
@@ -798,7 +850,7 @@ public class MasterCoprocessorHost
    * Invoked just after a split
    * @param regionInfoA the new left-hand daughter region
    * @param regionInfoB the new right-hand daughter region
-   * @param user        the user
+   * @param user        the user n
    */
   public void postCompletedSplitRegionAction(final RegionInfo regionInfoA,
     final RegionInfo regionInfoB, final User user) throws IOException {
@@ -811,8 +863,8 @@ public class MasterCoprocessorHost
   }
 
   /**
-   * This will be called before update META step as part of split table region procedure.
-   * @param user the user
+   * This will be called before update META step as part of split table region procedure. nn
+   * * @param user the user n
    */
   public void preSplitBeforeMETAAction(final byte[] splitKey, final List<Mutation> metaEntries,
     final User user) throws IOException {
@@ -826,7 +878,7 @@ public class MasterCoprocessorHost
 
   /**
    * This will be called after update META step as part of split table region procedure.
-   * @param user the user
+   * @param user the user n
    */
   public void preSplitAfterMETAAction(final User user) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation(user) {
@@ -839,7 +891,7 @@ public class MasterCoprocessorHost
 
   /**
    * Invoked just after the rollback of a failed split
-   * @param user the user
+   * @param user the user n
    */
   public void postRollBackSplitRegionAction(final User user) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation(user) {
@@ -853,7 +905,7 @@ public class MasterCoprocessorHost
   /**
    * Invoked just before a merge
    * @param regionsToMerge the regions to merge
-   * @param user           the user
+   * @param user           the user n
    */
   public void preMergeRegionsAction(final RegionInfo[] regionsToMerge, final User user)
     throws IOException {
@@ -869,7 +921,7 @@ public class MasterCoprocessorHost
    * Invoked after completing merge regions operation
    * @param regionsToMerge the regions to merge
    * @param mergedRegion   the new merged region
-   * @param user           the user
+   * @param user           the user n
    */
   public void postCompletedMergeRegionsAction(final RegionInfo[] regionsToMerge,
     final RegionInfo mergedRegion, final User user) throws IOException {
@@ -885,7 +937,7 @@ public class MasterCoprocessorHost
    * Invoked before merge regions operation writes the new region to hbase:meta
    * @param regionsToMerge the regions to merge
    * @param metaEntries    the meta entry
-   * @param user           the user
+   * @param user           the user n
    */
   public void preMergeRegionsCommit(final RegionInfo[] regionsToMerge,
     final @MetaMutationAnnotation List<Mutation> metaEntries, final User user) throws IOException {
@@ -901,7 +953,7 @@ public class MasterCoprocessorHost
    * Invoked after merge regions operation writes the new region to hbase:meta
    * @param regionsToMerge the regions to merge
    * @param mergedRegion   the new merged region
-   * @param user           the user
+   * @param user           the user n
    */
   public void postMergeRegionsCommit(final RegionInfo[] regionsToMerge,
     final RegionInfo mergedRegion, final User user) throws IOException {
@@ -916,7 +968,7 @@ public class MasterCoprocessorHost
   /**
    * Invoked after rollback merge regions operation
    * @param regionsToMerge the regions to merge
-   * @param user           the user
+   * @param user           the user n
    */
   public void postRollBackMergeRegionsAction(final RegionInfo[] regionsToMerge, final User user)
     throws IOException {
@@ -1172,6 +1224,24 @@ public class MasterCoprocessorHost
     });
   }
 
+  public void preMasterStoreFlush() throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.preMasterStoreFlush(this);
+      }
+    });
+  }
+
+  public void postMasterStoreFlush() throws IOException {
+    execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
+      @Override
+      public void call(MasterObserver observer) throws IOException {
+        observer.postMasterStoreFlush(this);
+      }
+    });
+  }
+
   public void preSetUserQuota(final String user, final GlobalQuotaSettings quotas)
     throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
@@ -1388,20 +1458,22 @@ public class MasterCoprocessorHost
     });
   }
 
-  public void preBalanceRSGroup(final String name) throws IOException {
+  public void preBalanceRSGroup(final String name, final BalanceRequest request)
+    throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
       @Override
       public void call(MasterObserver observer) throws IOException {
-        observer.preBalanceRSGroup(this, name);
+        observer.preBalanceRSGroup(this, name, request);
       }
     });
   }
 
-  public void postBalanceRSGroup(final String name, final boolean balanceRan) throws IOException {
+  public void postBalanceRSGroup(final String name, final BalanceRequest request,
+    final BalanceResponse response) throws IOException {
     execOperation(coprocEnvironments.isEmpty() ? null : new MasterObserverOperation() {
       @Override
       public void call(MasterObserver observer) throws IOException {
-        observer.postBalanceRSGroup(this, name, balanceRan);
+        observer.postBalanceRSGroup(this, name, request, response);
       }
     });
   }
