@@ -111,7 +111,7 @@ public interface MasterServices extends Server {
 
   /**
    * Check table is modifiable; i.e. exists and is offline.
-   * @param tableName Name of table to check.
+   * @param tableName Name of table to check. nnn
    */
   // We actually throw the exceptions mentioned in the
   void checkTableModifiable(final TableName tableName)
@@ -120,8 +120,8 @@ public interface MasterServices extends Server {
   /**
    * Create a table using the given table definition.
    * @param desc      The table definition
-   * @param splitKeys Starting row keys for the initial table regions. If null a single region is
-   *                  created.
+   * @param splitKeys Starting row keys for the initial table regions. If null nn * a single region
+   *                  is created.
    */
   long createTable(final TableDescriptor desc, final byte[][] splitKeys, final long nonceGroup,
     final long nonce) throws IOException;
@@ -134,7 +134,7 @@ public interface MasterServices extends Server {
 
   /**
    * Delete a table
-   * @param tableName The table name
+   * @param tableName The table name nnn
    */
   long deleteTable(final TableName tableName, final long nonceGroup, final long nonce)
     throws IOException;
@@ -142,7 +142,7 @@ public interface MasterServices extends Server {
   /**
    * Truncate a table
    * @param tableName      The table name
-   * @param preserveSplits True if the splits should be preserved
+   * @param preserveSplits True if the splits should be preserved nnn
    */
   public long truncateTable(final TableName tableName, final boolean preserveSplits,
     final long nonceGroup, final long nonce) throws IOException;
@@ -150,21 +150,27 @@ public interface MasterServices extends Server {
   /**
    * Modify the descriptor of an existing table
    * @param tableName  The table name
-   * @param descriptor The updated table descriptor
+   * @param descriptor The updated table descriptor nnn
    */
   long modifyTable(final TableName tableName, final TableDescriptor descriptor,
     final long nonceGroup, final long nonce) throws IOException;
 
+  /**
+   * Modify the store file tracker of an existing table
+   */
+  long modifyTableStoreFileTracker(final TableName tableName, final String dstSFT,
+    final long nonceGroup, final long nonce) throws IOException;
+
   /**
    * Enable an existing table
-   * @param tableName The table name
+   * @param tableName The table name nnn
    */
   long enableTable(final TableName tableName, final long nonceGroup, final long nonce)
     throws IOException;
 
   /**
    * Disable an existing table
-   * @param tableName The table name
+   * @param tableName The table name nnn
    */
   long disableTable(final TableName tableName, final long nonceGroup, final long nonce)
     throws IOException;
@@ -172,7 +178,7 @@ public interface MasterServices extends Server {
   /**
    * Add a new column to an existing table
    * @param tableName The table name
-   * @param column    The column definition
+   * @param column    The column definition nnn
    */
   long addColumn(final TableName tableName, final ColumnFamilyDescriptor column,
     final long nonceGroup, final long nonce) throws IOException;
@@ -180,15 +186,21 @@ public interface MasterServices extends Server {
   /**
    * Modify the column descriptor of an existing column in an existing table
    * @param tableName  The table name
-   * @param descriptor The updated column definition
+   * @param descriptor The updated column definition nnn
    */
   long modifyColumn(final TableName tableName, final ColumnFamilyDescriptor descriptor,
     final long nonceGroup, final long nonce) throws IOException;
 
+  /**
+   * Modify the store file tracker of an existing column in an existing table
+   */
+  long modifyColumnStoreFileTracker(final TableName tableName, final byte[] family,
+    final String dstSFT, final long nonceGroup, final long nonce) throws IOException;
+
   /**
    * Delete a column from an existing table
    * @param tableName  The table name
-   * @param columnName The column name
+   * @param columnName The column name nnn
    */
   long deleteColumn(final TableName tableName, final byte[] columnName, final long nonceGroup,
     final long nonce) throws IOException;
@@ -199,7 +211,7 @@ public interface MasterServices extends Server {
    * @param forcible       whether to force to merge even two regions are not adjacent
    * @param nonceGroup     used to detect duplicate
    * @param nonce          used to detect duplicate
-   * @return procedure Id
+   * @return procedure Id n
    */
   long mergeRegions(final RegionInfo[] regionsToMerge, final boolean forcible,
     final long nonceGroup, final long nonce) throws IOException;
@@ -210,7 +222,7 @@ public interface MasterServices extends Server {
    * @param splitRow   split point
    * @param nonceGroup used to detect duplicate
    * @param nonce      used to detect duplicate
-   * @return procedure Id
+   * @return procedure Id n
    */
   long splitRegion(final RegionInfo regionInfo, final byte[] splitRow, final long nonceGroup,
     final long nonce) throws IOException;
@@ -254,46 +266,46 @@ public interface MasterServices extends Server {
    * Abort a procedure.
    * @param procId                ID of the procedure
    * @param mayInterruptIfRunning if the proc completed at least one step, should it be aborted?
-   * @return true if aborted, false if procedure already completed or does not exist
+   * @return true if aborted, false if procedure already completed or does not exist n
    */
   public boolean abortProcedure(final long procId, final boolean mayInterruptIfRunning)
     throws IOException;
 
   /**
    * Get procedures
-   * @return procedure list
+   * @return procedure list n
    */
   public List<Procedure<?>> getProcedures() throws IOException;
 
   /**
    * Get locks
-   * @return lock list
+   * @return lock list n
    */
   public List<LockedResource> getLocks() throws IOException;
 
   /**
    * Get list of table descriptors by namespace
-   * @param name namespace name
+   * @param name namespace name nn
    */
   public List<TableDescriptor> listTableDescriptorsByNamespace(String name) throws IOException;
 
   /**
    * Get list of table names by namespace
    * @param name namespace name
-   * @return table names
+   * @return table names n
    */
   public List<TableName> listTableNamesByNamespace(String name) throws IOException;
 
   /**
    * @param table the table for which last successful major compaction time is queried
    * @return the timestamp of the last successful major compaction for the passed table, or 0 if no
-   *         HFile resulting from a major compaction exists
+   *         HFile resulting from a major compaction exists n
    */
   public long getLastMajorCompactionTimestamp(TableName table) throws IOException;
 
   /**
-   * Returns the timestamp of the last successful major compaction for the passed region or 0 if no
-   * HFile resulting from a major compaction exists
+   * n * @return the timestamp of the last successful major compaction for the passed region or 0 if
+   * no HFile resulting from a major compaction exists n
    */
   public long getLastMajorCompactionTimestampForRegion(byte[] regionName) throws IOException;
 
@@ -416,4 +428,9 @@ public interface MasterServices extends Server {
    * We need to get this in MTP to tell the syncer the new meta replica count.
    */
   MetaLocationSyncer getMetaLocationSyncer();
+
+  /**
+   * Flush master local region
+   */
+  void flushMasterStore() throws IOException;
 }
