@@ -23,6 +23,8 @@ import java.io.IOException;
 import java.net.InetAddress;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
@@ -43,7 +45,6 @@ import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.YouAreDeadException;
 import org.apache.hadoop.hbase.client.ClusterConnection;
 import org.apache.hadoop.hbase.client.RegionInfo;
-import org.apache.hadoop.hbase.client.RetriesExhaustedException;
 import org.apache.hadoop.hbase.ipc.HBaseRpcController;
 import org.apache.hadoop.hbase.ipc.RemoteWithExtrasException;
 import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
@@ -123,11 +124,18 @@ public class ServerManager {
   private final ConcurrentNavigableMap<ServerName, ServerMetrics> onlineServers =
     new ConcurrentSkipListMap<>();
 
+  /**
+   * Map of admin interfaces per registered regionserver; these interfaces we use to control
+   * regionservers out on the cluster
+   */
+  private final Map<ServerName, AdminService.BlockingInterface> rsAdmins = new HashMap<>();
+
   /** List of region servers that should not get any more new regions. */
   private final ArrayList<ServerName> drainingServers = new ArrayList<>();
 
   private final MasterServices master;
   private final ClusterConnection connection;
+  private final RegionServerList storage;
 
   private final DeadServer deadservers = new DeadServer();
 
@@ -142,8 +150,9 @@ public class ServerManager {
   /**
    * Constructor.
    */
-  public ServerManager(final MasterServices master) {
+  public ServerManager(final MasterServices master, RegionServerList storage) {
     this.master = master;
+    this.storage = storage;
     Configuration c = master.getConfiguration();
     maxSkew = c.getLong("hbase.master.maxclockskew", 30000);
     warningSkew = c.getLong("hbase.master.warningclockskew", 10000);
@@ -195,6 +204,7 @@ public class ServerManager {
       LOG.warn(
         "THIS SHOULD NOT HAPPEN, RegionServerStartup" + " could not record the server: " + sn);
     }
+    storage.started(sn);
     return sn;
   }
 
@@ -247,24 +257,8 @@ public class ServerManager {
       // the ServerName to use. Here we presume a master has already done
       // that so we'll press on with whatever it gave us for ServerName.
       if (!checkAndRecordNewServer(sn, sl)) {
-        // Master already registered server with same (host + port) and higher startcode.
-        // This can happen if regionserver report comes late from old server
-        // (possible race condition), by that time master has already processed SCP for that
-        // server and started accepting regionserver report from new server i.e. server with
-        // same (host + port) and higher startcode.
-        // The exception thrown here is not meant to tell the region server it is dead because if
-        // there is a new server on the same host port, the old server should have already been
-        // dead in ideal situation.
-        // The exception thrown here is to skip the later steps of the whole regionServerReport
-        // request processing. Usually, after recording it in ServerManager, we will call the
-        // related methods in AssignmentManager to record region states. If the region server
-        // is already dead, we should not do these steps anymore, so here we throw an exception
-        // to let the upper layer know that they should not continue processing anymore.
-        final String errorMsg = "RegionServerReport received from " + sn
-          + ", but another server with the same name and higher startcode is already registered,"
-          + " ignoring";
-        LOG.warn(errorMsg);
-        throw new YouAreDeadException(errorMsg);
+        LOG.info("RegionServerReport ignored, could not record the server: " + sn);
+        return; // Not recorded, so no need to move on
       }
     }
     updateLastFlushedSequenceIds(sn, sl);
@@ -330,8 +324,8 @@ public class ServerManager {
    * Checks if the clock skew between the server and the master. If the clock skew exceeds the
    * configured max, it will throw an exception; if it exceeds the configured warning threshold, it
    * will log a warning but start normally.
-   * @param serverName Incoming servers's name
-   * @throws ClockOutOfSyncException if the skew exceeds the configured max value
+   * @param serverName Incoming servers's name n * @throws ClockOutOfSyncException if the skew
+   *                   exceeds the configured max value
    */
   private void checkClockSkew(final ServerName serverName, final long serverCurrentTime)
     throws ClockOutOfSyncException {
@@ -403,6 +397,7 @@ public class ServerManager {
   void recordNewServerWithLock(final ServerName serverName, final ServerMetrics sl) {
     LOG.info("Registering regionserver=" + serverName);
     this.onlineServers.put(serverName, sl);
+    this.rsAdmins.remove(serverName);
   }
 
   public RegionStoreSequenceIds getLastFlushedSequenceId(byte[] encodedRegionName) {
@@ -421,7 +416,9 @@ public class ServerManager {
     return builder.build();
   }
 
-  /** Returns ServerMetrics if serverName is known else null */
+  /**
+   * n * @return ServerMetrics if serverName is known else null
+   */
   public ServerMetrics getLoad(final ServerName serverName) {
     return this.onlineServers.get(serverName);
   }
@@ -474,8 +471,7 @@ public class ServerManager {
     ZKWatcher zkw = master.getZooKeeper();
     int onlineServersCt;
     while ((onlineServersCt = onlineServers.size()) > 0) {
-
-      if (System.currentTimeMillis() > (previousLogTime + 1000)) {
+      if (EnvironmentEdgeManager.currentTime() > (previousLogTime + 1000)) {
         Set<ServerName> remainingServers = onlineServers.keySet();
         synchronized (onlineServers) {
           if (remainingServers.size() == 1 && remainingServers.contains(sn)) {
@@ -492,7 +488,7 @@ public class ServerManager {
           sb.append(key);
         }
         LOG.info("Waiting on regionserver(s) " + sb.toString());
-        previousLogTime = System.currentTimeMillis();
+        previousLogTime = EnvironmentEdgeManager.currentTime();
       }
 
       try {
@@ -576,6 +572,7 @@ public class ServerManager {
     }
     LOG.info("Processing expiration of " + serverName + " on " + this.master.getServerName());
     long pid = master.getAssignmentManager().submitServerCrash(serverName, true, force);
+    storage.expired(serverName);
     // Tell our listeners that a server was removed
     if (!this.listeners.isEmpty()) {
       this.listeners.stream().forEach(l -> l.serverRemoved(serverName));
@@ -604,6 +601,7 @@ public class ServerManager {
         LOG.trace("Expiration of {} but server not online", sn);
       }
     }
+    this.rsAdmins.remove(sn);
   }
 
   /*
@@ -622,8 +620,8 @@ public class ServerManager {
   }
 
   /**
-   * Add the server to the drain list.
-   * @return True if the server is added or the server is already on the drain list.
+   * Add the server to the drain list. n * @return True if the server is added or the server is
+   * already on the drain list.
    */
   public synchronized boolean addServerToDrainList(final ServerName sn) {
     // Warn if the server (sn) is not online. ServerName is of the form:
@@ -687,8 +685,8 @@ public class ServerManager {
     if (timeout < 0) {
       return;
     }
-    long expiration = timeout + System.currentTimeMillis();
-    while (System.currentTimeMillis() < expiration) {
+    long expiration = timeout + EnvironmentEdgeManager.currentTime();
+    while (EnvironmentEdgeManager.currentTime() < expiration) {
       controller.reset();
       try {
         RegionInfo rsRegion = ProtobufUtil.getRegionInfo(controller, rs, region.getRegionName());
@@ -711,17 +709,22 @@ public class ServerManager {
   }
 
   /**
-   * @return Admin interface for the remote regionserver named <code>sn</code>
-   * @throws RetriesExhaustedException wrapping a ConnectException if failed
+   * n * @return Admin interface for the remote regionserver named <code>sn</code> n * @throws
+   * RetriesExhaustedException wrapping a ConnectException if failed
    */
   public AdminService.BlockingInterface getRsAdmin(final ServerName sn) throws IOException {
-    LOG.debug("New admin connection to {}", sn);
-    if (sn.equals(master.getServerName()) && master instanceof HRegionServer) {
-      // A master is also a region server now, see HBASE-10569 for details
-      return ((HRegionServer) master).getRSRpcServices();
-    } else {
-      return this.connection.getAdmin(sn);
+    AdminService.BlockingInterface admin = this.rsAdmins.get(sn);
+    if (admin == null) {
+      LOG.debug("New admin connection to " + sn.toString());
+      if (sn.equals(master.getServerName()) && master instanceof HRegionServer) {
+        // A master is also a region server now, see HBASE-10569 for details
+        admin = ((HRegionServer) master).getRSRpcServices();
+      } else {
+        admin = this.connection.getAdmin(sn);
+      }
+      this.rsAdmins.put(sn, admin);
     }
+    return admin;
   }
 
   /**
@@ -754,7 +757,7 @@ public class ServerManager {
    * the master is stopped - the 'hbase.master.wait.on.regionservers.maxtostart' number of region
    * servers is reached - the 'hbase.master.wait.on.regionservers.mintostart' is reached AND there
    * have been no new region server in for 'hbase.master.wait.on.regionservers.interval' time AND
-   * the 'hbase.master.wait.on.regionservers.timeout' is reached
+   * the 'hbase.master.wait.on.regionservers.timeout' is reached n
    */
   public void waitForRegionServers(MonitoredTask status) throws InterruptedException {
     final long interval =
@@ -772,7 +775,7 @@ public class ServerManager {
       maxToStart = Integer.MAX_VALUE;
     }
 
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     final long startTime = now;
     long slept = 0;
     long lastLogTime = 0;
@@ -808,7 +811,7 @@ public class ServerManager {
       // We sleep for some time
       final long sleepTime = 50;
       Thread.sleep(sleepTime);
-      now = System.currentTimeMillis();
+      now = EnvironmentEdgeManager.currentTime();
       slept = now - startTime;
 
       oldCount = count;
@@ -926,7 +929,15 @@ public class ServerManager {
    * @param serversToExclude can be null if there is no server to exclude
    */
   public List<ServerName> createDestinationServersList(final List<ServerName> serversToExclude) {
-    final List<ServerName> destServers = getOnlineServersList();
+    Set<ServerName> destServers = new HashSet<>();
+    onlineServers.forEach((sn, sm) -> {
+      if (sm.getLastReportTimestamp() > 0) {
+        // This means we have already called regionServerReport at leaset once, then let's include
+        // this server for region assignment. This is an optimization to avoid assigning regions to
+        // an uninitialized server. See HBASE-25032 for more details.
+        destServers.add(sn);
+      }
+    });
 
     if (serversToExclude != null) {
       destServers.removeAll(serversToExclude);
@@ -936,7 +947,7 @@ public class ServerManager {
     final List<ServerName> drainingServersCopy = getDrainingServersList();
     destServers.removeAll(drainingServersCopy);
 
-    return destServers;
+    return new ArrayList<>(destServers);
   }
 
   /**
