@@ -17,6 +17,7 @@
  */
 package org.apache.hadoop.hbase.master.cleaner;
 
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -70,13 +71,6 @@ public abstract class CleanerChore<T extends FileCleanerDelegate> extends Schedu
    */
   public static final String LOG_CLEANER_CHORE_SIZE = "hbase.log.cleaner.scan.dir.concurrent.size";
   static final String DEFAULT_LOG_CLEANER_CHORE_POOL_SIZE = "1";
-  /**
-   * Enable the CleanerChore to sort the subdirectories by consumed space and start the cleaning
-   * with the largest subdirectory. Enabled by default.
-   */
-  public static final String LOG_CLEANER_CHORE_DIRECTORY_SORTING =
-    "hbase.cleaner.directory.sorting";
-  static final boolean DEFAULT_LOG_CLEANER_CHORE_DIRECTORY_SORTING = true;
 
   private final DirScanPool pool;
 
@@ -86,11 +80,11 @@ public abstract class CleanerChore<T extends FileCleanerDelegate> extends Schedu
   protected final Map<String, Object> params;
   private final AtomicBoolean enabled = new AtomicBoolean(true);
   protected List<T> cleanersChain;
-  private boolean sortDirectories;
+  protected List<String> excludeDirs;
 
   public CleanerChore(String name, final int sleepPeriod, final Stoppable s, Configuration conf,
     FileSystem fs, Path oldFileDir, String confKey, DirScanPool pool) {
-    this(name, sleepPeriod, s, conf, fs, oldFileDir, confKey, pool, null);
+    this(name, sleepPeriod, s, conf, fs, oldFileDir, confKey, pool, null, null);
   }
 
   /**
@@ -105,7 +99,8 @@ public abstract class CleanerChore<T extends FileCleanerDelegate> extends Schedu
    * @param params      members could be used in cleaner
    */
   public CleanerChore(String name, final int sleepPeriod, final Stoppable s, Configuration conf,
-    FileSystem fs, Path oldFileDir, String confKey, DirScanPool pool, Map<String, Object> params) {
+    FileSystem fs, Path oldFileDir, String confKey, DirScanPool pool, Map<String, Object> params,
+    List<Path> excludePaths) {
     super(name, s, sleepPeriod);
 
     Preconditions.checkNotNull(pool, "Chore's pool can not be null");
@@ -114,8 +109,19 @@ public abstract class CleanerChore<T extends FileCleanerDelegate> extends Schedu
     this.oldFileDir = oldFileDir;
     this.conf = conf;
     this.params = params;
-    sortDirectories = conf.getBoolean(LOG_CLEANER_CHORE_DIRECTORY_SORTING,
-      DEFAULT_LOG_CLEANER_CHORE_DIRECTORY_SORTING);
+    if (excludePaths != null && !excludePaths.isEmpty()) {
+      excludeDirs = new ArrayList<>(excludePaths.size());
+      for (Path path : excludePaths) {
+        StringBuilder dirPart = new StringBuilder(path.toString());
+        if (!path.toString().endsWith("/")) {
+          dirPart.append("/");
+        }
+        excludeDirs.add(dirPart.toString());
+      }
+    }
+    if (excludeDirs != null) {
+      LOG.info("Cleaner {} excludes sub dirs: {}", name, excludeDirs);
+    }
     initCleanerChain(confKey);
   }
 
@@ -390,6 +396,9 @@ public abstract class CleanerChore<T extends FileCleanerDelegate> extends Schedu
     return pool.getSize();
   }
 
+  /**
+   * n
+   */
   public boolean setEnabled(final boolean enabled) {
     return this.enabled.getAndSet(enabled);
   }
@@ -423,14 +432,14 @@ public abstract class CleanerChore<T extends FileCleanerDelegate> extends Schedu
       // Step.3: Start to traverse and delete the sub-directories.
       List<CompletableFuture<Boolean>> futures = new ArrayList<>();
       if (!subDirs.isEmpty()) {
-        if (sortDirectories) {
-          sortByConsumedSpace(subDirs);
-        }
+        sortByConsumedSpace(subDirs);
         // Submit the request of sub-directory deletion.
         subDirs.forEach(subDir -> {
-          CompletableFuture<Boolean> subFuture = new CompletableFuture<>();
-          pool.execute(() -> traverseAndDelete(subDir.getPath(), false, subFuture));
-          futures.add(subFuture);
+          if (!shouldExclude(subDir)) {
+            CompletableFuture<Boolean> subFuture = new CompletableFuture<>();
+            pool.execute(() -> traverseAndDelete(subDir.getPath(), false, subFuture));
+            futures.add(subFuture);
+          }
         });
       }
 
@@ -460,11 +469,34 @@ public abstract class CleanerChore<T extends FileCleanerDelegate> extends Schedu
           }
         });
     } catch (Exception e) {
-      LOG.debug("Failed to traverse and delete the path: {}", dir, e);
+      if (e instanceof FileNotFoundException) {
+        LOG.debug("Dir dose not exist, {}", dir);
+      } else {
+        LOG.error("Failed to traverse and delete the path: {}", dir, e);
+      }
       result.completeExceptionally(e);
     }
   }
 
+  /**
+   * Check if a path should not perform clear
+   */
+  private boolean shouldExclude(FileStatus f) {
+    if (!f.isDirectory()) {
+      return false;
+    }
+    if (excludeDirs != null && !excludeDirs.isEmpty()) {
+      for (String dirPart : excludeDirs) {
+        // since we make excludeDirs end with '/',
+        // if a path contains() the dirPart, the path should be excluded
+        if (f.getPath().toString().contains(dirPart)) {
+          return true;
+        }
+      }
+    }
+    return false;
+  }
+
   /**
    * Perform a delete on a specified type.
    * @param deletion a delete
