@@ -36,6 +36,7 @@ import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.master.MasterCoprocessorHost;
 import org.apache.hadoop.hbase.master.zksyncer.MetaLocationSyncer;
 import org.apache.hadoop.hbase.procedure2.ProcedureStateSerializer;
+import org.apache.hadoop.hbase.regionserver.storefiletracker.StoreFileTrackerValidationUtils;
 import org.apache.hadoop.hbase.replication.ReplicationException;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.ServerRegionReplicaUtil;
@@ -278,7 +279,7 @@ public class ModifyTableProcedure extends AbstractStateMachineTableProcedure<Mod
 
   /**
    * Check conditions before any real action of modifying a table.
-   * @param env MasterProcedureEnv
+   * @param env MasterProcedureEnv n
    */
   private void prepareModify(final MasterProcedureEnv env) throws IOException {
     // Checks whether the table exists
@@ -315,6 +316,10 @@ public class ModifyTableProcedure extends AbstractStateMachineTableProcedure<Mod
 
     this.deleteColumnFamilyInModify =
       isDeleteColumnFamily(unmodifiedTableDescriptor, modifiedTableDescriptor);
+
+    // check for store file tracker configurations
+    StoreFileTrackerValidationUtils.checkForModifyTable(env.getMasterConfiguration(),
+      unmodifiedTableDescriptor, modifiedTableDescriptor, !isTableEnabled(env));
   }
 
   /**
