@@ -24,6 +24,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
@@ -49,8 +50,6 @@ import org.apache.hadoop.hbase.snapshot.ClientSnapshotDescriptionUtils;
 import org.apache.hadoop.hbase.snapshot.RestoreSnapshotHelper;
 import org.apache.hadoop.hbase.snapshot.SnapshotDescriptionUtils;
 import org.apache.hadoop.hbase.snapshot.SnapshotManifest;
-import org.apache.hadoop.hbase.snapshot.SnapshotTTLExpiredException;
-import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
@@ -96,7 +95,7 @@ public class RestoreSnapshotProcedure
    * Constructor
    * @param env             MasterProcedureEnv
    * @param tableDescriptor the table to operate on
-   * @param snapshot        snapshot to restore from
+   * @param snapshot        snapshot to restore from n
    */
   public RestoreSnapshotProcedure(final MasterProcedureEnv env,
     final TableDescriptor tableDescriptor, final SnapshotDescription snapshot,
@@ -320,7 +319,7 @@ public class RestoreSnapshotProcedure
 
   /**
    * Action before any real action of restoring from snapshot.
-   * @param env MasterProcedureEnv
+   * @param env MasterProcedureEnv n
    */
   private void prepareRestore(final MasterProcedureEnv env) throws IOException {
     final TableName tableName = getTableName();
@@ -329,14 +328,6 @@ public class RestoreSnapshotProcedure
       throw new TableNotFoundException(tableName);
     }
 
-    // check whether ttl has expired for this snapshot
-    if (
-      SnapshotDescriptionUtils.isExpiredSnapshot(snapshot.getTtl(), snapshot.getCreationTime(),
-        EnvironmentEdgeManager.currentTime())
-    ) {
-      throw new SnapshotTTLExpiredException(ProtobufUtil.createSnapshotDesc(snapshot));
-    }
-
     // Check whether table is disabled.
     env.getMasterServices().checkTableModifiable(tableName);
 
@@ -365,7 +356,7 @@ public class RestoreSnapshotProcedure
 
   /**
    * Update descriptor
-   * @param env MasterProcedureEnv
+   * @param env MasterProcedureEnv n
    **/
   private void updateTableDescriptor(final MasterProcedureEnv env) throws IOException {
     env.getMasterServices().getTableDescriptors().update(modifiedTableDescriptor);
@@ -373,22 +364,21 @@ public class RestoreSnapshotProcedure
 
   /**
    * Execute the on-disk Restore
-   * @param env MasterProcedureEnv
+   * @param env MasterProcedureEnv n
    **/
   private void restoreSnapshot(final MasterProcedureEnv env) throws IOException {
     MasterFileSystem fileSystemManager = env.getMasterServices().getMasterFileSystem();
     FileSystem fs = fileSystemManager.getFileSystem();
     Path rootDir = fileSystemManager.getRootDir();
     final ForeignExceptionDispatcher monitorException = new ForeignExceptionDispatcher();
+    final Configuration conf = new Configuration(env.getMasterConfiguration());
 
     LOG.info("Starting restore snapshot=" + ClientSnapshotDescriptionUtils.toString(snapshot));
     try {
       Path snapshotDir = SnapshotDescriptionUtils.getCompletedSnapshotDir(snapshot, rootDir);
-      SnapshotManifest manifest = SnapshotManifest.open(env.getMasterServices().getConfiguration(),
-        fs, snapshotDir, snapshot);
-      RestoreSnapshotHelper restoreHelper =
-        new RestoreSnapshotHelper(env.getMasterServices().getConfiguration(), fs, manifest,
-          modifiedTableDescriptor, rootDir, monitorException, getMonitorStatus());
+      SnapshotManifest manifest = SnapshotManifest.open(conf, fs, snapshotDir, snapshot);
+      RestoreSnapshotHelper restoreHelper = new RestoreSnapshotHelper(conf, fs, manifest,
+        modifiedTableDescriptor, rootDir, monitorException, getMonitorStatus());
 
       RestoreSnapshotHelper.RestoreMetaChanges metaChanges = restoreHelper.restoreHdfsRegions();
       regionsToRestore = metaChanges.getRegionsToRestore();
@@ -407,7 +397,7 @@ public class RestoreSnapshotProcedure
 
   /**
    * Apply changes to hbase:meta
-   * @param env MasterProcedureEnv
+   * @param env MasterProcedureEnv n
    **/
   private void updateMETA(final MasterProcedureEnv env) throws IOException {
     try {
