@@ -40,8 +40,6 @@ import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.fs.permission.AclEntry;
-import org.apache.hadoop.fs.permission.AclStatus;
 import org.apache.hadoop.hbase.HBaseInterfaceAudience;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.Stoppable;
@@ -68,6 +66,7 @@ import org.apache.hadoop.hbase.procedure.ProcedureCoordinator;
 import org.apache.hadoop.hbase.procedure.ProcedureCoordinatorRpcs;
 import org.apache.hadoop.hbase.procedure.ZKProcedureCoordinator;
 import org.apache.hadoop.hbase.procedure2.ProcedureExecutor;
+import org.apache.hadoop.hbase.regionserver.storefiletracker.StoreFileTrackerValidationUtils;
 import org.apache.hadoop.hbase.security.AccessDeniedException;
 import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.security.access.AccessChecker;
@@ -306,9 +305,9 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
   }
 
   /**
-   * Delete the specified snapshot
-   * @throws SnapshotDoesNotExistException If the specified snapshot does not exist.
-   * @throws IOException                   For filesystem IOExceptions
+   * Delete the specified snapshot n * @throws SnapshotDoesNotExistException If the specified
+   * snapshot does not exist.
+   * @throws IOException For filesystem IOExceptions
    */
   public void deleteSnapshot(SnapshotDescription snapshot) throws IOException {
     // check to see if it is completed
@@ -346,8 +345,8 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
   }
 
   /**
-   * Check if the specified snapshot is done
-   * @return true if snapshot is ready to be restored, false if it is still being taken.
+   * Check if the specified snapshot is done n * @return true if snapshot is ready to be restored,
+   * false if it is still being taken.
    * @throws IOException              IOException if error from HDFS or RPC
    * @throws UnknownSnapshotException if snapshot is invalid or does not exist.
    */
@@ -487,7 +486,6 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
           "Couldn't create working directory (" + workingDir + ") for snapshot",
           ProtobufUtil.createSnapshotDesc(snapshot));
       }
-      updateWorkingDirAclsIfRequired(workingDir, workingDirFS);
     } catch (HBaseSnapshotException e) {
       throw e;
     } catch (IOException e) {
@@ -497,39 +495,6 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
     }
   }
 
-  /**
-   * If the parent dir of the snapshot working dir (e.g. /hbase/.hbase-snapshot) has non-empty ACLs,
-   * use them for the current working dir (e.g. /hbase/.hbase-snapshot/.tmp/{snapshot-name}) so that
-   * regardless of whether the snapshot commit phase performs atomic rename or non-atomic copy of
-   * the working dir to new snapshot dir, the ACLs are retained.
-   * @param workingDir   working dir to build the snapshot.
-   * @param workingDirFS working dir file system.
-   * @throws IOException If ACL read/modify operation fails.
-   */
-  private static void updateWorkingDirAclsIfRequired(Path workingDir, FileSystem workingDirFS)
-    throws IOException {
-    if (workingDir.getParent() == null || workingDir.getParent().getParent() == null) {
-      return;
-    }
-    AclStatus snapshotWorkingParentDirStatus;
-    try {
-      snapshotWorkingParentDirStatus =
-        workingDirFS.getAclStatus(workingDir.getParent().getParent());
-    } catch (IOException | UnsupportedOperationException e) {
-      LOG.warn("Unable to retrieve ACL status for path: {}, current working dir path: {}",
-        workingDir.getParent().getParent(), workingDir, e);
-      return;
-    }
-    List<AclEntry> snapshotWorkingParentDirAclStatusEntries =
-      snapshotWorkingParentDirStatus.getEntries();
-    if (
-      snapshotWorkingParentDirAclStatusEntries != null
-        && snapshotWorkingParentDirAclStatusEntries.size() > 0
-    ) {
-      workingDirFS.modifyAclEntries(workingDir, snapshotWorkingParentDirAclStatusEntries);
-    }
-  }
-
   /**
    * Take a snapshot of a disabled table.
    * @param snapshot description of the snapshot to take. Modified to be {@link Type#DISABLED}.
@@ -613,9 +578,9 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
   }
 
   /**
-   * Take a snapshot based on the enabled/disabled state of the table.
-   * @throws HBaseSnapshotException when a snapshot specific exception occurs.
-   * @throws IOException            when some sort of generic IO exception occurs.
+   * Take a snapshot based on the enabled/disabled state of the table. n * @throws
+   * HBaseSnapshotException when a snapshot specific exception occurs.
+   * @throws IOException when some sort of generic IO exception occurs.
    */
   public void takeSnapshot(SnapshotDescription snapshot) throws IOException {
     this.takingSnapshotLock.readLock().lock();
@@ -717,9 +682,8 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
   /**
    * Set the handler for the current snapshot
    * <p>
-   * Exposed for TESTING
-   * @param handler handler the master should use TODO get rid of this if possible, repackaging,
-   *                modify tests.
+   * Exposed for TESTING n * @param handler handler the master should use TODO get rid of this if
+   * possible, repackaging, modify tests.
    */
   public synchronized void setSnapshotHandlerForTesting(final TableName tableName,
     final SnapshotSentinel handler) {
@@ -763,11 +727,11 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
    * @param snapshot          Snapshot Descriptor
    * @param snapshotTableDesc Table Descriptor
    * @param nonceKey          unique identifier to prevent duplicated RPC
-   * @return procId the ID of the clone snapshot procedure
+   * @return procId the ID of the clone snapshot procedure n
    */
   private long cloneSnapshot(final SnapshotDescription reqSnapshot, final TableName tableName,
     final SnapshotDescription snapshot, final TableDescriptor snapshotTableDesc,
-    final NonceKey nonceKey, final boolean restoreAcl) throws IOException {
+    final NonceKey nonceKey, final boolean restoreAcl, final String customSFT) throws IOException {
     MasterCoprocessorHost cpHost = master.getMasterCoprocessorHost();
     TableDescriptor htd = TableDescriptorBuilder.copy(tableName, snapshotTableDesc);
     org.apache.hadoop.hbase.client.SnapshotDescription snapshotPOJO = null;
@@ -777,7 +741,7 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
     }
     long procId;
     try {
-      procId = cloneSnapshot(snapshot, htd, nonceKey, restoreAcl);
+      procId = cloneSnapshot(snapshot, htd, nonceKey, restoreAcl, customSFT);
     } catch (IOException e) {
       LOG.error("Exception occurred while cloning the snapshot " + snapshot.getName() + " as table "
         + tableName.getNameAsString(), e);
@@ -800,8 +764,8 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
    * @return procId the ID of the clone snapshot procedure
    */
   synchronized long cloneSnapshot(final SnapshotDescription snapshot,
-    final TableDescriptor tableDescriptor, final NonceKey nonceKey, final boolean restoreAcl)
-    throws HBaseSnapshotException {
+    final TableDescriptor tableDescriptor, final NonceKey nonceKey, final boolean restoreAcl,
+    final String customSFT) throws HBaseSnapshotException {
     TableName tableName = tableDescriptor.getTableName();
 
     // make sure we aren't running a snapshot on the same table
@@ -817,7 +781,7 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
     try {
       long procId = master.getMasterProcedureExecutor().submitProcedure(
         new CloneSnapshotProcedure(master.getMasterProcedureExecutor().getEnvironment(),
-          tableDescriptor, snapshot, restoreAcl),
+          tableDescriptor, snapshot, restoreAcl, customSFT),
         nonceKey);
       this.restoreTableToProcIdMap.put(tableName, procId);
       return procId;
@@ -830,11 +794,11 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
   }
 
   /**
-   * Restore or Clone the specified snapshot
-   * @param nonceKey unique identifier to prevent duplicated RPC
+   * Restore or Clone the specified snapshot n * @param nonceKey unique identifier to prevent
+   * duplicated RPC n
    */
   public long restoreOrCloneSnapshot(final SnapshotDescription reqSnapshot, final NonceKey nonceKey,
-    final boolean restoreAcl) throws IOException {
+    final boolean restoreAcl, String customSFT) throws IOException {
     FileSystem fs = master.getMasterFileSystem().getFileSystem();
     Path snapshotDir = SnapshotDescriptionUtils.getCompletedSnapshotDir(reqSnapshot, rootDir);
 
@@ -868,8 +832,8 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
       procId =
         restoreSnapshot(reqSnapshot, tableName, snapshot, snapshotTableDesc, nonceKey, restoreAcl);
     } else {
-      procId =
-        cloneSnapshot(reqSnapshot, tableName, snapshot, snapshotTableDesc, nonceKey, restoreAcl);
+      procId = cloneSnapshot(reqSnapshot, tableName, snapshot, snapshotTableDesc, nonceKey,
+        restoreAcl, customSFT);
     }
     return procId;
   }
@@ -883,13 +847,17 @@ public class SnapshotManager extends MasterProcedureManager implements Stoppable
    * @param snapshotTableDesc Table Descriptor
    * @param nonceKey          unique identifier to prevent duplicated RPC
    * @param restoreAcl        true to restore acl of snapshot
-   * @return procId the ID of the restore snapshot procedure
+   * @return procId the ID of the restore snapshot procedure n
    */
   private long restoreSnapshot(final SnapshotDescription reqSnapshot, final TableName tableName,
     final SnapshotDescription snapshot, final TableDescriptor snapshotTableDesc,
     final NonceKey nonceKey, final boolean restoreAcl) throws IOException {
     MasterCoprocessorHost cpHost = master.getMasterCoprocessorHost();
 
+    // have to check first if restoring the snapshot would break current SFT setup
+    StoreFileTrackerValidationUtils.validatePreRestoreSnapshot(
+      master.getTableDescriptors().get(tableName), snapshotTableDesc, master.getConfiguration());
+
     if (
       master.getTableStateManager().isTableState(TableName.valueOf(snapshot.getTable()),
         TableState.State.ENABLED)
