@@ -25,7 +25,6 @@ import java.util.concurrent.CancellationException;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.hbase.MetaTableAccessor;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.RegionInfo;
@@ -49,7 +48,6 @@ import org.apache.hadoop.hbase.snapshot.SnapshotDescriptionUtils;
 import org.apache.hadoop.hbase.snapshot.SnapshotManifest;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
 import org.apache.hadoop.hbase.util.Pair;
-import org.apache.hadoop.hbase.zookeeper.MetaTableLocator;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
@@ -129,8 +127,8 @@ public abstract class TakeSnapshotHandler extends EventHandler
     // prepare the verify
     this.verifier = new MasterSnapshotVerifier(masterServices, snapshot, workingDirFs);
     // update the running tasks
-    this.status = TaskMonitor.get().createStatus(
-      "Taking " + snapshot.getType() + " snapshot on table: " + snapshotTable, false, true);
+    this.status = TaskMonitor.get()
+      .createStatus("Taking " + snapshot.getType() + " snapshot on table: " + snapshotTable, true);
     this.snapshotManifest =
       SnapshotManifest.create(conf, rootFs, workingDir, snapshot, monitor, status);
   }
@@ -190,13 +188,8 @@ public abstract class TakeSnapshotHandler extends EventHandler
       snapshotManifest.addTableDescriptor(this.htd);
       monitor.rethrowException();
 
-      List<Pair<RegionInfo, ServerName>> regionsAndLocations;
-      if (TableName.META_TABLE_NAME.equals(snapshotTable)) {
-        regionsAndLocations = MetaTableLocator.getMetaRegionsAndLocations(server.getZooKeeper());
-      } else {
-        regionsAndLocations = MetaTableAccessor.getTableRegionsAndLocations(server.getConnection(),
-          snapshotTable, false);
-      }
+      List<Pair<RegionInfo, ServerName>> regionsAndLocations =
+        master.getAssignmentManager().getTableRegionsAndLocations(snapshotTable, false);
 
       // run the snapshot
       snapshotRegions(regionsAndLocations);
@@ -247,11 +240,11 @@ public abstract class TakeSnapshotHandler extends EventHandler
       try {
         // if the working dir is still present, the snapshot has failed. it is present we delete
         // it.
-        if (workingDirFs.exists(workingDir) && !workingDirFs.delete(workingDir, true)) {
-          LOG.error("Couldn't delete snapshot working directory: {}", workingDir);
+        if (!workingDirFs.delete(workingDir, true)) {
+          LOG.error("Couldn't delete snapshot working directory:" + workingDir);
         }
       } catch (IOException e) {
-        LOG.error("Couldn't get or delete snapshot working directory: {}", workingDir, e);
+        LOG.error("Couldn't delete snapshot working directory:" + workingDir);
       }
       if (LOG.isDebugEnabled()) {
         LOG.debug("Table snapshot journal : \n" + status.prettyPrintJournal());
