@@ -21,12 +21,16 @@ import java.io.IOException;
 import java.io.InterruptedIOException;
 import java.util.ArrayList;
 import java.util.Date;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
+import java.util.function.Consumer;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.monitoring.MonitoredTask;
 import org.apache.hadoop.hbase.regionserver.DefaultStoreFlusher;
 import org.apache.hadoop.hbase.regionserver.FlushLifeCycleTracker;
@@ -44,6 +48,8 @@ import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.hbase.thirdparty.com.google.common.collect.ImmutableSetMultimap;
+
 /**
  * An implementation of the StoreFlusher. It extends the DefaultStoreFlusher. If the store is not a
  * mob store, the flusher flushes the MemStore the same with DefaultStoreFlusher, If the store is a
@@ -65,6 +71,13 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
   private long mobCellValueSizeThreshold = 0;
   private Path targetPath;
   private HMobStore mobStore;
+  // MOB file reference set
+  static ThreadLocal<Set<String>> mobRefSet = new ThreadLocal<Set<String>>() {
+    @Override
+    protected Set<String> initialValue() {
+      return new HashSet<String>();
+    }
+  };
 
   public DefaultMobStoreFlusher(Configuration conf, HStore store) throws IOException {
     super(conf, store);
@@ -94,8 +107,8 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
    */
   @Override
   public List<Path> flushSnapshot(MemStoreSnapshot snapshot, long cacheFlushId,
-    MonitoredTask status, ThroughputController throughputController, FlushLifeCycleTracker tracker)
-    throws IOException {
+    MonitoredTask status, ThroughputController throughputController, FlushLifeCycleTracker tracker,
+    Consumer<Path> writerCreationTracker) throws IOException {
     ArrayList<Path> result = new ArrayList<>();
     long cellsCount = snapshot.getCellsCount();
     if (cellsCount == 0) return result; // don't flush if there are no entries
@@ -109,13 +122,13 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
       synchronized (flushLock) {
         status.setStatus("Flushing " + store + ": creating writer");
         // Write the map out to the disk
-        writer = store.createWriterInTmp(cellsCount,
-          store.getColumnFamilyDescriptor().getCompressionType(), false, true, true, false);
+        writer = createWriter(snapshot, true, writerCreationTracker);
         IOException e = null;
         try {
           // It's a mob store, flush the cells in a mob way. This is the difference of flushing
           // between a normal and a mob store.
-          performMobFlush(snapshot, cacheFlushId, scanner, writer, status, throughputController);
+          performMobFlush(snapshot, cacheFlushId, scanner, writer, status, throughputController,
+            writerCreationTracker);
         } catch (IOException ioe) {
           e = ioe;
           // throw the exception out
@@ -155,20 +168,25 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
    * @param writer               The store file writer.
    * @param status               Task that represents the flush operation and may be updated with
    *                             status.
-   * @param throughputController A controller to avoid flush too fast.
+   * @param throughputController A controller to avoid flush too fast. n
    */
   protected void performMobFlush(MemStoreSnapshot snapshot, long cacheFlushId,
     InternalScanner scanner, StoreFileWriter writer, MonitoredTask status,
-    ThroughputController throughputController) throws IOException {
+    ThroughputController throughputController, Consumer<Path> writerCreationTracker)
+    throws IOException {
     StoreFileWriter mobFileWriter = null;
     int compactionKVMax =
       conf.getInt(HConstants.COMPACTION_KV_MAX, HConstants.COMPACTION_KV_MAX_DEFAULT);
     long mobCount = 0;
     long mobSize = 0;
     long time = snapshot.getTimeRangeTracker().getMax();
-    mobFileWriter = mobStore.createWriterInTmp(new Date(time), snapshot.getCellsCount(),
-      store.getColumnFamilyDescriptor().getCompressionType(), store.getRegionInfo().getStartKey(),
-      false);
+    mobFileWriter = mobStore.getStoreEngine().requireWritingToTmpDirFirst()
+      ? mobStore.createWriterInTmp(new Date(time), snapshot.getCellsCount(),
+        store.getColumnFamilyDescriptor().getCompressionType(), store.getRegionInfo().getStartKey(),
+        false)
+      : mobStore.createWriter(new Date(time), snapshot.getCellsCount(),
+        store.getColumnFamilyDescriptor().getCompressionType(), store.getRegionInfo().getStartKey(),
+        false, writerCreationTracker);
     // the target path is {tableName}/.mob/{cfName}/mobFiles
     // the relative path is mobFiles
     byte[] fileName = Bytes.toBytes(mobFileWriter.getPath().getName());
@@ -183,6 +201,8 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
       throughputController.start(flushName);
     }
     IOException ioe = null;
+    // Clear all past MOB references
+    mobRefSet.get().clear();
     try {
       do {
         hasMore = scanner.next(cells, scannerContext);
@@ -201,7 +221,6 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
               mobFileWriter.append(c);
               mobSize += c.getValueLength();
               mobCount++;
-
               // append the tags to the KeyValue.
               // The key is same, the value is the filename of the mob file
               Cell reference =
@@ -241,9 +260,12 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
       status.setStatus("Flushing mob file " + store + ": closing flushed file");
       mobFileWriter.close();
       mobStore.commitFile(mobFileWriter.getPath(), targetPath);
+      LOG.debug("Flush store file: {}, store: {}", writer.getPath(), getStoreInfo());
       mobStore.updateMobFlushCount();
       mobStore.updateMobFlushedCellsCount(mobCount);
       mobStore.updateMobFlushedCellsSize(mobSize);
+      // Add mob reference to store file metadata
+      mobRefSet.get().add(mobFileWriter.getPath().getName());
     } else {
       try {
         status.setStatus("Flushing mob file " + store + ": no mob cells, closing flushed file");
@@ -255,4 +277,23 @@ public class DefaultMobStoreFlusher extends DefaultStoreFlusher {
       }
     }
   }
+
+  @Override
+  protected void finalizeWriter(StoreFileWriter writer, long cacheFlushSeqNum, MonitoredTask status)
+    throws IOException {
+    // Write out the log sequence number that corresponds to this output
+    // hfile. Also write current time in metadata as minFlushTime.
+    // The hfile is current up to and including cacheFlushSeqNum.
+    status.setStatus("Flushing " + store + ": appending metadata");
+    writer.appendMetadata(cacheFlushSeqNum, false);
+    writer.appendMobMetadata(ImmutableSetMultimap.<TableName, String> builder()
+      .putAll(store.getTableName(), mobRefSet.get()).build());
+    status.setStatus("Flushing " + store + ": closing flushed file");
+    writer.close();
+  }
+
+  private String getStoreInfo() {
+    return String.format("[table=%s family=%s region=%s]", store.getTableName().getNameAsString(),
+      store.getColumnFamilyName(), store.getRegionInfo().getEncodedName());
+  }
 }
