@@ -26,9 +26,12 @@ import java.io.StringWriter;
 import java.util.Comparator;
 import java.util.Iterator;
 import java.util.Optional;
+import java.util.Set;
 import java.util.concurrent.BlockingQueue;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executors;
 import java.util.concurrent.RejectedExecutionException;
+import java.util.concurrent.RejectedExecutionHandler;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -90,6 +93,7 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
   private volatile ThreadPoolExecutor splits;
 
   private volatile ThroughputController compactionThroughputController;
+  private volatile Set<String> underCompactionStores = ConcurrentHashMap.newKeySet();
 
   private volatile boolean compactionsEnabled;
   /**
@@ -111,6 +115,15 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
       CompactionThroughputControllerFactory.create(server, conf);
   }
 
+  // only for test
+  public CompactSplit(Configuration conf) {
+    this.server = null;
+    this.conf = conf;
+    this.compactionsEnabled = this.conf.getBoolean(HBASE_REGION_SERVER_ENABLE_COMPACTION, true);
+    createCompactionExecutors();
+    createSplitExcecutors();
+  }
+
   private void createSplitExcecutors() {
     final String n = Thread.currentThread().getName();
     int splitThreads = conf.getInt(SPLIT_THREADS, SPLIT_THREADS_DEFAULT);
@@ -132,18 +145,15 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
     final String n = Thread.currentThread().getName();
 
     StealJobQueue<Runnable> stealJobQueue = new StealJobQueue<Runnable>(COMPARATOR);
-    // Since the StealJobQueue inner uses the PriorityBlockingQueue,
-    // which is an unbounded blocking queue, we remove the RejectedExecutionHandler for
-    // the long and short compaction thread pool executors since HBASE-27332.
-    // If anyone who what to change the StealJobQueue to a bounded queue,
-    // please add the rejection handler back.
     this.longCompactions = new ThreadPoolExecutor(largeThreads, largeThreads, 60, TimeUnit.SECONDS,
       stealJobQueue,
       new ThreadFactoryBuilder().setNameFormat(n + "-longCompactions-%d").setDaemon(true).build());
+    this.longCompactions.setRejectedExecutionHandler(new Rejection());
     this.longCompactions.prestartAllCoreThreads();
     this.shortCompactions = new ThreadPoolExecutor(smallThreads, smallThreads, 60, TimeUnit.SECONDS,
       stealJobQueue.getStealFromQueue(),
       new ThreadFactoryBuilder().setNameFormat(n + "-shortCompactions-%d").setDaemon(true).build());
+    this.shortCompactions.setRejectedExecutionHandler(new Rejection());
   }
 
   @Override
@@ -240,7 +250,8 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
     createCompactionExecutors();
   }
 
-  private interface CompactionCompleteTracker {
+  // set protected for test
+  protected interface CompactionCompleteTracker {
 
     default void completed(Store store) {
     }
@@ -302,13 +313,11 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
         LOG.info("Re-Initializing compactions because user switched on compactions");
         reInitializeCompactionsExecutors();
       }
-      setCompactionsEnabled(onOrOff);
-      return;
+    } else {
+      LOG.info("Interrupting running compactions because user switched off compactions");
+      interrupt();
     }
-
     setCompactionsEnabled(onOrOff);
-    LOG.info("Interrupting running compactions because user switched off compactions");
-    interrupt();
   }
 
   private void requestCompactionInternal(HRegion region, String why, int priority,
@@ -321,14 +330,10 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
     }
   }
 
-  private void requestCompactionInternal(HRegion region, HStore store, String why, int priority,
+  // set protected for test
+  protected void requestCompactionInternal(HRegion region, HStore store, String why, int priority,
     boolean selectNow, CompactionLifeCycleTracker tracker,
     CompactionCompleteTracker completeTracker, User user) throws IOException {
-    if (!this.isCompactionsEnabled()) {
-      LOG.info("Ignoring compaction request for " + region + ",because compaction is disabled.");
-      return;
-    }
-
     if (
       this.server.isStopped() || (region.getTableDescriptor() != null
         && !region.getTableDescriptor().isCompactionEnabled())
@@ -379,6 +384,13 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
     }
     pool.execute(
       new CompactionRunner(store, region, compaction, tracker, completeTracker, pool, user));
+    if (LOG.isDebugEnabled()) {
+      LOG.debug(
+        "Add compact mark for store {}, priority={}, current under compaction "
+          + "store size is {}",
+        getStoreNameForUnderCompaction(store), priority, underCompactionStores.size());
+    }
+    underCompactionStores.add(getStoreNameForUnderCompaction(store));
     region.incrementCompactionsQueuedCount();
     if (LOG.isDebugEnabled()) {
       String type = (pool == shortCompactions) ? "Small " : "Large ";
@@ -392,8 +404,17 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
       DUMMY_COMPLETE_TRACKER, null);
   }
 
-  public synchronized void requestSystemCompaction(HRegion region, HStore store, String why)
-    throws IOException {
+  public void requestSystemCompaction(HRegion region, HStore store, String why) throws IOException {
+    requestSystemCompaction(region, store, why, false);
+  }
+
+  public synchronized void requestSystemCompaction(HRegion region, HStore store, String why,
+    boolean giveUpIfRequestedOrCompacting) throws IOException {
+    if (giveUpIfRequestedOrCompacting && isUnderCompaction(store)) {
+      LOG.debug("Region {} store {} is under compaction now, skip to request compaction", region,
+        store.getColumnFamilyName());
+      return;
+    }
     requestCompactionInternal(region, store, why, NO_PRIORITY, false,
       CompactionLifeCycleTracker.DUMMY, DUMMY_COMPLETE_TRACKER, null);
   }
@@ -481,6 +502,13 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
     return this.regionSplitLimit;
   }
 
+  /**
+   * Check if this store is under compaction
+   */
+  public boolean isUnderCompaction(final HStore s) {
+    return underCompactionStores.contains(getStoreNameForUnderCompaction(s));
+  }
+
   private static final Comparator<Runnable> COMPARATOR = new Comparator<Runnable>() {
 
     private int compare(CompactionRequestImpl r1, CompactionRequestImpl r2) {
@@ -662,15 +690,24 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
 
     @Override
     public void run() {
-      Preconditions.checkNotNull(server);
-      if (
-        server.isStopped() || (region.getTableDescriptor() != null
-          && !region.getTableDescriptor().isCompactionEnabled())
-      ) {
-        region.decrementCompactionsQueuedCount();
-        return;
+      try {
+        Preconditions.checkNotNull(server);
+        if (
+          server.isStopped() || (region.getTableDescriptor() != null
+            && !region.getTableDescriptor().isCompactionEnabled())
+        ) {
+          region.decrementCompactionsQueuedCount();
+          return;
+        }
+        doCompaction(user);
+      } finally {
+        if (LOG.isDebugEnabled()) {
+          LOG.debug("Remove under compaction mark for store: {}",
+            store.getHRegion().getRegionInfo().getEncodedName() + ":"
+              + store.getColumnFamilyName());
+        }
+        underCompactionStores.remove(getStoreNameForUnderCompaction(store));
       }
-      doCompaction(user);
     }
 
     private String formatStackTrace(Exception ex) {
@@ -682,6 +719,22 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
     }
   }
 
+  /**
+   * Cleanup class to use when rejecting a compaction request from the queue.
+   */
+  private static class Rejection implements RejectedExecutionHandler {
+    @Override
+    public void rejectedExecution(Runnable runnable, ThreadPoolExecutor pool) {
+      if (runnable instanceof CompactionRunner) {
+        CompactionRunner runner = (CompactionRunner) runnable;
+        LOG.debug("Compaction Rejected: " + runner);
+        if (runner.compaction != null) {
+          runner.store.cancelRequestedCompaction(runner.compaction);
+        }
+      }
+    }
+  }
+
   /**
    * {@inheritDoc}
    */
@@ -811,4 +864,10 @@ public class CompactSplit implements CompactionRequester, PropagatingConfigurati
     return shortCompactions;
   }
 
+  private String getStoreNameForUnderCompaction(HStore store) {
+    return String.format("%s:%s",
+      store.getHRegion() != null ? store.getHRegion().getRegionInfo().getEncodedName() : "",
+      store.getColumnFamilyName());
+  }
+
 }
