@@ -24,9 +24,11 @@ import java.util.Date;
 import java.util.List;
 import java.util.Map;
 import java.util.NavigableSet;
+import java.util.Optional;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicLong;
+import java.util.function.Consumer;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
@@ -54,7 +56,6 @@ import org.apache.hadoop.hbase.mob.MobFileCache;
 import org.apache.hadoop.hbase.mob.MobFileName;
 import org.apache.hadoop.hbase.mob.MobStoreEngine;
 import org.apache.hadoop.hbase.mob.MobUtils;
-import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.HFileArchiveUtil;
 import org.apache.hadoop.hbase.util.IdLock;
 import org.apache.yetus.audience.InterfaceAudience;
@@ -90,7 +91,7 @@ public class HMobStore extends HStore {
   private AtomicLong mobFlushedCellsSize = new AtomicLong();
   private AtomicLong mobScanCellsCount = new AtomicLong();
   private AtomicLong mobScanCellsSize = new AtomicLong();
-  private Map<String, List<Path>> map = new ConcurrentHashMap<>();
+  private Map<TableName, List<Path>> map = new ConcurrentHashMap<>();
   private final IdLock keyLock = new IdLock();
   // When we add a MOB reference cell to the HFile, we will add 2 tags along with it
   // 1. A ref tag with type TagType.MOB_REFERENCE_TAG_TYPE. This just denote this this cell is not
@@ -112,7 +113,7 @@ public class HMobStore extends HStore {
     TableName tn = region.getTableDescriptor().getTableName();
     locations.add(HFileArchiveUtil.getStoreArchivePath(conf, tn,
       MobUtils.getMobRegionInfo(tn).getEncodedName(), family.getNameAsString()));
-    map.put(Bytes.toString(tn.getName()), locations);
+    map.put(tn, locations);
     List<Tag> tags = new ArrayList<>(2);
     tags.add(MobConstants.MOB_REF_TAG);
     Tag tableNameTag =
@@ -156,7 +157,7 @@ public class HMobStore extends HStore {
   protected StoreEngine<?, ?, ?, ?> createStoreEngine(HStore store, Configuration conf,
     CellComparator cellComparator) throws IOException {
     MobStoreEngine engine = new MobStoreEngine();
-    engine.createComponents(conf, store, cellComparator);
+    engine.createComponentsOnce(conf, store, cellComparator);
     return engine;
   }
 
@@ -175,7 +176,7 @@ public class HMobStore extends HStore {
    * @param compression  The compression algorithm.
    * @param startKey     The start key.
    * @param isCompaction If the writer is used in compaction.
-   * @return The writer for the mob file.
+   * @return The writer for the mob file. n
    */
   public StoreFileWriter createWriterInTmp(Date date, long maxKeyCount,
     Compression.Algorithm compression, byte[] startKey, boolean isCompaction) throws IOException {
@@ -184,27 +185,27 @@ public class HMobStore extends HStore {
     }
     Path path = getTempDir();
     return createWriterInTmp(MobUtils.formatDate(date), path, maxKeyCount, compression, startKey,
-      isCompaction);
+      isCompaction, null);
   }
 
   /**
-   * Creates the writer for the del file in temp directory. The del file keeps tracking the delete
-   * markers. Its name has a suffix _del, the format is [0-9a-f]+(_del)?.
-   * @param date        The latest date of written cells.
-   * @param maxKeyCount The key count.
-   * @param compression The compression algorithm.
-   * @param startKey    The start key.
-   * @return The writer for the del file.
+   * Creates the writer for the mob file in the mob family directory.
+   * @param date         The latest date of written cells.
+   * @param maxKeyCount  The key count.
+   * @param compression  The compression algorithm.
+   * @param startKey     The start key.
+   * @param isCompaction If the writer is used in compaction.
+   * @return The writer for the mob file. n
    */
-  public StoreFileWriter createDelFileWriterInTmp(Date date, long maxKeyCount,
-    Compression.Algorithm compression, byte[] startKey) throws IOException {
+  public StoreFileWriter createWriter(Date date, long maxKeyCount,
+    Compression.Algorithm compression, byte[] startKey, boolean isCompaction,
+    Consumer<Path> writerCreationTracker) throws IOException {
     if (startKey == null) {
       startKey = HConstants.EMPTY_START_ROW;
     }
-    Path path = getTempDir();
-    String suffix = UUID.randomUUID().toString().replaceAll("-", "") + "_del";
-    MobFileName mobFileName = MobFileName.create(startKey, MobUtils.formatDate(date), suffix);
-    return createWriterInTmp(mobFileName, path, maxKeyCount, compression, true);
+    Path path = getPath();
+    return createWriterInTmp(MobUtils.formatDate(date), path, maxKeyCount, compression, startKey,
+      isCompaction, writerCreationTracker);
   }
 
   /**
@@ -215,13 +216,16 @@ public class HMobStore extends HStore {
    * @param compression  The compression algorithm.
    * @param startKey     The start key.
    * @param isCompaction If the writer is used in compaction.
-   * @return The writer for the mob file.
+   * @return The writer for the mob file. n
    */
   public StoreFileWriter createWriterInTmp(String date, Path basePath, long maxKeyCount,
-    Compression.Algorithm compression, byte[] startKey, boolean isCompaction) throws IOException {
+    Compression.Algorithm compression, byte[] startKey, boolean isCompaction,
+    Consumer<Path> writerCreationTracker) throws IOException {
     MobFileName mobFileName =
-      MobFileName.create(startKey, date, UUID.randomUUID().toString().replaceAll("-", ""));
-    return createWriterInTmp(mobFileName, basePath, maxKeyCount, compression, isCompaction);
+      MobFileName.create(startKey, date, UUID.randomUUID().toString().replaceAll("-", ""),
+        getHRegion().getRegionInfo().getEncodedName());
+    return createWriterInTmp(mobFileName, basePath, maxKeyCount, compression, isCompaction,
+      writerCreationTracker);
   }
 
   /**
@@ -231,21 +235,23 @@ public class HMobStore extends HStore {
    * @param maxKeyCount  The key count.
    * @param compression  The compression algorithm.
    * @param isCompaction If the writer is used in compaction.
-   * @return The writer for the mob file.
+   * @return The writer for the mob file. n
    */
+
   public StoreFileWriter createWriterInTmp(MobFileName mobFileName, Path basePath, long maxKeyCount,
-    Compression.Algorithm compression, boolean isCompaction) throws IOException {
+    Compression.Algorithm compression, boolean isCompaction, Consumer<Path> writerCreationTracker)
+    throws IOException {
     return MobUtils.createWriter(conf, getFileSystem(), getColumnFamilyDescriptor(),
       new Path(basePath, mobFileName.getFileName()), maxKeyCount, compression, getCacheConfig(),
       getStoreContext().getEncryptionContext(), StoreUtils.getChecksumType(conf),
       StoreUtils.getBytesPerChecksum(conf), getStoreContext().getBlockSize(), BloomType.NONE,
-      isCompaction);
+      isCompaction, writerCreationTracker);
   }
 
   /**
    * Commits the mob file.
    * @param sourceFile The source file.
-   * @param targetPath The directory path where the source file is renamed to.
+   * @param targetPath The directory path where the source file is renamed to. n
    */
   public void commitFile(final Path sourceFile, Path targetPath) throws IOException {
     if (sourceFile == null) {
@@ -253,8 +259,11 @@ public class HMobStore extends HStore {
     }
     Path dstPath = new Path(targetPath, sourceFile.getName());
     validateMobFile(sourceFile);
-    String msg = "Renaming flushed file from " + sourceFile + " to " + dstPath;
-    LOG.info(msg);
+    if (sourceFile.equals(targetPath)) {
+      LOG.info("File is already in the destination dir: {}", sourceFile);
+      return;
+    }
+    LOG.info(" FLUSH Renaming flushed file from {} to {}", sourceFile, dstPath);
     Path parent = dstPath.getParent();
     if (!getFileSystem().exists(parent)) {
       getFileSystem().mkdirs(parent);
@@ -289,12 +298,26 @@ public class HMobStore extends HStore {
    * DefaultMobStoreCompactor where we can read empty value for the missing cell.
    * @param reference   The cell found in the HBase, its value is a path to a mob file.
    * @param cacheBlocks Whether the scanner should cache blocks.
-   * @return The cell found in the mob file.
+   * @return The cell found in the mob file. n
    */
   public MobCell resolve(Cell reference, boolean cacheBlocks) throws IOException {
     return resolve(reference, cacheBlocks, -1, true);
   }
 
+  /**
+   * Reads the cell from the mob file with readEmptyValueOnMobCellMiss
+   * @param reference                   The cell found in the HBase, its value is a path to a mob
+   *                                    file.
+   * @param cacheBlocks                 Whether the scanner should cache blocks.
+   * @param readEmptyValueOnMobCellMiss should return empty mob cell if reference can not be
+   *                                    resolved.
+   * @return The cell found in the mob file. n
+   */
+  public MobCell resolve(Cell reference, boolean cacheBlocks, boolean readEmptyValueOnMobCellMiss)
+    throws IOException {
+    return resolve(reference, cacheBlocks, -1, readEmptyValueOnMobCellMiss);
+  }
+
   /**
    * Reads the cell from the mob file.
    * @param reference                   The cell found in the HBase, its value is a path to a mob
@@ -303,33 +326,16 @@ public class HMobStore extends HStore {
    * @param readPt                      the read point.
    * @param readEmptyValueOnMobCellMiss Whether return null value when the mob file is missing or
    *                                    corrupt.
-   * @return The cell found in the mob file.
+   * @return The cell found in the mob file. n
    */
   public MobCell resolve(Cell reference, boolean cacheBlocks, long readPt,
     boolean readEmptyValueOnMobCellMiss) throws IOException {
     MobCell mobCell = null;
     if (MobUtils.hasValidMobRefCellValue(reference)) {
       String fileName = MobUtils.getMobFileName(reference);
-      Tag tableNameTag = MobUtils.getTableNameTag(reference);
-      if (tableNameTag != null) {
-        String tableNameString = Tag.getValueAsString(tableNameTag);
-        List<Path> locations = map.get(tableNameString);
-        if (locations == null) {
-          IdLock.Entry lockEntry = keyLock.getLockEntry(tableNameString.hashCode());
-          try {
-            locations = map.get(tableNameString);
-            if (locations == null) {
-              locations = new ArrayList<>(2);
-              TableName tn = TableName.valueOf(tableNameString);
-              locations.add(MobUtils.getMobFamilyPath(conf, tn, getColumnFamilyName()));
-              locations.add(HFileArchiveUtil.getStoreArchivePath(conf, tn,
-                MobUtils.getMobRegionInfo(tn).getEncodedName(), getColumnFamilyName()));
-              map.put(tableNameString, locations);
-            }
-          } finally {
-            keyLock.releaseLockEntry(lockEntry);
-          }
-        }
+      Optional<TableName> tableName = MobUtils.getTableName(reference);
+      if (tableName.isPresent()) {
+        List<Path> locations = getLocations(tableName.get());
         mobCell = readCell(locations, fileName, reference, cacheBlocks, readPt,
           readEmptyValueOnMobCellMiss);
       }
@@ -352,6 +358,32 @@ public class HMobStore extends HStore {
     return mobCell;
   }
 
+  /**
+   * @param tableName to look up locations for, can not be null
+   * @return a list of location in order of working dir, archive dir. will not be null.
+   */
+  public List<Path> getLocations(TableName tableName) throws IOException {
+    List<Path> locations = map.get(tableName);
+    if (locations == null) {
+      IdLock.Entry lockEntry = keyLock.getLockEntry(tableName.hashCode());
+      try {
+        locations = map.get(tableName);
+        if (locations == null) {
+          locations = new ArrayList<>(2);
+          locations.add(MobUtils.getMobFamilyPath(conf, tableName,
+            getColumnFamilyDescriptor().getNameAsString()));
+          locations.add(HFileArchiveUtil.getStoreArchivePath(conf, tableName,
+            MobUtils.getMobRegionInfo(tableName).getEncodedName(),
+            getColumnFamilyDescriptor().getNameAsString()));
+          map.put(tableName, locations);
+        }
+      } finally {
+        keyLock.releaseLockEntry(lockEntry);
+      }
+    }
+    return locations;
+  }
+
   /**
    * Reads the cell from a mob file. The mob file might be located in different directories. 1. The
    * working directory. 2. The archive directory. Reads the cell from the files located in both of
@@ -363,12 +395,12 @@ public class HMobStore extends HStore {
    * @param readPt                      the read point.
    * @param readEmptyValueOnMobCellMiss Whether return null value when the mob file is missing or
    *                                    corrupt.
-   * @return The found cell. Null if there's no such a cell.
+   * @return The found cell. Null if there's no such a cell. n
    */
   private MobCell readCell(List<Path> locations, String fileName, Cell search,
     boolean cacheMobBlocks, long readPt, boolean readEmptyValueOnMobCellMiss) throws IOException {
     FileSystem fs = getFileSystem();
-    IOException ioe = null;
+    Throwable throwable = null;
     for (Path location : locations) {
       MobFile file = null;
       Path path = new Path(location, fileName);
@@ -379,7 +411,7 @@ public class HMobStore extends HStore {
           : file.readCell(search, cacheMobBlocks);
       } catch (IOException e) {
         mobFileCache.evictFile(fileName);
-        ioe = e;
+        throwable = e;
         if (
           (e instanceof FileNotFoundException) || (e.getCause() instanceof FileNotFoundException)
         ) {
@@ -390,6 +422,14 @@ public class HMobStore extends HStore {
         } else {
           throw e;
         }
+      } catch (NullPointerException e) { // HDFS 1.x - DFSInputStream.getBlockAt()
+        mobFileCache.evictFile(fileName);
+        LOG.debug("Fail to read the cell", e);
+        throwable = e;
+      } catch (AssertionError e) { // assert in HDFS 1.x - DFSInputStream.getBlockAt()
+        mobFileCache.evictFile(fileName);
+        LOG.debug("Fail to read the cell", e);
+        throwable = e;
       } finally {
         if (file != null) {
           mobFileCache.closeFile(file);
@@ -401,15 +441,18 @@ public class HMobStore extends HStore {
     if (readEmptyValueOnMobCellMiss) {
       return null;
     } else if (
-      (ioe instanceof FileNotFoundException) || (ioe.getCause() instanceof FileNotFoundException)
+      (throwable instanceof FileNotFoundException)
+        || (throwable.getCause() instanceof FileNotFoundException)
     ) {
       // The region is re-opened when FileNotFoundException is thrown.
       // This is not necessary when MOB files cannot be found, because the store files
       // in a region only contain the references to MOB files and a re-open on a region
       // doesn't help fix the lost MOB files.
-      throw new DoNotRetryIOException(ioe);
+      throw new DoNotRetryIOException(throwable);
+    } else if (throwable instanceof IOException) {
+      throw (IOException) throwable;
     } else {
-      throw ioe;
+      throw new IOException(throwable);
     }
   }
 
@@ -496,4 +539,5 @@ public class HMobStore extends HStore {
   public byte[] getRefCellTags() {
     return this.refCellTags;
   }
+
 }
