@@ -25,7 +25,9 @@ import java.io.IOException;
 import java.io.InterruptedIOException;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.UUID;
@@ -50,6 +52,9 @@ import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.fs.HFileSystem;
 import org.apache.hadoop.hbase.io.HFileLink;
 import org.apache.hadoop.hbase.io.Reference;
+import org.apache.hadoop.hbase.master.procedure.MasterProcedureEnv;
+import org.apache.hadoop.hbase.regionserver.storefiletracker.StoreFileTracker;
+import org.apache.hadoop.hbase.regionserver.storefiletracker.StoreFileTrackerFactory;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
 import org.apache.hadoop.hbase.util.FSUtils;
@@ -147,7 +152,7 @@ public class HRegionFileSystem {
   // Temp Helpers
   // ===========================================================================
   /** Returns {@link Path} to the region's temp directory, used for file creations */
-  Path getTempDir() {
+  public Path getTempDir() {
     return new Path(getRegionDir(), REGION_TEMP_DIR);
   }
 
@@ -220,6 +225,20 @@ public class HRegionFileSystem {
     CommonFSUtils.setStoragePolicy(this.fs, getStoreDir(familyName), policyName);
   }
 
+  /**
+   * Set storage policy for a whole region. <br>
+   * <i>"LAZY_PERSIST"</i>, <i>"ALL_SSD"</i>, <i>"ONE_SSD"</i>, <i>"HOT"</i>, <i>"WARM"</i>,
+   * <i>"COLD"</i> <br>
+   * <br>
+   * See {@link org.apache.hadoop.hdfs.protocol.HdfsConstants} for more details.
+   * @param policyName The name of the storage policy: 'HOT', 'COLD', etc. See hadoop 2.6+
+   *                   org.apache.hadoop.hdfs.protocol.HdfsConstants for possible list e.g 'COLD',
+   *                   'WARM', 'HOT', 'ONE_SSD', 'ALL_SSD', 'LAZY_PERSIST'.
+   */
+  public void setStoragePolicy(String policyName) {
+    CommonFSUtils.setStoragePolicy(this.fs, getRegionDir(), policyName);
+  }
+
   /**
    * Get the storage policy of the directory of CF.
    * @param familyName The name of column family.
@@ -242,11 +261,7 @@ public class HRegionFileSystem {
    * @param familyName Column Family Name
    * @return a set of {@link StoreFileInfo} for the specified family.
    */
-  public Collection<StoreFileInfo> getStoreFiles(final byte[] familyName) throws IOException {
-    return getStoreFiles(Bytes.toString(familyName));
-  }
-
-  public Collection<StoreFileInfo> getStoreFiles(final String familyName) throws IOException {
+  public List<StoreFileInfo> getStoreFiles(final String familyName) throws IOException {
     return getStoreFiles(familyName, true);
   }
 
@@ -256,7 +271,7 @@ public class HRegionFileSystem {
    * @param familyName Column Family Name
    * @return a set of {@link StoreFileInfo} for the specified family.
    */
-  public Collection<StoreFileInfo> getStoreFiles(final String familyName, final boolean validate)
+  public List<StoreFileInfo> getStoreFiles(final String familyName, final boolean validate)
     throws IOException {
     Path familyDir = getStoreDir(familyName);
     FileStatus[] files = CommonFSUtils.listStatus(this.fs, familyDir);
@@ -345,7 +360,7 @@ public class HRegionFileSystem {
   /**
    * Returns true if the specified family has reference files
    * @param familyName Column Family Name
-   * @return true if family contains reference files
+   * @return true if family contains reference files n
    */
   public boolean hasReferences(final String familyName) throws IOException {
     Path storeDir = getStoreDir(familyName);
@@ -367,7 +382,7 @@ public class HRegionFileSystem {
   /**
    * Check whether region has Reference file
    * @param htd table desciptor of the region
-   * @return true if region has reference file
+   * @return true if region has reference file n
    */
   public boolean hasReferences(final TableDescriptor htd) throws IOException {
     for (ColumnFamilyDescriptor family : htd.getColumnFamilies()) {
@@ -450,7 +465,7 @@ public class HRegionFileSystem {
    * Move the file from a build/temp location to the main family store directory.
    * @param familyName Family that will gain the file
    * @param buildPath  {@link Path} to the file to commit.
-   * @return The new {@link Path} of the committed file
+   * @return The new {@link Path} of the committed file n
    */
   public Path commitStoreFile(final String familyName, final Path buildPath) throws IOException {
     Path dstPath = preCommitStoreFile(familyName, buildPath, -1, false);
@@ -465,7 +480,7 @@ public class HRegionFileSystem {
    * @param seqNum          Sequence Number to append to the file name (less then 0 if no sequence
    *                        number)
    * @param generateNewName False if you want to keep the buildPath name
-   * @return The new {@link Path} of the to be committed file
+   * @return The new {@link Path} of the to be committed file n
    */
   private Path preCommitStoreFile(final String familyName, final Path buildPath, final long seqNum,
     final boolean generateNewName) throws IOException {
@@ -491,9 +506,13 @@ public class HRegionFileSystem {
    * Moves file from staging dir to region dir
    * @param buildPath {@link Path} to the file to commit.
    * @param dstPath {@link Path} to the file under region dir
-   * @return The {@link Path} of the committed file
+   * @return The {@link Path} of the committed file n
    */
   Path commitStoreFile(final Path buildPath, Path dstPath) throws IOException {
+    // rename is not necessary in case of direct-insert stores
+    if (buildPath.equals(dstPath)) {
+      return dstPath;
+    }
     // buildPath exists, therefore not doing an exists() check.
     if (!rename(buildPath, dstPath)) {
       throw new IOException("Failed rename of " + buildPath + " to " + dstPath);
@@ -531,7 +550,7 @@ public class HRegionFileSystem {
    * @param familyName Family that will gain the file
    * @param srcPath    {@link Path} to the file to import
    * @param seqNum     Bulk Load sequence number
-   * @return The destination {@link Path} of the bulk loaded file
+   * @return The destination {@link Path} of the bulk loaded file n
    */
   Pair<Path, Path> bulkLoadStoreFile(final String familyName, Path srcPath, long seqNum)
     throws IOException {
@@ -559,52 +578,14 @@ public class HRegionFileSystem {
   // ===========================================================================
   // Splits Helpers
   // ===========================================================================
-  /** Returns {@link Path} to the temp directory used during split operations */
-  Path getSplitsDir() {
-    return new Path(getRegionDir(), REGION_SPLITS_DIR);
-  }
 
   public Path getSplitsDir(final RegionInfo hri) {
-    return new Path(getSplitsDir(), hri.getEncodedName());
-  }
-
-  /**
-   * Clean up any split detritus that may have been left around from previous split attempts.
-   */
-  void cleanupSplitsDir() throws IOException {
-    deleteDir(getSplitsDir());
-  }
-
-  /**
-   * Clean up any split detritus that may have been left around from previous split attempts. Call
-   * this method on initial region deploy.
-   */
-  void cleanupAnySplitDetritus() throws IOException {
-    Path splitdir = this.getSplitsDir();
-    if (!fs.exists(splitdir)) return;
-    // Look at the splitdir. It could have the encoded names of the daughter
-    // regions we tried to make. See if the daughter regions actually got made
-    // out under the tabledir. If here under splitdir still, then the split did
-    // not complete. Try and do cleanup. This code WILL NOT catch the case
-    // where we successfully created daughter a but regionserver crashed during
-    // the creation of region b. In this case, there'll be an orphan daughter
-    // dir in the filesystem. TOOD: Fix.
-    FileStatus[] daughters = CommonFSUtils.listStatus(fs, splitdir, new FSUtils.DirFilter(fs));
-    if (daughters != null) {
-      for (FileStatus daughter : daughters) {
-        Path daughterDir = new Path(getTableDir(), daughter.getPath().getName());
-        if (fs.exists(daughterDir) && !deleteDir(daughterDir)) {
-          throw new IOException("Failed delete of " + daughterDir);
-        }
-      }
-    }
-    cleanupSplitsDir();
-    LOG.info("Cleaned up old failed split transaction detritus: " + splitdir);
+    return new Path(getTableDir(), hri.getEncodedName());
   }
 
   /**
    * Remove daughter region
-   * @param regionInfo daughter {@link RegionInfo}
+   * @param regionInfo daughter {@link RegionInfo} n
    */
   void cleanupDaughterRegion(final RegionInfo regionInfo) throws IOException {
     Path regionDir = new Path(this.tableDir, regionInfo.getEncodedName());
@@ -618,48 +599,63 @@ public class HRegionFileSystem {
    * in the filesystem.
    * @param regionInfo daughter {@link org.apache.hadoop.hbase.client.RegionInfo}
    */
-  public Path commitDaughterRegion(final RegionInfo regionInfo) throws IOException {
-    Path regionDir = new Path(this.tableDir, regionInfo.getEncodedName());
-    Path daughterTmpDir = this.getSplitsDir(regionInfo);
-
-    if (fs.exists(daughterTmpDir)) {
-
+  public Path commitDaughterRegion(final RegionInfo regionInfo, List<Path> allRegionFiles,
+    MasterProcedureEnv env) throws IOException {
+    Path regionDir = this.getSplitsDir(regionInfo);
+    if (fs.exists(regionDir)) {
       // Write HRI to a file in case we need to recover hbase:meta
-      Path regionInfoFile = new Path(daughterTmpDir, REGION_INFO_FILE);
+      Path regionInfoFile = new Path(regionDir, REGION_INFO_FILE);
       byte[] regionInfoContent = getRegionInfoFileContent(regionInfo);
       writeRegionInfoFileContent(conf, fs, regionInfoFile, regionInfoContent);
-
-      // Move the daughter temp dir to the table dir
-      if (!rename(daughterTmpDir, regionDir)) {
-        throw new IOException("Unable to rename " + daughterTmpDir + " to " + regionDir);
-      }
+      HRegionFileSystem regionFs = HRegionFileSystem.openRegionFromFileSystem(
+        env.getMasterConfiguration(), fs, getTableDir(), regionInfo, false);
+      insertRegionFilesIntoStoreTracker(allRegionFiles, env, regionFs);
     }
-
     return regionDir;
   }
 
+  private void insertRegionFilesIntoStoreTracker(List<Path> allFiles, MasterProcedureEnv env,
+    HRegionFileSystem regionFs) throws IOException {
+    TableDescriptor tblDesc =
+      env.getMasterServices().getTableDescriptors().get(regionInfo.getTable());
+    // we need to map trackers per store
+    Map<String, StoreFileTracker> trackerMap = new HashMap<>();
+    // we need to map store files per store
+    Map<String, List<StoreFileInfo>> fileInfoMap = new HashMap<>();
+    for (Path file : allFiles) {
+      String familyName = file.getParent().getName();
+      trackerMap.computeIfAbsent(familyName, t -> StoreFileTrackerFactory.create(conf, tblDesc,
+        tblDesc.getColumnFamily(Bytes.toBytes(familyName)), regionFs));
+      fileInfoMap.computeIfAbsent(familyName, l -> new ArrayList<>());
+      List<StoreFileInfo> infos = fileInfoMap.get(familyName);
+      infos.add(new StoreFileInfo(conf, fs, file, true));
+    }
+    for (Map.Entry<String, StoreFileTracker> entry : trackerMap.entrySet()) {
+      entry.getValue().add(fileInfoMap.get(entry.getKey()));
+    }
+  }
+
   /**
-   * Create the region splits directory.
+   * Creates region split daughter directories under the table dir. If the daughter regions already
+   * exist, for example, in the case of a recovery from a previous failed split procedure, this
+   * method deletes the given region dir recursively, then recreates it again.
    */
   public void createSplitsDir(RegionInfo daughterA, RegionInfo daughterB) throws IOException {
-    Path splitdir = getSplitsDir();
-    if (fs.exists(splitdir)) {
-      LOG.info("The " + splitdir + " directory exists.  Hence deleting it to recreate it");
-      if (!deleteDir(splitdir)) {
-        throw new IOException("Failed deletion of " + splitdir + " before creating them again.");
-      }
+    Path daughterADir = getSplitsDir(daughterA);
+    if (fs.exists(daughterADir) && !deleteDir(daughterADir)) {
+      throw new IOException("Failed deletion of " + daughterADir + " before creating them again.");
+
     }
-    // splitDir doesn't exists now. No need to do an exists() call for it.
-    if (!createDir(splitdir)) {
-      throw new IOException("Failed create of " + splitdir);
+    if (!createDir(daughterADir)) {
+      throw new IOException("Failed create of " + daughterADir);
     }
-    Path daughterATmpDir = getSplitsDir(daughterA);
-    if (!createDir(daughterATmpDir)) {
-      throw new IOException("Failed create of " + daughterATmpDir);
+    Path daughterBDir = getSplitsDir(daughterB);
+    if (fs.exists(daughterBDir) && !deleteDir(daughterBDir)) {
+      throw new IOException("Failed deletion of " + daughterBDir + " before creating them again.");
+
     }
-    Path daughterBTmpDir = getSplitsDir(daughterB);
-    if (!createDir(daughterBTmpDir)) {
-      throw new IOException("Failed create of " + daughterBTmpDir);
+    if (!createDir(daughterBDir)) {
+      throw new IOException("Failed create of " + daughterBDir);
     }
   }
 
@@ -677,8 +673,20 @@ public class HRegionFileSystem {
    */
   public Path splitStoreFile(RegionInfo hri, String familyName, HStoreFile f, byte[] splitRow,
     boolean top, RegionSplitPolicy splitPolicy) throws IOException {
-    boolean createLinkFile = false;
     Path splitDir = new Path(getSplitsDir(hri), familyName);
+    // Add the referred-to regions name as a dot separated suffix.
+    // See REF_NAME_REGEX regex above. The referred-to regions name is
+    // up in the path of the passed in <code>f</code> -- parentdir is family,
+    // then the directory above is the region name.
+    String parentRegionName = regionInfoForFs.getEncodedName();
+    // Write reference with same file id only with the other region name as
+    // suffix and into the new region location (under same family).
+    Path p = new Path(splitDir, f.getPath().getName() + "." + parentRegionName);
+    if (fs.exists(p)) {
+      LOG.warn("Found an already existing split file for {}. Assuming this is a recovery.", p);
+      return p;
+    }
+    boolean createLinkFile = false;
     if (splitPolicy == null || !splitPolicy.skipStoreFileRangeCheck(familyName)) {
       // Check whether the split row lies in the range of the store file
       // If it is outside the range, return directly.
@@ -718,7 +726,6 @@ public class HRegionFileSystem {
         f.closeStoreFile(f.getCacheConf() != null ? f.getCacheConf().shouldEvictOnClose() : true);
       }
     }
-
     if (createLinkFile) {
       // create HFileLink file instead of Reference file for child
       String hfileName = f.getPath().getName();
@@ -751,39 +758,20 @@ public class HRegionFileSystem {
     // A reference to the bottom half of the hsf store file.
     Reference r =
       top ? Reference.createTopReference(splitRow) : Reference.createBottomReference(splitRow);
-    // Add the referred-to regions name as a dot separated suffix.
-    // See REF_NAME_REGEX regex above. The referred-to regions name is
-    // up in the path of the passed in <code>f</code> -- parentdir is family,
-    // then the directory above is the region name.
-    String parentRegionName = regionInfoForFs.getEncodedName();
-    // Write reference with same file id only with the other region name as
-    // suffix and into the new region location (under same family).
-    Path p = new Path(splitDir, f.getPath().getName() + "." + parentRegionName);
     return r.write(fs, p);
   }
 
   // ===========================================================================
   // Merge Helpers
   // ===========================================================================
-  /** Returns {@link Path} to the temp directory used during merge operations */
-  public Path getMergesDir() {
-    return new Path(getRegionDir(), REGION_MERGES_DIR);
-  }
 
   Path getMergesDir(final RegionInfo hri) {
-    return new Path(getMergesDir(), hri.getEncodedName());
-  }
-
-  /**
-   * Clean up any merge detritus that may have been left around from previous merge attempts.
-   */
-  void cleanupMergesDir() throws IOException {
-    deleteDir(getMergesDir());
+    return new Path(getTableDir(), hri.getEncodedName());
   }
 
   /**
    * Remove merged region
-   * @param mergedRegion {@link RegionInfo}
+   * @param mergedRegion {@link RegionInfo} n
    */
   public void cleanupMergedRegion(final RegionInfo mergedRegion) throws IOException {
     Path regionDir = new Path(this.tableDir, mergedRegion.getEncodedName());
@@ -804,41 +792,23 @@ public class HRegionFileSystem {
   }
 
   /**
-   * Create the region merges directory, a temporary directory to accumulate merges in.
-   * @throws IOException If merges dir already exists or we fail to create it.
-   * @see HRegionFileSystem#cleanupMergesDir()
-   */
-  public void createMergesDir() throws IOException {
-    Path mergesdir = getMergesDir();
-    if (fs.exists(mergesdir)) {
-      LOG.info("{} directory exists. Deleting it to recreate it anew", mergesdir);
-      if (!fs.delete(mergesdir, true)) {
-        throw new IOException("Failed deletion of " + mergesdir + " before recreate.");
-      }
-    }
-    if (!mkdirs(fs, conf, mergesdir)) {
-      throw new IOException("Failed create of " + mergesdir);
-    }
-  }
-
-  /**
-   * Write out a merge reference under the given merges directory. Package local so it doesnt leak
-   * out of regionserver.
-   * @param mergedRegion {@link RegionInfo} of the merged region
-   * @param familyName   Column Family Name
-   * @param f            File to create reference.
+   * Write out a merge reference under the given merges directory.
+   * @param mergingRegion {@link RegionInfo} for one of the regions being merged.
+   * @param familyName    Column Family Name
+   * @param f             File to create reference.
    * @return Path to created reference.
+   * @throws IOException if the merge write fails.
    */
-  public Path mergeStoreFile(RegionInfo mergedRegion, String familyName, HStoreFile f,
-    Path mergedDir) throws IOException {
-    Path referenceDir = new Path(new Path(mergedDir, mergedRegion.getEncodedName()), familyName);
+  public Path mergeStoreFile(RegionInfo mergingRegion, String familyName, HStoreFile f)
+    throws IOException {
+    Path referenceDir = new Path(getMergesDir(regionInfoForFs), familyName);
     // A whole reference to the store file.
-    Reference r = Reference.createTopReference(regionInfoForFs.getStartKey());
+    Reference r = Reference.createTopReference(mergingRegion.getStartKey());
     // Add the referred-to regions name as a dot separated suffix.
     // See REF_NAME_REGEX regex above. The referred-to regions name is
     // up in the path of the passed in <code>f</code> -- parentdir is family,
     // then the directory above is the region name.
-    String mergingRegionName = regionInfoForFs.getEncodedName();
+    String mergingRegionName = mergingRegion.getEncodedName();
     // Write reference with same file id only with the other region name as
     // suffix and into the new region location (under same family).
     Path p = new Path(referenceDir, f.getPath().getName() + "." + mergingRegionName);
@@ -846,40 +816,27 @@ public class HRegionFileSystem {
   }
 
   /**
-   * Commit a merged region, moving it from the merges temporary directory to the proper location in
-   * the filesystem.
-   * @param mergedRegionInfo merged region {@link RegionInfo}
+   * Commit a merged region, making it ready for use. n
    */
-  public void commitMergedRegion(final RegionInfo mergedRegionInfo) throws IOException {
-    Path regionDir = new Path(this.tableDir, mergedRegionInfo.getEncodedName());
-    Path mergedRegionTmpDir = this.getMergesDir(mergedRegionInfo);
-    // Move the tmp dir to the expected location
-    if (mergedRegionTmpDir != null && fs.exists(mergedRegionTmpDir)) {
-
+  public void commitMergedRegion(List<Path> allMergedFiles, MasterProcedureEnv env)
+    throws IOException {
+    Path regionDir = getMergesDir(regionInfoForFs);
+    if (regionDir != null && fs.exists(regionDir)) {
       // Write HRI to a file in case we need to recover hbase:meta
-      Path regionInfoFile = new Path(mergedRegionTmpDir, REGION_INFO_FILE);
+      Path regionInfoFile = new Path(regionDir, REGION_INFO_FILE);
       byte[] regionInfoContent = getRegionInfoFileContent(regionInfo);
       writeRegionInfoFileContent(conf, fs, regionInfoFile, regionInfoContent);
-
-      if (!fs.rename(mergedRegionTmpDir, regionDir)) {
-        throw new IOException("Unable to rename " + mergedRegionTmpDir + " to " + regionDir);
-      }
+      insertRegionFilesIntoStoreTracker(allMergedFiles, env, this);
     }
   }
 
   // ===========================================================================
   // Create/Open/Delete Helpers
   // ===========================================================================
-  /**
-   * Log the current state of the region
-   * @param LOG log to output information
-   * @throws IOException if an unexpected exception occurs
-   */
-  void logFileSystemState(final Logger LOG) throws IOException {
-    CommonFSUtils.logFileSystemState(fs, this.getRegionDir(), LOG);
-  }
 
-  /** Returns Content of the file we write out to the filesystem under a region */
+  /**
+   * n * @return Content of the file we write out to the filesystem under a region n
+   */
   private static byte[] getRegionInfoFileContent(final RegionInfo hri) throws IOException {
     return RegionInfo.toDelimitedByteArray(hri);
   }
@@ -1065,8 +1022,6 @@ public class HRegionFileSystem {
     if (!readOnly) {
       // Cleanup temporary directories
       regionFs.cleanupTempDir();
-      regionFs.cleanupSplitsDir();
-      regionFs.cleanupMergesDir();
 
       // If it doesn't exists, Write HRI to a file, in case we need to recover hbase:meta
       // Only create HRI if we are the default replica
@@ -1115,9 +1070,9 @@ public class HRegionFileSystem {
   }
 
   /**
-   * Creates a directory. Assumes the user has already checked for this directory existence.
-   * @return the result of fs.mkdirs(). In case underlying fs throws an IOException, it checks
-   *         whether the directory exists or not, and returns true if it exists.
+   * Creates a directory. Assumes the user has already checked for this directory existence. n
+   * * @return the result of fs.mkdirs(). In case underlying fs throws an IOException, it checks
+   * whether the directory exists or not, and returns true if it exists. n
    */
   boolean createDir(Path dir) throws IOException {
     int i = 0;
@@ -1139,8 +1094,8 @@ public class HRegionFileSystem {
   }
 
   /**
-   * Renames a directory. Assumes the user has already checked for this directory existence.
-   * @return true if rename is successful.
+   * Renames a directory. Assumes the user has already checked for this directory existence. nn
+   * * @return true if rename is successful. n
    */
   boolean rename(Path srcpath, Path dstPath) throws IOException {
     IOException lastIOE = null;
@@ -1164,8 +1119,8 @@ public class HRegionFileSystem {
   }
 
   /**
-   * Deletes a directory. Assumes the user has already checked for this directory existence.
-   * @return true if the directory is deleted.
+   * Deletes a directory. Assumes the user has already checked for this directory existence. n
+   * * @return true if the directory is deleted. n
    */
   boolean deleteDir(Path dir) throws IOException {
     IOException lastIOE = null;
@@ -1197,9 +1152,9 @@ public class HRegionFileSystem {
 
   /**
    * Creates a directory for a filesystem and configuration object. Assumes the user has already
-   * checked for this directory existence.
-   * @return the result of fs.mkdirs(). In case underlying fs throws an IOException, it checks
-   *         whether the directory exists or not, and returns true if it exists.
+   * checked for this directory existence. nnn * @return the result of fs.mkdirs(). In case
+   * underlying fs throws an IOException, it checks whether the directory exists or not, and returns
+   * true if it exists. n
    */
   private static boolean createDirOnFileSystem(FileSystem fs, Configuration conf, Path dir)
     throws IOException {
