@@ -17,6 +17,8 @@
  */
 package org.apache.hadoop.hbase.regionserver;
 
+import io.opentelemetry.api.trace.Span;
+import io.opentelemetry.context.Scope;
 import java.io.IOException;
 import java.lang.Thread.UncaughtExceptionHandler;
 import java.util.ArrayList;
@@ -47,7 +49,6 @@ import org.apache.hadoop.hbase.util.ServerRegionReplicaUtil;
 import org.apache.hadoop.hbase.util.Threads;
 import org.apache.hadoop.ipc.RemoteException;
 import org.apache.hadoop.util.StringUtils.TraditionalBinaryPrefix;
-import org.apache.htrace.core.TraceScope;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -61,14 +62,14 @@ import org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFacto
  * @see FlushRequester
  */
 @InterfaceAudience.Private
-class MemStoreFlusher implements FlushRequester {
+public class MemStoreFlusher implements FlushRequester {
   private static final Logger LOG = LoggerFactory.getLogger(MemStoreFlusher.class);
 
   private Configuration conf;
   // These two data members go together. Any entry in the one must have
   // a corresponding entry in the other.
   private final BlockingQueue<FlushQueueEntry> flushQueue = new DelayQueue<>();
-  private final Map<Region, FlushRegionEntry> regionsInQueue = new HashMap<>();
+  protected final Map<Region, FlushRegionEntry> regionsInQueue = new HashMap<>();
   private AtomicBoolean wakeupPending = new AtomicBoolean();
 
   private final long threadWakeFrequency;
@@ -108,7 +109,8 @@ class MemStoreFlusher implements FlushRequester {
   };
 
   /**
-   *   */
+   * nn
+   */
   public MemStoreFlusher(final Configuration conf, final HRegionServer server) {
     super();
     this.conf = conf;
@@ -116,19 +118,22 @@ class MemStoreFlusher implements FlushRequester {
     this.threadWakeFrequency = conf.getLong(HConstants.THREAD_WAKE_FREQUENCY, 10 * 1000);
     this.blockingWaitTime = conf.getInt("hbase.hstore.blockingWaitTime", 90000);
     int handlerCount = conf.getInt("hbase.hstore.flusher.count", 2);
-    if (handlerCount < 1) {
-      LOG.warn("hbase.hstore.flusher.count was configed to {} which is less than 1, corrected to 1",
-        handlerCount);
-      handlerCount = 1;
+    if (server != null) {
+      if (handlerCount < 1) {
+        LOG.warn(
+          "hbase.hstore.flusher.count was configed to {} which is less than 1, " + "corrected to 1",
+          handlerCount);
+        handlerCount = 1;
+      }
+      LOG.info("globalMemStoreLimit="
+        + TraditionalBinaryPrefix
+          .long2String(this.server.getRegionServerAccounting().getGlobalMemStoreLimit(), "", 1)
+        + ", globalMemStoreLimitLowMark="
+        + TraditionalBinaryPrefix.long2String(
+          this.server.getRegionServerAccounting().getGlobalMemStoreLimitLowMark(), "", 1)
+        + ", Offheap=" + (this.server.getRegionServerAccounting().isOffheap()));
     }
     this.flushHandlers = new FlushHandler[handlerCount];
-    LOG.info("globalMemStoreLimit="
-      + TraditionalBinaryPrefix
-        .long2String(this.server.getRegionServerAccounting().getGlobalMemStoreLimit(), "", 1)
-      + ", globalMemStoreLimitLowMark="
-      + TraditionalBinaryPrefix
-        .long2String(this.server.getRegionServerAccounting().getGlobalMemStoreLimitLowMark(), "", 1)
-      + ", Offheap=" + (this.server.getRegionServerAccounting().isOffheap()));
   }
 
   public LongAdder getUpdatesBlockedMsHighWater() {
@@ -438,18 +443,28 @@ class MemStoreFlusher implements FlushRequester {
   @Override
   public boolean requestFlush(HRegion r, List<byte[]> families, FlushLifeCycleTracker tracker) {
     synchronized (regionsInQueue) {
-      if (!regionsInQueue.containsKey(r)) {
-        // This entry has no delay so it will be added at the top of the flush
-        // queue. It'll come out near immediately.
-        FlushRegionEntry fqe = new FlushRegionEntry(r, families, tracker);
-        this.regionsInQueue.put(r, fqe);
-        this.flushQueue.add(fqe);
-        r.incrementFlushesQueuedCount();
-        return true;
-      } else {
-        tracker.notExecuted("Flush already requested on " + r);
-        return false;
+      FlushRegionEntry existFqe = regionsInQueue.get(r);
+      if (existFqe != null) {
+        // if a delayed one exists and not reach the time to execute, just remove it
+        if (existFqe.isDelay() && existFqe.whenToExpire > EnvironmentEdgeManager.currentTime()) {
+          LOG.info("Remove the existing delayed flush entry for {}, "
+            + "because we need to flush it immediately", r);
+          this.regionsInQueue.remove(r);
+          this.flushQueue.remove(existFqe);
+          r.decrementFlushesQueuedCount();
+        } else {
+          tracker.notExecuted("Flush already requested on " + r);
+          return false;
+        }
       }
+
+      // This entry has no delay so it will be added at the top of the flush
+      // queue. It'll come out near immediately.
+      FlushRegionEntry fqe = new FlushRegionEntry(r, families, tracker);
+      this.regionsInQueue.put(r, fqe);
+      this.flushQueue.add(fqe);
+      r.incrementFlushesQueuedCount();
+      return true;
     }
   }
 
@@ -517,9 +532,8 @@ class MemStoreFlusher implements FlushRequester {
 
   /**
    * A flushRegion that checks store file count. If too many, puts the flush on delay queue to retry
-   * later.
-   * @return true if the region was successfully flushed, false otherwise. If false, there will be
-   *         accompanying log messages explaining why the region was not flushed.
+   * later. n * @return true if the region was successfully flushed, false otherwise. If false,
+   * there will be accompanying log messages explaining why the region was not flushed.
    */
   private boolean flushRegion(final FlushRegionEntry fqe) {
     HRegion region = fqe.region;
@@ -536,10 +550,10 @@ class MemStoreFlusher implements FlushRequester {
           LOG.warn("{} has too many store files({}); delaying flush up to {} ms",
             region.getRegionInfo().getEncodedName(), getStoreFileCount(region),
             this.blockingWaitTime);
-          if (!this.server.compactSplitThread.requestSplit(region)) {
+          final CompactSplit compactSplitThread = server.getCompactSplitThread();
+          if (!compactSplitThread.requestSplit(region)) {
             try {
-              this.server.compactSplitThread.requestSystemCompaction(region,
-                Thread.currentThread().getName());
+              compactSplitThread.requestSystemCompaction(region, Thread.currentThread().getName());
             } catch (IOException e) {
               e = e instanceof RemoteException ? ((RemoteException) e).unwrapRemoteException() : e;
               LOG.error("Cache flush failed for region "
@@ -583,6 +597,7 @@ class MemStoreFlusher implements FlushRequester {
 
     tracker.beforeExecution();
     lock.readLock().lock();
+    final CompactSplit compactSplitThread = server.getCompactSplitThread();
     try {
       notifyFlushRequest(region, emergencyFlush);
       FlushResult flushResult = region.flushcache(families, false, tracker);
@@ -590,9 +605,9 @@ class MemStoreFlusher implements FlushRequester {
       // We just want to check the size
       boolean shouldSplit = region.checkSplit().isPresent();
       if (shouldSplit) {
-        this.server.compactSplitThread.requestSplit(region);
+        compactSplitThread.requestSplit(region);
       } else if (shouldCompact) {
-        server.compactSplitThread.requestSystemCompaction(region, Thread.currentThread().getName());
+        compactSplitThread.requestSystemCompaction(region, Thread.currentThread().getName());
       }
     } catch (DroppedSnapshotException ex) {
       // Cache flush can fail in a few places. If it fails in a critical
@@ -666,10 +681,12 @@ class MemStoreFlusher implements FlushRequester {
    * callers until we're down to a safe amount of memstore consumption.
    */
   public void reclaimMemStoreMemory() {
-    try (TraceScope scope = TraceUtil.createTrace("MemStoreFluser.reclaimMemStoreMemory")) {
+    Span span =
+      TraceUtil.getGlobalTracer().spanBuilder("MemStoreFluser.reclaimMemStoreMemory").startSpan();
+    try (Scope scope = span.makeCurrent()) {
       FlushType flushType = isAboveHighWaterMark();
       if (flushType != FlushType.NORMAL) {
-        TraceUtil.addTimelineAnnotation("Force Flush. We're above high water mark.");
+        span.addEvent("Force Flush. We're above high water mark.");
         long start = EnvironmentEdgeManager.currentTime();
         long nextLogTimeMs = start;
         synchronized (this.blockSignal) {
@@ -738,6 +755,7 @@ class MemStoreFlusher implements FlushRequester {
         if (flushType != FlushType.NORMAL) {
           wakeupFlushThread();
         }
+        span.end();
       }
     }
   }
@@ -768,7 +786,7 @@ class MemStoreFlusher implements FlushRequester {
   }
 
   /**
-   * Register a MemstoreFlushListener
+   * Register a MemstoreFlushListener n
    */
   @Override
   public void registerFlushRequestListener(final FlushRequestListener listener) {
@@ -776,8 +794,8 @@ class MemStoreFlusher implements FlushRequester {
   }
 
   /**
-   * Unregister the listener from MemstoreFlushListeners
-   * @return true when passed listener is unregistered successfully.
+   * Unregister the listener from MemstoreFlushListeners n * @return true when passed listener is
+   * unregistered successfully.
    */
   @Override
   public boolean unregisterFlushRequestListener(final FlushRequestListener listener) {
@@ -785,7 +803,7 @@ class MemStoreFlusher implements FlushRequester {
   }
 
   /**
-   * Sets the global memstore limit to a new size.
+   * Sets the global memstore limit to a new size. n
    */
   @Override
   public void setGlobalMemStoreLimit(long globalMemStoreSize) {
@@ -821,11 +839,18 @@ class MemStoreFlusher implements FlushRequester {
       this.tracker = tracker;
     }
 
-    /** Returns True if we have been delayed > <code>maximumWait</code> milliseconds. */
+    /**
+     * n * @return True if we have been delayed > <code>maximumWait</code> milliseconds.
+     */
     public boolean isMaximumWait(final long maximumWait) {
       return (EnvironmentEdgeManager.currentTime() - this.createTime) > maximumWait;
     }
 
+    /** Returns True if the entry is a delay flush task */
+    protected boolean isDelay() {
+      return this.whenToExpire > this.createTime;
+    }
+
     /**
      * @return Count of times {@link #requeue(long)} was called; i.e this is number of times we've
      *         been requeued.
