@@ -20,6 +20,7 @@ package org.apache.hadoop.hbase.regionserver;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.OptionalDouble;
@@ -27,6 +28,7 @@ import java.util.OptionalLong;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
+import java.util.stream.Collectors;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.hbase.CompatibilitySingletonFactory;
 import org.apache.hadoop.hbase.HConstants;
@@ -35,6 +37,7 @@ import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.io.ByteBuffAllocator;
 import org.apache.hadoop.hbase.io.FSDataInputStreamWrapper;
+import org.apache.hadoop.hbase.io.asyncfs.monitor.ExcludeDatanodeManager;
 import org.apache.hadoop.hbase.io.hfile.BlockCache;
 import org.apache.hadoop.hbase.io.hfile.CacheStats;
 import org.apache.hadoop.hbase.io.hfile.CombinedBlockCache;
@@ -75,6 +78,8 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
   private volatile long walFileSize = 0;
   private volatile long numStoreFiles = 0;
   private volatile long memstoreSize = 0;
+  private volatile long onHeapMemstoreSize = 0;
+  private volatile long offHeapMemstoreSize = 0;
   private volatile long storeFileSize = 0;
   private volatile long maxStoreFileCount = 0;
   private volatile long maxStoreFileAge = 0;
@@ -92,6 +97,9 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
   private volatile long storefileIndexSize = 0;
   private volatile long totalStaticIndexSize = 0;
   private volatile long totalStaticBloomSize = 0;
+  private volatile long bloomFilterRequestsCount = 0;
+  private volatile long bloomFilterNegativeResultsCount = 0;
+  private volatile long bloomFilterEligibleRequestsCount = 0;
   private volatile long numMutationsWithoutWAL = 0;
   private volatile long dataInMemoryWithoutWAL = 0;
   private volatile double percentFileLocal = 0;
@@ -130,10 +138,13 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
    */
   private DFSHedgedReadMetrics dfsHedgedReadMetrics;
 
+  private final ExcludeDatanodeManager excludeDatanodeManager;
+
   public MetricsRegionServerWrapperImpl(final HRegionServer regionServer) {
     this.regionServer = regionServer;
     initBlockCache();
     initMobFileCache();
+    this.excludeDatanodeManager = this.regionServer.getWalFactory().getExcludeDatanodeManager();
 
     this.period = regionServer.getConfiguration().getLong(HConstants.REGIONSERVER_METRICS_PERIOD,
       HConstants.DEFAULT_REGIONSERVER_METRICS_PERIOD);
@@ -241,37 +252,26 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
 
   @Override
   public int getSplitQueueSize() {
-    if (this.regionServer.compactSplitThread == null) {
-      return 0;
-    }
-    return this.regionServer.compactSplitThread.getSplitQueueSize();
+    final CompactSplit compactSplit = regionServer.getCompactSplitThread();
+    return compactSplit == null ? 0 : compactSplit.getSplitQueueSize();
   }
 
   @Override
   public int getCompactionQueueSize() {
-    // The thread could be zero. if so assume there is no queue.
-    if (this.regionServer.compactSplitThread == null) {
-      return 0;
-    }
-    return this.regionServer.compactSplitThread.getCompactionQueueSize();
+    final CompactSplit compactSplit = regionServer.getCompactSplitThread();
+    return compactSplit == null ? 0 : compactSplit.getCompactionQueueSize();
   }
 
   @Override
   public int getSmallCompactionQueueSize() {
-    // The thread could be zero. if so assume there is no queue.
-    if (this.regionServer.compactSplitThread == null) {
-      return 0;
-    }
-    return this.regionServer.compactSplitThread.getSmallCompactionQueueSize();
+    final CompactSplit compactSplit = regionServer.getCompactSplitThread();
+    return compactSplit == null ? 0 : compactSplit.getSmallCompactionQueueSize();
   }
 
   @Override
   public int getLargeCompactionQueueSize() {
-    // The thread could be zero. if so assume there is no queue.
-    if (this.regionServer.compactSplitThread == null) {
-      return 0;
-    }
-    return this.regionServer.compactSplitThread.getLargeCompactionQueueSize();
+    final CompactSplit compactSplit = regionServer.getCompactSplitThread();
+    return compactSplit == null ? 0 : compactSplit.getLargeCompactionQueueSize();
   }
 
   @Override
@@ -298,6 +298,16 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
     return this.regionServer.getRegionServerAccounting().getGlobalMemStoreLimit();
   }
 
+  @Override
+  public long getOnHeapMemStoreLimit() {
+    return this.regionServer.getRegionServerAccounting().getGlobalOnHeapMemStoreLimit();
+  }
+
+  @Override
+  public long getOffHeapMemStoreLimit() {
+    return this.regionServer.getRegionServerAccounting().getGlobalOffHeapMemStoreLimit();
+  }
+
   @Override
   public long getBlockCacheSize() {
     return this.blockCache != null ? this.blockCache.getCurrentSize() : 0L;
@@ -318,11 +328,6 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
     return this.cacheStats != null ? this.cacheStats.getPrimaryHitCount() : 0L;
   }
 
-  @Override
-  public long getBlockCacheHitCachingCount() {
-    return this.cacheStats != null ? this.cacheStats.getHitCachingCount() : 0L;
-  }
-
   @Override
   public long getBlockCacheMissCount() {
     return this.cacheStats != null ? this.cacheStats.getMissCount() : 0L;
@@ -333,11 +338,6 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
     return this.cacheStats != null ? this.cacheStats.getPrimaryMissCount() : 0L;
   }
 
-  @Override
-  public long getBlockCacheMissCachingCount() {
-    return this.cacheStats != null ? this.cacheStats.getMissCachingCount() : 0L;
-  }
-
   @Override
   public long getBlockCacheEvictedCount() {
     return this.cacheStats != null ? this.cacheStats.getEvictedCount() : 0L;
@@ -463,6 +463,15 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
     return walFileSize;
   }
 
+  @Override
+  public List<String> getWALExcludeDNs() {
+    if (excludeDatanodeManager == null) {
+      return Collections.emptyList();
+    }
+    return excludeDatanodeManager.getExcludeDNs().entrySet().stream()
+      .map(e -> e.getKey().toString() + ", " + e.getValue()).collect(Collectors.toList());
+  }
+
   @Override
   public long getNumWALSlowAppend() {
     return metricsWALSource.getSlowAppendCount();
@@ -503,6 +512,16 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
     return memstoreSize;
   }
 
+  @Override
+  public long getOnHeapMemStoreSize() {
+    return onHeapMemstoreSize;
+  }
+
+  @Override
+  public long getOffHeapMemStoreSize() {
+    return offHeapMemstoreSize;
+  }
+
   @Override
   public long getStoreFileSize() {
     return storeFileSize;
@@ -588,6 +607,21 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
     return totalStaticBloomSize;
   }
 
+  @Override
+  public long getBloomFilterRequestsCount() {
+    return bloomFilterRequestsCount;
+  }
+
+  @Override
+  public long getBloomFilterNegativeResultsCount() {
+    return bloomFilterNegativeResultsCount;
+  }
+
+  @Override
+  public long getBloomFilterEligibleRequestsCount() {
+    return bloomFilterEligibleRequestsCount;
+  }
+
   @Override
   public long getNumMutationsWithoutWAL() {
     return numMutationsWithoutWAL;
@@ -716,6 +750,11 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
     return mobFileCacheHitRatio * 100;
   }
 
+  @Override
+  public int getActiveScanners() {
+    return regionServer.getRSRpcServices().getScannersCount();
+  }
+
   /**
    * This is the runnable that will be executed on the executor every PERIOD number of seconds It
    * will take metrics/numbers from all of the regions and use them to compute point in time
@@ -732,7 +771,8 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
         HDFSBlocksDistribution hdfsBlocksDistributionSecondaryRegions =
           new HDFSBlocksDistribution();
 
-        long tempNumStores = 0, tempNumStoreFiles = 0, tempMemstoreSize = 0, tempStoreFileSize = 0;
+        long tempNumStores = 0, tempNumStoreFiles = 0, tempStoreFileSize = 0;
+        long tempMemstoreSize = 0, tempOnHeapMemstoreSize = 0, tempOffHeapMemstoreSize = 0;
         long tempMaxStoreFileAge = 0, tempNumReferenceFiles = 0;
         long tempMaxStoreFileCount = 0;
         long avgAgeNumerator = 0, numHFiles = 0;
@@ -744,6 +784,9 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
         long tempStorefileIndexSize = 0;
         long tempTotalStaticIndexSize = 0;
         long tempTotalStaticBloomSize = 0;
+        long tempBloomFilterRequestsCount = 0;
+        long tempBloomFilterNegativeResultsCount = 0;
+        long tempBloomFilterEligibleRequestsCount = 0;
         long tempNumMutationsWithoutWAL = 0;
         long tempDataInMemoryWithoutWAL = 0;
         double tempPercentFileLocal = 0;
@@ -812,6 +855,8 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
           for (Store store : storeList) {
             tempNumStoreFiles += store.getStorefilesCount();
             tempMemstoreSize += store.getMemStoreSize().getDataSize();
+            tempOnHeapMemstoreSize += store.getMemStoreSize().getHeapSize();
+            tempOffHeapMemstoreSize += store.getMemStoreSize().getOffHeapSize();
             tempStoreFileSize += store.getStorefilesSize();
 
             tempMaxStoreFileCount = Math.max(tempMaxStoreFileCount, store.getStorefilesCount());
@@ -845,6 +890,9 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
             tempStorefileIndexSize += store.getStorefilesRootLevelIndexSize();
             tempTotalStaticBloomSize += store.getTotalStaticBloomSize();
             tempTotalStaticIndexSize += store.getTotalStaticIndexSize();
+            tempBloomFilterRequestsCount += store.getBloomFilterRequestsCount();
+            tempBloomFilterNegativeResultsCount += store.getBloomFilterNegativeResultsCount();
+            tempBloomFilterEligibleRequestsCount += store.getBloomFilterEligibleRequestsCount();
             tempFlushedCellsCount += store.getFlushedCellsCount();
             tempCompactedCellsCount += store.getCompactedCellsCount();
             tempMajorCompactedCellsCount += store.getMajorCompactedCellsCount();
@@ -912,6 +960,8 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
         numStores = tempNumStores;
         numStoreFiles = tempNumStoreFiles;
         memstoreSize = tempMemstoreSize;
+        onHeapMemstoreSize = tempOnHeapMemstoreSize;
+        offHeapMemstoreSize = tempOffHeapMemstoreSize;
         storeFileSize = tempStoreFileSize;
         maxStoreFileCount = tempMaxStoreFileCount;
         maxStoreFileAge = tempMaxStoreFileAge;
@@ -935,6 +985,9 @@ class MetricsRegionServerWrapperImpl implements MetricsRegionServerWrapper {
         storefileIndexSize = tempStorefileIndexSize;
         totalStaticIndexSize = tempTotalStaticIndexSize;
         totalStaticBloomSize = tempTotalStaticBloomSize;
+        bloomFilterRequestsCount = tempBloomFilterRequestsCount;
+        bloomFilterNegativeResultsCount = tempBloomFilterNegativeResultsCount;
+        bloomFilterEligibleRequestsCount = tempBloomFilterEligibleRequestsCount;
         numMutationsWithoutWAL = tempNumMutationsWithoutWAL;
         dataInMemoryWithoutWAL = tempDataInMemoryWithoutWAL;
         percentFileLocal = tempPercentFileLocal;
