@@ -55,7 +55,7 @@ public class ScannerContext {
   /**
    * A different set of progress fields. Only include batch, dataSize and heapSize. Compare to
    * LimitFields, ProgressFields doesn't contain time field. As we save a deadline in LimitFields,
-   * so use {@link System#currentTimeMillis()} directly when check time limit.
+   * so use {@link EnvironmentEdgeManager.currentTime()} directly when check time limit.
    */
   ProgressFields progress;
 
@@ -177,7 +177,7 @@ public class ScannerContext {
   }
 
   /**
-   * Update the time progress with {@link System#currentTimeMillis()}
+   * Update the time progress.
    * @deprecated will be removed in 3.0
    */
   @Deprecated
@@ -201,7 +201,7 @@ public class ScannerContext {
    */
   @Deprecated
   long getTimeProgress() {
-    return System.currentTimeMillis();
+    return EnvironmentEdgeManager.currentTime();
   }
 
   /**
@@ -245,8 +245,8 @@ public class ScannerContext {
    * Note that this is not a typical setter. This setter returns the {@link NextState} that was
    * passed in so that methods can be invoked against the new state. Furthermore, this pattern
    * allows the {@link NoLimitScannerContext} to cleanly override this setter and simply return the
-   * new state, thus preserving the immutability of {@link NoLimitScannerContext}
-   * @return The state that was passed in.
+   * new state, thus preserving the immutability of {@link NoLimitScannerContext} n * @return The
+   * state that was passed in.
    */
   NextState setScannerState(NextState state) {
     if (!NextState.isValidState(state)) {
@@ -267,24 +267,32 @@ public class ScannerContext {
       || scannerState == NextState.BATCH_LIMIT_REACHED;
   }
 
-  /** Returns true if the batch limit can be enforced in the checker's scope */
+  /**
+   * n * @return true if the batch limit can be enforced in the checker's scope
+   */
   boolean hasBatchLimit(LimitScope checkerScope) {
     return limits.canEnforceBatchLimitFromScope(checkerScope) && limits.getBatch() > 0;
   }
 
-  /** Returns true if the size limit can be enforced in the checker's scope */
+  /**
+   * n * @return true if the size limit can be enforced in the checker's scope
+   */
   boolean hasSizeLimit(LimitScope checkerScope) {
     return limits.canEnforceSizeLimitFromScope(checkerScope)
       && (limits.getDataSize() > 0 || limits.getHeapSize() > 0);
   }
 
-  /** Returns true if the time limit can be enforced in the checker's scope */
+  /**
+   * n * @return true if the time limit can be enforced in the checker's scope
+   */
   boolean hasTimeLimit(LimitScope checkerScope) {
     return limits.canEnforceTimeLimitFromScope(checkerScope)
       && (limits.getTime() > 0 || returnImmediately);
   }
 
-  /** Returns true if any limit can be enforced within the checker's scope */
+  /**
+   * n * @return true if any limit can be enforced within the checker's scope
+   */
   boolean hasAnyLimit(LimitScope checkerScope) {
     return hasBatchLimit(checkerScope) || hasSizeLimit(checkerScope) || hasTimeLimit(checkerScope);
   }
@@ -334,7 +342,7 @@ public class ScannerContext {
 
   /**
    * @param checkerScope The scope that the limit is being checked from. The time limit is always
-   *                     checked against {@link System#currentTimeMillis()}
+   *                     checked against {@link EnvironmentEdgeManager.currentTime}
    * @return true when the limit is enforceable from the checker's scope and it has been reached
    */
   boolean checkTimeLimit(LimitScope checkerScope) {
@@ -601,7 +609,9 @@ public class ScannerContext {
       this.batch = batch;
     }
 
-    /** Returns true when the limit can be enforced from the scope of the checker */
+    /**
+     * n * @return true when the limit can be enforced from the scope of the checker
+     */
     boolean canEnforceBatchLimitFromScope(LimitScope checkerScope) {
       return LimitScope.BETWEEN_CELLS.canEnforceLimitFromScope(checkerScope);
     }
@@ -634,7 +644,9 @@ public class ScannerContext {
       this.sizeScope = scope;
     }
 
-    /** Returns true when the limit can be enforced from the scope of the checker */
+    /**
+     * n * @return true when the limit can be enforced from the scope of the checker
+     */
     boolean canEnforceSizeLimitFromScope(LimitScope checkerScope) {
       return this.sizeScope.canEnforceLimitFromScope(checkerScope);
     }
@@ -659,7 +671,9 @@ public class ScannerContext {
       this.timeScope = scope;
     }
 
-    /** Returns true when the limit can be enforced from the scope of the checker */
+    /**
+     * n * @return true when the limit can be enforced from the scope of the checker
+     */
     boolean canEnforceTimeLimitFromScope(LimitScope checkerScope) {
       return this.timeScope.canEnforceLimitFromScope(checkerScope);
     }
