@@ -1,5 +1,4 @@
-/**
- *
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -16,7 +15,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.hadoop.hbase.regionserver;
 
 import java.io.FileNotFoundException;
@@ -24,7 +22,7 @@ import java.io.IOException;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-
+import org.apache.hadoop.conf.Configurable;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
@@ -39,8 +37,8 @@ import org.apache.hadoop.hbase.io.hfile.HFileInfo;
 import org.apache.hadoop.hbase.io.hfile.ReaderContext;
 import org.apache.hadoop.hbase.io.hfile.ReaderContext.ReaderType;
 import org.apache.hadoop.hbase.io.hfile.ReaderContextBuilder;
+import org.apache.hadoop.hbase.mob.MobUtils;
 import org.apache.hadoop.hbase.util.FSUtils;
-import org.apache.hadoop.hbase.util.Pair;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -49,46 +47,35 @@ import org.slf4j.LoggerFactory;
  * Describe a StoreFile (hfile, reference, link)
  */
 @InterfaceAudience.Private
-public class StoreFileInfo {
+public class StoreFileInfo implements Configurable {
   private static final Logger LOG = LoggerFactory.getLogger(StoreFileInfo.class);
 
   /**
-   * A non-capture group, for hfiles, so that this can be embedded.
-   * HFiles are uuid ([0-9a-z]+). Bulk loaded hfiles has (_SeqId_[0-9]+_) has suffix.
-   * The mob del file has (_del) as suffix.
+   * A non-capture group, for hfiles, so that this can be embedded. HFiles are uuid ([0-9a-z]+).
+   * Bulk loaded hfiles has (_SeqId_[0-9]+_) has suffix. The mob del file has (_del) as suffix.
    */
   public static final String HFILE_NAME_REGEX = "[0-9a-f]+(?:(?:_SeqId_[0-9]+_)|(?:_del))?";
 
   /** Regex that will work for hfiles */
-  private static final Pattern HFILE_NAME_PATTERN =
-    Pattern.compile("^(" + HFILE_NAME_REGEX + ")");
+  private static final Pattern HFILE_NAME_PATTERN = Pattern.compile("^(" + HFILE_NAME_REGEX + ")");
 
   /**
-   * A non-capture group, for del files, so that this can be embedded.
-   * A del file has (_del) as suffix.
-   */
-  public static final String DELFILE_NAME_REGEX = "[0-9a-f]+(?:_del)";
-
-  /** Regex that will work for del files */
-  private static final Pattern DELFILE_NAME_PATTERN =
-    Pattern.compile("^(" + DELFILE_NAME_REGEX + ")");
-
-  /**
-   * Regex that will work for straight reference names ({@code <hfile>.<parentEncRegion>})
-   * and hfilelink reference names ({@code <table>=<region>-<hfile>.<parentEncRegion>})
-   * If reference, then the regex has more than just one group.
-   * Group 1, hfile/hfilelink pattern, is this file's id.
-   * Group 2 '(.+)' is the reference's parent region name.
+   * Regex that will work for straight reference names ({@code <hfile>.<parentEncRegion>}) and
+   * hfilelink reference names ({@code
+   *
+  <table>
+   * =<region>-<hfile>.<parentEncRegion>}) If reference, then the regex has more than just one
+   * group. Group 1, hfile/hfilelink pattern, is this file's id. Group 2 '(.+)' is the reference's
+   * parent region name.
    */
   private static final Pattern REF_NAME_PATTERN =
-    Pattern.compile(String.format("^(%s|%s)\\.(.+)$",
-      HFILE_NAME_REGEX, HFileLink.LINK_NAME_REGEX));
+    Pattern.compile(String.format("^(%s|%s)\\.(.+)$", HFILE_NAME_REGEX, HFileLink.LINK_NAME_REGEX));
 
   public static final String STORE_FILE_READER_NO_READAHEAD = "hbase.store.reader.no-readahead";
   public static final boolean DEFAULT_STORE_FILE_READER_NO_READAHEAD = false;
 
   // Configuration
-  private final Configuration conf;
+  private Configuration conf;
 
   // FileSystem handle
   private final FileSystem fs;
@@ -124,28 +111,28 @@ public class StoreFileInfo {
 
   /**
    * Create a Store File Info
-   * @param conf the {@link Configuration} to use
-   * @param fs The current file system to use.
-   * @param initialPath The {@link Path} of the file
+   * @param conf           the {@link Configuration} to use
+   * @param fs             The current file system to use.
+   * @param initialPath    The {@link Path} of the file
    * @param primaryReplica true if this is a store file for primary replica, otherwise false.
    */
   public StoreFileInfo(final Configuration conf, final FileSystem fs, final Path initialPath,
-      final boolean primaryReplica) throws IOException {
+    final boolean primaryReplica) throws IOException {
     this(conf, fs, null, initialPath, primaryReplica);
   }
 
   private StoreFileInfo(final Configuration conf, final FileSystem fs, final FileStatus fileStatus,
-      final Path initialPath, final boolean primaryReplica) throws IOException {
+    final Path initialPath, final boolean primaryReplica) throws IOException {
     assert fs != null;
     assert initialPath != null;
     assert conf != null;
 
     this.fs = fs;
     this.conf = conf;
-    this.initialPath = initialPath;
+    this.initialPath = fs.makeQualified(initialPath);
     this.primaryReplica = primaryReplica;
-    this.noReadahead = this.conf.getBoolean(STORE_FILE_READER_NO_READAHEAD,
-        DEFAULT_STORE_FILE_READER_NO_READAHEAD);
+    this.noReadahead =
+      this.conf.getBoolean(STORE_FILE_READER_NO_READAHEAD, DEFAULT_STORE_FILE_READER_NO_READAHEAD);
     Path p = initialPath;
     if (HFileLink.isHFileLink(p)) {
       // HFileLink
@@ -163,7 +150,7 @@ public class StoreFileInfo {
         this.link = null;
       }
       LOG.trace("{} is a {} reference to {}", p, reference.getFileRegion(), referencePath);
-    } else if (isHFile(p)) {
+    } else if (isHFile(p) || isMobFile(p) || isMobRefFile(p)) {
       // HFile
       if (fileStatus != null) {
         this.createdTimestamp = fileStatus.getModificationTime();
@@ -182,105 +169,112 @@ public class StoreFileInfo {
 
   /**
    * Create a Store File Info
-   * @param conf the {@link Configuration} to use
-   * @param fs The current file system to use.
+   * @param conf       the {@link Configuration} to use
+   * @param fs         The current file system to use.
    * @param fileStatus The {@link FileStatus} of the file
    */
   public StoreFileInfo(final Configuration conf, final FileSystem fs, final FileStatus fileStatus)
-      throws IOException {
+    throws IOException {
     this(conf, fs, fileStatus, fileStatus.getPath(), true);
   }
 
   /**
    * Create a Store File Info from an HFileLink
-   * @param conf The {@link Configuration} to use
-   * @param fs The current file system to use
+   * @param conf       The {@link Configuration} to use
+   * @param fs         The current file system to use
    * @param fileStatus The {@link FileStatus} of the file
    */
   public StoreFileInfo(final Configuration conf, final FileSystem fs, final FileStatus fileStatus,
-      final HFileLink link) {
+    final HFileLink link) {
     this(conf, fs, fileStatus, null, link);
   }
 
   /**
    * Create a Store File Info from an HFileLink
-   * @param conf The {@link Configuration} to use
-   * @param fs The current file system to use
+   * @param conf       The {@link Configuration} to use
+   * @param fs         The current file system to use
    * @param fileStatus The {@link FileStatus} of the file
-   * @param reference The reference instance
+   * @param reference  The reference instance
    */
   public StoreFileInfo(final Configuration conf, final FileSystem fs, final FileStatus fileStatus,
-      final Reference reference) {
+    final Reference reference) {
     this(conf, fs, fileStatus, reference, null);
   }
 
   /**
    * Create a Store File Info from an HFileLink and a Reference
-   * @param conf The {@link Configuration} to use
-   * @param fs The current file system to use
+   * @param conf       The {@link Configuration} to use
+   * @param fs         The current file system to use
    * @param fileStatus The {@link FileStatus} of the file
-   * @param reference The reference instance
-   * @param link The link instance
+   * @param reference  The reference instance
+   * @param link       The link instance
    */
   public StoreFileInfo(final Configuration conf, final FileSystem fs, final FileStatus fileStatus,
-      final Reference reference, final HFileLink link) {
+    final Reference reference, final HFileLink link) {
     this.fs = fs;
     this.conf = conf;
     this.primaryReplica = false;
     this.initialPath = (fileStatus == null) ? null : fileStatus.getPath();
-    this.createdTimestamp = (fileStatus == null) ? 0 :fileStatus.getModificationTime();
+    this.createdTimestamp = (fileStatus == null) ? 0 : fileStatus.getModificationTime();
     this.reference = reference;
     this.link = link;
-    this.noReadahead = this.conf.getBoolean(STORE_FILE_READER_NO_READAHEAD,
-        DEFAULT_STORE_FILE_READER_NO_READAHEAD);
+    this.noReadahead =
+      this.conf.getBoolean(STORE_FILE_READER_NO_READAHEAD, DEFAULT_STORE_FILE_READER_NO_READAHEAD);
+  }
+
+  @Override
+  public Configuration getConf() {
+    return conf;
+  }
+
+  @Override
+  public void setConf(Configuration conf) {
+    this.conf = conf;
   }
 
   /**
-   * Size of the Hfile
-   * @return size
+   * Size of the Hfile n
    */
   public long getSize() {
     return size;
   }
 
   /**
-   * Sets the region coprocessor env.
-   * @param coprocessorHost
+   * Sets the region coprocessor env. n
    */
   public void setRegionCoprocessorHost(RegionCoprocessorHost coprocessorHost) {
     this.coprocessorHost = coprocessorHost;
   }
 
   /*
-   * @return the Reference object associated to this StoreFileInfo.
-   *         null if the StoreFile is not a reference.
+   * @return the Reference object associated to this StoreFileInfo. null if the StoreFile is not a
+   * reference.
    */
   public Reference getReference() {
     return this.reference;
   }
 
-  /** @return True if the store file is a Reference */
+  /** Returns True if the store file is a Reference */
   public boolean isReference() {
     return this.reference != null;
   }
 
-  /** @return True if the store file is a top Reference */
+  /** Returns True if the store file is a top Reference */
   public boolean isTopReference() {
     return this.reference != null && Reference.isTopFileRegion(this.reference.getFileRegion());
   }
 
-  /** @return True if the store file is a link */
+  /** Returns True if the store file is a link */
   public boolean isLink() {
     return this.link != null && this.reference == null;
   }
 
-  /** @return the HDFS block distribution */
+  /** Returns the HDFS block distribution */
   public HDFSBlocksDistribution getHDFSBlockDistribution() {
     return this.hdfsBlocksDistribution;
   }
 
-  StoreFileReader createReader(ReaderContext context, CacheConfig cacheConf)
-      throws IOException {
+  StoreFileReader createReader(ReaderContext context, CacheConfig cacheConf) throws IOException {
     StoreFileReader reader = null;
     if (this.reference != null) {
       reader = new HalfStoreFileReader(context, hfileInfo, cacheConf, reference, refCount, conf);
@@ -291,7 +285,7 @@ public class StoreFileInfo {
   }
 
   ReaderContext createReaderContext(boolean doDropBehind, long readahead, ReaderType type)
-      throws IOException {
+    throws IOException {
     FSDataInputStreamWrapper in;
     FileStatus status;
     if (this.link != null) {
@@ -317,12 +311,9 @@ public class StoreFileInfo {
       status = fs.getFileStatus(initialPath);
     }
     long length = status.getLen();
-    ReaderContextBuilder contextBuilder = new ReaderContextBuilder()
-        .withInputStreamWrapper(in)
-        .withFileSize(length)
-        .withPrimaryReplicaReader(this.primaryReplica)
-        .withReaderType(type)
-        .withFileSystem(fs);
+    ReaderContextBuilder contextBuilder =
+      new ReaderContextBuilder().withInputStreamWrapper(in).withFileSize(length)
+        .withPrimaryReplicaReader(this.primaryReplica).withReaderType(type).withFileSystem(fs);
     if (this.reference != null) {
       contextBuilder.withFilePath(this.getPath());
     } else {
@@ -335,7 +326,7 @@ public class StoreFileInfo {
    * Compute the HDFS Block Distribution for this StoreFile
    */
   public HDFSBlocksDistribution computeHDFSBlocksDistribution(final FileSystem fs)
-      throws IOException {
+    throws IOException {
     // guard against the case where we get the FileStatus from link, but by the time we
     // call compute the file is moved again
     if (this.link != null) {
@@ -355,7 +346,7 @@ public class StoreFileInfo {
   }
 
   private HDFSBlocksDistribution computeHDFSBlocksDistributionInternal(final FileSystem fs)
-      throws IOException {
+    throws IOException {
     FileStatus status = getReferencedFileStatus(fs);
     if (this.reference != null) {
       return computeRefFileHDFSBlockDistribution(fs, reference, status);
@@ -409,25 +400,25 @@ public class StoreFileInfo {
     return status;
   }
 
-  /** @return The {@link Path} of the file */
+  /** Returns The {@link Path} of the file */
   public Path getPath() {
     return initialPath;
   }
 
-  /** @return The {@link FileStatus} of the file */
+  /** Returns The {@link FileStatus} of the file */
   public FileStatus getFileStatus() throws IOException {
     return getReferencedFileStatus(fs);
   }
 
-  /** @return Get the modification time of the file. */
+  /** Returns Get the modification time of the file. */
   public long getModificationTime() throws IOException {
     return getFileStatus().getModificationTime();
   }
 
   @Override
   public String toString() {
-    return this.getPath() +
-      (isReference() ? "->" + getReferredToFile(this.getPath()) + "-" + reference : "");
+    return this.getPath()
+      + (isReference() ? "->" + getReferredToFile(this.getPath()) + "-" + reference : "");
   }
 
   /**
@@ -444,20 +435,38 @@ public class StoreFileInfo {
   }
 
   /**
-   * @param path Path to check.
-   * @return True if the path has format of a del file.
+   * Checks if the file is a MOB file
+   * @param path path to a file
+   * @return true, if - yes, false otherwise
    */
-  public static boolean isDelFile(final Path path) {
-    return isDelFile(path.getName());
+  public static boolean isMobFile(final Path path) {
+    String fileName = path.getName();
+    String[] parts = fileName.split(MobUtils.SEP);
+    if (parts.length != 2) {
+      return false;
+    }
+    Matcher m = HFILE_NAME_PATTERN.matcher(parts[0]);
+    Matcher mm = HFILE_NAME_PATTERN.matcher(parts[1]);
+    return m.matches() && mm.matches();
   }
 
   /**
-   * @param fileName Sting version of path to validate.
-   * @return True if the file name has format of a del file.
+   * Checks if the file is a MOB reference file, created by snapshot
+   * @param path path to a file
+   * @return true, if - yes, false otherwise
    */
-  public static boolean isDelFile(final String fileName) {
-    Matcher m = DELFILE_NAME_PATTERN.matcher(fileName);
-    return m.matches() && m.groupCount() > 0;
+  public static boolean isMobRefFile(final Path path) {
+    String fileName = path.getName();
+    int lastIndex = fileName.lastIndexOf(MobUtils.SEP);
+    if (lastIndex < 0) {
+      return false;
+    }
+    String[] parts = new String[2];
+    parts[0] = fileName.substring(0, lastIndex);
+    parts[1] = fileName.substring(lastIndex + 1);
+    String name = parts[0] + "." + parts[1];
+    Matcher m = REF_NAME_PATTERN.matcher(name);
+    return m.matches() && m.groupCount() > 1;
   }
 
   /**
@@ -477,16 +486,14 @@ public class StoreFileInfo {
     return m.matches() && m.groupCount() > 1;
   }
 
-  /**
-   * @return timestamp when this file was created (as returned by filesystem)
-   */
+  /** Returns timestamp when this file was created (as returned by filesystem) */
   public long getCreatedTimestamp() {
     return createdTimestamp;
   }
 
   /*
-   * Return path to the file referred to by a Reference.  Presumes a directory
-   * hierarchy of <code>${hbase.rootdir}/data/${namespace}/tablename/regionname/familyname</code>.
+   * Return path to the file referred to by a Reference. Presumes a directory hierarchy of
+   * <code>${hbase.rootdir}/data/${namespace}/tablename/regionname/familyname</code>.
    * @param p Path to a Reference file.
    * @return Calculated path to parent region file.
    * @throws IllegalArgumentException when path regex fails to match.
@@ -495,8 +502,7 @@ public class StoreFileInfo {
     Matcher m = REF_NAME_PATTERN.matcher(p.getName());
     if (m == null || !m.matches()) {
       LOG.warn("Failed match of store file name {}", p.toString());
-      throw new IllegalArgumentException("Failed match of store file name " +
-          p.toString());
+      throw new IllegalArgumentException("Failed match of store file name " + p.toString());
     }
 
     // Other region name is suffix on the passed Reference file name
@@ -507,27 +513,9 @@ public class StoreFileInfo {
     LOG.trace("reference {} to region={} hfile={}", p, otherRegion, nameStrippedOfSuffix);
 
     // Build up new path with the referenced region in place of our current
-    // region in the reference path.  Also strip regionname suffix from name.
-    return new Path(new Path(new Path(tableDir, otherRegion),
-      p.getParent().getName()), nameStrippedOfSuffix);
-  }
-
-  /*
-   * Return region and file name referred to by a Reference.
-   * @param referenceFile HFile name which is a Reference.
-   * @return Calculated referenced region and file name.
-   * @throws IllegalArgumentException when referenceFile regex fails to match.
-   */
-  public static Pair<String, String> getReferredToRegionAndFile(final String referenceFile) {
-    Matcher m = REF_NAME_PATTERN.matcher(referenceFile);
-    if (m == null || !m.matches()) {
-      LOG.warn("Failed match of store file name {}", referenceFile);
-      throw new IllegalArgumentException("Failed match of store file name " + referenceFile);
-    }
-    String referencedRegion = m.group(2);
-    String referencedFile = m.group(1);
-    LOG.trace("reference {} to region={} file={}", referenceFile, referencedRegion, referencedFile);
-    return new Pair<>(referencedRegion, referencedFile);
+    // region in the reference path. Also strip regionname suffix from name.
+    return new Path(new Path(new Path(tableDir, otherRegion), p.getParent().getName()),
+      nameStrippedOfSuffix);
   }
 
   /**
@@ -536,8 +524,7 @@ public class StoreFileInfo {
    * @return <tt>true</tt> if the file could be a valid store file, <tt>false</tt> otherwise
    */
   public static boolean validateStoreFileName(final String fileName) {
-    if (HFileLink.isHFileLink(fileName) || isReference(fileName))
-      return(true);
+    if (HFileLink.isHFileLink(fileName) || isReference(fileName)) return (true);
     return !fileName.contains("-");
   }
 
@@ -546,12 +533,10 @@ public class StoreFileInfo {
    * @param fileStatus The {@link FileStatus} of the file
    * @return <tt>true</tt> if the file is valid
    */
-  public static boolean isValid(final FileStatus fileStatus)
-      throws IOException {
+  public static boolean isValid(final FileStatus fileStatus) throws IOException {
     final Path p = fileStatus.getPath();
 
-    if (fileStatus.isDirectory())
-      return false;
+    if (fileStatus.isDirectory()) return false;
 
     // Check for empty hfile. Should never be the case but can happen
     // after data loss in hdfs for whatever reason (upgrade, etc.): HBASE-646
@@ -565,21 +550,19 @@ public class StoreFileInfo {
   }
 
   /**
-   * helper function to compute HDFS blocks distribution of a given reference
-   * file.For reference file, we don't compute the exact value. We use some
-   * estimate instead given it might be good enough. we assume bottom part
-   * takes the first half of reference file, top part takes the second half
-   * of the reference file. This is just estimate, given
-   * midkey ofregion != midkey of HFile, also the number and size of keys vary.
-   * If this estimate isn't good enough, we can improve it later.
-   * @param fs  The FileSystem
-   * @param reference  The reference
-   * @param status  The reference FileStatus
+   * helper function to compute HDFS blocks distribution of a given reference file.For reference
+   * file, we don't compute the exact value. We use some estimate instead given it might be good
+   * enough. we assume bottom part takes the first half of reference file, top part takes the second
+   * half of the reference file. This is just estimate, given midkey ofregion != midkey of HFile,
+   * also the number and size of keys vary. If this estimate isn't good enough, we can improve it
+   * later.
+   * @param fs        The FileSystem
+   * @param reference The reference
+   * @param status    The reference FileStatus
    * @return HDFS blocks distribution
    */
-  private static HDFSBlocksDistribution computeRefFileHDFSBlockDistribution(
-      final FileSystem fs, final Reference reference, final FileStatus status)
-      throws IOException {
+  private static HDFSBlocksDistribution computeRefFileHDFSBlockDistribution(final FileSystem fs,
+    final Reference reference, final FileStatus status) throws IOException {
     if (status == null) {
       return null;
     }
@@ -588,48 +571,59 @@ public class StoreFileInfo {
     long length = 0;
 
     if (Reference.isTopFileRegion(reference.getFileRegion())) {
-      start = status.getLen()/2;
-      length = status.getLen() - status.getLen()/2;
+      start = status.getLen() / 2;
+      length = status.getLen() - status.getLen() / 2;
     } else {
       start = 0;
-      length = status.getLen()/2;
+      length = status.getLen() / 2;
     }
     return FSUtils.computeHDFSBlocksDistribution(fs, status, start, length);
   }
 
   @Override
   public boolean equals(Object that) {
-    if (this == that) return true;
-    if (that == null) return false;
+    if (this == that) {
+      return true;
+    }
+    if (that == null) {
+      return false;
+    }
 
-    if (!(that instanceof StoreFileInfo)) return false;
+    if (!(that instanceof StoreFileInfo)) {
+      return false;
+    }
 
-    StoreFileInfo o = (StoreFileInfo)that;
+    StoreFileInfo o = (StoreFileInfo) that;
     if (initialPath != null && o.initialPath == null) return false;
     if (initialPath == null && o.initialPath != null) return false;
-    if (initialPath != o.initialPath && initialPath != null
-            && !initialPath.equals(o.initialPath)) return false;
+    if (initialPath != o.initialPath && initialPath != null && !initialPath.equals(o.initialPath))
+      return false;
 
     if (reference != null && o.reference == null) return false;
     if (reference == null && o.reference != null) return false;
-    if (reference != o.reference && reference != null
-            && !reference.equals(o.reference)) return false;
+    if (reference != o.reference && reference != null && !reference.equals(o.reference))
+      return false;
 
-    if (link != null && o.link == null) return false;
-    if (link == null && o.link != null) return false;
-    if (link != o.link && link != null && !link.equals(o.link)) return false;
+    if (link != null && o.link == null) {
+      return false;
+    }
+    if (link == null && o.link != null) {
+      return false;
+    }
+    if (link != o.link && link != null && !link.equals(o.link)) {
+      return false;
+    }
 
     return true;
   };
 
-
   @Override
   public int hashCode() {
     int hash = 17;
     hash = hash * 31 + ((reference == null) ? 0 : reference.hashCode());
-    hash = hash * 31 + ((initialPath ==  null) ? 0 : initialPath.hashCode());
+    hash = hash * 31 + ((initialPath == null) ? 0 : initialPath.hashCode());
     hash = hash * 31 + ((link == null) ? 0 : link.hashCode());
-    return  hash;
+    return hash;
   }
 
   /**
@@ -651,10 +645,6 @@ public class StoreFileInfo {
     return this.fs;
   }
 
-  Configuration getConf() {
-    return this.conf;
-  }
-
   boolean isNoReadahead() {
     return this.noReadahead;
   }
@@ -668,23 +658,21 @@ public class StoreFileInfo {
   }
 
   StoreFileReader preStoreFileReaderOpen(ReaderContext context, CacheConfig cacheConf)
-      throws IOException {
+    throws IOException {
     StoreFileReader reader = null;
     if (this.coprocessorHost != null) {
       reader = this.coprocessorHost.preStoreFileReaderOpen(fs, this.getPath(),
-          context.getInputStreamWrapper(), context.getFileSize(),
-          cacheConf, reference);
+        context.getInputStreamWrapper(), context.getFileSize(), cacheConf, reference);
     }
     return reader;
   }
 
   StoreFileReader postStoreFileReaderOpen(ReaderContext context, CacheConfig cacheConf,
-      StoreFileReader reader) throws IOException {
+    StoreFileReader reader) throws IOException {
     StoreFileReader res = reader;
     if (this.coprocessorHost != null) {
       res = this.coprocessorHost.postStoreFileReaderOpen(fs, this.getPath(),
-          context.getInputStreamWrapper(), context.getFileSize(),
-          cacheConf, reference, reader);
+        context.getInputStreamWrapper(), context.getFileSize(), cacheConf, reference, reader);
     }
     return res;
   }
@@ -692,4 +680,5 @@ public class StoreFileInfo {
   public void initHFileInfo(ReaderContext context) throws IOException {
     this.hfileInfo = new HFileInfo(context, conf);
   }
+
 }
