@@ -38,6 +38,7 @@ import org.apache.hadoop.hbase.PrivateCellUtil;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.io.TimeRange;
 import org.apache.hadoop.hbase.io.hfile.BlockType;
+import org.apache.hadoop.hbase.io.hfile.BloomFilterMetrics;
 import org.apache.hadoop.hbase.io.hfile.CacheConfig;
 import org.apache.hadoop.hbase.io.hfile.HFile;
 import org.apache.hadoop.hbase.io.hfile.HFileBlock;
@@ -64,6 +65,7 @@ public class StoreFileReader {
 
   protected BloomFilter generalBloomFilter = null;
   protected BloomFilter deleteFamilyBloomFilter = null;
+  private BloomFilterMetrics bloomFilterMetrics = null;
   protected BloomType bloomFilterType;
   private final HFile.Reader reader;
   protected long sequenceID = -1;
@@ -74,6 +76,7 @@ public class StoreFileReader {
   private KeyValue.KeyOnlyKeyValue lastBloomKeyOnlyKV = null;
   private boolean skipResetSeqId = true;
   private int prefixLength = -1;
+  protected Configuration conf;
 
   // Counter that is incremented every time a scanner is created on the
   // store file. It is decremented when the scan on the store file is
@@ -81,16 +84,18 @@ public class StoreFileReader {
   private final AtomicInteger refCount;
   private final ReaderContext context;
 
-  private StoreFileReader(HFile.Reader reader, AtomicInteger refCount, ReaderContext context) {
+  private StoreFileReader(HFile.Reader reader, AtomicInteger refCount, ReaderContext context,
+    Configuration conf) {
     this.reader = reader;
     bloomFilterType = BloomType.NONE;
     this.refCount = refCount;
     this.context = context;
+    this.conf = conf;
   }
 
   public StoreFileReader(ReaderContext context, HFileInfo fileInfo, CacheConfig cacheConf,
     AtomicInteger refCount, Configuration conf) throws IOException {
-    this(HFile.createReader(context, fileInfo, cacheConf, conf), refCount, context);
+    this(HFile.createReader(context, fileInfo, cacheConf, conf), refCount, context, conf);
   }
 
   void copyFields(StoreFileReader storeFileReader) throws IOException {
@@ -191,14 +196,14 @@ public class StoreFileReader {
    * @deprecated since 2.0.0 and will be removed in 3.0.0. Do not write further code which depends
    *             on this call. Instead use getStoreFileScanner() which uses the StoreFileScanner
    *             class/interface which is the preferred way to scan a store with higher level
-   *             concepts. should we cache the blocks? use pread (for concurrent small readers) is
-   *             scanner being used for compaction?
+   *             concepts. n * should we cache the blocks? n * use pread (for concurrent small
+   *             readers) n * is scanner being used for compaction?
    * @return the underlying HFileScanner
    * @see <a href="https://issues.apache.org/jira/browse/HBASE-15296">HBASE-15296</a>
    */
   @Deprecated
   public HFileScanner getScanner(boolean cacheBlocks, boolean pread, boolean isCompaction) {
-    return reader.getScanner(cacheBlocks, pread, isCompaction);
+    return reader.getScanner(conf, cacheBlocks, pread, isCompaction);
   }
 
   public void close(boolean evictOnClose) throws IOException {
@@ -258,6 +263,9 @@ public class StoreFileReader {
       case ROWPREFIX_FIXED_LENGTH:
         return passesGeneralRowPrefixBloomFilter(scan);
       default:
+        if (scan.isGetScan()) {
+          bloomFilterMetrics.incrementEligible();
+        }
         return true;
     }
   }
@@ -297,6 +305,7 @@ public class StoreFileReader {
   private boolean passesGeneralRowBloomFilter(byte[] row, int rowOffset, int rowLen) {
     BloomFilter bloomFilter = this.generalBloomFilter;
     if (bloomFilter == null) {
+      bloomFilterMetrics.incrementEligible();
       return true;
     }
 
@@ -311,12 +320,13 @@ public class StoreFileReader {
 
   /**
    * A method for checking Bloom filters. Called directly from StoreFileScanner in case of a
-   * multi-column query. the cell to check if present in BloomFilter
+   * multi-column query. n * the cell to check if present in BloomFilter
    * @return True if passes
    */
   public boolean passesGeneralRowColBloomFilter(Cell cell) {
     BloomFilter bloomFilter = this.generalBloomFilter;
     if (bloomFilter == null) {
+      bloomFilterMetrics.incrementEligible();
       return true;
     }
     // Used in ROW_COL bloom
@@ -338,6 +348,7 @@ public class StoreFileReader {
   private boolean passesGeneralRowPrefixBloomFilter(Scan scan) {
     BloomFilter bloomFilter = this.generalBloomFilter;
     if (bloomFilter == null) {
+      bloomFilterMetrics.incrementEligible();
       return true;
     }
 
@@ -488,12 +499,13 @@ public class StoreFileReader {
   }
 
   public void loadBloomfilter() {
-    this.loadBloomfilter(BlockType.GENERAL_BLOOM_META);
-    this.loadBloomfilter(BlockType.DELETE_FAMILY_BLOOM_META);
+    this.loadBloomfilter(BlockType.GENERAL_BLOOM_META, null);
+    this.loadBloomfilter(BlockType.DELETE_FAMILY_BLOOM_META, null);
   }
 
-  public void loadBloomfilter(BlockType blockType) {
+  public void loadBloomfilter(BlockType blockType, BloomFilterMetrics metrics) {
     try {
+      this.bloomFilterMetrics = metrics;
       if (blockType == BlockType.GENERAL_BLOOM_META) {
         if (this.generalBloomFilter != null) return; // Bloom has been loaded
 
@@ -503,7 +515,7 @@ public class StoreFileReader {
           if (bloomFilterType == BloomType.NONE) {
             throw new IOException("valid bloom filter type not found in FileInfo");
           } else {
-            generalBloomFilter = BloomFilterFactory.createFromMeta(bloomMeta, reader);
+            generalBloomFilter = BloomFilterFactory.createFromMeta(bloomMeta, reader, metrics);
             if (LOG.isTraceEnabled()) {
               LOG.trace("Loaded " + bloomFilterType.toString() + " "
                 + generalBloomFilter.getClass().getSimpleName() + " metadata for "
@@ -516,7 +528,9 @@ public class StoreFileReader {
 
         DataInput bloomMeta = reader.getDeleteBloomFilterMetadata();
         if (bloomMeta != null) {
-          deleteFamilyBloomFilter = BloomFilterFactory.createFromMeta(bloomMeta, reader);
+          // don't pass in metrics for the delete family bloom for now since the
+          // goal is to give users insight into blooms _they_ configured.
+          deleteFamilyBloomFilter = BloomFilterFactory.createFromMeta(bloomMeta, reader, null);
           LOG.info(
             "Loaded Delete Family Bloom (" + deleteFamilyBloomFilter.getClass().getSimpleName()
               + ") metadata for " + reader.getName());
