@@ -25,6 +25,7 @@ import static org.apache.hadoop.hbase.regionserver.HStoreFile.EARLIEST_PUT_TS;
 import static org.apache.hadoop.hbase.regionserver.HStoreFile.MAJOR_COMPACTION_KEY;
 import static org.apache.hadoop.hbase.regionserver.HStoreFile.MAX_SEQ_ID_KEY;
 import static org.apache.hadoop.hbase.regionserver.HStoreFile.MOB_CELLS_COUNT;
+import static org.apache.hadoop.hbase.regionserver.HStoreFile.MOB_FILE_REFS;
 import static org.apache.hadoop.hbase.regionserver.HStoreFile.TIMERANGE_KEY;
 
 import java.io.IOException;
@@ -34,6 +35,7 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
 import java.util.UUID;
+import java.util.function.Consumer;
 import java.util.function.Supplier;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
@@ -44,10 +46,13 @@ import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.PrivateCellUtil;
+import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.io.hfile.CacheConfig;
 import org.apache.hadoop.hbase.io.hfile.HFile;
 import org.apache.hadoop.hbase.io.hfile.HFileContext;
+import org.apache.hadoop.hbase.io.hfile.HFileWriterImpl;
+import org.apache.hadoop.hbase.mob.MobUtils;
 import org.apache.hadoop.hbase.util.BloomContext;
 import org.apache.hadoop.hbase.util.BloomFilterFactory;
 import org.apache.hadoop.hbase.util.BloomFilterUtil;
@@ -63,6 +68,7 @@ import org.slf4j.LoggerFactory;
 
 import org.apache.hbase.thirdparty.com.google.common.base.Preconditions;
 import org.apache.hbase.thirdparty.com.google.common.base.Strings;
+import org.apache.hbase.thirdparty.com.google.common.collect.SetMultimap;
 
 import org.apache.hadoop.hbase.shaded.protobuf.ProtobufUtil;
 
@@ -164,6 +170,10 @@ public class StoreFileWriter implements CellSink, ShipperListener {
     }
   }
 
+  public long getPos() throws IOException {
+    return ((HFileWriterImpl) writer).getPos();
+  }
+
   /**
    * Writes meta data. Call before {@link #close()} since its written as meta data to this file.
    * @param maxSequenceId   Maximum sequence id.
@@ -232,6 +242,15 @@ public class StoreFileWriter implements CellSink, ShipperListener {
     appendTrackedTimestampsToMetadata();
   }
 
+  /**
+   * Appends MOB - specific metadata (even if it is empty)
+   * @param mobRefSet - original table -> set of MOB file names
+   * @throws IOException problem writing to FS
+   */
+  public void appendMobMetadata(SetMultimap<TableName, String> mobRefSet) throws IOException {
+    writer.appendFileInfo(MOB_FILE_REFS, MobUtils.serializeMobFileRefs(mobRefSet));
+  }
+
   /**
    * Add TimestampRange and earliest put timestamp to Metadata
    */
@@ -406,6 +425,12 @@ public class StoreFileWriter implements CellSink, ShipperListener {
     private boolean shouldDropCacheBehind;
     private Supplier<Collection<HStoreFile>> compactedFilesSupplier = () -> Collections.emptySet();
     private String fileStoragePolicy;
+    // this is used to track the creation of the StoreFileWriter, mainly used for the SFT
+    // implementation where we will write store files directly to the final place, instead of
+    // writing a tmp file first. Under this scenario, we will have a background task to purge the
+    // store files which are not recorded in the SFT, but for the newly created store file writer,
+    // they are not tracked in SFT, so here we need to record them and treat them specially.
+    private Consumer<Path> writerCreationTracker;
 
     public Builder(Configuration conf, CacheConfig cacheConf, FileSystem fs) {
       this.conf = conf;
@@ -490,6 +515,11 @@ public class StoreFileWriter implements CellSink, ShipperListener {
       return this;
     }
 
+    public Builder withWriterCreationTracker(Consumer<Path> writerCreationTracker) {
+      this.writerCreationTracker = writerCreationTracker;
+      return this;
+    }
+
     /**
      * Create a store file writer. Client is responsible for closing file when done. If metadata,
      * add BEFORE closing using {@link StoreFileWriter#appendMetadata}.
@@ -536,7 +566,14 @@ public class StoreFileWriter implements CellSink, ShipperListener {
           bloomType = BloomType.NONE;
         }
       }
-
+      // make sure we call this before actually create the writer
+      // in fact, it is not a big deal to even add an inexistent file to the track, as we will never
+      // try to delete it and finally we will clean the tracker up after compaction. But if the file
+      // cleaner find the file but we haven't recorded it yet, it may accidentally delete the file
+      // and cause problem.
+      if (writerCreationTracker != null) {
+        writerCreationTracker.accept(filePath);
+      }
       return new StoreFileWriter(fs, filePath, conf, cacheConf, bloomType, maxKeyCount,
         favoredNodes, fileContext, shouldDropCacheBehind, compactedFilesSupplier);
     }
