@@ -225,7 +225,7 @@ public class StoreScanner extends NonReversedNonLazyKeyValueScanner
    * compaction.
    * @param store   who we scan
    * @param scan    the spec
-   * @param columns which columns we are scanning
+   * @param columns which columns we are scanning n
    */
   public StoreScanner(HStore store, ScanInfo scanInfo, Scan scan, NavigableSet<byte[]> columns,
     long readPt) throws IOException {
@@ -384,9 +384,8 @@ public class StoreScanner extends NonReversedNonLazyKeyValueScanner
   }
 
   /**
-   * Seek the specified scanners with the given key
-   * @param isLazy         true if using lazy seek
-   * @param isParallelSeek true if using parallel seek
+   * Seek the specified scanners with the given key nn * @param isLazy true if using lazy seek
+   * @param isParallelSeek true if using parallel seek n
    */
   protected void seekScanners(List<? extends KeyValueScanner> scanners, Cell seekKey,
     boolean isLazy, boolean isParallelSeek) throws IOException {
@@ -531,8 +530,8 @@ public class StoreScanner extends NonReversedNonLazyKeyValueScanner
   }
 
   /**
-   * Get the next row of values from this Store.
-   * @return true if there are more rows, false if scanner is done
+   * Get the next row of values from this Store. nn * @return true if there are more rows, false if
+   * scanner is done
    */
   @Override
   public boolean next(List<Cell> outResult, ScannerContext scannerContext) throws IOException {
@@ -913,7 +912,7 @@ public class StoreScanner extends NonReversedNonLazyKeyValueScanner
     // We need this check because it may happen that the new scanner that we get
     // during heap.next() is requiring reseek due of fake KV previously generated for
     // ROWCOL bloom filter optimization. See HBASE-19863 for more details
-    if (useRowColBloom && nextCell != null && cell.getTimestamp() == HConstants.OLDEST_TIMESTAMP) {
+    if (useRowColBloom && nextCell != null && matcher.compareKeyForNextColumn(nextCell, cell) < 0) {
       return false;
     }
     return true;
@@ -1051,7 +1050,7 @@ public class StoreScanner extends NonReversedNonLazyKeyValueScanner
   }
 
   /**
-   * Check whether scan as expected order
+   * Check whether scan as expected order nnnn
    */
   protected void checkScanOrder(Cell prevKV, Cell kv, CellComparator comparator)
     throws IOException {
@@ -1065,8 +1064,8 @@ public class StoreScanner extends NonReversedNonLazyKeyValueScanner
   }
 
   /**
-   * Do a reseek in a normal StoreScanner(scan forward)
-   * @return true if scanner has values left, false if end of scanner
+   * Do a reseek in a normal StoreScanner(scan forward) n * @return true if scanner has values left,
+   * false if end of scanner n
    */
   protected boolean seekAsDirection(Cell kv) throws IOException {
     return reseek(kv);
@@ -1157,7 +1156,7 @@ public class StoreScanner extends NonReversedNonLazyKeyValueScanner
   /**
    * Seek storefiles in parallel to optimize IO latency as much as possible
    * @param scanners the list {@link KeyValueScanner}s to be read from
-   * @param kv       the KeyValue on which the operation is being requested
+   * @param kv       the KeyValue on which the operation is being requested n
    */
   private void parallelSeek(final List<? extends KeyValueScanner> scanners, final Cell kv)
     throws IOException {
