@@ -20,11 +20,13 @@ package org.apache.hadoop.hbase.regionserver.wal;
 import static org.apache.hadoop.hbase.regionserver.wal.WALActionsListener.RollRequestReason.ERROR;
 import static org.apache.hadoop.hbase.regionserver.wal.WALActionsListener.RollRequestReason.LOW_REPLICATION;
 import static org.apache.hadoop.hbase.regionserver.wal.WALActionsListener.RollRequestReason.SLOW_SYNC;
+import static org.apache.hadoop.hbase.trace.HBaseSemanticAttributes.WAL_IMPL;
 import static org.apache.hadoop.hbase.wal.AbstractFSWALProvider.WAL_FILE_NAME_DELIMITER;
 import static org.apache.hbase.thirdparty.com.google.common.base.Preconditions.checkArgument;
 import static org.apache.hbase.thirdparty.com.google.common.base.Preconditions.checkNotNull;
 
 import com.lmax.disruptor.RingBuffer;
+import io.opentelemetry.api.trace.Span;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InterruptedIOException;
@@ -37,7 +39,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.OptionalLong;
 import java.util.Set;
-import java.util.concurrent.Callable;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentNavigableMap;
 import java.util.concurrent.ConcurrentSkipListMap;
@@ -45,11 +46,7 @@ import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
-import java.util.concurrent.Future;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
@@ -88,7 +85,6 @@ import org.apache.hadoop.hbase.wal.WALProvider.WriterBase;
 import org.apache.hadoop.hbase.wal.WALSplitter;
 import org.apache.hadoop.hdfs.protocol.DatanodeInfo;
 import org.apache.hadoop.util.StringUtils;
-import org.apache.htrace.core.TraceScope;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -147,9 +143,6 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
   public static final String RING_BUFFER_SLOT_COUNT =
     "hbase.regionserver.wal.disruptor.event.count";
 
-  public static final String WAL_SHUTDOWN_WAIT_TIMEOUT_MS = "hbase.wal.shutdown.wait.timeout.ms";
-  public static final int DEFAULT_WAL_SHUTDOWN_WAIT_TIMEOUT_MS = 15 * 1000;
-
   /**
    * file system instance
    */
@@ -223,8 +216,8 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
   protected final long blocksize;
 
   /*
-   * If more than this many logs, force flush of oldest region to the oldest edit goes to disk. If
-   * too many and we crash, then will take forever replaying. Keep the number of logs tidy.
+   * If more than this many logs, force flush of oldest region to oldest edit goes to disk. If too
+   * many and we crash, then will take forever replaying. Keep the number of logs tidy.
    */
   protected final int maxLogs;
 
@@ -277,9 +270,6 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
   protected volatile boolean closed = false;
 
   protected final AtomicBoolean shutdown = new AtomicBoolean(false);
-
-  protected final long walShutdownTimeout;
-
   /**
    * WAL Comparator; it compares the timestamp (log filenum), present in the log file name. Throws
    * an IllegalArgumentException if used to compare paths from different wals.
@@ -287,29 +277,22 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
   final Comparator<Path> LOG_NAME_COMPARATOR =
     (o1, o2) -> Long.compare(getFileNumFromFileName(o1), getFileNumFromFileName(o2));
 
-  private static final class WALProps {
+  private static final class WalProps {
 
     /**
      * Map the encoded region name to the highest sequence id.
      * <p/>
      * Contains all the regions it has an entry for.
      */
-    private final Map<byte[], Long> encodedName2HighestSequenceId;
+    public final Map<byte[], Long> encodedName2HighestSequenceId;
 
     /**
      * The log file size. Notice that the size may not be accurate if we do asynchronous close in
-     * subclasses.
+     * sub classes.
      */
-    private final long logSize;
+    public final long logSize;
 
-    /**
-     * If we do asynchronous close in subclasses, it is possible that when adding WALProps to the
-     * rolled map, the file is not closed yet, so in cleanOldLogs we should not archive this file,
-     * for safety.
-     */
-    private volatile boolean closed = false;
-
-    WALProps(Map<byte[], Long> encodedName2HighestSequenceId, long logSize) {
+    public WalProps(Map<byte[], Long> encodedName2HighestSequenceId, long logSize) {
       this.encodedName2HighestSequenceId = encodedName2HighestSequenceId;
       this.logSize = logSize;
     }
@@ -319,7 +302,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
    * Map of WAL log file to properties. The map is sorted by the log file creation timestamp
    * (contained in the log file name).
    */
-  protected final ConcurrentNavigableMap<Path, WALProps> walFile2Props =
+  protected ConcurrentNavigableMap<Path, WalProps> walFile2Props =
     new ConcurrentSkipListMap<>(LOG_NAME_COMPARATOR);
 
   /**
@@ -338,15 +321,8 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
 
   protected final AtomicBoolean rollRequested = new AtomicBoolean(false);
 
-  protected final ExecutorService closeExecutor = Executors.newCachedThreadPool(
-    new ThreadFactoryBuilder().setDaemon(true).setNameFormat("Close-WAL-Writer-%d").build());
-
-  // Run in caller if we get reject execution exception, to avoid aborting region server when we get
-  // reject execution exception. Usually this should not happen but let's make it more robust.
-  private final ExecutorService logArchiveExecutor =
-    new ThreadPoolExecutor(1, 1, 1L, TimeUnit.MINUTES, new LinkedBlockingQueue<Runnable>(),
-      new ThreadFactoryBuilder().setDaemon(true).setNameFormat("WAL-Archive-%d").build(),
-      new ThreadPoolExecutor.CallerRunsPolicy());
+  private final ExecutorService logArchiveExecutor = Executors.newSingleThreadExecutor(
+    new ThreadFactoryBuilder().setDaemon(true).setNameFormat("Log-Archiver-%d").build());
 
   private final int archiveRetries;
 
@@ -373,9 +349,6 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
   }
 
   private int calculateMaxLogFiles(Configuration conf, long logRollSize) {
-    checkArgument(logRollSize > 0,
-      "The log roll size cannot be zero or negative when calculating max log files, "
-        + "current value is " + logRollSize);
     Pair<Long, MemoryType> globalMemstoreSize = MemorySizeUtil.getGlobalMemStoreSize(conf);
     return (int) ((globalMemstoreSize.getFirst() * 2) / logRollSize);
   }
@@ -506,9 +479,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     this.syncFutureCache = new SyncFutureCache(conf);
     this.implClassName = getClass().getSimpleName();
     this.useHsync = conf.getBoolean(HRegion.WAL_HSYNC_CONF_KEY, HRegion.DEFAULT_WAL_HSYNC);
-    archiveRetries = this.conf.getInt("hbase.regionserver.walroll.archive.retries", 0);
-    this.walShutdownTimeout =
-      conf.getLong(WAL_SHUTDOWN_WAIT_TIMEOUT_MS, DEFAULT_WAL_SHUTDOWN_WAIT_TIMEOUT_MS);
+    archiveRetries = this.conf.getInt("hbase.regionserver.logroll.archive.retries", 0);
   }
 
   /**
@@ -577,9 +548,33 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     return rollWriter(false);
   }
 
+  @Override
+  public final void sync() throws IOException {
+    sync(useHsync);
+  }
+
+  @Override
+  public final void sync(long txid) throws IOException {
+    sync(txid, useHsync);
+  }
+
+  @Override
+  public final void sync(boolean forceSync) throws IOException {
+    TraceUtil.trace(() -> doSync(forceSync), () -> createSpan("WAL.sync"));
+  }
+
+  @Override
+  public final void sync(long txid, boolean forceSync) throws IOException {
+    TraceUtil.trace(() -> doSync(txid, forceSync), () -> createSpan("WAL.sync"));
+  }
+
+  protected abstract void doSync(boolean forceSync) throws IOException;
+
+  protected abstract void doSync(long txid, boolean forceSync) throws IOException;
+
   /**
    * This is a convenience method that computes a new filename with a given file-number.
-   * @param filenum to use
+   * @param filenum to use n
    */
   protected Path computeFilename(final long filenum) {
     if (filenum < 0) {
@@ -591,7 +586,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
 
   /**
    * This is a convenience method that computes a new filename with a given using the current WAL
-   * file-number
+   * file-number n
    */
   public Path getCurrentFileName() {
     return computeFilename(this.filenum.get());
@@ -601,7 +596,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
    * retrieve the next path to use for writing. Increments the internal filenum.
    */
   private Path getNewPath() throws IOException {
-    this.filenum.set(Math.max(getFilenum() + 1, System.currentTimeMillis()));
+    this.filenum.set(Math.max(getFilenum() + 1, EnvironmentEdgeManager.currentTime()));
     Path newPath = getCurrentFileName();
     return newPath;
   }
@@ -661,18 +656,18 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
    * If the number of un-archived WAL files ('live' WALs) is greater than maximum allowed, check the
    * first (oldest) WAL, and return those regions which should be flushed so that it can be
    * let-go/'archived'.
-   * @return stores of regions (encodedRegionNames) to flush in order to archive the oldest WAL file
+   * @return stores of regions (encodedRegionNames) to flush in order to archive oldest WAL file.
    */
   Map<byte[], List<byte[]>> findRegionsToForceFlush() throws IOException {
     Map<byte[], List<byte[]>> regions = null;
     int logCount = getNumRolledLogFiles();
     if (logCount > this.maxLogs && logCount > 0) {
-      Map.Entry<Path, WALProps> firstWALEntry = this.walFile2Props.firstEntry();
+      Map.Entry<Path, WalProps> firstWALEntry = this.walFile2Props.firstEntry();
       regions =
         this.sequenceIdAccounting.findLower(firstWALEntry.getValue().encodedName2HighestSequenceId);
     }
     if (regions != null) {
-      List<String> listForPrint = new ArrayList();
+      List<String> listForPrint = new ArrayList<>();
       for (Map.Entry<byte[], List<byte[]>> r : regions.entrySet()) {
         StringBuilder families = new StringBuilder();
         for (int i = 0; i < r.getValue().size(); i++) {
@@ -690,35 +685,14 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     return regions;
   }
 
-  /**
-   * Mark this WAL file as closed and call cleanOldLogs to see if we can archive this file.
-   */
-  protected final void markClosedAndClean(Path path) {
-    WALProps props = walFile2Props.get(path);
-    // typically this should not be null, but if there is no big issue if it is already null, so
-    // let's make the code more robust
-    if (props != null) {
-      props.closed = true;
-      cleanOldLogs();
-    }
-  }
-
   /**
    * Archive old logs. A WAL is eligible for archiving if all its WALEdits have been flushed.
-   * <p/>
-   * Use synchronized because we may call this method in different threads, normally when replacing
-   * writer, and since now close writer may be asynchronous, we will also call this method in the
-   * closeExecutor, right after we actually close a WAL writer.
    */
-  private synchronized void cleanOldLogs() {
+  private void cleanOldLogs() throws IOException {
     List<Pair<Path, Long>> logsToArchive = null;
-    // For each log file, look at its Map of regions to the highest sequence id; if all sequence ids
+    // For each log file, look at its Map of regions to highest sequence id; if all sequence ids
     // are older than what is currently in memory, the WAL can be GC'd.
-    for (Map.Entry<Path, WALProps> e : this.walFile2Props.entrySet()) {
-      if (!e.getValue().closed) {
-        LOG.debug("{} is not closed yet, will try archiving it next time", e.getKey());
-        continue;
-      }
+    for (Map.Entry<Path, WalProps> e : this.walFile2Props.entrySet()) {
       Path log = e.getKey();
       Map<byte[], Long> sequenceNums = e.getValue().encodedName2HighestSequenceId;
       if (this.sequenceIdAccounting.areAllLower(sequenceNums)) {
@@ -800,7 +774,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     String newPathString = newPath != null ? CommonFSUtils.getPath(newPath) : null;
     if (oldPath != null) {
       this.walFile2Props.put(oldPath,
-        new WALProps(this.sequenceIdAccounting.resetHighest(), oldFileLen));
+        new WalProps(this.sequenceIdAccounting.resetHighest(), oldFileLen));
       this.totalLogSize.addAndGet(oldFileLen);
       LOG.info("Rolled WAL {} with entries={}, filesize={}; new WAL {}",
         CommonFSUtils.getPath(oldPath), oldNumEntries, StringUtils.byteDesc(oldFileLen),
@@ -810,6 +784,10 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     }
   }
 
+  private Span createSpan(String name) {
+    return TraceUtil.createSpan(name).setAttribute(WAL_IMPL, implClassName);
+  }
+
   /**
    * Cleans up current writer closing it and then puts in place the passed in {@code nextWriter}.
    * <p/>
@@ -827,10 +805,10 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
    * @throws IOException if there is a problem flushing or closing the underlying FS
    */
   Path replaceWriter(Path oldPath, Path newPath, W nextWriter) throws IOException {
-    try (TraceScope scope = TraceUtil.createTrace("FSHFile.replaceWriter")) {
+    return TraceUtil.trace(() -> {
       doReplaceWriter(oldPath, newPath, nextWriter);
       return newPath;
-    }
+    }, () -> createSpan("WAL.replaceWriter"));
   }
 
   protected final void blockOnSync(SyncFuture syncFuture) throws IOException {
@@ -864,8 +842,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     return ioe;
   }
 
-  @Override
-  public Map<byte[], List<byte[]>> rollWriter(boolean force) throws IOException {
+  private Map<byte[], List<byte[]>> rollWriterInternal(boolean force) throws IOException {
     rollWriterLock.lock();
     try {
       // Return if nothing to flush.
@@ -877,10 +854,10 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
         LOG.debug("WAL closed. Skipping rolling of writer");
         return regionsToFlush;
       }
-      try (TraceScope scope = TraceUtil.createTrace("FSHLog.rollWriter")) {
+      try {
         Path oldPath = getOldPath();
         Path newPath = getNewPath();
-        // Any exception from here on is catastrophic, non-recoverable, so we currently abort.
+        // Any exception from here on is catastrophic, non-recoverable so we currently abort.
         W nextWriter = this.createWriterInstance(newPath);
         tellListenersAboutPreLogRoll(oldPath, newPath);
         // NewPath could be equal to oldPath if replaceWriter fails.
@@ -899,7 +876,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
           regionsToFlush = findRegionsToForceFlush();
         }
       } catch (CommonFSUtils.StreamLacksCapabilityException exception) {
-        // If the underlying FileSystem can't do what we ask, treat as IO failure, so
+        // If the underlying FileSystem can't do what we ask, treat as IO failure so
         // we'll abort.
         throw new IOException(
           "Underlying FileSystem can't meet stream requirements. See RS log " + "for details.",
@@ -911,6 +888,11 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     }
   }
 
+  @Override
+  public Map<byte[], List<byte[]>> rollWriter(boolean force) throws IOException {
+    return TraceUtil.trace(() -> rollWriterInternal(force), () -> createSpan("WAL.rollWriter"));
+  }
+
   // public only until class moves to o.a.h.h.wal
   /** Returns the size of log files in use */
   public long getLogFileSize() {
@@ -942,64 +924,17 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
         i.logCloseRequested();
       }
     }
-
-    ExecutorService shutdownExecutor = Executors.newSingleThreadExecutor(
-      new ThreadFactoryBuilder().setDaemon(true).setNameFormat("WAL-Shutdown-%d").build());
-
-    Future<Void> future = shutdownExecutor.submit(new Callable<Void>() {
-      @Override
-      public Void call() throws Exception {
-        if (rollWriterLock.tryLock(walShutdownTimeout, TimeUnit.SECONDS)) {
-          try {
-            doShutdown();
-            if (syncFutureCache != null) {
-              syncFutureCache.clear();
-            }
-          } finally {
-            rollWriterLock.unlock();
-          }
-        } else {
-          throw new IOException("Waiting for rollWriterLock timeout");
-        }
-        return null;
-      }
-    });
-    shutdownExecutor.shutdown();
-
+    rollWriterLock.lock();
     try {
-      future.get(walShutdownTimeout, TimeUnit.MILLISECONDS);
-    } catch (InterruptedException e) {
-      throw new InterruptedIOException("Interrupted when waiting for shutdown WAL");
-    } catch (TimeoutException e) {
-      throw new TimeoutIOException("We have waited " + walShutdownTimeout + "ms, but"
-        + " the shutdown of WAL doesn't complete! Please check the status of underlying "
-        + "filesystem or increase the wait time by the config \"" + WAL_SHUTDOWN_WAIT_TIMEOUT_MS
-        + "\"", e);
-    } catch (ExecutionException e) {
-      if (e.getCause() instanceof IOException) {
-        throw (IOException) e.getCause();
-      } else {
-        throw new IOException(e.getCause());
+      doShutdown();
+      if (syncFutureCache != null) {
+        syncFutureCache.clear();
+      }
+      if (logArchiveExecutor != null) {
+        logArchiveExecutor.shutdownNow();
       }
     } finally {
-      // in shutdown, we may call cleanOldLogs so shutdown this executor in the end.
-      // In sync replication implementation, we may shut down a WAL without shutting down the whole
-      // region server, if we shut down this executor earlier we may get reject execution exception
-      logArchiveExecutor.shutdown();
-    }
-    // we also need to wait logArchive to finish if we want to a graceful shutdown as we may still
-    // have some pending archiving tasks not finished yet, and in close we may archive all the
-    // remaining WAL files, there could be race if we do not wait for the background archive task
-    // finish
-    try {
-      if (!logArchiveExecutor.awaitTermination(walShutdownTimeout, TimeUnit.MILLISECONDS)) {
-        throw new TimeoutIOException("We have waited " + walShutdownTimeout + "ms, but"
-          + " the shutdown of WAL doesn't complete! Please check the status of underlying "
-          + "filesystem or increase the wait time by the config \"" + WAL_SHUTDOWN_WAIT_TIMEOUT_MS
-          + "\"");
-      }
-    } catch (InterruptedException e) {
-      throw new InterruptedIOException("Interrupted when waiting for shutdown WAL");
+      rollWriterLock.unlock();
     }
   }
 
@@ -1101,7 +1036,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     coprocessorHost.preWALWrite(entry.getRegionInfo(), entry.getKey(), entry.getEdit());
     if (!listeners.isEmpty()) {
       for (WALActionsListener i : listeners) {
-        i.visitLogEntryBeforeWrite(entry.getKey(), entry.getEdit());
+        i.visitLogEntryBeforeWrite(entry.getRegionInfo(), entry.getKey(), entry.getEdit());
       }
     }
     doAppend(writer, entry);
@@ -1139,7 +1074,6 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
       String msg = new StringBuilder().append("Slow sync cost: ")
         .append(TimeUnit.NANOSECONDS.toMillis(timeInNanos)).append(" ms, current pipeline: ")
         .append(Arrays.toString(getPipeline())).toString();
-      TraceUtil.addTimelineAnnotation(msg);
       LOG.info(msg);
       // A single sync took too long.
       // Elsewhere in checkSlowSync, called from checkLogRoll, we will look at cumulative
@@ -1174,7 +1108,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
     long txid = txidHolder.longValue();
     ServerCall<?> rpcCall = RpcServer.getCurrentCall().filter(c -> c instanceof ServerCall)
       .filter(c -> c.getCellScanner() != null).map(c -> (ServerCall) c).orElse(null);
-    try (TraceScope scope = TraceUtil.createTrace(implClassName + ".append")) {
+    try {
       FSWALEntry entry = new FSWALEntry(txid, key, edits, hri, inMemstore, rpcCall);
       entry.stampRegionSequenceId(we);
       ringBuffer.get(txid).load(entry);
@@ -1222,12 +1156,14 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
 
   @Override
   public long appendData(RegionInfo info, WALKeyImpl key, WALEdit edits) throws IOException {
-    return append(info, key, edits, true);
+    return TraceUtil.trace(() -> append(info, key, edits, true),
+      () -> createSpan("WAL.appendData"));
   }
 
   @Override
   public long appendMarker(RegionInfo info, WALKeyImpl key, WALEdit edits) throws IOException {
-    return append(info, key, edits, false);
+    return TraceUtil.trace(() -> append(info, key, edits, false),
+      () -> createSpan("WAL.appendMarker"));
   }
 
   /**
@@ -1237,12 +1173,12 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
    * have its region edit/sequence id assigned else it messes up our unification of mvcc and
    * sequenceid. On return <code>key</code> will have the region edit/sequence id filled in.
    * <p/>
-   * NOTE: This appends, at a time that is usually after this call returns, starts a mvcc
+   * NOTE: This append, at a time that is usually after this call returns, starts an mvcc
    * transaction by calling 'begin' wherein which we assign this update a sequenceid. At assignment
    * time, we stamp all the passed in Cells inside WALEdit with their sequenceId. You must
    * 'complete' the transaction this mvcc transaction by calling
    * MultiVersionConcurrencyControl#complete(...) or a variant otherwise mvcc will get stuck. Do it
-   * in the finally of a try/finally block within which this appends lives and any subsequent
+   * in the finally of a try/finally block within which this append lives and any subsequent
    * operations like sync or update of memstore, etc. Get the WriteEntry to pass mvcc out of the
    * passed in WALKey <code>walKey</code> parameter. Be warned that the WriteEntry is not
    * immediately available on return from this method. It WILL be available subsequent to a sync of
@@ -1272,7 +1208,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
    * Notice that you need to clear the {@link #rollRequested} flag in this method, as the new writer
    * will begin to work before returning from this method. If we clear the flag after returning from
    * this call, we may miss a roll request. The implementation class should choose a proper place to
-   * clear the {@link #rollRequested} flag, so we do not miss a roll request, typically before you
+   * clear the {@link #rollRequested} flag so we do not miss a roll request, typically before you
    * start writing to the new writer.
    */
   protected abstract void doReplaceWriter(Path oldPath, Path newPath, W nextWriter)
@@ -1374,7 +1310,7 @@ public abstract class AbstractFSWAL<W extends WriterBase> implements WAL {
   }
 
   /**
-   * Pass one or more log file names, and it will either dump out a text version on
+   * Pass one or more log file names and it will either dump out a text version on
    * <code>stdout</code> or split the specified log files.
    */
   public static void main(String[] args) throws IOException {
