@@ -25,6 +25,7 @@ import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.StreamCapabilities;
 import org.apache.hadoop.hbase.Cell;
+import org.apache.hadoop.hbase.io.asyncfs.monitor.StreamSlowMonitor;
 import org.apache.hadoop.hbase.util.AtomicUtils;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
 import org.apache.hadoop.hbase.util.CommonFSUtils.StreamLacksCapabilityException;
@@ -63,10 +64,15 @@ public class ProtobufLogWriter extends AbstractProtobufLogWriter implements FSHL
   @Override
   public void close() throws IOException {
     if (this.output != null) {
-      if (!trailerWritten) {
-        writeWALTrailer();
+      try {
+        if (!trailerWritten) {
+          writeWALTrailer();
+        }
+        this.output.close();
+      } catch (NullPointerException npe) {
+        // Can get a NPE coming up from down in DFSClient$DFSOutputStream#close
+        LOG.warn(npe.toString(), npe);
       }
-      this.output.close();
       this.output = null;
     }
   }
@@ -97,7 +103,8 @@ public class ProtobufLogWriter extends AbstractProtobufLogWriter implements FSHL
 
   @Override
   protected void initOutput(FileSystem fs, Path path, boolean overwritable, int bufferSize,
-    short replication, long blockSize) throws IOException, StreamLacksCapabilityException {
+    short replication, long blockSize, StreamSlowMonitor monitor)
+    throws IOException, StreamLacksCapabilityException {
     this.output =
       CommonFSUtils.createForWal(fs, path, overwritable, bufferSize, replication, blockSize, false);
     if (fs.getConf().getBoolean(CommonFSUtils.UNSAFE_STREAM_CAPABILITY_ENFORCE, true)) {
