@@ -18,7 +18,6 @@
 package org.apache.hadoop.hbase.replication.regionserver;
 
 import java.io.IOException;
-import java.io.InterruptedIOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -28,7 +27,9 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.TreeMap;
 import java.util.UUID;
+import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicLong;
+import java.util.stream.Collectors;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
@@ -39,16 +40,17 @@ import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.TableNotFoundException;
+import org.apache.hadoop.hbase.client.AsyncConnection;
+import org.apache.hadoop.hbase.client.AsyncTable;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
-import org.apache.hadoop.hbase.client.RetriesExhaustedWithDetailsException;
+import org.apache.hadoop.hbase.client.RetriesExhaustedException;
 import org.apache.hadoop.hbase.client.Row;
-import org.apache.hadoop.hbase.client.Table;
-import org.apache.hadoop.hbase.regionserver.RegionServerCoprocessorHost;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.FutureUtils;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.hbase.wal.WALEdit;
 import org.apache.yetus.audience.InterfaceAudience;
@@ -84,10 +86,18 @@ public class ReplicationSink {
   private final Configuration conf;
   // Volatile because of note in here -- look for double-checked locking:
   // http://www.oracle.com/technetwork/articles/javase/bloch-effective-08-qa-140880.html
-  private volatile Connection sharedHtableCon;
+  /**
+   * This shared {@link Connection} is used for handling bulk load hfiles replication.
+   */
+  private volatile Connection sharedConnection;
+  /**
+   * This shared {@link AsyncConnection} is used for handling wal replication.
+   */
+  private volatile AsyncConnection sharedAsyncConnection;
   private final MetricsSink metrics;
   private final AtomicLong totalReplicatedEdits = new AtomicLong();
-  private final Object sharedHtableConLock = new Object();
+  private final Object sharedConnectionLock = new Object();
+  private final Object sharedAsyncConnectionLock = new Object();
   // Number of hfiles that we successfully replicated
   private long hfilesReplicated = 0;
   private SourceFSConfigurationProvider provider;
@@ -98,17 +108,13 @@ public class ReplicationSink {
    */
   private final int rowSizeWarnThreshold;
 
-  private final RegionServerCoprocessorHost rsServerHost;
-
   /**
    * Create a sink for replication
    * @param conf conf object
    * @throws IOException thrown when HDFS goes bad or bad file name
    */
-  public ReplicationSink(Configuration conf, RegionServerCoprocessorHost rsServerHost)
-    throws IOException {
+  public ReplicationSink(Configuration conf) throws IOException {
     this.conf = HBaseConfiguration.create(conf);
-    this.rsServerHost = rsServerHost;
     rowSizeWarnThreshold =
       conf.getInt(HConstants.BATCH_ROWS_THRESHOLD_NAME, HConstants.BATCH_ROWS_THRESHOLD_DEFAULT);
     decorateConf();
@@ -165,8 +171,6 @@ public class ReplicationSink {
   /**
    * Replicate this array of entries directly into the local cluster using the native client. Only
    * operates against raw protobuf type saving on a conversion from pb to pojo.
-   * @param entries                    WAL entries to be replicated.
-   * @param cells                      cell scanner for iteration.
    * @param replicationClusterId       Id which will uniquely identify source cluster FS client
    *                                   configurations in the replication configuration directory
    * @param sourceBaseNamespaceDirPath Path that point to the source cluster base namespace
@@ -187,8 +191,6 @@ public class ReplicationSink {
       Map<TableName, Map<List<UUID>, List<Row>>> rowMap = new TreeMap<>();
 
       Map<List<String>, Map<String, List<Pair<byte[], List<String>>>>> bulkLoadsPerClusters = null;
-      Pair<List<Mutation>, List<WALEntry>> mutationsToWalEntriesPairs =
-        new Pair<>(new ArrayList<>(), new ArrayList<>());
       for (WALEntry entry : entries) {
         TableName table = TableName.valueOf(entry.getKey().getTableName().toByteArray());
         if (this.walEntrySinkFilter != null) {
@@ -240,11 +242,6 @@ public class ReplicationSink {
                 clusterIds.add(toUUID(clusterId));
               }
               mutation.setClusterIds(clusterIds);
-              if (rsServerHost != null) {
-                rsServerHost.preReplicationSinkBatchMutate(entry, mutation);
-                mutationsToWalEntriesPairs.getFirst().add(mutation);
-                mutationsToWalEntriesPairs.getSecond().add(entry);
-              }
               addToHashMultiMap(rowMap, table, clusterIds, mutation);
             }
             if (CellUtil.isDelete(cell)) {
@@ -267,14 +264,6 @@ public class ReplicationSink {
         LOG.debug("Finished replicating mutations.");
       }
 
-      if (rsServerHost != null) {
-        List<Mutation> mutations = mutationsToWalEntriesPairs.getFirst();
-        List<WALEntry> walEntries = mutationsToWalEntriesPairs.getSecond();
-        for (int i = 0; i < mutations.size(); i++) {
-          rsServerHost.postReplicationSinkBatchMutate(walEntries.get(i), mutations.get(i));
-        }
-      }
-
       if (bulkLoadsPerClusters != null) {
         for (Entry<List<String>,
           Map<String, List<Pair<byte[], List<String>>>>> entry : bulkLoadsPerClusters.entrySet()) {
@@ -368,7 +357,9 @@ public class ReplicationSink {
       .append(Bytes.toString(family)).append(Path.SEPARATOR).append(storeFile).toString();
   }
 
-  /** Returns True if we have crossed over onto a new row or type */
+  /**
+   * nn * @return True if we have crossed over onto a new row or type
+   */
   private boolean isNewRowOrType(final Cell previousCell, final Cell cell) {
     return previousCell == null || previousCell.getTypeByte() != cell.getTypeByte()
       || !CellUtil.matchingRows(previousCell, cell);
@@ -379,8 +370,8 @@ public class ReplicationSink {
   }
 
   /**
-   * Simple helper to a map from key to (a list of) values TODO: Make a general utility method
-   * @return the list of values corresponding to key1 and key2
+   * Simple helper to a map from key to (a list of) values TODO: Make a general utility method nnnn
+   * * @return the list of values corresponding to key1 and key2
    */
   private <K1, K2, V> List<V> addToHashMultiMap(Map<K1, Map<K2, List<V>>> map, K1 key1, K2 key2,
     V value) {
@@ -395,16 +386,31 @@ public class ReplicationSink {
    */
   public void stopReplicationSinkServices() {
     try {
-      if (this.sharedHtableCon != null) {
-        synchronized (sharedHtableConLock) {
-          if (this.sharedHtableCon != null) {
-            this.sharedHtableCon.close();
-            this.sharedHtableCon = null;
+      if (this.sharedConnection != null) {
+        synchronized (sharedConnectionLock) {
+          if (this.sharedConnection != null) {
+            this.sharedConnection.close();
+            this.sharedConnection = null;
           }
         }
       }
     } catch (IOException e) {
-      LOG.warn("IOException while closing the connection", e); // ignoring as we are closing.
+      // ignoring as we are closing.
+      LOG.warn("IOException while closing the sharedConnection", e);
+    }
+
+    try {
+      if (this.sharedAsyncConnection != null) {
+        synchronized (sharedAsyncConnectionLock) {
+          if (this.sharedAsyncConnection != null) {
+            this.sharedAsyncConnection.close();
+            this.sharedAsyncConnection = null;
+          }
+        }
+      }
+    } catch (IOException e) {
+      // ignoring as we are closing.
+      LOG.warn("IOException while closing the sharedAsyncConnection", e);
     }
   }
 
@@ -419,51 +425,69 @@ public class ReplicationSink {
     if (allRows.isEmpty()) {
       return;
     }
-    Table table = null;
-    try {
-      Connection connection = getConnection();
-      table = connection.getTable(tableName);
-      for (List<Row> rows : allRows) {
-        List<List<Row>> batchRows;
-        if (rows.size() > batchRowSizeThreshold) {
-          batchRows = Lists.partition(rows, batchRowSizeThreshold);
-        } else {
-          batchRows = Collections.singletonList(rows);
-        }
-        for (List<Row> rowList : batchRows) {
-          table.batch(rowList, null);
-        }
+    AsyncTable<?> table = getAsyncConnection().getTable(tableName);
+    List<Future<?>> futures = new ArrayList<>();
+    for (List<Row> rows : allRows) {
+      List<List<Row>> batchRows;
+      if (rows.size() > batchRowSizeThreshold) {
+        batchRows = Lists.partition(rows, batchRowSizeThreshold);
+      } else {
+        batchRows = Collections.singletonList(rows);
       }
-    } catch (RetriesExhaustedWithDetailsException rewde) {
-      for (Throwable ex : rewde.getCauses()) {
-        if (ex instanceof TableNotFoundException) {
+      futures.addAll(batchRows.stream().map(table::batchAll).collect(Collectors.toList()));
+    }
+
+    for (Future<?> future : futures) {
+      try {
+        FutureUtils.get(future);
+      } catch (RetriesExhaustedException e) {
+        if (e.getCause() instanceof TableNotFoundException) {
           throw new TableNotFoundException("'" + tableName + "'");
         }
-      }
-      throw rewde;
-    } catch (InterruptedException ix) {
-      throw (InterruptedIOException) new InterruptedIOException().initCause(ix);
-    } finally {
-      if (table != null) {
-        table.close();
+        throw e;
       }
     }
   }
 
+  /**
+   * Return the shared {@link Connection} which is used for handling bulk load hfiles replication.
+   */
   private Connection getConnection() throws IOException {
     // See https://en.wikipedia.org/wiki/Double-checked_locking
-    Connection connection = sharedHtableCon;
+    Connection connection = sharedConnection;
     if (connection == null) {
-      synchronized (sharedHtableConLock) {
-        connection = sharedHtableCon;
+      synchronized (sharedConnectionLock) {
+        connection = sharedConnection;
         if (connection == null) {
-          connection = sharedHtableCon = ConnectionFactory.createConnection(conf);
+          connection = ConnectionFactory.createConnection(conf);
+          sharedConnection = connection;
         }
       }
     }
     return connection;
   }
 
+  /**
+   * Return the shared {@link AsyncConnection} which is used for handling wal replication.
+   */
+  private AsyncConnection getAsyncConnection() throws IOException {
+    // See https://en.wikipedia.org/wiki/Double-checked_locking
+    AsyncConnection asyncConnection = sharedAsyncConnection;
+    if (asyncConnection == null) {
+      synchronized (sharedAsyncConnectionLock) {
+        asyncConnection = sharedAsyncConnection;
+        if (asyncConnection == null) {
+          /**
+           * Get the AsyncConnection immediately.
+           */
+          asyncConnection = FutureUtils.get(ConnectionFactory.createAsyncConnection(conf));
+          sharedAsyncConnection = asyncConnection;
+        }
+      }
+    }
+    return asyncConnection;
+  }
+
   /**
    * Get a string representation of this sink's metrics
    * @return string with the total replicated edits count and the date of the last edit that was
@@ -477,7 +501,7 @@ public class ReplicationSink {
   }
 
   /**
-   * Get replication Sink Metrics
+   * Get replication Sink Metrics n
    */
   public MetricsSink getSinkMetrics() {
     return this.metrics;
