@@ -27,6 +27,7 @@ import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.client.ClusterConnection;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.replication.HBaseReplicationEndpoint;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -121,7 +122,7 @@ public class ReplicationSinkManager {
   /**
    * Report a {@code SinkPeer} as being bad (i.e. an attempt to replicate to it failed). If a single
    * SinkPeer is reported as bad more than replication.bad.sink.threshold times, it will be removed
-   * from the pool of potential replication targets. The SinkPeer that had a failed replication
+   * from the pool of potential replication targets. n * The SinkPeer that had a failed replication
    * attempt on it
    */
   public synchronized void reportBadSink(SinkPeer sinkPeer) {
@@ -138,8 +139,8 @@ public class ReplicationSinkManager {
   }
 
   /**
-   * Report that a {@code SinkPeer} successfully replicated a chunk of data. The SinkPeer that had a
-   * failed replication attempt on it
+   * Report that a {@code SinkPeer} successfully replicated a chunk of data. n * The SinkPeer that
+   * had a failed replication attempt on it
    */
   public synchronized void reportSinkSuccess(SinkPeer sinkPeer) {
     badReportCounts.remove(sinkPeer.getServerName());
@@ -156,7 +157,7 @@ public class ReplicationSinkManager {
     Collections.shuffle(slaveAddresses, random);
     int numSinks = (int) Math.ceil(slaveAddresses.size() * ratio);
     sinks = slaveAddresses.subList(0, numSinks);
-    lastUpdateToPeers = System.currentTimeMillis();
+    lastUpdateToPeers = EnvironmentEdgeManager.currentTime();
     badReportCounts.clear();
   }
 
