@@ -347,10 +347,12 @@ public class ReplicationSource implements ReplicationSourceInterface {
         ReplicationSourceShipper worker = createNewShipper(walGroupId);
         ReplicationSourceWALReader walReader =
           createNewWALReader(walGroupId, worker.getStartPosition());
-        Threads.setDaemonThreadRunning(walReader, Thread.currentThread().getName()
-          + ".replicationSource.wal-reader." + walGroupId + "," + queueId, this::retryRefreshing);
+        Threads.setDaemonThreadRunning(
+          walReader, Thread.currentThread().getName() + ".replicationSource.wal-reader."
+            + walGroupId + "," + queueId,
+          (t, e) -> this.uncaughtException(t, e, this.manager, this.getPeerId()));
         worker.setWALReader(walReader);
-        worker.startup(this::retryRefreshing);
+        worker.startup((t, e) -> this.uncaughtException(t, e, this.manager, this.getPeerId()));
         return worker;
       }
     });
@@ -423,30 +425,24 @@ public class ReplicationSource implements ReplicationSourceInterface {
     return walEntryFilter;
   }
 
-  // log the error, check if the error is OOME, or whether we should abort the server
-  private void checkError(Thread t, Throwable error) {
-    RSRpcServices.exitIfOOME(error);
-    LOG.error("Unexpected exception in {} currentPath={}", t.getName(), getCurrentPath(), error);
+  protected final void uncaughtException(Thread t, Throwable e, ReplicationSourceManager manager,
+    String peerId) {
+    RSRpcServices.exitIfOOME(e);
+    LOG.error("Unexpected exception in {} currentPath={}", t.getName(), getCurrentPath(), e);
     if (abortOnError) {
-      server.abort("Unexpected exception in " + t.getName(), error);
+      server.abort("Unexpected exception in " + t.getName(), e);
     }
-  }
-
-  private void retryRefreshing(Thread t, Throwable error) {
-    checkError(t, error);
-    while (true) {
-      if (server.isAborted() || server.isStopped() || server.isStopping()) {
-        LOG.warn("Server is shutting down, give up refreshing source for peer {}", getPeerId());
-        return;
-      }
-      try {
-        LOG.info("Refreshing replication sources now due to previous error on thread: {}",
-          t.getName());
-        manager.refreshSources(getPeerId());
-        break;
-      } catch (Exception e) {
-        LOG.error("Replication sources refresh failed.", e);
-        sleepForRetries("Sleeping before try refreshing sources again", maxRetriesMultiplier);
+    if (manager != null) {
+      while (true) {
+        try {
+          LOG.info("Refreshing replication sources now due to previous error on thread: {}",
+            t.getName());
+          manager.refreshSources(peerId);
+          break;
+        } catch (IOException e1) {
+          LOG.error("Replication sources refresh failed.", e1);
+          sleepForRetries("Sleeping before try refreshing sources again", maxRetriesMultiplier);
+        }
       }
     }
   }
@@ -556,10 +552,15 @@ public class ReplicationSource implements ReplicationSourceInterface {
     }
 
     if (!this.isSourceActive()) {
-      // this means the server is shutting down or the source is terminated, just give up
-      // initializing
       setSourceStartupStatus(false);
-      return;
+      if (Thread.currentThread().isInterrupted()) {
+        // If source is not running and thread is interrupted this means someone has tried to
+        // remove this peer.
+        return;
+      }
+
+      retryStartup.set(!this.abortOnError);
+      throw new IllegalStateException("Source should be active.");
     }
 
     sleepMultiplier = 1;
@@ -581,12 +582,15 @@ public class ReplicationSource implements ReplicationSourceInterface {
     }
 
     if (!this.isSourceActive()) {
-      // this means the server is shutting down or the source is terminated, just give up
-      // initializing
       setSourceStartupStatus(false);
-      return;
+      if (Thread.currentThread().isInterrupted()) {
+        // If source is not running and thread is interrupted this means someone has tried to
+        // remove this peer.
+        return;
+      }
+      retryStartup.set(!this.abortOnError);
+      throw new IllegalStateException("Source should be active.");
     }
-
     LOG.info("{} queueId={} (queues={}) is replicating from cluster={} to cluster={}", logPeerId(),
       this.replicationQueueInfo.getQueueId(), logQueue.getNumQueues(), clusterId, peerClusterId);
     initializeWALEntryFilter(peerClusterId);
@@ -620,7 +624,7 @@ public class ReplicationSource implements ReplicationSourceInterface {
         // keep looping in this thread until initialize eventually succeeds,
         // while the server main startup one can go on with its work.
         sourceRunning = false;
-        checkError(t, e);
+        uncaughtException(t, e, null, null);
         retryStartup.set(!this.abortOnError);
         do {
           if (retryStartup.get()) {
@@ -631,7 +635,7 @@ public class ReplicationSource implements ReplicationSourceInterface {
               initialize();
             } catch (Throwable error) {
               setSourceStartupStatus(false);
-              checkError(t, error);
+              uncaughtException(t, error, null, null);
               retryStartup.set(!this.abortOnError);
             }
           }
@@ -723,13 +727,10 @@ public class ReplicationSource implements ReplicationSourceInterface {
         }
       }
     }
-
-    // Can be null in test context.
-    if (this.metrics != null) {
-      if (clearMetrics) {
+    if (clearMetrics) {
+      // Can be null in test context.
+      if (this.metrics != null) {
         this.metrics.clear();
-      } else {
-        this.metrics.terminate();
       }
     }
   }
@@ -788,7 +789,7 @@ public class ReplicationSource implements ReplicationSourceInterface {
         sb.append("currently replicating from: ").append(currentPath).append(" at position: ")
           .append(position).append("\n");
       } else {
-        sb.append("no replication ongoing, waiting for new log").append("\n");
+        sb.append("no replication ongoing, waiting for new log");
       }
     }
     return sb.toString();
