@@ -569,14 +569,6 @@ public class VisibilityController implements MasterCoprocessor, RegionCoprocesso
     scannerOwners.remove(s);
   }
 
-  @Override
-  @Deprecated // Removed in later versions by HBASE-25277
-  public boolean postScannerFilterRow(final ObserverContext<RegionCoprocessorEnvironment> e,
-    final InternalScanner s, final Cell curRowCell, final boolean hasMore) throws IOException {
-    // 'default' in RegionObserver might do unnecessary copy for Off heap backed Cells.
-    return hasMore;
-  }
-
   /**
    * Verify, when servicing an RPC, that the caller is the scanner owner. If so, we assume that
    * access control is correctly enforced based on the checks performed in preScannerOpen()
@@ -1020,7 +1012,9 @@ public class VisibilityController implements MasterCoprocessor, RegionCoprocesso
     }
   }
 
-  /** Returns NameValuePair of the exception name to stringified version os exception. */
+  /**
+   * n * @return NameValuePair of the exception name to stringified version os exception.
+   */
   // Copied from ResponseConverter and made private. Only used in here.
   private static NameBytesPair buildException(final Throwable t) {
     NameBytesPair.Builder parameterBuilder = NameBytesPair.newBuilder();
