@@ -17,6 +17,8 @@
  */
 package org.apache.hadoop.hbase.util;
 
+import static org.apache.hadoop.hdfs.protocol.HdfsConstants.SafeModeAction.SAFEMODE_GET;
+
 import edu.umd.cs.findbugs.annotations.CheckForNull;
 import java.io.ByteArrayInputStream;
 import java.io.DataInputStream;
@@ -78,9 +80,12 @@ import org.apache.hadoop.hdfs.DFSClient;
 import org.apache.hadoop.hdfs.DFSHedgedReadMetrics;
 import org.apache.hadoop.hdfs.DFSUtil;
 import org.apache.hadoop.hdfs.DistributedFileSystem;
-import org.apache.hadoop.hdfs.protocol.HdfsConstants;
+import org.apache.hadoop.hdfs.client.HdfsDataInputStream;
+import org.apache.hadoop.hdfs.protocol.DatanodeInfo;
+import org.apache.hadoop.hdfs.protocol.LocatedBlock;
 import org.apache.hadoop.io.IOUtils;
 import org.apache.hadoop.ipc.RemoteException;
+import org.apache.hadoop.util.Progressable;
 import org.apache.hadoop.util.StringUtils;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
@@ -127,8 +132,8 @@ public final class FSUtils {
    * Compare path component of the Path URI; e.g. if hdfs://a/b/c and /a/b/c, it will compare the
    * '/a/b/c' part. If you passed in 'hdfs://a/b/c and b/c, it would return true. Does not consider
    * schema; i.e. if schemas different but path or subpath matches, the two will equate.
-   * @param pathToSearch Path we will be trying to match.
-   * @return True if <code>pathTail</code> is tail on the path of <code>pathToSearch</code>
+   * @param pathToSearch Path we will be trying to match. n * @return True if <code>pathTail</code>
+   *                     is tail on the path of <code>pathToSearch</code>
    */
   public static boolean isMatchingTail(final Path pathToSearch, final Path pathTail) {
     Path tailPath = pathTail;
@@ -160,7 +165,7 @@ public final class FSUtils {
 
   /**
    * Delete the region directory if exists.
-   * @return True if deleted the region directory.
+   * @return True if deleted the region directory. n
    */
   public static boolean deleteRegionDir(final Configuration conf, final RegionInfo hri)
     throws IOException {
@@ -194,20 +199,27 @@ public final class FSUtils {
     if (fs instanceof HFileSystem) {
       FileSystem backingFs = ((HFileSystem) fs).getBackingFs();
       if (backingFs instanceof DistributedFileSystem) {
+        // Try to use the favoredNodes version via reflection to allow backwards-
+        // compatibility.
         short replication = Short.parseShort(conf.get(ColumnFamilyDescriptorBuilder.DFS_REPLICATION,
           String.valueOf(ColumnFamilyDescriptorBuilder.DEFAULT_DFS_REPLICATION)));
-        DistributedFileSystem.HdfsDataOutputStreamBuilder builder =
-          ((DistributedFileSystem) backingFs).createFile(path).recursive().permission(perm)
-            .create();
-        if (favoredNodes != null) {
-          builder.favoredNodes(favoredNodes);
+        try {
+          return (FSDataOutputStream) (DistributedFileSystem.class
+            .getDeclaredMethod("create", Path.class, FsPermission.class, boolean.class, int.class,
+              short.class, long.class, Progressable.class, InetSocketAddress[].class)
+            .invoke(backingFs, path, perm, true, CommonFSUtils.getDefaultBufferSize(backingFs),
+              replication > 0 ? replication : CommonFSUtils.getDefaultReplication(backingFs, path),
+              CommonFSUtils.getDefaultBlockSize(backingFs, path), null, favoredNodes));
+        } catch (InvocationTargetException ite) {
+          // Function was properly called, but threw it's own exception.
+          throw new IOException(ite.getCause());
+        } catch (NoSuchMethodException e) {
+          LOG.debug("DFS Client does not support most favored nodes create; using default create");
+          LOG.trace("Ignoring; use default create", e);
+        } catch (IllegalArgumentException | SecurityException | IllegalAccessException e) {
+          LOG.debug("Ignoring (most likely Reflection related exception) " + e);
         }
-        if (replication > 0) {
-          builder.replication(replication);
-        }
-        return builder.build();
       }
-
     }
     return CommonFSUtils.create(fs, path, perm, true);
   }
@@ -239,30 +251,16 @@ public final class FSUtils {
   }
 
   /**
-   * We use reflection because
-   * {@link DistributedFileSystem#setSafeMode( HdfsConstants.SafeModeAction action, boolean isChecked)}
-   * is not in hadoop 1.1
-   * @return whether we're in safe mode
+   * Inquire the Active NameNode's safe mode status.
+   * @param dfs A DistributedFileSystem object representing the underlying HDFS.
+   * @return whether we're in safe mode n
    */
   private static boolean isInSafeMode(DistributedFileSystem dfs) throws IOException {
-    boolean inSafeMode = false;
-    try {
-      Method m = DistributedFileSystem.class.getMethod("setSafeMode", new Class<?>[] {
-        org.apache.hadoop.hdfs.protocol.HdfsConstants.SafeModeAction.class, boolean.class });
-      inSafeMode = (Boolean) m.invoke(dfs,
-        org.apache.hadoop.hdfs.protocol.HdfsConstants.SafeModeAction.SAFEMODE_GET, true);
-    } catch (Exception e) {
-      if (e instanceof IOException) throw (IOException) e;
-
-      // Check whether dfs is on safemode.
-      inSafeMode =
-        dfs.setSafeMode(org.apache.hadoop.hdfs.protocol.HdfsConstants.SafeModeAction.SAFEMODE_GET);
-    }
-    return inSafeMode;
+    return dfs.setSafeMode(SAFEMODE_GET, true);
   }
 
   /**
-   * Check whether dfs is in safemode.
+   * Check whether dfs is in safemode. nn
    */
   public static void checkDfsSafeMode(final Configuration conf) throws IOException {
     boolean isInSafeMode = false;
@@ -568,12 +566,13 @@ public final class FSUtils {
   }
 
   /**
-   *   */
+   * nn
+   */
   private static void rewriteAsPb(final FileSystem fs, final Path rootdir, final Path p,
     final ClusterId cid) throws IOException {
     // Rewrite the file as pb. Move aside the old one first, write new
     // then delete the moved-aside file.
-    Path movedAsideName = new Path(p + "." + System.currentTimeMillis());
+    Path movedAsideName = new Path(p + "." + EnvironmentEdgeManager.currentTime());
     if (!fs.rename(p, movedAsideName)) throw new IOException("Failed rename of " + p);
     setClusterId(fs, rootdir, cid, 100);
     if (!fs.delete(movedAsideName, false)) {
@@ -669,6 +668,37 @@ public final class FSUtils {
     return fs.exists(metaRegionDir);
   }
 
+  /**
+   * Compute HDFS block distribution of a given HdfsDataInputStream. All HdfsDataInputStreams are
+   * backed by a series of LocatedBlocks, which are fetched periodically from the namenode. This
+   * method retrieves those blocks from the input stream and uses them to calculate
+   * HDFSBlockDistribution. The underlying method in DFSInputStream does attempt to use locally
+   * cached blocks, but may hit the namenode if the cache is determined to be incomplete. The method
+   * also involves making copies of all LocatedBlocks rather than return the underlying blocks
+   * themselves.
+   */
+  public static HDFSBlocksDistribution
+    computeHDFSBlocksDistribution(HdfsDataInputStream inputStream) throws IOException {
+    List<LocatedBlock> blocks = inputStream.getAllBlocks();
+    HDFSBlocksDistribution blocksDistribution = new HDFSBlocksDistribution();
+    for (LocatedBlock block : blocks) {
+      String[] hosts = getHostsForLocations(block);
+      long len = block.getBlockSize();
+      StorageType[] storageTypes = block.getStorageTypes();
+      blocksDistribution.addHostsAndBlockWeight(hosts, len, storageTypes);
+    }
+    return blocksDistribution;
+  }
+
+  private static String[] getHostsForLocations(LocatedBlock block) {
+    DatanodeInfo[] locations = block.getLocations();
+    String[] hosts = new String[locations.length];
+    for (int i = 0; i < hosts.length; i++) {
+      hosts[i] = locations[i].getHostName();
+    }
+    return hosts;
+  }
+
   /**
    * Compute HDFS blocks distribution of a given file, or a portion of the file
    * @param fs     file system
@@ -883,8 +913,8 @@ public final class FSUtils {
   }
 
   /**
-   * @return All the table directories under <code>rootdir</code>. Ignore non table hbase folders
-   *         such as .logs, .oldlogs, .corrupt folders.
+   * nn * @return All the table directories under <code>rootdir</code>. Ignore non table hbase
+   * folders such as .logs, .oldlogs, .corrupt folders. n
    */
   public static List<Path> getLocalTableDirs(final FileSystem fs, final Path rootdir)
     throws IOException {
@@ -930,7 +960,7 @@ public final class FSUtils {
    * .tableinfo
    * @param fs       A file system for the Path
    * @param tableDir Path to a specific table directory &lt;hbase.rootdir&gt;/&lt;tabledir&gt;
-   * @return List of paths to valid region directories in table dir.
+   * @return List of paths to valid region directories in table dir. n
    */
   public static List<Path> getRegionDirs(final FileSystem fs, final Path tableDir)
     throws IOException {
@@ -995,7 +1025,7 @@ public final class FSUtils {
    * Given a particular region dir, return all the familydirs inside it
    * @param fs        A file system for the Path
    * @param regionDir Path to a specific region directory
-   * @return List of paths to valid family directories in region dir.
+   * @return List of paths to valid family directories in region dir. n
    */
   public static List<Path> getFamilyDirs(final FileSystem fs, final Path regionDir)
     throws IOException {
@@ -1070,7 +1100,7 @@ public final class FSUtils {
 
     @Override
     protected boolean accept(Path p, @CheckForNull Boolean isDir) {
-      if (!StoreFileInfo.isHFile(p)) {
+      if (!StoreFileInfo.isHFile(p) && !StoreFileInfo.isMobFile(p)) {
         return false;
       }
 
@@ -1143,7 +1173,7 @@ public final class FSUtils {
    * @param hbaseRootDir The root directory to scan.
    * @param tableName    name of the table to scan.
    * @return Map keyed by StoreFile name with a value of the full Path.
-   * @throws IOException When scanning the directory fails.
+   * @throws IOException When scanning the directory fails. n
    */
   public static Map<String, Path> getTableStoreFilePathMap(Map<String, Path> map,
     final FileSystem fs, final Path hbaseRootDir, TableName tableName)
@@ -1399,7 +1429,7 @@ public final class FSUtils {
    * @param progressReporter Instance or null; gets called every time we move to new region of
    *                         family dir and for each store file.
    * @return Map keyed by StoreFile name with a value of the full Path.
-   * @throws IOException When scanning the directory fails.
+   * @throws IOException When scanning the directory fails. n
    */
   public static Map<String, Path> getTableStoreFilePathMap(final FileSystem fs,
     final Path hbaseRootDir, PathFilter sfFilter, ExecutorService executor,
@@ -1485,10 +1515,10 @@ public final class FSUtils {
   /**
    * This function is to scan the root path of the file system to get the degree of locality for
    * each region on each of the servers having at least one block of that region. This is used by
-   * the tool {@link org.apache.hadoop.hbase.master.RegionPlacementMaintainer} the configuration to
-   * use
-   * @return the mapping from region encoded name to a map of server names to locality fraction in
-   *         case of file system errors or interrupts
+   * the tool {@link org.apache.hadoop.hbase.master.RegionPlacementMaintainer} n * the configuration
+   * to use
+   * @return the mapping from region encoded name to a map of server names to locality fraction n *
+   *         in case of file system errors or interrupts
    */
   public static Map<String, Map<String, Float>>
     getRegionDegreeLocalityMappingFromFS(final Configuration conf) throws IOException {
@@ -1499,10 +1529,11 @@ public final class FSUtils {
 
   /**
    * This function is to scan the root path of the file system to get the degree of locality for
-   * each region on each of the servers having at least one block of that region. the configuration
-   * to use the table you wish to scan locality for the thread pool size to use
-   * @return the mapping from region encoded name to a map of server names to locality fraction in
-   *         case of file system errors or interrupts
+   * each region on each of the servers having at least one block of that region. n * the
+   * configuration to use n * the table you wish to scan locality for n * the thread pool size to
+   * use
+   * @return the mapping from region encoded name to a map of server names to locality fraction n *
+   *         in case of file system errors or interrupts
    */
   public static Map<String, Map<String, Float>> getRegionDegreeLocalityMappingFromFS(
     final Configuration conf, final String desiredTable, int threadPoolSize) throws IOException {
@@ -1515,9 +1546,9 @@ public final class FSUtils {
    * This function is to scan the root path of the file system to get either the mapping between the
    * region name and its best locality region server or the degree of locality of each region on
    * each of the servers having at least one block of that region. The output map parameters are
-   * both optional. the configuration to use the table you wish to scan locality for the thread pool
-   * size to use the map into which to put the locality degree mapping or null, must be a
-   * thread-safe implementation in case of file system errors or interrupts
+   * both optional. n * the configuration to use n * the table you wish to scan locality for n * the
+   * thread pool size to use n * the map into which to put the locality degree mapping or null, must
+   * be a thread-safe implementation n * in case of file system errors or interrupts
    */
   private static void getRegionLocalityMappingFromFS(final Configuration conf,
     final String desiredTable, int threadPoolSize,
@@ -1617,7 +1648,7 @@ public final class FSUtils {
 
   /**
    * Do our short circuit read setup. Checks buffer size to use and whether to do checksumming in
-   * hbase or hdfs.
+   * hbase or hdfs. n
    */
   public static void setupShortCircuitRead(final Configuration conf) {
     // Check that the user has not set the "dfs.client.read.shortcircuit.skip.checksum" property.
@@ -1637,7 +1668,7 @@ public final class FSUtils {
   }
 
   /**
-   * Check if short circuit read buffer size is set and if not, set it to hbase value.
+   * Check if short circuit read buffer size is set and if not, set it to hbase value. n
    */
   public static void checkShortCircuitReadBufferSize(final Configuration conf) {
     final int defaultSize = HConstants.DEFAULT_BLOCKSIZE * 2;
@@ -1653,7 +1684,8 @@ public final class FSUtils {
   }
 
   /**
-   * Returns The DFSClient DFSHedgedReadMetrics instance or null if can't be found or not on hdfs.
+   * n * @return The DFSClient DFSHedgedReadMetrics instance or null if can't be found or not on
+   * hdfs. n
    */
   public static DFSHedgedReadMetrics getDFSHedgedReadMetrics(final Configuration c)
     throws IOException {
