@@ -73,8 +73,7 @@ public class JVMClusterUtil {
    * Creates a {@link RegionServerThread}. Call 'start' on the returned thread to make it run.
    * @param c     Configuration to use.
    * @param hrsc  Class to create.
-   * @param index Used distinguishing the object returned.
-   * @return Region server added.
+   * @param index Used distinguishing the object returned. n * @return Region server added.
    */
   public static JVMClusterUtil.RegionServerThread createRegionServerThread(final Configuration c,
     final Class<? extends HRegionServer> hrsc, final int index) throws IOException {
@@ -114,8 +113,7 @@ public class JVMClusterUtil {
    * Creates a {@link MasterThread}. Call 'start' on the returned thread to make it run.
    * @param c     Configuration to use.
    * @param hmc   Class to create.
-   * @param index Used distinguishing the object returned.
-   * @return Master added.
+   * @param index Used distinguishing the object returned. n * @return Master added.
    */
   public static JVMClusterUtil.MasterThread createMasterThread(final Configuration c,
     final Class<? extends HMaster> hmc, final int index) throws IOException {
@@ -150,7 +148,7 @@ public class JVMClusterUtil {
 
   /**
    * Start the cluster. Waits until there is a primary master initialized and returns its address.
-   * @return Address to use contacting primary master.
+   * nn * @return Address to use contacting primary master.
    */
   public static String startup(final List<JVMClusterUtil.MasterThread> masters,
     final List<JVMClusterUtil.RegionServerThread> regionservers) throws IOException {
@@ -231,7 +229,8 @@ public class JVMClusterUtil {
   }
 
   /**
-   *   */
+   * nn
+   */
   public static void shutdown(final List<MasterThread> masters,
     final List<RegionServerThread> regionservers) {
     LOG.debug("Shutting down HBase Cluster");
@@ -269,14 +268,14 @@ public class JVMClusterUtil {
       }
     }
     boolean wasInterrupted = false;
-    final long maxTime = System.currentTimeMillis() + 30 * 1000;
+    final long maxTime = EnvironmentEdgeManager.currentTime() + 30 * 1000;
     if (regionservers != null) {
       // first try nicely.
       for (RegionServerThread t : regionservers) {
         t.getRegionServer().stop("Shutdown requested");
       }
       for (RegionServerThread t : regionservers) {
-        long now = System.currentTimeMillis();
+        long now = EnvironmentEdgeManager.currentTime();
         if (t.isAlive() && !wasInterrupted && now < maxTime) {
           try {
             t.join(maxTime - now);
