@@ -397,11 +397,10 @@ public abstract class AbstractFSWALProvider<T extends AbstractFSWAL<?>> implemen
       serverName = ServerName.parseServerName(logDirName);
     } catch (IllegalArgumentException | IllegalStateException ex) {
       serverName = null;
-      LOG.warn("Cannot parse a server name from path={}", logFile, ex);
+      LOG.warn("Cannot parse a server name from path=" + logFile + "; " + ex.getMessage());
     }
     if (serverName != null && serverName.getStartcode() < 0) {
-      LOG.warn("Invalid log file path={}, start code {} is less than 0", logFile,
-        serverName.getStartcode());
+      LOG.warn("Invalid log file path=" + logFile);
       serverName = null;
     }
     return serverName;
@@ -466,11 +465,6 @@ public abstract class AbstractFSWALProvider<T extends AbstractFSWAL<?>> implemen
     }
 
     ServerName serverName = getServerNameFromWALDirectoryName(path);
-    if (serverName == null) {
-      LOG.warn("Can not extract server name from path {}, "
-        + "give up searching the separated old log dir", path);
-      return null;
-    }
     // Try finding the log in separate old log dir
     oldLogDir = new Path(walRootDir, new StringBuilder(HConstants.HREGION_OLDLOGDIR_NAME)
       .append(Path.SEPARATOR).append(serverName.getServerName()).toString());
@@ -489,9 +483,8 @@ public abstract class AbstractFSWALProvider<T extends AbstractFSWAL<?>> implemen
    * @param conf configuration
    * @return WAL Reader instance
    */
-  @edu.umd.cs.findbugs.annotations.SuppressWarnings(value = "DCN_NULLPOINTER_EXCEPTION",
-      justification = "HDFS-4380")
-  public static WAL.Reader openReader(Path path, Configuration conf) throws IOException {
+  public static org.apache.hadoop.hbase.wal.WAL.Reader openReader(Path path, Configuration conf)
+    throws IOException {
     long retryInterval = 2000; // 2 sec
     int maxAttempts = 30;
     int attempt = 0;
