@@ -104,23 +104,16 @@ public class WALPrettyPrinter {
   }
 
   /**
-   * Fully specified constructor.
-   * @param outputValues     when true, enables output of values along with other log information
-   * @param outputJSON       when true, enables output in JSON format rather than a "pretty string"
-   * @param sequence         when nonnegative, serves as a filter; only log entries with this
-   *                         sequence id will be printed
-   * @param tableSet         when non null, serves as a filter. only entries corresponding to tables
-   *                         in the tableSet are printed
-   * @param region           when not null, serves as a filter; only log entries from this region
-   *                         will be printed
-   * @param row              when not null, serves as a filter; only log entries from this row will
-   *                         be printed
-   * @param rowPrefix        when not null, serves as a filter; only log entries with row key having
-   *                         this prefix will be printed
-   * @param persistentOutput keeps a single list running for multiple files. if enabled, the
-   *                         endPersistentOutput() method must be used!
-   * @param out              Specifies an alternative to stdout for the destination of this
-   *                         PrettyPrinter's output.
+   * Fully specified constructor. n * when true, enables output of values along with other log
+   * information n * when true, enables output in JSON format rather than a "pretty string" n * when
+   * nonnegative, serves as a filter; only log entries with this sequence id will be printed n *
+   * when non null, serves as a filter. only entries corresponding to tables in the tableSet are
+   * printed n * when not null, serves as a filter; only log entries from this region will be
+   * printed n * when not null, serves as a filter; only log entries from this row will be printed n
+   * * when not null, serves as a filter; only log entries with row key having this prefix will be
+   * printed n * keeps a single list running for multiple files. if enabled, the
+   * endPersistentOutput() method must be used! n * Specifies an alternative to stdout for the
+   * destination of this PrettyPrinter's output.
    */
   public WALPrettyPrinter(boolean outputValues, boolean outputJSON, long sequence,
     Set<String> tableSet, String region, String row, String rowPrefix, boolean outputOnlyRowKey,
@@ -170,8 +163,8 @@ public class WALPrettyPrinter {
   }
 
   /**
-   * sets the region by which output will be filtered when nonnegative, serves as a filter; only log
-   * entries with this sequence id will be printed
+   * sets the region by which output will be filtered n * when nonnegative, serves as a filter; only
+   * log entries with this sequence id will be printed
    */
   public void setSequenceFilter(long sequence) {
     this.sequence = sequence;
@@ -186,23 +179,23 @@ public class WALPrettyPrinter {
   }
 
   /**
-   * sets the region by which output will be filtered when not null, serves as a filter; only log
-   * entries from this region will be printed
+   * sets the region by which output will be filtered n * when not null, serves as a filter; only
+   * log entries from this region will be printed
    */
   public void setRegionFilter(String region) {
     this.region = region;
   }
 
   /**
-   * sets the row key by which output will be filtered when not null, serves as a filter; only log
-   * entries from this row will be printed
+   * sets the row key by which output will be filtered n * when not null, serves as a filter; only
+   * log entries from this row will be printed
    */
   public void setRowFilter(String row) {
     this.row = row;
   }
 
   /**
-   * sets the rowPrefix key prefix by which output will be filtered when not null, serves as a
+   * sets the rowPrefix key prefix by which output will be filtered n * when not null, serves as a
    * filter; only log entries with rows having this prefix will be printed
    */
   public void setRowPrefixFilter(String rowPrefix) {
@@ -217,8 +210,8 @@ public class WALPrettyPrinter {
   }
 
   /**
-   * sets the position to start seeking the WAL file initial position to start seeking the given WAL
-   * file
+   * sets the position to start seeking the WAL file n * initial position to start seeking the given
+   * WAL file
    */
   public void setPosition(long position) {
     this.position = position;
@@ -254,8 +247,9 @@ public class WALPrettyPrinter {
 
   /**
    * reads a log file and outputs its contents, one transaction at a time, as specified by the
-   * currently configured options the HBase configuration relevant to this log file the path of the
-   * log file to be read may be unable to access the configured filesystem or requested file.
+   * currently configured options n * the HBase configuration relevant to this log file n * the path
+   * of the log file to be read n * may be unable to access the configured filesystem or requested
+   * file.
    */
   public void processFile(final Configuration conf, final Path p) throws IOException {
     FileSystem fs = p.getFileSystem(conf);
@@ -371,6 +365,7 @@ public class WALPrettyPrinter {
     }
 
     rowDetails += ", column=" + op.get("family") + ":" + op.get("qualifier");
+    rowDetails += ", timestamp=" + op.get("timestamp");
     rowDetails += ", type=" + op.get("type");
     out.println(rowDetails);
     if (op.get("tag") != null) {
@@ -434,7 +429,8 @@ public class WALPrettyPrinter {
 
   /**
    * Pass one or more log file names and formatting options and it will dump out a text version of
-   * the contents on <code>stdout</code>. Command line arguments Thrown upon file system errors etc.
+   * the contents on <code>stdout</code>. n * Command line arguments n * Thrown upon file system
+   * errors etc.
    */
   public static void run(String[] args) throws IOException {
     // create options
