@@ -20,8 +20,6 @@ package org.apache.hadoop.hbase;
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.util.NavigableMap;
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
@@ -50,7 +48,7 @@ import org.slf4j.LoggerFactory;
  * @see <a href="https://issues.apache.org/jira/browse/HBASE-11912">HBASE-11912</a>
  */
 @Deprecated
-public abstract class HBaseTestCase extends TestCase {
+public abstract class HBaseTestCase extends junit.framework.TestCase {
   private static final Logger LOG = LoggerFactory.getLogger(HBaseTestCase.class);
 
   protected final static byte[] fam1 = Bytes.toBytes("colfamily11");
@@ -88,7 +86,8 @@ public abstract class HBaseTestCase extends TestCase {
   }
 
   /**
-   *   */
+   * n
+   */
   public HBaseTestCase(String name) {
     super(name);
   }
@@ -135,8 +134,7 @@ public abstract class HBaseTestCase extends TestCase {
   }
 
   /**
-   * @see HBaseTestingUtility#getBaseTestDir
-   * @return directory to use for this test
+   * @see HBaseTestingUtility#getBaseTestDir n * @return directory to use for this test
    */
   protected Path getUnitTestdir(String testName) {
     return testUtil.getDataTestDir(testName);
@@ -145,7 +143,7 @@ public abstract class HBaseTestCase extends TestCase {
   /**
    * You must call close on the returned region and then close on the log file it created. Do
    * {@link HBaseTestingUtility#closeRegionAndWAL(HRegion)} to close both the region and the WAL.
-   * @return An {@link HRegion}
+   * nnn * @return An {@link HRegion} n
    */
   public HRegion createNewHRegion(HTableDescriptor desc, byte[] startKey, byte[] endKey)
     throws IOException {
@@ -201,8 +199,7 @@ public abstract class HBaseTestCase extends TestCase {
 
   /**
    * Add content to region <code>r</code> on the passed column <code>column</code>. Adds data of the
-   * from 'aaa', 'aab', etc where key and value are the same.
-   * @return count of what we added.
+   * from 'aaa', 'aab', etc where key and value are the same. nnnn * @return count of what we added.
    */
   public static long addContent(final Region r, final byte[] columnFamily, final byte[] column)
     throws IOException {
@@ -222,8 +219,7 @@ public abstract class HBaseTestCase extends TestCase {
 
   /**
    * Add content to region <code>r</code> on the passed column <code>column</code>. Adds data of the
-   * from 'aaa', 'aab', etc where key and value are the same.
-   * @return count of what we added.
+   * from 'aaa', 'aab', etc where key and value are the same. n * @return count of what we added.
    */
   public static long addContent(final Table updater, final String columnFamily) throws IOException {
     return addContent(updater, columnFamily, START_KEY_BYTES, null);
@@ -237,7 +233,7 @@ public abstract class HBaseTestCase extends TestCase {
   /**
    * Add content to region <code>r</code> on the passed column <code>column</code>. Adds data of the
    * from 'aaa', 'aab', etc where key and value are the same.
-   * @return count of what we added.
+   * @return count of what we added. n
    */
   public static long addContent(final Table updater, final String columnFamily,
     final byte[] startKeyBytes, final byte[] endKey) throws IOException {
@@ -252,7 +248,7 @@ public abstract class HBaseTestCase extends TestCase {
   /**
    * Add content to region <code>r</code> on the passed column <code>column</code>. Adds data of the
    * from 'aaa', 'aab', etc where key and value are the same.
-   * @return count of what we added.
+   * @return count of what we added. n
    */
   public static long addContent(final Table updater, final String columnFamily, final String column,
     final byte[] startKeyBytes, final byte[] endKey, final long ts) throws IOException {
@@ -351,7 +347,7 @@ public abstract class HBaseTestCase extends TestCase {
   }
 
   /**
-   * Common method to close down a MiniDFSCluster and the associated file system
+   * Common method to close down a MiniDFSCluster and the associated file system n
    */
   public static void shutdownDfs(MiniDFSCluster cluster) {
     if (cluster != null) {
@@ -378,6 +374,7 @@ public abstract class HBaseTestCase extends TestCase {
 
   /**
    * You must call {@link #closeRootAndMeta()} when done after calling this method. It does cleanup.
+   * n
    */
   protected void createMetaRegion() throws IOException {
     FSTableDescriptors fsTableDescriptors = new FSTableDescriptors(conf);
@@ -391,15 +388,15 @@ public abstract class HBaseTestCase extends TestCase {
 
   public static void assertByteEquals(byte[] expected, byte[] actual) {
     if (Bytes.compareTo(expected, actual) != 0) {
-      throw new AssertionFailedError(
+      throw new junit.framework.AssertionFailedError(
         "expected:<" + Bytes.toString(expected) + "> but was:<" + Bytes.toString(actual) + ">");
     }
   }
 
   public static void assertEquals(byte[] expected, byte[] actual) {
     if (Bytes.compareTo(expected, actual) != 0) {
-      throw new AssertionFailedError("expected:<" + Bytes.toStringBinary(expected) + "> but was:<"
-        + Bytes.toStringBinary(actual) + ">");
+      throw new junit.framework.AssertionFailedError("expected:<" + Bytes.toStringBinary(expected)
+        + "> but was:<" + Bytes.toStringBinary(actual) + ">");
     }
   }
 }
