@@ -37,6 +37,7 @@ import org.apache.hadoop.hbase.io.hfile.HFileContextBuilder;
 import org.apache.hadoop.hbase.io.hfile.HFileScanner;
 import org.apache.hadoop.hbase.io.hfile.HFileWriterImpl;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.yetus.audience.InterfaceAudience;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -97,7 +98,7 @@ public class HFilePerformanceEvaluation {
 
   /**
    * Add any supported codec or cipher to test the HFile read/write performance. Specify "none" to
-   * disable codec or cipher or both.
+   * disable codec or cipher or both. n
    */
   private void runBenchmarks() throws Exception {
     final Configuration conf = new Configuration();
@@ -163,9 +164,9 @@ public class HFilePerformanceEvaluation {
   }
 
   /**
-   * Write a test HFile with the given codec & cipher
-   * @param codec  "none", "lzo", "gz", "snappy"
-   * @param cipher "none", "aes"
+   * Write a test HFile with the given codec & cipher nnn * @param codec "none", "lzo", "gz",
+   * "snappy"
+   * @param cipher "none", "aes" n
    */
   private void runWriteBenchmark(Configuration conf, FileSystem fs, Path mf, String codec,
     String cipher) throws Exception {
@@ -179,8 +180,7 @@ public class HFilePerformanceEvaluation {
   }
 
   /**
-   * Run all the read benchmarks for the test HFile
-   * @param codec  "none", "lzo", "gz", "snappy"
+   * Run all the read benchmarks for the test HFile nnn * @param codec "none", "lzo", "gz", "snappy"
    * @param cipher "none", "aes"
    */
   private void runReadBenchmark(final Configuration conf, final FileSystem fs, final Path mf,
@@ -297,12 +297,12 @@ public class HFilePerformanceEvaluation {
 
     /**
      * Run benchmark
-     * @return elapsed time.
+     * @return elapsed time. n
      */
     long run() throws Exception {
       long elapsedTime;
       setUp();
-      long startTime = System.currentTimeMillis();
+      long startTime = EnvironmentEdgeManager.currentTime();
       try {
         for (int i = 0; i < totalRows; i++) {
           if (i > 0 && i % getReportingPeriod() == 0) {
@@ -310,7 +310,7 @@ public class HFilePerformanceEvaluation {
           }
           doRow(i);
         }
-        elapsedTime = System.currentTimeMillis() - startTime;
+        elapsedTime = EnvironmentEdgeManager.currentTime() - startTime;
       } finally {
         tearDown();
       }
@@ -401,7 +401,7 @@ public class HFilePerformanceEvaluation {
     @Override
     void setUp() throws Exception {
       super.setUp();
-      this.scanner = this.reader.getScanner(false, false);
+      this.scanner = this.reader.getScanner(conf, false, false);
       this.scanner.seekTo();
     }
 
@@ -430,7 +430,7 @@ public class HFilePerformanceEvaluation {
 
     @Override
     void doRow(int i) throws Exception {
-      HFileScanner scanner = this.reader.getScanner(false, true);
+      HFileScanner scanner = this.reader.getScanner(conf, false, true);
       byte[] b = getRandomRow();
       if (scanner.seekTo(createCell(b)) < 0) {
         LOG.info("Not able to seekTo " + new String(b));
@@ -455,7 +455,7 @@ public class HFilePerformanceEvaluation {
 
     @Override
     void doRow(int i) throws Exception {
-      HFileScanner scanner = this.reader.getScanner(false, false);
+      HFileScanner scanner = this.reader.getScanner(conf, false, false);
       byte[] b = getRandomRow();
       // System.out.println("Random row: " + new String(b));
       Cell c = createCell(b);
@@ -493,7 +493,7 @@ public class HFilePerformanceEvaluation {
 
     @Override
     void doRow(int i) throws Exception {
-      HFileScanner scanner = this.reader.getScanner(false, true);
+      HFileScanner scanner = this.reader.getScanner(conf, false, true);
       byte[] gaussianRandomRowBytes = getGaussianRandomRowBytes();
       scanner.seekTo(createCell(gaussianRandomRowBytes));
       for (int ii = 0; ii < 30; ii++) {
@@ -514,7 +514,8 @@ public class HFilePerformanceEvaluation {
   }
 
   /**
-   *   */
+   * nnn
+   */
   public static void main(String[] args) throws Exception {
     new HFilePerformanceEvaluation().runBenchmarks();
   }
