@@ -33,6 +33,7 @@ import org.apache.hadoop.hbase.regionserver.HRegionServer;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.test.MetricsAssertHelper;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.JVMClusterUtil;
 import org.apache.hadoop.hbase.util.JVMClusterUtil.MasterThread;
 import org.apache.hadoop.hbase.util.JVMClusterUtil.RegionServerThread;
@@ -60,7 +61,7 @@ public class MiniHBaseCluster extends HBaseCluster {
   /**
    * Start a MiniHBaseCluster.
    * @param conf             Configuration to be used for cluster
-   * @param numRegionServers initial number of region servers to start.
+   * @param numRegionServers initial number of region servers to start. n
    */
   public MiniHBaseCluster(Configuration conf, int numRegionServers)
     throws IOException, InterruptedException {
@@ -71,7 +72,7 @@ public class MiniHBaseCluster extends HBaseCluster {
    * Start a MiniHBaseCluster.
    * @param conf             Configuration to be used for cluster
    * @param numMasters       initial number of masters to start.
-   * @param numRegionServers initial number of region servers to start.
+   * @param numRegionServers initial number of region servers to start. n
    */
   public MiniHBaseCluster(Configuration conf, int numMasters, int numRegionServers)
     throws IOException, InterruptedException {
@@ -95,7 +96,7 @@ public class MiniHBaseCluster extends HBaseCluster {
    * @param rsPorts Ports that RegionServer should use; pass ports if you want to test cluster
    *                restart where for sure the regionservers come up on same address+port (but just
    *                with different startcode); by default mini hbase clusters choose new arbitrary
-   *                ports on each cluster start.
+   *                ports on each cluster start. nn
    */
   public MiniHBaseCluster(Configuration conf, int numMasters, int numAlwaysStandByMasters,
     int numRegionServers, List<Integer> rsPorts, Class<? extends HMaster> masterClass,
@@ -137,9 +138,9 @@ public class MiniHBaseCluster extends HBaseCluster {
     }
 
     /*
-     * @param currentfs We return this if we did not make a new one.
+     * n * @param currentfs We return this if we did not make a new one.
      * @param uniqueName Same name used to help identify the created fs.
-     * @return A new fs instance if we are up on DistributeFileSystem.
+     * @return A new fs instance if we are up on DistributeFileSystem. n
      */
 
     @Override
@@ -214,6 +215,8 @@ public class MiniHBaseCluster extends HBaseCluster {
       try {
         LOG.info("Hook closing fs=" + this.fs);
         this.fs.close();
+      } catch (NullPointerException npe) {
+        LOG.debug("Need to fix these: " + npe.toString());
       } catch (IOException e) {
         LOG.warn("Running hook", e);
       }
@@ -376,31 +379,6 @@ public class MiniHBaseCluster extends HBaseCluster {
     LOG.warn("Waiting for namenodes to stop on mini cluster is not supported");
   }
 
-  @Override
-  public void startJournalNode(ServerName serverName) {
-    LOG.warn("Starting journalnodes on mini cluster is not supported");
-  }
-
-  @Override
-  public void killJournalNode(ServerName serverName) {
-    LOG.warn("Aborting journalnodes on mini cluster is not supported");
-  }
-
-  @Override
-  public void stopJournalNode(ServerName serverName) {
-    LOG.warn("Stopping journalnodes on mini cluster is not supported");
-  }
-
-  @Override
-  public void waitForJournalNodeToStart(ServerName serverName, long timeout) {
-    LOG.warn("Waiting for journalnodes to start on mini cluster is not supported");
-  }
-
-  @Override
-  public void waitForJournalNodeToStop(ServerName serverName, long timeout) {
-    LOG.warn("Waiting for journalnodes to stop on mini cluster is not supported");
-  }
-
   @Override
   public void startMaster(String hostname, int port) throws IOException {
     this.startMaster();
@@ -423,8 +401,7 @@ public class MiniHBaseCluster extends HBaseCluster {
   }
 
   /**
-   * Starts a region server thread running
-   * @return New RegionServerThread
+   * Starts a region server thread running n * @return New RegionServerThread
    */
   public JVMClusterUtil.RegionServerThread startRegionServer() throws IOException {
     final Configuration newConf = HBaseConfiguration.create(conf);
@@ -458,9 +435,9 @@ public class MiniHBaseCluster extends HBaseCluster {
     JVMClusterUtil.RegionServerThread t = startRegionServer();
     ServerName rsServerName = t.getRegionServer().getServerName();
 
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     ClusterStatus clusterStatus = getClusterStatus();
-    while ((System.currentTimeMillis() - start) < timeout) {
+    while ((EnvironmentEdgeManager.currentTime() - start) < timeout) {
       if (clusterStatus != null && clusterStatus.getServers().contains(rsServerName)) {
         return t;
       }
@@ -512,7 +489,7 @@ public class MiniHBaseCluster extends HBaseCluster {
 
   /**
    * Suspend the specified region server
-   * @param serverNumber Used as index into a list.
+   * @param serverNumber Used as index into a list. n
    */
   public JVMClusterUtil.RegionServerThread suspendRegionServer(int serverNumber) {
     JVMClusterUtil.RegionServerThread server = hbaseCluster.getRegionServers().get(serverNumber);
@@ -523,7 +500,7 @@ public class MiniHBaseCluster extends HBaseCluster {
 
   /**
    * Resume the specified region server
-   * @param serverNumber Used as index into a list.
+   * @param serverNumber Used as index into a list. n
    */
   public JVMClusterUtil.RegionServerThread resumeRegionServer(int serverNumber) {
     JVMClusterUtil.RegionServerThread server = hbaseCluster.getRegionServers().get(serverNumber);
@@ -534,7 +511,7 @@ public class MiniHBaseCluster extends HBaseCluster {
 
   /**
    * Wait for the specified region server to stop. Removes this thread from list of running threads.
-   * @return Name of region server that just went down.
+   * n * @return Name of region server that just went down.
    */
   public String waitOnRegionServer(final int serverNumber) {
     return this.hbaseCluster.waitOnRegionServer(serverNumber);
@@ -634,8 +611,8 @@ public class MiniHBaseCluster extends HBaseCluster {
   }
 
   /**
-   * Wait for the specified master to stop. Removes this thread from list of running threads.
-   * @return Name of master that just went down.
+   * Wait for the specified master to stop. Removes this thread from list of running threads. n
+   * * @return Name of master that just went down.
    */
   public String waitOnMaster(final int serverNumber) {
     return this.hbaseCluster.waitOnMaster(serverNumber);
@@ -643,14 +620,15 @@ public class MiniHBaseCluster extends HBaseCluster {
 
   /**
    * Blocks until there is an active master and that master has completed initialization.
-   * @return true if an active master becomes available. false if there are no masters left.
+   * @return true if an active master becomes available. false if there are no masters left. n
    */
   @Override
   public boolean waitForActiveAndReadyMaster(long timeout) throws IOException {
     List<JVMClusterUtil.MasterThread> mts;
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     while (
-      !(mts = getMasterThreads()).isEmpty() && (System.currentTimeMillis() - start) < timeout
+      !(mts = getMasterThreads()).isEmpty()
+        && (EnvironmentEdgeManager.currentTime() - start) < timeout
     ) {
       for (JVMClusterUtil.MasterThread mt : mts) {
         if (mt.getMaster().isActiveMaster() && mt.getMaster().isInitialized()) {
@@ -749,7 +727,7 @@ public class MiniHBaseCluster extends HBaseCluster {
   }
 
   /**
-   * Call flushCache on all regions on all participating regionservers.
+   * Call flushCache on all regions on all participating regionservers. n
    */
   public void compact(boolean major) throws IOException {
     for (JVMClusterUtil.RegionServerThread t : this.hbaseCluster.getRegionServers()) {
@@ -762,7 +740,7 @@ public class MiniHBaseCluster extends HBaseCluster {
   }
 
   /**
-   * Call flushCache on all regions of the specified table.
+   * Call flushCache on all regions of the specified table. n
    */
   public void compact(TableName tableName, boolean major) throws IOException {
     for (JVMClusterUtil.RegionServerThread t : this.hbaseCluster.getRegionServers()) {
@@ -795,8 +773,7 @@ public class MiniHBaseCluster extends HBaseCluster {
   }
 
   /**
-   * Grab a numbered region server of your choice.
-   * @return region server
+   * Grab a numbered region server of your choice. n * @return region server
    */
   public HRegionServer getRegionServer(int serverNumber) {
     return hbaseCluster.getRegionServer(serverNumber);
