@@ -41,6 +41,7 @@ import org.apache.hadoop.hbase.io.TimeRange;
 import org.apache.hadoop.hbase.testclassification.MiscTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.io.DataInputBuffer;
 import org.junit.ClassRule;
 import org.junit.Test;
@@ -65,7 +66,7 @@ public class TestSerialization {
     byte[] row = name.getBytes();
     byte[] fam = "fam".getBytes();
     byte[] qf = "qf".getBytes();
-    long ts = System.currentTimeMillis();
+    long ts = EnvironmentEdgeManager.currentTime();
     byte[] val = "val".getBytes();
     KeyValue kv = new KeyValue(row, fam, qf, ts, val);
     ByteArrayOutputStream baos = new ByteArrayOutputStream();
@@ -142,7 +143,7 @@ public class TestSerialization {
   }
 
   /**
-   * Test RegionInfo serialization
+   * Test RegionInfo serialization n
    */
   @Test
   public void testRegionInfo() throws Exception {
@@ -187,53 +188,12 @@ public class TestSerialization {
       HConstants.EMPTY_END_ROW);
   }
 
-  /*
-   * TODO
-   * @Test public void testPut() throws Exception{ byte[] row = "row".getBytes(); byte[] fam =
-   * "fam".getBytes(); byte[] qf1 = "qf1".getBytes(); byte[] qf2 = "qf2".getBytes(); byte[] qf3 =
-   * "qf3".getBytes(); byte[] qf4 = "qf4".getBytes(); byte[] qf5 = "qf5".getBytes(); byte[] qf6 =
-   * "qf6".getBytes(); byte[] qf7 = "qf7".getBytes(); byte[] qf8 = "qf8".getBytes(); long ts =
-   * System.currentTimeMillis(); byte[] val = "val".getBytes(); Put put = new Put(row);
-   * put.setWriteToWAL(false); put.add(fam, qf1, ts, val); put.add(fam, qf2, ts, val); put.add(fam,
-   * qf3, ts, val); put.add(fam, qf4, ts, val); put.add(fam, qf5, ts, val); put.add(fam, qf6, ts,
-   * val); put.add(fam, qf7, ts, val); put.add(fam, qf8, ts, val); byte[] sb =
-   * Writables.getBytes(put); Put desPut = (Put)Writables.getWritable(sb, new Put()); //Timing test
-   * // long start = System.nanoTime(); // desPut = (Put)Writables.getWritable(sb, new Put()); //
-   * long stop = System.nanoTime(); // System.out.println("timer " +(stop-start));
-   * assertTrue(Bytes.equals(put.getRow(), desPut.getRow())); List<KeyValue> list = null;
-   * List<KeyValue> desList = null; for(Map.Entry<byte[], List<KeyValue>> entry :
-   * put.getFamilyMap().entrySet()){ assertTrue(desPut.getFamilyMap().containsKey(entry.getKey()));
-   * list = entry.getValue(); desList = desPut.getFamilyMap().get(entry.getKey()); for(int i=0;
-   * i<list.size(); i++){ assertTrue(list.get(i).equals(desList.get(i))); } } }
-   * @Test public void testPut2() throws Exception{ byte[] row =
-   * "testAbort,,1243116656250".getBytes(); byte[] fam = "historian".getBytes(); byte[] qf1 =
-   * "creation".getBytes(); long ts = 9223372036854775807L; byte[] val = "dont-care".getBytes(); Put
-   * put = new Put(row); put.add(fam, qf1, ts, val); byte[] sb = Writables.getBytes(put); Put desPut
-   * = (Put)Writables.getWritable(sb, new Put()); assertTrue(Bytes.equals(put.getRow(),
-   * desPut.getRow())); List<KeyValue> list = null; List<KeyValue> desList = null;
-   * for(Map.Entry<byte[], List<KeyValue>> entry : put.getFamilyMap().entrySet()){
-   * assertTrue(desPut.getFamilyMap().containsKey(entry.getKey())); list = entry.getValue(); desList
-   * = desPut.getFamilyMap().get(entry.getKey()); for(int i=0; i<list.size(); i++){
-   * assertTrue(list.get(i).equals(desList.get(i))); } } }
-   * @Test public void testDelete() throws Exception{ byte[] row = "row".getBytes(); byte[] fam =
-   * "fam".getBytes(); byte[] qf1 = "qf1".getBytes(); long ts = System.currentTimeMillis(); Delete
-   * delete = new Delete(row); delete.deleteColumn(fam, qf1, ts); byte[] sb =
-   * Writables.getBytes(delete); Delete desDelete = (Delete)Writables.getWritable(sb, new Delete());
-   * assertTrue(Bytes.equals(delete.getRow(), desDelete.getRow())); List<KeyValue> list = null;
-   * List<KeyValue> desList = null; for(Map.Entry<byte[], List<KeyValue>> entry :
-   * delete.getFamilyMap().entrySet()){
-   * assertTrue(desDelete.getFamilyMap().containsKey(entry.getKey())); list = entry.getValue();
-   * desList = desDelete.getFamilyMap().get(entry.getKey()); for(int i=0; i<list.size(); i++){
-   * assertTrue(list.get(i).equals(desList.get(i))); } } }
-   */
-
   @Test
   public void testGet() throws Exception {
     byte[] row = "row".getBytes();
     byte[] fam = "fam".getBytes();
     byte[] qf1 = "qf1".getBytes();
-
-    long ts = System.currentTimeMillis();
+    long ts = EnvironmentEdgeManager.currentTime();
     int maxVersions = 2;
 
     Get get = new Get(row);
@@ -266,13 +226,11 @@ public class TestSerialization {
 
   @Test
   public void testScan() throws Exception {
-
     byte[] startRow = "startRow".getBytes();
     byte[] stopRow = "stopRow".getBytes();
     byte[] fam = "fam".getBytes();
     byte[] qf1 = "qf1".getBytes();
-
-    long ts = System.currentTimeMillis();
+    long ts = EnvironmentEdgeManager.currentTime();
     int maxVersions = 2;
 
     Scan scan = new Scan(startRow, stopRow);
