@@ -60,6 +60,7 @@ import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.MiscTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.FSUtils;
 import org.apache.hadoop.hbase.util.HFileArchiveTestingUtil;
 import org.apache.hadoop.hbase.util.HFileArchiveUtil;
@@ -346,7 +347,7 @@ public class TestHFileArchiving {
 
   /**
    * Test that the region directory is removed when we archive a region without store files, but
-   * still has hidden files.
+   * still has hidden files. n
    */
   @Test
   public void testDeleteRegionWithNoStoreFiles() throws Exception {
@@ -534,14 +535,14 @@ public class TestHFileArchiving {
 
   private void assertArchiveFiles(FileSystem fs, List<String> storeFiles, long timeout)
     throws IOException {
-    long end = System.currentTimeMillis() + timeout;
+    long end = EnvironmentEdgeManager.currentTime() + timeout;
     Path archiveDir = HFileArchiveUtil.getArchivePath(UTIL.getConfiguration());
     List<String> archivedFiles = new ArrayList<>();
 
     // We have to ensure that the DeleteTableHandler is finished. HBaseAdmin.deleteXXX() can return
     // before all files
     // are archived. We should fix HBASE-5487 and fix synchronous operations from admin.
-    while (System.currentTimeMillis() < end) {
+    while (EnvironmentEdgeManager.currentTime() < end) {
       archivedFiles = getAllFileNames(fs, archiveDir);
       if (archivedFiles.size() >= storeFiles.size()) {
         break;
@@ -565,7 +566,7 @@ public class TestHFileArchiving {
   }
 
   /**
-   * Test that the store files are archived when a column family is removed.
+   * Test that the store files are archived when a column family is removed. n
    */
   @Test
   public void testArchiveOnTableFamilyDelete() throws Exception {
@@ -640,8 +641,8 @@ public class TestHFileArchiving {
       choreService.scheduleChore(cleaner);
 
       // Keep creating/archiving new files while the cleaner is running in the other thread
-      long startTime = System.currentTimeMillis();
-      for (long fid = 0; (System.currentTimeMillis() - startTime) < TEST_TIME; ++fid) {
+      long startTime = EnvironmentEdgeManager.currentTime();
+      for (long fid = 0; (EnvironmentEdgeManager.currentTime() - startTime) < TEST_TIME; ++fid) {
         Path file = new Path(familyDir, String.valueOf(fid));
         Path sourceFile = new Path(rootDir, file);
         Path archiveFile = new Path(archiveDir, file);
@@ -731,7 +732,7 @@ public class TestHFileArchiving {
    * Get the names of all the files below the given directory
    * @param fs         the file system to inspect
    * @param archiveDir the directory in which to look
-   * @return a list of all files in the directory and sub-directories
+   * @return a list of all files in the directory and sub-directories n
    */
   private List<String> getAllFileNames(final FileSystem fs, Path archiveDir) throws IOException {
     FileStatus[] files = CommonFSUtils.listStatus(fs, archiveDir, new PathFilter() {
