@@ -93,12 +93,12 @@ class FromClientSideBase {
     Class<?> confClass = conf.getClass(HConstants.CLIENT_CONNECTION_REGISTRY_IMPL_CONF_KEY,
       ZKConnectionRegistry.class);
     int hedgedReqConfig = conf.getInt(MasterRegistry.MASTER_REGISTRY_HEDGED_REQS_FANOUT_KEY,
-      MasterRegistry.MASTER_REGISTRY_HEDGED_REQS_FANOUT_DEFAULT);
+      AbstractRpcBasedConnectionRegistry.HEDGED_REQS_FANOUT_DEFAULT);
     return confClass.getName().equals(registryImpl.getName()) && numHedgedReqs == hedgedReqConfig;
   }
 
-  protected static final void initialize(Class<? extends ConnectionRegistry> registryImpl,
-    int numHedgedReqs, Class<?>... cps) throws Exception {
+  protected static final void initialize(Class<?> registryImpl, int numHedgedReqs, Class<?>... cps)
+    throws Exception {
     // initialize() is called for every unit test, however we only want to reset the cluster state
     // at the end of every parameterized run.
     if (isSameParameterizedCluster(registryImpl, numHedgedReqs)) {
@@ -210,14 +210,14 @@ class FromClientSideBase {
   }
 
   /*
-   * @return Scan with RowFilter that does LESS than passed key.
+   * n * @return Scan with RowFilter that does LESS than passed key.
    */
   protected Scan createScanWithRowFilter(final byte[] key) {
     return createScanWithRowFilter(key, null, CompareOperator.LESS);
   }
 
   /*
-   * @return Scan with RowFilter that does CompareOp op on passed key.
+   * nnn * @return Scan with RowFilter that does CompareOp op on passed key.
    */
   protected Scan createScanWithRowFilter(final byte[] key, final byte[] startRow,
     CompareOperator op) {
@@ -250,8 +250,8 @@ class FromClientSideBase {
 
   /*
    * Wait on table split. May return because we waited long enough on the split and it didn't
-   * happen. Caller should check.
-   * @return Map of table regions; caller needs to check table actually split.
+   * happen. Caller should check. n * @return Map of table regions; caller needs to check table
+   * actually split.
    */
   private List<HRegionLocation> waitOnSplit(final Table t) throws IOException {
     try (RegionLocator locator = TEST_UTIL.getConnection().getRegionLocator(t.getName())) {
