@@ -19,6 +19,7 @@ package org.apache.hadoop.hbase.client;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -60,6 +61,7 @@ import org.apache.hadoop.hbase.regionserver.HStore;
 import org.apache.hadoop.hbase.testclassification.ClientTests;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.hbase.wal.AbstractFSWALProvider;
 import org.junit.Assert;
@@ -138,7 +140,7 @@ public class TestAdmin2 extends TestAdminBase {
   }
 
   /**
-   * Test for hadoop-1581 'HBASE: Unopenable tablename bug'.
+   * Test for hadoop-1581 'HBASE: Unopenable tablename bug'. n
    */
   @Test
   public void testTableNameClash() throws Exception {
@@ -156,7 +158,7 @@ public class TestAdmin2 extends TestAdminBase {
   /***
    * HMaster.createTable used to be kind of synchronous call Thus creating of table with lots of
    * regions can cause RPC timeout After the fix to make createTable truly async, RPC timeout
-   * shouldn't be an issue anymore
+   * shouldn't be an issue anymore n
    */
   @Test
   public void testCreateTableRPCTimeOut() throws Exception {
@@ -179,7 +181,7 @@ public class TestAdmin2 extends TestAdminBase {
   }
 
   /**
-   * Test read only tables
+   * Test read only tables n
    */
   @Test
   public void testReadOnlyTable() throws Exception {
@@ -195,7 +197,7 @@ public class TestAdmin2 extends TestAdminBase {
 
   /**
    * Test that user table names can contain '-' and '.' so long as they do not start with same.
-   * HBASE-771
+   * HBASE-771 n
    */
   @Test
   public void testTableNames() throws IOException {
@@ -219,7 +221,7 @@ public class TestAdmin2 extends TestAdminBase {
   }
 
   /**
-   * For HADOOP-2579
+   * For HADOOP-2579 n
    */
   @Test(expected = TableExistsException.class)
   public void testTableExistsExceptionWithATable() throws IOException {
@@ -229,7 +231,7 @@ public class TestAdmin2 extends TestAdminBase {
   }
 
   /**
-   * Can't disable a table if the table isn't in enabled state
+   * Can't disable a table if the table isn't in enabled state n
    */
   @Test(expected = TableNotEnabledException.class)
   public void testTableNotEnabledExceptionWithATable() throws IOException {
@@ -278,8 +280,8 @@ public class TestAdmin2 extends TestAdminBase {
       }
     }
     boolean isInList = ProtobufUtil.getOnlineRegions(rs.getRSRpcServices()).contains(info);
-    long timeout = System.currentTimeMillis() + 10000;
-    while ((System.currentTimeMillis() < timeout) && (isInList)) {
+    long timeout = EnvironmentEdgeManager.currentTime() + 10000;
+    while ((EnvironmentEdgeManager.currentTime() < timeout) && (isInList)) {
       Thread.sleep(100);
       isInList = ProtobufUtil.getOnlineRegions(rs.getRSRpcServices()).contains(info);
     }
@@ -300,11 +302,8 @@ public class TestAdmin2 extends TestAdminBase {
       if (!regionInfo.isMetaRegion()) {
         if (regionInfo.getRegionNameAsString().contains(name)) {
           info = regionInfo;
-          try {
-            ADMIN.unassign(Bytes.toBytes("sample"), true);
-          } catch (UnknownRegionException nsre) {
-            // expected, ignore it
-          }
+          assertThrows(UnknownRegionException.class, () -> ADMIN.unassign(
+            Bytes.toBytes("test,,1358563771069.acc1ad1b7962564fc3a43e5907e8db33."), true));
         }
       }
     }
@@ -331,8 +330,8 @@ public class TestAdmin2 extends TestAdminBase {
     }
 
     boolean isInList = ProtobufUtil.getOnlineRegions(rs.getRSRpcServices()).contains(info);
-    long timeout = System.currentTimeMillis() + 10000;
-    while ((System.currentTimeMillis() < timeout) && (isInList)) {
+    long timeout = EnvironmentEdgeManager.currentTime() + 10000;
+    while ((EnvironmentEdgeManager.currentTime() < timeout) && (isInList)) {
       Thread.sleep(100);
       isInList = ProtobufUtil.getOnlineRegions(rs.getRSRpcServices()).contains(info);
     }
@@ -420,11 +419,9 @@ public class TestAdmin2 extends TestAdminBase {
       r.flush(true);
     }
     ADMIN.rollWALWriter(regionServer.getServerName());
-    TEST_UTIL.waitFor(5000, () -> {
-      int count = AbstractFSWALProvider.getNumRolledLogFiles(regionServer.getWAL(null));
-      LOG.info("after flushing all regions and rolling logs there are " + count + " log files");
-      return count <= 2;
-    });
+    int count = AbstractFSWALProvider.getNumRolledLogFiles(regionServer.getWAL(null));
+    LOG.info("after flushing all regions and rolling logs there are " + count + " log files");
+    assertTrue(("actual count: " + count), count <= 2);
   }
 
   private void setUpforLogRolling() {
@@ -506,14 +503,14 @@ public class TestAdmin2 extends TestAdminBase {
     conf.setInt(HConstants.ZOOKEEPER_CLIENT_PORT,
       conf.getInt(HConstants.ZOOKEEPER_CLIENT_PORT, 9999) + 10);
 
-    long start = System.currentTimeMillis();
+    long start = EnvironmentEdgeManager.currentTime();
     try {
       HBaseAdmin.available(conf);
       assertTrue(false);
     } catch (ZooKeeperConnectionException ignored) {
     } catch (IOException ignored) {
     }
-    long end = System.currentTimeMillis();
+    long end = EnvironmentEdgeManager.currentTime();
 
     LOG.info("It took " + (end - start) + " ms to find out that" + " HBase was not available");
   }
@@ -783,6 +780,7 @@ public class TestAdmin2 extends TestAdminBase {
     assertEquals(11111111, ADMIN.getDescriptor(tableName).getMaxFileSize());
   }
 
+  @SuppressWarnings("FutureReturnValueIgnored")
   @Test
   public void testTableMergeFollowedByModify() throws Exception {
     final TableName tableName = TableName.valueOf(name.getMethodName());
