@@ -25,6 +25,7 @@ import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
 import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Modifier;
 import java.net.SocketTimeoutException;
 import java.util.ArrayList;
@@ -41,8 +42,11 @@ import java.util.concurrent.atomic.AtomicReference;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.hbase.CallDroppedException;
+import org.apache.hadoop.hbase.CallQueueTooBigException;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
+import org.apache.hadoop.hbase.HBaseServerException;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionLocation;
@@ -66,7 +70,6 @@ import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.JVMClusterUtil;
 import org.apache.hadoop.hbase.util.ManualEnvironmentEdge;
-import org.apache.hadoop.hbase.util.ReflectionUtils;
 import org.apache.hadoop.hbase.util.Threads;
 import org.junit.After;
 import org.junit.AfterClass;
@@ -396,7 +399,7 @@ public class TestConnectionImplementation {
     table.put(put);
 
     ManualEnvironmentEdge mee = new ManualEnvironmentEdge();
-    mee.setValue(System.currentTimeMillis());
+    mee.setValue(EnvironmentEdgeManager.currentTime());
     EnvironmentEdgeManager.injectEdge(mee);
     LOG.info("first get");
     table.get(new Get(ROW));
@@ -433,7 +436,7 @@ public class TestConnectionImplementation {
 
   /**
    * Test that the connection to the dead server is cut immediately when we receive the
-   * notification.
+   * notification. n
    */
   @Test
   public void testConnectionCut() throws Exception {
@@ -529,7 +532,7 @@ public class TestConnectionImplementation {
   }
 
   /**
-   * Test that when we delete a location using the first row of a region that we really delete it.
+   * Test that when we delete a location using the first row of a region that we really delete it. n
    */
   @Test
   public void testRegionCaching() throws Exception {
@@ -716,7 +719,7 @@ public class TestConnectionImplementation {
   }
 
   /**
-   * Test that Connection or Pool are not closed when managed externally
+   * Test that Connection or Pool are not closed when managed externally n
    */
   @Test
   public void testConnectionManagement() throws Exception {
@@ -847,7 +850,7 @@ public class TestConnectionImplementation {
   private int setNumTries(ConnectionImplementation hci, int newVal) throws Exception {
     Field numTries = hci.getClass().getDeclaredField("numTries");
     numTries.setAccessible(true);
-    Field modifiersField = ReflectionUtils.getModifiersField();
+    Field modifiersField = Field.class.getDeclaredField("modifiers");
     modifiersField.setAccessible(true);
     modifiersField.setInt(numTries, numTries.getModifiers() & ~Modifier.FINAL);
     final int prevNumRetriesVal = (Integer) numTries.get(hci);
@@ -1075,6 +1078,104 @@ public class TestConnectionImplementation {
     }
   }
 
+  @Test
+  public void testLocateRegionsRetrySpecialPauseCQTBE() throws IOException {
+    testLocateRegionsRetrySpecialPause(CallQueueTooBigException.class);
+  }
+
+  @Test
+  public void testLocateRegionsRetrySpecialPauseCDE() throws IOException {
+    testLocateRegionsRetrySpecialPause(CallDroppedException.class);
+  }
+
+  private void testLocateRegionsRetrySpecialPause(
+    Class<? extends HBaseServerException> exceptionClass) throws IOException {
+
+    int regionReplication = 3;
+    byte[] family = Bytes.toBytes("cf");
+    TableName tableName = TableName.valueOf(name.getMethodName());
+
+    // Create a table with region replicas
+    TableDescriptorBuilder builder =
+      TableDescriptorBuilder.newBuilder(tableName).setRegionReplication(regionReplication)
+        .setColumnFamily(ColumnFamilyDescriptorBuilder.of(family));
+    TEST_UTIL.getAdmin().createTable(builder.build());
+
+    Configuration conf = new Configuration(TEST_UTIL.getConfiguration());
+
+    conf.setClass(RpcRetryingCallerFactory.CUSTOM_CALLER_CONF_KEY, ThrowingCallerFactory.class,
+      RpcRetryingCallerFactory.class);
+    conf.setClass("testSpecialPauseException", exceptionClass, HBaseServerException.class);
+
+    conf.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER, 2);
+    // normal pause very short, 10 millis
+    conf.setInt(HConstants.HBASE_CLIENT_PAUSE, 10);
+
+    // special pause 10x longer, so we can detect it
+    long specialPauseMillis = 1000;
+    conf.setLong(ConnectionConfiguration.HBASE_CLIENT_PAUSE_FOR_SERVER_OVERLOADED,
+      specialPauseMillis);
+
+    try (ConnectionImplementation con =
+      (ConnectionImplementation) ConnectionFactory.createConnection(conf)) {
+      // Get locations of the regions of the table
+
+      long start = System.nanoTime();
+      try {
+        con.locateRegion(tableName, new byte[0], false, true, 0);
+      } catch (HBaseServerException e) {
+        assertTrue(e.isServerOverloaded());
+        // pass: expected
+      }
+      assertTrue(System.nanoTime() - start > TimeUnit.MILLISECONDS.toNanos(specialPauseMillis));
+    } finally {
+      TEST_UTIL.deleteTable(tableName);
+    }
+  }
+
+  private static class ThrowingCallerFactory extends RpcRetryingCallerFactory {
+
+    private final Class<? extends HBaseServerException> exceptionClass;
+
+    public ThrowingCallerFactory(Configuration conf) {
+      super(conf);
+      this.exceptionClass =
+        conf.getClass("testSpecialPauseException", null, HBaseServerException.class);
+    }
+
+    @Override
+    public <T> RpcRetryingCaller<T> newCaller(int rpcTimeout) {
+      return newCaller();
+    }
+
+    @Override
+    public <T> RpcRetryingCaller<T> newCaller() {
+      return new RpcRetryingCaller<T>() {
+        @Override
+        public void cancel() {
+
+        }
+
+        @Override
+        public T callWithRetries(RetryingCallable<T> callable, int callTimeout)
+          throws IOException, RuntimeException {
+          return callWithoutRetries(null, 0);
+        }
+
+        @Override
+        public T callWithoutRetries(RetryingCallable<T> callable, int callTimeout)
+          throws IOException, RuntimeException {
+          try {
+            throw exceptionClass.getConstructor().newInstance();
+          } catch (IllegalAccessException | InstantiationException | InvocationTargetException
+            | NoSuchMethodException e) {
+            throw new RuntimeException(e);
+          }
+        }
+      };
+    }
+  }
+
   @Test
   public void testMetaLookupThreadPoolCreated() throws Exception {
     final TableName tableName = TableName.valueOf(name.getMethodName());
