@@ -90,7 +90,7 @@ public class TestMasterRegistry {
     int numMasters = 10;
     conf.set(HConstants.MASTER_ADDRS_KEY, generateDummyMastersList(numMasters));
     try (MasterRegistry registry = new MasterRegistry(conf)) {
-      List<ServerName> parsedMasters = new ArrayList<>(registry.getParsedMasterServers());
+      List<ServerName> parsedMasters = new ArrayList<>(registry.getParsedServers());
       // Half of them would be without a port, duplicates are removed.
       assertEquals(numMasters / 2 + 1, parsedMasters.size());
       // Sort in the increasing order of port numbers.
@@ -108,24 +108,6 @@ public class TestMasterRegistry {
     }
   }
 
-  @Test
-  public void testMasterPortDefaults() throws IOException {
-    Configuration conf = new Configuration(TEST_UTIL.getConfiguration());
-    conf.set(HConstants.MASTER_ADDRS_KEY, "localhost");
-    try (MasterRegistry registry = new MasterRegistry(conf)) {
-      List<ServerName> parsedMasters = new ArrayList<>(registry.getParsedMasterServers());
-      ServerName sn = parsedMasters.get(0);
-      assertEquals(HConstants.DEFAULT_MASTER_PORT, sn.getPort());
-    }
-    final int CUSTOM_MASTER_PORT = 9999;
-    conf.setInt(HConstants.MASTER_PORT, CUSTOM_MASTER_PORT);
-    try (MasterRegistry registry = new MasterRegistry(conf)) {
-      List<ServerName> parsedMasters = new ArrayList<>(registry.getParsedMasterServers());
-      ServerName sn = parsedMasters.get(0);
-      assertEquals(CUSTOM_MASTER_PORT, sn.getPort());
-    }
-  }
-
   @Test
   public void testRegistryRPCs() throws Exception {
     Configuration conf = new Configuration(TEST_UTIL.getConfiguration());
@@ -167,17 +149,17 @@ public class TestMasterRegistry {
     // Set the hedging fan out so that all masters are queried.
     conf.setInt(MasterRegistry.MASTER_REGISTRY_HEDGED_REQS_FANOUT_KEY, 4);
     // Do not limit the number of refreshes during the test run.
-    conf.setLong(MasterAddressRefresher.MIN_SECS_BETWEEN_REFRESHES, 0);
+    conf.setLong(MasterRegistry.MASTER_REGISTRY_MIN_SECS_BETWEEN_REFRESHES, 0);
     try (MasterRegistry registry = new MasterRegistry(conf)) {
-      final Set<ServerName> masters = registry.getParsedMasterServers();
+      final Set<ServerName> masters = registry.getParsedServers();
       assertTrue(masters.contains(badServer));
       // Make a registry RPC, this should trigger a refresh since one of the hedged RPC fails.
       assertEquals(registry.getClusterId().get(), clusterId);
       // Wait for new set of masters to be populated.
       TEST_UTIL.waitFor(5000,
-        (Waiter.Predicate<Exception>) () -> !registry.getParsedMasterServers().equals(masters));
+        (Waiter.Predicate<Exception>) () -> !registry.getParsedServers().equals(masters));
       // new set of masters should not include the bad server
-      final Set<ServerName> newMasters = registry.getParsedMasterServers();
+      final Set<ServerName> newMasters = registry.getParsedServers();
       // Bad one should be out.
       assertEquals(3, newMasters.size());
       assertFalse(newMasters.contains(badServer));
@@ -188,8 +170,8 @@ public class TestMasterRegistry {
       TEST_UTIL.getMiniHBaseCluster().waitForActiveAndReadyMaster(10000);
       // Wait until the killed master de-registered. This should also trigger another refresh.
       TEST_UTIL.waitFor(10000, () -> registry.getMasters().get().size() == 2);
-      TEST_UTIL.waitFor(20000, () -> registry.getParsedMasterServers().size() == 2);
-      final Set<ServerName> newMasters2 = registry.getParsedMasterServers();
+      TEST_UTIL.waitFor(20000, () -> registry.getParsedServers().size() == 2);
+      final Set<ServerName> newMasters2 = registry.getParsedServers();
       assertEquals(2, newMasters2.size());
       assertFalse(newMasters2.contains(activeMaster.getServerName()));
     } finally {
