@@ -17,18 +17,21 @@
  */
 package org.apache.hadoop.hbase.client;
 
-import static org.apache.hadoop.hbase.HBaseTestCase.assertByteEquals;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.greaterThan;
-import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.lessThan;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
-import junit.framework.TestCase;
 import org.apache.hadoop.hbase.ArrayBackedTag;
 import org.apache.hadoop.hbase.ByteBufferKeyValue;
 import org.apache.hadoop.hbase.Cell;
@@ -43,12 +46,13 @@ import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.ByteBufferUtils;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.junit.ClassRule;
+import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 @Category({ SmallTests.class, ClientTests.class })
-public class TestResult extends TestCase {
+public class TestResult {
 
   @ClassRule
   public static final HBaseClassTestRule CLASS_RULE = HBaseClassTestRule.forClass(TestResult.class);
@@ -74,6 +78,7 @@ public class TestResult extends TestCase {
   /**
    * Run some tests to ensure Result acts like a proper CellScanner.
    */
+  @Test
   public void testResultAsCellScanner() throws IOException {
     Cell[] cells = genKVs(row, family, value, 1, 10);
     Arrays.sort(cells, CellComparator.getInstance());
@@ -95,6 +100,7 @@ public class TestResult extends TestCase {
     assertEquals(cells.length, count);
   }
 
+  @Test
   public void testBasicGetColumn() throws Exception {
     KeyValue[] kvs = genKVs(row, family, value, 1, 100);
 
@@ -112,12 +118,14 @@ public class TestResult extends TestCase {
     }
   }
 
+  @Test
   public void testCurrentOnEmptyCell() throws IOException {
     Result r = Result.create(new Cell[0]);
     assertFalse(r.advance());
     assertNull(r.current());
   }
 
+  @Test
   public void testAdvanceMultipleOnEmptyCell() throws IOException {
     Result r = Result.create(new Cell[0]);
     // After HBASE-26688, advance of result with empty cell list will always return false.
@@ -127,6 +135,7 @@ public class TestResult extends TestCase {
     }
   }
 
+  @Test
   public void testMultiVersionGetColumn() throws Exception {
     KeyValue[] kvs1 = genKVs(row, family, value, 1, 100);
     KeyValue[] kvs2 = genKVs(row, family, value, 200, 100);
@@ -149,6 +158,7 @@ public class TestResult extends TestCase {
     }
   }
 
+  @Test
   public void testBasicGetValue() throws Exception {
     KeyValue[] kvs = genKVs(row, family, value, 1, 100);
 
@@ -159,11 +169,12 @@ public class TestResult extends TestCase {
     for (int i = 0; i < 100; ++i) {
       final byte[] qf = Bytes.toBytes(i);
 
-      assertByteEquals(Bytes.add(value, Bytes.toBytes(i)), r.getValue(family, qf));
+      assertArrayEquals(Bytes.add(value, Bytes.toBytes(i)), r.getValue(family, qf));
       assertTrue(r.containsColumn(family, qf));
     }
   }
 
+  @Test
   public void testMultiVersionGetValue() throws Exception {
     KeyValue[] kvs1 = genKVs(row, family, value, 1, 100);
     KeyValue[] kvs2 = genKVs(row, family, value, 200, 100);
@@ -178,11 +189,12 @@ public class TestResult extends TestCase {
     for (int i = 0; i < 100; ++i) {
       final byte[] qf = Bytes.toBytes(i);
 
-      assertByteEquals(Bytes.add(value, Bytes.toBytes(i)), r.getValue(family, qf));
+      assertArrayEquals(Bytes.add(value, Bytes.toBytes(i)), r.getValue(family, qf));
       assertTrue(r.containsColumn(family, qf));
     }
   }
 
+  @Test
   public void testBasicLoadValue() throws Exception {
     KeyValue[] kvs = genKVs(row, family, value, 1, 100);
 
@@ -203,6 +215,7 @@ public class TestResult extends TestCase {
     }
   }
 
+  @Test
   public void testMultiVersionLoadValue() throws Exception {
     KeyValue[] kvs1 = genKVs(row, family, value, 1, 100);
     KeyValue[] kvs2 = genKVs(row, family, value, 200, 100);
@@ -231,6 +244,7 @@ public class TestResult extends TestCase {
   /**
    * Verify that Result.compareResults(...) behaves correctly.
    */
+  @Test
   public void testCompareResults() throws Exception {
     byte[] value1 = Bytes.toBytes("value1");
     byte[] qual = Bytes.toBytes("qual");
@@ -251,6 +265,7 @@ public class TestResult extends TestCase {
     }
   }
 
+  @Test
   public void testCompareResultsWithTags() throws Exception {
     Tag t1 = new ArrayBackedTag((byte) 1, Bytes.toBytes("TAG1"));
     Tag t2 = new ArrayBackedTag((byte) 2, Bytes.toBytes("TAG2"));
@@ -365,6 +380,7 @@ public class TestResult extends TestCase {
     }
   }
 
+  @Test
   public void testCompareResultMemoryUsage() {
     List<Cell> cells1 = new ArrayList<>();
     for (long i = 0; i < 100; i++) {
@@ -383,7 +399,7 @@ public class TestResult extends TestCase {
       fail();
     } catch (Exception x) {
       assertTrue(x.getMessage().startsWith("This result was different:"));
-      assertThat(x.getMessage().length(), is(greaterThan(100)));
+      assertThat(x.getMessage().length(), greaterThan(100));
     }
 
     try {
@@ -391,7 +407,7 @@ public class TestResult extends TestCase {
       fail();
     } catch (Exception x) {
       assertEquals("This result was different: row=row", x.getMessage());
-      assertThat(x.getMessage().length(), is(lessThan(100)));
+      assertThat(x.getMessage().length(), lessThan(100));
     }
   }
 
@@ -419,6 +435,7 @@ public class TestResult extends TestCase {
   /**
    * Verifies that one can't modify instance of EMPTY_RESULT.
    */
+  @Test
   public void testEmptyResultIsReadonly() {
     Result emptyResult = Result.EMPTY_RESULT;
     Result otherResult = new Result();
@@ -439,6 +456,7 @@ public class TestResult extends TestCase {
 
   /**
    * Microbenchmark that compares {@link Result#getValue} and {@link Result#loadValue} performance.
+   * n
    */
   public void doReadBenchmark() throws Exception {
 
@@ -500,7 +518,7 @@ public class TestResult extends TestCase {
   }
 
   /**
-   * Calls non-functional test methods.
+   * Calls non-functional test methods. n
    */
   public static void main(String[] args) {
     TestResult testResult = new TestResult();
