@@ -142,7 +142,7 @@ public class TestScannersFromClientSide {
     Class<?> confClass = conf.getClass(HConstants.CLIENT_CONNECTION_REGISTRY_IMPL_CONF_KEY,
       ZKConnectionRegistry.class);
     int hedgedReqConfig = conf.getInt(MasterRegistry.MASTER_REGISTRY_HEDGED_REQS_FANOUT_KEY,
-      MasterRegistry.MASTER_REGISTRY_HEDGED_REQS_FANOUT_DEFAULT);
+      AbstractRpcBasedConnectionRegistry.HEDGED_REQS_FANOUT_DEFAULT);
     return confClass.getName().equals(registryImpl.getName()) && numHedgedReqs == hedgedReqConfig;
   }
 
@@ -168,7 +168,7 @@ public class TestScannersFromClientSide {
   }
 
   /**
-   * Test from client side for batch of scan
+   * Test from client side for batch of scan n
    */
   @Test
   public void testScanBatch() throws Exception {
@@ -344,7 +344,7 @@ public class TestScannersFromClientSide {
   }
 
   /**
-   * Run through a variety of test configurations with a small scan
+   * Run through a variety of test configurations with a small scan nnnnn
    */
   private void testSmallScan(Table table, boolean reversed, int rows, int columns)
     throws Exception {
@@ -385,7 +385,7 @@ public class TestScannersFromClientSide {
   }
 
   /**
-   * Test from client side for get with maxResultPerCF set
+   * Test from client side for get with maxResultPerCF set n
    */
   @Test
   public void testGetMaxResults() throws Exception {
@@ -502,7 +502,7 @@ public class TestScannersFromClientSide {
   }
 
   /**
-   * Test from client side for scan with maxResultPerCF set
+   * Test from client side for scan with maxResultPerCF set n
    */
   @Test
   public void testScanMaxResults() throws Exception {
@@ -550,7 +550,7 @@ public class TestScannersFromClientSide {
   }
 
   /**
-   * Test from client side for get with rowOffset
+   * Test from client side for get with rowOffset n
    */
   @Test
   public void testGetRowOffset() throws Exception {
@@ -666,7 +666,7 @@ public class TestScannersFromClientSide {
   }
 
   /**
-   * Test from client side for scan while the region is reopened on the same region server.
+   * Test from client side for scan while the region is reopened on the same region server. n
    */
   @Test
   public void testScanOnReopenedRegion() throws Exception {
@@ -872,7 +872,7 @@ public class TestScannersFromClientSide {
   @Test
   public void testReadExpiredDataForRawScan() throws IOException {
     TableName tableName = name.getTableName();
-    long ts = System.currentTimeMillis() - 10000;
+    long ts = EnvironmentEdgeManager.currentTime() - 10000;
     byte[] value = Bytes.toBytes("expired");
     try (Table table = TEST_UTIL.createTable(tableName, FAMILY)) {
       table.put(new Put(ROW).addColumn(FAMILY, QUALIFIER, ts, value));
@@ -892,7 +892,7 @@ public class TestScannersFromClientSide {
   @Test
   public void testScanWithColumnsAndFilterAndVersion() throws IOException {
     TableName tableName = name.getTableName();
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     try (Table table = TEST_UTIL.createTable(tableName, FAMILY, 4)) {
       for (int i = 0; i < 4; i++) {
         Put put = new Put(ROW);
