@@ -22,6 +22,8 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.Mockito.when;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -31,7 +33,6 @@ import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
-import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.ServerName;
@@ -39,9 +40,10 @@ import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.RegionInfoBuilder;
 import org.apache.hadoop.hbase.master.RackManager;
-import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.MasterTests;
+import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Triple;
 import org.junit.BeforeClass;
 import org.junit.ClassRule;
@@ -54,7 +56,7 @@ import org.mockito.Mockito;
 import org.apache.hbase.thirdparty.com.google.common.collect.Lists;
 import org.apache.hbase.thirdparty.com.google.common.collect.Sets;
 
-@Category({ MasterTests.class, LargeTests.class })
+@Category({ MasterTests.class, MediumTests.class })
 public class TestFavoredNodeAssignmentHelper {
 
   @ClassRule
@@ -71,35 +73,36 @@ public class TestFavoredNodeAssignmentHelper {
   @Rule
   public TestName name = new TestName();
 
+  private static String getRack(int index) {
+    if (index < 10) {
+      return "rack1";
+    } else if (index < 20) {
+      return "rack2";
+    } else if (index < 30) {
+      return "rack3";
+    } else {
+      return RackManager.UNKNOWN_RACK;
+    }
+  }
+
   @BeforeClass
   public static void setupBeforeClass() throws Exception {
     // Set up some server -> rack mappings
     // Have three racks in the cluster with 10 hosts each.
+    when(rackManager.getRack(any(ServerName.class))).then(invocation -> {
+      ServerName sn = invocation.getArgument(0, ServerName.class);
+      try {
+        int i = Integer.parseInt(sn.getHostname().substring("foo".length()));
+        return getRack(i);
+      } catch (NumberFormatException e) {
+        return RackManager.UNKNOWN_RACK;
+      }
+    });
     for (int i = 0; i < 40; i++) {
-      ServerName server = ServerName.valueOf("foo" + i + ":1234", -1);
-      if (i < 10) {
-        Mockito.when(rackManager.getRack(server)).thenReturn("rack1");
-        if (rackToServers.get("rack1") == null) {
-          List<ServerName> servers = new ArrayList<>();
-          rackToServers.put("rack1", servers);
-        }
-        rackToServers.get("rack1").add(server);
-      }
-      if (i >= 10 && i < 20) {
-        Mockito.when(rackManager.getRack(server)).thenReturn("rack2");
-        if (rackToServers.get("rack2") == null) {
-          List<ServerName> servers = new ArrayList<>();
-          rackToServers.put("rack2", servers);
-        }
-        rackToServers.get("rack2").add(server);
-      }
-      if (i >= 20 && i < 30) {
-        Mockito.when(rackManager.getRack(server)).thenReturn("rack3");
-        if (rackToServers.get("rack3") == null) {
-          List<ServerName> servers = new ArrayList<>();
-          rackToServers.put("rack3", servers);
-        }
-        rackToServers.get("rack3").add(server);
+      ServerName server = ServerName.valueOf("foo" + i, 1234, EnvironmentEdgeManager.currentTime());
+      String rack = getRack(i);
+      if (!rack.equals(RackManager.UNKNOWN_RACK)) {
+        rackToServers.computeIfAbsent(rack, k -> new ArrayList<>()).add(server);
       }
       servers.add(server);
     }
@@ -107,7 +110,7 @@ public class TestFavoredNodeAssignmentHelper {
 
   // The tests decide which racks to work with, and how many machines to
   // work with from any given rack
-  // Return a rondom 'count' number of servers from 'rack'
+  // Return a random 'count' number of servers from 'rack'
   private static List<ServerName> getServersFromRack(Map<String, Integer> rackToServerCount) {
     List<ServerName> chosenServers = new ArrayList<>();
     for (Map.Entry<String, Integer> entry : rackToServerCount.entrySet()) {
@@ -126,8 +129,7 @@ public class TestFavoredNodeAssignmentHelper {
     Map<String, Integer> rackToServerCount = new HashMap<>();
     rackToServerCount.put("rack1", 2);
     List<ServerName> servers = getServersFromRack(rackToServerCount);
-    FavoredNodeAssignmentHelper helper =
-      new FavoredNodeAssignmentHelper(servers, new Configuration());
+    FavoredNodeAssignmentHelper helper = new FavoredNodeAssignmentHelper(servers, rackManager);
     helper.initialize();
     assertFalse(helper.canPlaceFavoredNodes());
   }
@@ -364,12 +366,13 @@ public class TestFavoredNodeAssignmentHelper {
     regionMap.put(regionsOnRack1, 1);
     regionMap.put(regionsOnRack2, 2);
     regionMap.put(regionsOnRack3, 3);
-    assertEquals(printProportions(firstRackSize, secondRackSize, thirdRackSize, regionsOnRack1,
-      regionsOnRack2, regionsOnRack3), rackMap.get(firstRackSize), regionMap.get(regionsOnRack1));
-    assertEquals(printProportions(firstRackSize, secondRackSize, thirdRackSize, regionsOnRack1,
-      regionsOnRack2, regionsOnRack3), rackMap.get(secondRackSize), regionMap.get(regionsOnRack2));
-    assertEquals(printProportions(firstRackSize, secondRackSize, thirdRackSize, regionsOnRack1,
-      regionsOnRack2, regionsOnRack3), rackMap.get(thirdRackSize), regionMap.get(regionsOnRack3));
+    assertTrue(printProportions(firstRackSize, secondRackSize, thirdRackSize, regionsOnRack1,
+      regionsOnRack2, regionsOnRack3), rackMap.get(firstRackSize) == regionMap.get(regionsOnRack1));
+    assertTrue(printProportions(firstRackSize, secondRackSize, thirdRackSize, regionsOnRack1,
+      regionsOnRack2, regionsOnRack3),
+      rackMap.get(secondRackSize) == regionMap.get(regionsOnRack2));
+    assertTrue(printProportions(firstRackSize, secondRackSize, thirdRackSize, regionsOnRack1,
+      regionsOnRack2, regionsOnRack3), rackMap.get(thirdRackSize) == regionMap.get(regionsOnRack3));
   }
 
   private String printProportions(int firstRackSize, int secondRackSize, int thirdRackSize,
