@@ -43,6 +43,7 @@ import org.apache.hadoop.hbase.regionserver.InternalScanner;
 import org.apache.hadoop.hbase.testclassification.FilterTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.ClassRule;
@@ -62,7 +63,7 @@ public class TestDependentColumnFilter {
   private static final byte[][] ROWS = { Bytes.toBytes("test1"), Bytes.toBytes("test2") };
   private static final byte[][] FAMILIES =
     { Bytes.toBytes("familyOne"), Bytes.toBytes("familyTwo") };
-  private static final long STAMP_BASE = System.currentTimeMillis();
+  private static final long STAMP_BASE = EnvironmentEdgeManager.currentTime();
   private static final long[] STAMPS = { STAMP_BASE - 100, STAMP_BASE - 200, STAMP_BASE - 300 };
   private static final byte[] QUALIFIER = Bytes.toBytes("qualifier");
   private static final byte[][] BAD_VALS =
@@ -135,7 +136,7 @@ public class TestDependentColumnFilter {
 
   /**
    * This shouldn't be confused with TestFilter#verifyScan as expectedKeys is not the per row total,
-   * but the scan total
+   * but the scan total nnnn
    */
   private void verifyScan(Scan s, long expectedRows, long expectedCells) throws IOException {
     InternalScanner scanner = this.region.getScanner(s);
@@ -210,7 +211,7 @@ public class TestDependentColumnFilter {
   }
 
   /**
-   * Test that the filter correctly drops rows without a corresponding timestamp
+   * Test that the filter correctly drops rows without a corresponding timestamp n
    */
   @Test
   public void testFilterDropping() throws Exception {
