@@ -69,6 +69,7 @@ import org.apache.hadoop.hbase.regionserver.throttle.StoreHotnessProtector;
 import org.apache.hadoop.hbase.testclassification.IOTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.ClassSize;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.junit.BeforeClass;
 import org.junit.ClassRule;
 import org.junit.Test;
@@ -289,7 +290,7 @@ public class TestHeapSize {
 
   /**
    * Testing the classes that implements HeapSize and are a part of 0.20. Some are not tested here
-   * for example BlockIndex which is tested in TestHFile since it is a non public class
+   * for example BlockIndex which is tested in TestHFile since it is a non public class n
    */
   @Test
   public void testSizes() throws IOException {
@@ -609,9 +610,9 @@ public class TestHeapSize {
       // do estimate in advance to ensure class is loaded
       ClassSize.estimateBase(cl, false);
 
-      long startTime = System.currentTimeMillis();
+      long startTime = EnvironmentEdgeManager.currentTime();
       ClassSize.estimateBase(cl, false);
-      long endTime = System.currentTimeMillis();
+      long endTime = EnvironmentEdgeManager.currentTime();
       assertTrue(endTime - startTime < 5);
     }
   }
