@@ -31,12 +31,13 @@ import java.util.Collection;
 import java.util.List;
 import java.util.Random;
 import java.util.concurrent.ThreadLocalRandom;
+import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.ArrayBackedTag;
-import org.apache.hadoop.hbase.ByteBufferKeyValue;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellComparatorImpl;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
+import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.KeyValue;
@@ -84,6 +85,7 @@ public class TestDataBlockEncoders {
     HConstants.HFILEBLOCK_HEADER_SIZE + DataBlockEncoding.ID_SIZE;
   static final byte[] HFILEBLOCK_DUMMY_HEADER = new byte[HConstants.HFILEBLOCK_HEADER_SIZE];
 
+  private final Configuration conf = HBaseConfiguration.create();
   private final RedundantKVGenerator generator = new RedundantKVGenerator();
   private final boolean includesMemstoreTS;
   private final boolean includesTags;
@@ -101,21 +103,21 @@ public class TestDataBlockEncoders {
     this.useOffheapData = useOffheapData;
   }
 
-  private HFileBlockEncodingContext getEncodingContext(Compression.Algorithm algo,
-    DataBlockEncoding encoding) {
+  private HFileBlockEncodingContext getEncodingContext(Configuration conf,
+    Compression.Algorithm algo, DataBlockEncoding encoding) {
     DataBlockEncoder encoder = encoding.getEncoder();
     HFileContext meta =
       new HFileContextBuilder().withHBaseCheckSum(false).withIncludesMvcc(includesMemstoreTS)
         .withIncludesTags(includesTags).withCompression(algo).build();
     if (encoder != null) {
-      return encoder.newDataBlockEncodingContext(encoding, HFILEBLOCK_DUMMY_HEADER, meta);
+      return encoder.newDataBlockEncodingContext(conf, encoding, HFILEBLOCK_DUMMY_HEADER, meta);
     } else {
-      return new HFileBlockDefaultEncodingContext(encoding, HFILEBLOCK_DUMMY_HEADER, meta);
+      return new HFileBlockDefaultEncodingContext(conf, encoding, HFILEBLOCK_DUMMY_HEADER, meta);
     }
   }
 
   /**
-   * Test data block encoding of empty KeyValue. On test failure.
+   * Test data block encoding of empty KeyValue. n * On test failure.
    */
   @Test
   public void testEmptyKeyValues() throws IOException {
@@ -139,7 +141,7 @@ public class TestDataBlockEncoders {
   }
 
   /**
-   * Test KeyValues with negative timestamp. On test failure.
+   * Test KeyValues with negative timestamp. n * On test failure.
    */
   @Test
   public void testNegativeTimestamps() throws IOException {
@@ -189,12 +191,12 @@ public class TestDataBlockEncoders {
       }
       LOG.info("Encoder: " + encoder);
       ByteBuffer encodedBuffer = encodeKeyValues(encoding, sampleKv,
-        getEncodingContext(Compression.Algorithm.NONE, encoding), this.useOffheapData);
+        getEncodingContext(conf, Compression.Algorithm.NONE, encoding), this.useOffheapData);
       HFileContext meta =
         new HFileContextBuilder().withHBaseCheckSum(false).withIncludesMvcc(includesMemstoreTS)
           .withIncludesTags(includesTags).withCompression(Compression.Algorithm.NONE).build();
       DataBlockEncoder.EncodedSeeker seeker =
-        encoder.createSeeker(encoder.newDataBlockDecodingContext(meta));
+        encoder.createSeeker(encoder.newDataBlockDecodingContext(conf, meta));
       seeker.setCurrentBuffer(new SingleByteBuff(encodedBuffer));
       encodedSeekers.add(seeker);
     }
@@ -228,59 +230,6 @@ public class TestDataBlockEncoders {
     LOG.info("Done");
   }
 
-  @Test
-  public void testSeekingToOffHeapKeyValueInSample() throws IOException {
-    List<KeyValue> sampleKv = generator.generateTestKeyValues(NUMBER_OF_KV, includesTags);
-
-    // create all seekers
-    List<DataBlockEncoder.EncodedSeeker> encodedSeekers = new ArrayList<>();
-    for (DataBlockEncoding encoding : DataBlockEncoding.values()) {
-      LOG.info("Encoding: " + encoding);
-      DataBlockEncoder encoder = encoding.getEncoder();
-      if (encoder == null) {
-        continue;
-      }
-      LOG.info("Encoder: " + encoder);
-      ByteBuffer encodedBuffer = encodeKeyValues(encoding, sampleKv,
-        getEncodingContext(Compression.Algorithm.NONE, encoding), this.useOffheapData);
-      HFileContext meta =
-        new HFileContextBuilder().withHBaseCheckSum(false).withIncludesMvcc(includesMemstoreTS)
-          .withIncludesTags(includesTags).withCompression(Compression.Algorithm.NONE).build();
-      DataBlockEncoder.EncodedSeeker seeker =
-        encoder.createSeeker(encoder.newDataBlockDecodingContext(meta));
-      seeker.setCurrentBuffer(new SingleByteBuff(encodedBuffer));
-      encodedSeekers.add(seeker);
-    }
-    LOG.info("Testing it!");
-    // test it!
-    // try a few random seeks
-    Random rand = ThreadLocalRandom.current();
-    for (boolean seekBefore : new boolean[] { false, true }) {
-      for (int i = 0; i < NUM_RANDOM_SEEKS; ++i) {
-        int keyValueId;
-        if (!seekBefore) {
-          keyValueId = rand.nextInt(sampleKv.size());
-        } else {
-          keyValueId = rand.nextInt(sampleKv.size() - 1) + 1;
-        }
-
-        KeyValue keyValue = sampleKv.get(keyValueId);
-        checkSeekingConsistency(encodedSeekers, seekBefore, buildOffHeapKeyValue(keyValue));
-      }
-    }
-
-    // check edge cases
-    LOG.info("Checking edge cases");
-    checkSeekingConsistency(encodedSeekers, false, sampleKv.get(0));
-    for (boolean seekBefore : new boolean[] { false, true }) {
-      checkSeekingConsistency(encodedSeekers, seekBefore, sampleKv.get(sampleKv.size() - 1));
-      KeyValue midKv = sampleKv.get(sampleKv.size() / 2);
-      Cell lastMidKv = PrivateCellUtil.createLastOnRowCol(midKv);
-      checkSeekingConsistency(encodedSeekers, seekBefore, lastMidKv);
-    }
-    LOG.info("Done");
-  }
-
   static ByteBuffer encodeKeyValues(DataBlockEncoding encoding, List<KeyValue> kvs,
     HFileBlockEncodingContext encodingContext, boolean useOffheapData) throws IOException {
     DataBlockEncoder encoder = encoding.getEncoder();
@@ -313,12 +262,12 @@ public class TestDataBlockEncoders {
       }
       DataBlockEncoder encoder = encoding.getEncoder();
       ByteBuffer encodedBuffer = encodeKeyValues(encoding, sampleKv,
-        getEncodingContext(Compression.Algorithm.NONE, encoding), this.useOffheapData);
+        getEncodingContext(conf, Compression.Algorithm.NONE, encoding), this.useOffheapData);
       HFileContext meta =
         new HFileContextBuilder().withHBaseCheckSum(false).withIncludesMvcc(includesMemstoreTS)
           .withIncludesTags(includesTags).withCompression(Compression.Algorithm.NONE).build();
       DataBlockEncoder.EncodedSeeker seeker =
-        encoder.createSeeker(encoder.newDataBlockDecodingContext(meta));
+        encoder.createSeeker(encoder.newDataBlockDecodingContext(conf, meta));
       seeker.setCurrentBuffer(new SingleByteBuff(encodedBuffer));
       int i = 0;
       do {
@@ -343,7 +292,7 @@ public class TestDataBlockEncoders {
   }
 
   /**
-   * Test whether the decompression of first key is implemented correctly.
+   * Test whether the decompression of first key is implemented correctly. n
    */
   @Test
   public void testFirstKeyInBlockOnSample() throws IOException {
@@ -355,7 +304,7 @@ public class TestDataBlockEncoders {
       }
       DataBlockEncoder encoder = encoding.getEncoder();
       ByteBuffer encodedBuffer = encodeKeyValues(encoding, sampleKv,
-        getEncodingContext(Compression.Algorithm.NONE, encoding), this.useOffheapData);
+        getEncodingContext(conf, Compression.Algorithm.NONE, encoding), this.useOffheapData);
       Cell key = encoder.getFirstKeyCellInBlock(new SingleByteBuff(encodedBuffer));
       KeyValue firstKv = sampleKv.get(0);
       if (0 != PrivateCellUtil.compareKeyIgnoresMvcc(CellComparatorImpl.COMPARATOR, key, firstKv)) {
@@ -377,12 +326,12 @@ public class TestDataBlockEncoders {
     DataBlockEncoding encoding = DataBlockEncoding.ROW_INDEX_V1;
     DataBlockEncoder encoder = encoding.getEncoder();
     ByteBuffer encodedBuffer =
-      encodeKeyValues(encoding, kvList, getEncodingContext(Algorithm.NONE, encoding), false);
+      encodeKeyValues(encoding, kvList, getEncodingContext(conf, Algorithm.NONE, encoding), false);
     HFileContext meta =
       new HFileContextBuilder().withHBaseCheckSum(false).withIncludesMvcc(includesMemstoreTS)
         .withIncludesTags(includesTags).withCompression(Compression.Algorithm.NONE).build();
     DataBlockEncoder.EncodedSeeker seeker =
-      encoder.createSeeker(encoder.newDataBlockDecodingContext(meta));
+      encoder.createSeeker(encoder.newDataBlockDecodingContext(conf, meta));
     seeker.setCurrentBuffer(new SingleByteBuff(encodedBuffer));
     Cell cell = seeker.getCell();
     Assert.assertEquals(expectedKV.getLength(), ((KeyValue) cell).getLength());
@@ -434,8 +383,7 @@ public class TestDataBlockEncoders {
         continue;
       }
       HFileBlockEncodingContext encodingContext =
-        new HFileBlockDefaultEncodingContext(encoding, HFILEBLOCK_DUMMY_HEADER, fileContext);
-
+        new HFileBlockDefaultEncodingContext(conf, encoding, HFILEBLOCK_DUMMY_HEADER, fileContext);
       ByteArrayOutputStream baos = new ByteArrayOutputStream();
       baos.write(HFILEBLOCK_DUMMY_HEADER);
       DataOutputStream dos = new DataOutputStream(baos);
@@ -481,7 +429,7 @@ public class TestDataBlockEncoders {
     HFileContext meta =
       new HFileContextBuilder().withHBaseCheckSum(false).withIncludesMvcc(includesMemstoreTS)
         .withIncludesTags(includesTags).withCompression(Compression.Algorithm.NONE).build();
-    actualDataset = encoder.decodeKeyValues(dis, encoder.newDataBlockDecodingContext(meta));
+    actualDataset = encoder.decodeKeyValues(dis, encoder.newDataBlockDecodingContext(conf, meta));
     actualDataset.rewind();
 
     // this is because in case of prefix tree the decoded stream will not have
@@ -490,15 +438,4 @@ public class TestDataBlockEncoders {
     assertEquals("Encoding -> decoding gives different results for " + encoder,
       Bytes.toStringBinary(unencodedDataBuf), Bytes.toStringBinary(actualDataset));
   }
-
-  private static ByteBufferKeyValue buildOffHeapKeyValue(KeyValue keyValue) throws IOException {
-    ByteArrayOutputStream out = new ByteArrayOutputStream();
-    keyValue.write(out, false);
-    byte[] bytes = out.toByteArray();
-    ByteBuffer bb = ByteBuffer.allocateDirect(bytes.length);
-    bb.put(bytes);
-    bb.flip();
-
-    return new ByteBufferKeyValue(bb, 0, bytes.length);
-  }
 }
