@@ -42,13 +42,11 @@ import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.HBaseCommonTestingUtility;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
-import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.KeyValueUtil;
 import org.apache.hadoop.hbase.PrivateCellUtil;
 import org.apache.hadoop.hbase.fs.HFileSystem;
 import org.apache.hadoop.hbase.io.ByteBuffAllocator;
-import org.apache.hadoop.hbase.io.FSDataInputStreamWrapper;
 import org.apache.hadoop.hbase.io.compress.Compression;
 import org.apache.hadoop.hbase.io.compress.Compression.Algorithm;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
@@ -178,14 +176,6 @@ public class TestHFileBlockIndex {
     public HFileBlock readBlock(long offset, long onDiskSize, boolean cacheBlock, boolean pread,
       boolean isCompaction, boolean updateCacheMetrics, BlockType expectedBlockType,
       DataBlockEncoding expectedDataBlockEncoding) throws IOException {
-      return readBlock(offset, onDiskSize, cacheBlock, pread, isCompaction, updateCacheMetrics,
-        expectedBlockType, expectedDataBlockEncoding, false);
-    }
-
-    @Override
-    public HFileBlock readBlock(long offset, long onDiskSize, boolean cacheBlock, boolean pread,
-      boolean isCompaction, boolean updateCacheMetrics, BlockType expectedBlockType,
-      DataBlockEncoding expectedDataBlockEncoding, boolean cacheOnly) throws IOException {
       if (offset == prevOffset && onDiskSize == prevOnDiskSize && pread == prevPread) {
         hitCount += 1;
         return prevBlock;
@@ -211,7 +201,7 @@ public class TestHFileBlockIndex {
         .withIncludesTags(useTags).withCompression(compr).build();
     ReaderContext context = new ReaderContextBuilder().withFileSystemAndPath(fs, path).build();
     HFileBlock.FSReader blockReader =
-      new HFileBlock.FSReaderImpl(context, meta, ByteBuffAllocator.HEAP);
+      new HFileBlock.FSReaderImpl(context, meta, ByteBuffAllocator.HEAP, conf);
 
     BlockReaderWrapper brw = new BlockReaderWrapper(blockReader);
     HFileBlockIndex.BlockIndexReader indexReader =
@@ -262,7 +252,7 @@ public class TestHFileBlockIndex {
     HFileContext meta = new HFileContextBuilder().withHBaseCheckSum(true)
       .withIncludesMvcc(includesMemstoreTS).withIncludesTags(useTags).withCompression(compr)
       .withBytesPerCheckSum(HFile.DEFAULT_BYTES_PER_CHECKSUM).build();
-    HFileBlock.Writer hbw = new HFileBlock.Writer(null, meta);
+    HFileBlock.Writer hbw = new HFileBlock.Writer(TEST_UTIL.getConfiguration(), null, meta);
     FSDataOutputStream outputStream = fs.create(path);
     HFileBlockIndex.BlockIndexWriter biw = new HFileBlockIndex.BlockIndexWriter(hbw, null, null);
     for (int i = 0; i < NUM_DATA_BLOCKS; ++i) {
@@ -496,7 +486,7 @@ public class TestHFileBlockIndex {
   }
 
   /**
-   * to check if looks good when midKey on a leaf index block boundary
+   * to check if looks good when midKey on a leaf index block boundary n
    */
   @Test
   public void testMidKeyOnLeafIndexBlockBoundary() throws IOException {
@@ -553,6 +543,7 @@ public class TestHFileBlockIndex {
   /**
    * Testing block index through the HFile writer/reader APIs. Allows to test setting index block
    * size through configuration, intermediate-level index blocks, and caching index blocks on write.
+   * n
    */
   @Test
   public void testHFileWriterAndReader() throws IOException {
@@ -610,7 +601,7 @@ public class TestHFileBlockIndex {
       LOG.info("Last key: " + Bytes.toStringBinary(keys[NUM_KV - 1]));
 
       for (boolean pread : new boolean[] { false, true }) {
-        HFileScanner scanner = reader.getScanner(true, pread);
+        HFileScanner scanner = reader.getScanner(conf, true, pread);
         for (int i = 0; i < NUM_KV; ++i) {
           checkSeekTo(keys, scanner, i);
           checkKeyValue("i=" + i, keys[i], values[i],
@@ -726,71 +717,10 @@ public class TestHFileBlockIndex {
 
     HFile.Reader reader = HFile.createReader(fs, hfPath, cacheConf, true, conf);
     // Scanner doesn't do Cells yet. Fix.
-    HFileScanner scanner = reader.getScanner(true, true);
+    HFileScanner scanner = reader.getScanner(conf, true, true);
     for (int i = 0; i < keys.size(); ++i) {
       scanner.seekTo(CellUtil.createCell(keys.get(i)));
     }
     reader.close();
   }
-
-  /**
-   * This test is for HBASE-27940, which midkey metadata in root index block would always be ignored
-   * by {@link BlockIndexReader#readMultiLevelIndexRoot}.
-   */
-  @Test
-  public void testMidKeyReadSuccessfullyFromRootIndexBlock() throws IOException {
-    conf.setInt(HFileBlockIndex.MAX_CHUNK_SIZE_KEY, 128);
-    Path hfilePath =
-      new Path(TEST_UTIL.getDataTestDir(), "testMidKeyReadSuccessfullyFromRootIndexBlock");
-    Compression.Algorithm compressAlgo = Compression.Algorithm.NONE;
-    int entryCount = 50000;
-    HFileContext context = new HFileContextBuilder().withBlockSize(4096).withIncludesTags(false)
-      .withDataBlockEncoding(DataBlockEncoding.NONE).withCompression(compressAlgo).build();
-
-    try (HFile.Writer writer = new HFile.WriterFactory(conf, new CacheConfig(conf))
-      .withPath(fs, hfilePath).withFileContext(context).create()) {
-
-      List<KeyValue> keyValues = new ArrayList<>(entryCount);
-      for (int i = 0; i < entryCount; ++i) {
-        byte[] keyBytes = RandomKeyValueUtil.randomOrderedKey(RNG, i);
-        // A random-length random value.
-        byte[] valueBytes = RandomKeyValueUtil.randomValue(RNG);
-        KeyValue keyValue =
-          new KeyValue(keyBytes, null, null, HConstants.LATEST_TIMESTAMP, valueBytes);
-        writer.append(keyValue);
-        keyValues.add(keyValue);
-      }
-    }
-
-    try (FSDataInputStream fsdis = fs.open(hfilePath)) {
-      long fileSize = fs.getFileStatus(hfilePath).getLen();
-      FixedFileTrailer trailer = FixedFileTrailer.readFromStream(fsdis, fileSize);
-
-      assertEquals(3, trailer.getMajorVersion());
-      assertEquals(entryCount, trailer.getEntryCount());
-      HFileContext meta = new HFileContextBuilder().withCompression(compressAlgo)
-        .withIncludesMvcc(false).withIncludesTags(false)
-        .withDataBlockEncoding(DataBlockEncoding.NONE).withHBaseCheckSum(true).build();
-      ReaderContext readerContext =
-        new ReaderContextBuilder().withInputStreamWrapper(new FSDataInputStreamWrapper(fsdis))
-          .withFilePath(hfilePath).withFileSystem(fs).withFileSize(fileSize).build();
-      HFileBlock.FSReader blockReader =
-        new HFileBlock.FSReaderImpl(readerContext, meta, ByteBuffAllocator.HEAP);
-
-      HFileBlockIndex.CellBasedKeyBlockIndexReader dataBlockIndexReader =
-        new HFileBlockIndex.CellBasedKeyBlockIndexReader(trailer.createComparator(),
-          trailer.getNumDataIndexLevels());
-
-      HFileBlock.BlockIterator blockIter = blockReader.blockRange(trailer.getLoadOnOpenDataOffset(),
-        fileSize - trailer.getTrailerSize());
-      // Data index. We also read statistics about the block index written after
-      // the root level.
-      dataBlockIndexReader.readMultiLevelIndexRoot(
-        blockIter.nextBlockWithBlockType(BlockType.ROOT_INDEX), trailer.getDataIndexCount());
-      // Assert we have read midkey metadata successfully.
-      assertTrue(dataBlockIndexReader.midLeafBlockOffset >= 0);
-      assertTrue(dataBlockIndexReader.midLeafBlockOnDiskSize > 0);
-      assertTrue(dataBlockIndexReader.midKeyEntry >= 0);
-    }
-  }
 }
