@@ -58,7 +58,6 @@ import org.apache.hadoop.hbase.nio.ByteBuff;
 import org.apache.hadoop.hbase.testclassification.IOTests;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.util.Pair;
-import org.apache.hadoop.hbase.util.Threads;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
@@ -121,6 +120,7 @@ public class TestBucketCache {
       int writerThreads, int writerQLen, String persistencePath) throws IOException {
       super(ioEngineName, capacity, blockSize, bucketSizes, writerThreads, writerQLen,
         persistencePath);
+      super.wait_when_cache = true;
     }
 
     @Override
@@ -242,8 +242,8 @@ public class TestBucketCache {
   // BucketCache.cacheBlock is async, it first adds block to ramCache and writeQueue, then writer
   // threads will flush it to the bucket and put reference entry in backingMap.
   private void cacheAndWaitUntilFlushedToBucket(BucketCache cache, BlockCacheKey cacheKey,
-    Cacheable block, boolean waitWhenCache) throws InterruptedException {
-    cache.cacheBlock(cacheKey, block, false, waitWhenCache);
+    Cacheable block) throws InterruptedException {
+    cache.cacheBlock(cacheKey, block);
     waitUntilFlushedToBucket(cache, cacheKey);
   }
 
@@ -251,7 +251,7 @@ public class TestBucketCache {
   public void testMemoryLeak() throws Exception {
     final BlockCacheKey cacheKey = new BlockCacheKey("dummy", 1L);
     cacheAndWaitUntilFlushedToBucket(cache, cacheKey,
-      new CacheTestUtils.ByteArrayCacheable(new byte[10]), true);
+      new CacheTestUtils.ByteArrayCacheable(new byte[10]));
     long lockId = cache.backingMap.get(cacheKey).offset();
     ReentrantReadWriteLock lock = cache.offsetLock.getLock(lockId);
     lock.writeLock().lock();
@@ -263,10 +263,10 @@ public class TestBucketCache {
     };
     evictThread.start();
     cache.offsetLock.waitForWaiters(lockId, 1);
-    cache.blockEvicted(cacheKey, cache.backingMap.remove(cacheKey), true);
+    cache.blockEvicted(cacheKey, cache.backingMap.remove(cacheKey), true, true);
     assertEquals(0, cache.getBlockCount());
     cacheAndWaitUntilFlushedToBucket(cache, cacheKey,
-      new CacheTestUtils.ByteArrayCacheable(new byte[10]), false);
+      new CacheTestUtils.ByteArrayCacheable(new byte[10]));
     assertEquals(1, cache.getBlockCount());
     lock.writeLock().unlock();
     evictThread.join();
@@ -312,7 +312,7 @@ public class TestBucketCache {
       bucketCache.cacheBlock(block.getBlockName(), block.getBlock());
     }
     for (HFileBlockPair block : blocks) {
-      cacheAndWaitUntilFlushedToBucket(bucketCache, block.getBlockName(), block.getBlock(), false);
+      cacheAndWaitUntilFlushedToBucket(bucketCache, block.getBlockName(), block.getBlock());
     }
     usedSize = bucketCache.getAllocator().getUsedSize();
     assertNotEquals(0, usedSize);
@@ -481,6 +481,56 @@ public class TestBucketCache {
     assertEquals(testValue, bucketEntry.offset());
   }
 
+  @Test
+  public void testEvictionCount() throws InterruptedException {
+    int size = 100;
+    int length = HConstants.HFILEBLOCK_HEADER_SIZE + size;
+    ByteBuffer buf1 = ByteBuffer.allocate(size), buf2 = ByteBuffer.allocate(size);
+    HFileContext meta = new HFileContextBuilder().build();
+    ByteBuffAllocator allocator = ByteBuffAllocator.HEAP;
+    HFileBlock blockWithNextBlockMetadata = new HFileBlock(BlockType.DATA, size, size, -1,
+      ByteBuff.wrap(buf1), HFileBlock.FILL_HEADER, -1, 52, -1, meta, allocator);
+    HFileBlock blockWithoutNextBlockMetadata = new HFileBlock(BlockType.DATA, size, size, -1,
+      ByteBuff.wrap(buf2), HFileBlock.FILL_HEADER, -1, -1, -1, meta, allocator);
+
+    BlockCacheKey key = new BlockCacheKey("testEvictionCount", 0);
+    ByteBuffer actualBuffer = ByteBuffer.allocate(length);
+    ByteBuffer block1Buffer = ByteBuffer.allocate(length);
+    ByteBuffer block2Buffer = ByteBuffer.allocate(length);
+    blockWithNextBlockMetadata.serialize(block1Buffer, true);
+    blockWithoutNextBlockMetadata.serialize(block2Buffer, true);
+
+    // Add blockWithNextBlockMetadata, expect blockWithNextBlockMetadata back.
+    CacheTestUtils.getBlockAndAssertEquals(cache, key, blockWithNextBlockMetadata, actualBuffer,
+      block1Buffer);
+
+    waitUntilFlushedToBucket(cache, key);
+
+    assertEquals(0, cache.getStats().getEvictionCount());
+
+    // evict call should return 1, but then eviction count be 0
+    assertEquals(1, cache.evictBlocksByHfileName("testEvictionCount"));
+    assertEquals(0, cache.getStats().getEvictionCount());
+
+    // add back
+    CacheTestUtils.getBlockAndAssertEquals(cache, key, blockWithNextBlockMetadata, actualBuffer,
+      block1Buffer);
+    waitUntilFlushedToBucket(cache, key);
+
+    // should not increment
+    assertTrue(cache.evictBlock(key));
+    assertEquals(0, cache.getStats().getEvictionCount());
+
+    // add back
+    CacheTestUtils.getBlockAndAssertEquals(cache, key, blockWithNextBlockMetadata, actualBuffer,
+      block1Buffer);
+    waitUntilFlushedToBucket(cache, key);
+
+    // should finally increment eviction count
+    cache.freeSpace("testing");
+    assertEquals(1, cache.getStats().getEvictionCount());
+  }
+
   @Test
   public void testCacheBlockNextBlockMetadataMissing() throws Exception {
     int size = 100;
@@ -606,7 +656,8 @@ public class TestBucketCache {
 
     Assert.assertEquals(0, allocator.getUsedSize());
     try {
-      re.writeToCache(ioEngine, allocator, null, null);
+      re.writeToCache(ioEngine, allocator, null, null,
+        ByteBuffer.allocate(HFileBlock.BLOCK_METADATA_SPACE));
       Assert.fail();
     } catch (Exception e) {
     }
@@ -640,7 +691,7 @@ public class TestBucketCache {
 
       for (HFileBlockPair hfileBlockPair : hfileBlockPairs) {
         cacheAndWaitUntilFlushedToBucket(bucketCache, hfileBlockPair.getBlockName(),
-          hfileBlockPair.getBlock(), false);
+          hfileBlockPair.getBlock());
       }
       usedByteSize = bucketCache.getAllocator().getUsedSize();
       assertNotEquals(0, usedByteSize);
@@ -665,58 +716,4 @@ public class TestBucketCache {
     }
   }
 
-  @Test
-  public void testBlockAdditionWaitWhenCache() throws Exception {
-    try {
-      final Path dataTestDir = createAndGetTestDir();
-
-      String ioEngineName = "file:" + dataTestDir + "/bucketNoRecycler.cache";
-      String persistencePath = dataTestDir + "/bucketNoRecycler.persistence";
-
-      BucketCache bucketCache = new BucketCache(ioEngineName, capacitySize, constructedBlockSize,
-        constructedBlockSizes, 1, 1, persistencePath);
-      long usedByteSize = bucketCache.getAllocator().getUsedSize();
-      assertEquals(0, usedByteSize);
-
-      HFileBlockPair[] hfileBlockPairs =
-        CacheTestUtils.generateHFileBlocks(constructedBlockSize, 10);
-      // Add blocks
-      for (HFileBlockPair hfileBlockPair : hfileBlockPairs) {
-        bucketCache.cacheBlock(hfileBlockPair.getBlockName(), hfileBlockPair.getBlock(), false,
-          true);
-      }
-
-      // Max wait for 10 seconds.
-      long timeout = 10000;
-      // Wait for blocks size to match the number of blocks.
-      while (bucketCache.backingMap.size() != 10) {
-        if (timeout <= 0) break;
-        Threads.sleep(100);
-        timeout -= 100;
-      }
-      for (HFileBlockPair hfileBlockPair : hfileBlockPairs) {
-        assertTrue(bucketCache.backingMap.containsKey(hfileBlockPair.getBlockName()));
-      }
-      usedByteSize = bucketCache.getAllocator().getUsedSize();
-      assertNotEquals(0, usedByteSize);
-      // persist cache to file
-      bucketCache.shutdown();
-      assertTrue(new File(persistencePath).exists());
-
-      // restore cache from file
-      bucketCache = new BucketCache(ioEngineName, capacitySize, constructedBlockSize,
-        constructedBlockSizes, writeThreads, writerQLen, persistencePath);
-      assertFalse(new File(persistencePath).exists());
-      assertEquals(usedByteSize, bucketCache.getAllocator().getUsedSize());
-
-      for (HFileBlockPair hfileBlockPair : hfileBlockPairs) {
-        BlockCacheKey blockCacheKey = hfileBlockPair.getBlockName();
-        bucketCache.evictBlock(blockCacheKey);
-      }
-      assertEquals(0, bucketCache.getAllocator().getUsedSize());
-      assertEquals(0, bucketCache.backingMap.size());
-    } finally {
-      HBASE_TESTING_UTILITY.cleanupTestDir();
-    }
-  }
 }
