@@ -64,9 +64,13 @@ public class MockNoopMasterServices implements MasterServices {
   private final Configuration conf;
   private final MetricsMaster metricsMaster;
 
+  public MockNoopMasterServices() {
+    this(null);
+  }
+
   public MockNoopMasterServices(final Configuration conf) {
     this.conf = conf;
-    this.metricsMaster = new MetricsMaster(new MetricsMasterWrapperImpl(mock(HMaster.class)));
+    this.metricsMaster = new MetricsMaster(new MetricsMasterWrapperImpl(null));
   }
 
   @Override
@@ -475,4 +479,20 @@ public class MockNoopMasterServices implements MasterServices {
   public MetaLocationSyncer getMetaLocationSyncer() {
     return null;
   }
+
+  @Override
+  public void flushMasterStore() throws IOException {
+  }
+
+  @Override
+  public long modifyTableStoreFileTracker(TableName tableName, String dstSFT, long nonceGroup,
+    long nonce) throws IOException {
+    return -1;
+  }
+
+  @Override
+  public long modifyColumnStoreFileTracker(TableName tableName, byte[] family, String dstSFT,
+    long nonceGroup, long nonce) throws IOException {
+    return -1;
+  }
 }
