@@ -21,8 +21,6 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.Mockito.when;
 
 import java.io.IOException;
 import java.io.InterruptedIOException;
@@ -40,9 +38,9 @@ import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.client.ClusterConnection;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.monitoring.MonitoredTask;
-import org.apache.hadoop.hbase.monitoring.TaskGroup;
 import org.apache.hadoop.hbase.testclassification.MasterTests;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.zookeeper.ClusterStatusTracker;
 import org.apache.hadoop.hbase.zookeeper.MasterAddressTracker;
 import org.apache.hadoop.hbase.zookeeper.ZKListener;
@@ -93,7 +91,7 @@ public class TestActiveMasterManager {
       }
 
       // Create the master node with a dummy address
-      ServerName master = ServerName.valueOf("localhost", 1, System.currentTimeMillis());
+      ServerName master = ServerName.valueOf("localhost", 1, EnvironmentEdgeManager.currentTime());
       // Should not have a master yet
       DummyMaster dummyMaster = new DummyMaster(zk, master);
       ClusterStatusTracker clusterStatusTracker = dummyMaster.getClusterStatusTracker();
@@ -102,7 +100,7 @@ public class TestActiveMasterManager {
       assertFalse(activeMasterManager.getActiveMasterServerName().isPresent());
 
       // First test becoming the active master uninterrupted
-      TaskGroup status = mockTaskGroup();
+      MonitoredTask status = Mockito.mock(MonitoredTask.class);
       clusterStatusTracker.setClusterUp();
 
       activeMasterManager.blockUntilBecomingActiveMaster(100, status);
@@ -124,7 +122,7 @@ public class TestActiveMasterManager {
 
   /**
    * Unit tests that uses ZooKeeper but does not use the master-side methods but rather acts
-   * directly on ZK.
+   * directly on ZK. n
    */
   @Test
   public void testActiveMasterManagerFromZK() throws Exception {
@@ -138,9 +136,9 @@ public class TestActiveMasterManager {
 
       // Create the master node with a dummy address
       ServerName firstMasterAddress =
-        ServerName.valueOf("localhost", 1, System.currentTimeMillis());
+        ServerName.valueOf("localhost", 1, EnvironmentEdgeManager.currentTime());
       ServerName secondMasterAddress =
-        ServerName.valueOf("localhost", 2, System.currentTimeMillis());
+        ServerName.valueOf("localhost", 2, EnvironmentEdgeManager.currentTime());
 
       // Should not have a master yet
       DummyMaster ms1 = new DummyMaster(zk, firstMasterAddress);
@@ -151,8 +149,7 @@ public class TestActiveMasterManager {
       // First test becoming the active master uninterrupted
       ClusterStatusTracker clusterStatusTracker = ms1.getClusterStatusTracker();
       clusterStatusTracker.setClusterUp();
-
-      activeMasterManager.blockUntilBecomingActiveMaster(100, mockTaskGroup());
+      activeMasterManager.blockUntilBecomingActiveMaster(100, Mockito.mock(MonitoredTask.class));
       assertTrue(activeMasterManager.clusterHasActiveMaster.get());
       assertMaster(zk, firstMasterAddress);
       assertMaster(zk, activeMasterManager.getActiveMasterServerName().get());
@@ -218,7 +215,7 @@ public class TestActiveMasterManager {
       ServerName sn1 = ServerName.valueOf("localhost", 1, -1);
       DummyMaster master1 = new DummyMaster(zk, sn1);
       ActiveMasterManager activeMasterManager = master1.getActiveMasterManager();
-      activeMasterManager.blockUntilBecomingActiveMaster(100, mockTaskGroup());
+      activeMasterManager.blockUntilBecomingActiveMaster(100, Mockito.mock(MonitoredTask.class));
       assertEquals(sn1, activeMasterManager.getActiveMasterServerName().get());
       assertEquals(0, activeMasterManager.getBackupMasters().size());
       // Add backup masters
@@ -271,19 +268,12 @@ public class TestActiveMasterManager {
 
     @Override
     public void run() {
-      manager.blockUntilBecomingActiveMaster(100, mockTaskGroup());
+      manager.blockUntilBecomingActiveMaster(100, Mockito.mock(MonitoredTask.class));
       LOG.info("Second master has become the active master!");
       isActiveMaster = true;
     }
   }
 
-  private static TaskGroup mockTaskGroup() {
-    TaskGroup taskGroup = Mockito.mock(TaskGroup.class);
-    MonitoredTask task = Mockito.mock(MonitoredTask.class);
-    when(taskGroup.addTask(any())).thenReturn(task);
-    return taskGroup;
-  }
-
   public static class NodeDeletionListener extends ZKListener {
     private static final Logger LOG = LoggerFactory.getLogger(NodeDeletionListener.class);
 
