@@ -41,6 +41,7 @@ import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.testclassification.MasterTests;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.Threads;
 import org.apache.hadoop.hbase.zookeeper.MetaTableLocator;
 import org.apache.hadoop.hbase.zookeeper.ZKUtil;
@@ -134,7 +135,7 @@ public class TestMasterNoCluster {
   }
 
   /**
-   * Test starting master then stopping it before its fully up.
+   * Test starting master then stopping it before its fully up. nnn
    */
   @Test
   public void testStopDuringStart() throws IOException, KeeperException, InterruptedException {
@@ -146,13 +147,13 @@ public class TestMasterNoCluster {
   }
 
   /**
-   * Test master failover. Start up three fake regionservers and a master.
-   * @throws org.apache.hbase.thirdparty.com.google.protobuf.ServiceException
+   * Test master failover. Start up three fake regionservers and a master. nnn * @throws
+   * org.apache.hbase.thirdparty.com.google.protobuf.ServiceException
    */
   @Ignore
   @Test // Disabled since HBASE-18511. Reenable when master can carry regions.
   public void testFailover() throws Exception {
-    final long now = System.currentTimeMillis();
+    final long now = EnvironmentEdgeManager.currentTime();
     // Names for our three servers. Make the port numbers match hostname.
     // Will come in use down in the server when we need to figure how to respond.
     final ServerName sn0 = ServerName.valueOf("0.example.org", 0, now);
@@ -209,8 +210,9 @@ public class TestMasterNoCluster {
       }
 
       @Override
-      protected ServerManager createServerManager(MasterServices master) throws IOException {
-        ServerManager sm = super.createServerManager(master);
+      protected ServerManager createServerManager(MasterServices master, RegionServerList storage)
+        throws IOException {
+        ServerManager sm = super.createServerManager(master, storage);
         // Spy on the created servermanager
         ServerManager spy = Mockito.spy(sm);
         return spy;
