@@ -21,21 +21,19 @@ import static org.apache.hadoop.hbase.util.HFileArchiveTestingUtil.assertArchive
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.when;
 
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
+import java.util.NavigableMap;
 import java.util.Objects;
 import java.util.SortedMap;
+import java.util.SortedSet;
 import java.util.TreeMap;
-import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.ConcurrentSkipListMap;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
@@ -46,13 +44,12 @@ import org.apache.hadoop.hbase.HColumnDescriptor;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.MetaMockingUtil;
+import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.io.Reference;
-import org.apache.hadoop.hbase.master.MasterFileSystem;
 import org.apache.hadoop.hbase.master.MasterServices;
 import org.apache.hadoop.hbase.master.assignment.MockMasterServices;
 import org.apache.hadoop.hbase.master.janitor.CatalogJanitor.SplitParentFirstComparator;
@@ -66,6 +63,7 @@ import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.HFileArchiveUtil;
+import org.apache.zookeeper.KeeperException;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.BeforeClass;
@@ -101,9 +99,11 @@ public class TestCatalogJanitor {
   }
 
   @Before
-  public void setup() throws Exception {
+  public void setup() throws IOException, KeeperException {
     setRootDirAndCleanIt(HTU, this.name.getMethodName());
-    this.masterServices = new MockMasterServices(HTU.getConfiguration());
+    NavigableMap<ServerName, SortedSet<byte[]>> regionsToRegionServers =
+      new ConcurrentSkipListMap<ServerName, SortedSet<byte[]>>();
+    this.masterServices = new MockMasterServices(HTU.getConfiguration(), regionsToRegionServers);
     this.masterServices.start(10, null);
     this.janitor = new CatalogJanitor(masterServices);
   }
@@ -114,100 +114,6 @@ public class TestCatalogJanitor {
     this.masterServices.stop("DONE");
   }
 
-  @Test
-  public void testCleanMerge() throws IOException {
-    TableDescriptor td = createTableDescriptorForCurrentMethod();
-    // Create regions.
-    HRegionInfo merged =
-      new HRegionInfo(td.getTableName(), Bytes.toBytes("aaa"), Bytes.toBytes("eee"));
-    HRegionInfo parenta =
-      new HRegionInfo(td.getTableName(), Bytes.toBytes("aaa"), Bytes.toBytes("ccc"));
-    HRegionInfo parentb =
-      new HRegionInfo(td.getTableName(), Bytes.toBytes("ccc"), Bytes.toBytes("eee"));
-
-    List<RegionInfo> parents = new ArrayList<>();
-    parents.add(parenta);
-    parents.add(parentb);
-
-    Path rootdir = this.masterServices.getMasterFileSystem().getRootDir();
-    Path tabledir = CommonFSUtils.getTableDir(rootdir, td.getTableName());
-    Path storedir =
-      HRegionFileSystem.getStoreHomedir(tabledir, merged, td.getColumnFamilies()[0].getName());
-
-    Path parentaRef = createMergeReferenceFile(storedir, merged, parenta);
-    Path parentbRef = createMergeReferenceFile(storedir, merged, parentb);
-
-    // references exist, should not clean
-    assertFalse(CatalogJanitor.cleanMergeRegion(masterServices, merged, parents));
-
-    masterServices.getMasterFileSystem().getFileSystem().delete(parentaRef, false);
-
-    // one reference still exists, should not clean
-    assertFalse(CatalogJanitor.cleanMergeRegion(masterServices, merged, parents));
-
-    masterServices.getMasterFileSystem().getFileSystem().delete(parentbRef, false);
-
-    // all references removed, should clean
-    assertTrue(CatalogJanitor.cleanMergeRegion(masterServices, merged, parents));
-  }
-
-  @Test
-  public void testDontCleanMergeIfFileSystemException() throws IOException {
-    TableDescriptor td = createTableDescriptorForCurrentMethod();
-    // Create regions.
-    HRegionInfo merged =
-      new HRegionInfo(td.getTableName(), Bytes.toBytes("aaa"), Bytes.toBytes("eee"));
-    HRegionInfo parenta =
-      new HRegionInfo(td.getTableName(), Bytes.toBytes("aaa"), Bytes.toBytes("ccc"));
-    HRegionInfo parentb =
-      new HRegionInfo(td.getTableName(), Bytes.toBytes("ccc"), Bytes.toBytes("eee"));
-
-    List<RegionInfo> parents = new ArrayList<>();
-    parents.add(parenta);
-    parents.add(parentb);
-
-    Path rootdir = this.masterServices.getMasterFileSystem().getRootDir();
-    Path tabledir = CommonFSUtils.getTableDir(rootdir, td.getTableName());
-    Path storedir =
-      HRegionFileSystem.getStoreHomedir(tabledir, merged, td.getColumnFamilies()[0].getName());
-    createMergeReferenceFile(storedir, merged, parenta);
-
-    MasterServices mockedMasterServices = spy(masterServices);
-    MasterFileSystem mockedMasterFileSystem = spy(masterServices.getMasterFileSystem());
-    FileSystem mockedFileSystem = spy(masterServices.getMasterFileSystem().getFileSystem());
-
-    when(mockedMasterServices.getMasterFileSystem()).thenReturn(mockedMasterFileSystem);
-    when(mockedMasterFileSystem.getFileSystem()).thenReturn(mockedFileSystem);
-
-    // throw on the first exists check
-    doThrow(new IOException("Some exception")).when(mockedFileSystem).exists(any());
-
-    assertFalse(CatalogJanitor.cleanMergeRegion(mockedMasterServices, merged, parents));
-
-    // throw on the second exists check (within HRegionfileSystem)
-    AtomicBoolean returned = new AtomicBoolean(false);
-    doAnswer(invocationOnMock -> {
-      if (!returned.get()) {
-        returned.set(true);
-        return masterServices.getMasterFileSystem().getFileSystem()
-          .exists(invocationOnMock.getArgument(0));
-      }
-      throw new IOException("Some exception");
-    }).when(mockedFileSystem).exists(any());
-
-    assertFalse(CatalogJanitor.cleanMergeRegion(mockedMasterServices, merged, parents));
-  }
-
-  private Path createMergeReferenceFile(Path storeDir, HRegionInfo mergedRegion,
-    HRegionInfo parentRegion) throws IOException {
-    Reference ref = Reference.createTopReference(mergedRegion.getStartKey());
-    long now = EnvironmentEdgeManager.currentTime();
-    // Reference name has this format: StoreFile#REF_NAME_PARSER
-    Path p = new Path(storeDir, Long.toString(now) + "." + parentRegion.getEncodedName());
-    FileSystem fs = this.masterServices.getMasterFileSystem().getFileSystem();
-    return ref.write(fs, p);
-  }
-
   /**
    * Test clearing a split parent.
    */
@@ -230,7 +136,7 @@ public class TestCatalogJanitor {
     Path storedir =
       HRegionFileSystem.getStoreHomedir(tabledir, splita, td.getColumnFamilies()[0].getName());
     Reference ref = Reference.createTopReference(Bytes.toBytes("ccc"));
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     // Reference name has this format: StoreFile#REF_NAME_PARSER
     Path p = new Path(storedir, Long.toString(now) + "." + parent.getEncodedName());
     FileSystem fs = this.masterServices.getMasterFileSystem().getFileSystem();
@@ -434,7 +340,7 @@ public class TestCatalogJanitor {
   }
 
   /**
-   * Test that we correctly archive all the storefiles when a region is deleted
+   * Test that we correctly archive all the storefiles when a region is deleted n
    */
   @Test
   public void testSplitParentFirstComparator() {
@@ -700,7 +606,7 @@ public class TestCatalogJanitor {
       HRegionFileSystem.getStoreHomedir(tabledir, daughter, td.getColumnFamilies()[0].getName());
     Reference ref =
       top ? Reference.createTopReference(midkey) : Reference.createBottomReference(midkey);
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     // Reference name has this format: StoreFile#REF_NAME_PARSER
     Path p = new Path(storedir, Long.toString(now) + "." + parent.getEncodedName());
     FileSystem fs = services.getMasterFileSystem().getFileSystem();
