@@ -21,8 +21,8 @@ import static java.lang.String.format;
 import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.DEFAULT_MERGE_MIN_REGION_AGE_DAYS;
 import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.MERGE_ENABLED_KEY;
 import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.MERGE_MIN_REGION_AGE_DAYS_KEY;
+import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.MERGE_MIN_REGION_COUNT_KEY;
 import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.MERGE_MIN_REGION_SIZE_MB_KEY;
-import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.MERGE_REQUEST_MAX_NUMBER_OF_REGIONS_COUNT_KEY;
 import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.MIN_REGION_COUNT_KEY;
 import static org.apache.hadoop.hbase.master.normalizer.SimpleRegionNormalizer.SPLIT_ENABLED_KEY;
 import static org.hamcrest.MatcherAssert.assertThat;
@@ -138,7 +138,7 @@ public class TestSimpleRegionNormalizer {
     when(
       masterServices.getAssignmentManager().getRegionStates().getRegionState(any(RegionInfo.class)))
         .thenReturn(RegionState.createForTesting(null, state));
-    assertThat(normalizer.getMinRegionCount(), greaterThanOrEqualTo(regionInfos.size()));
+    assertThat(normalizer.getMergeMinRegionCount(), greaterThanOrEqualTo(regionInfos.size()));
 
     List<NormalizationPlan> plans = normalizer.computePlansForTable(tableDescriptor);
     assertThat(format("Unexpected plans for RegionState %s", state), plans, empty());
@@ -342,7 +342,19 @@ public class TestSimpleRegionNormalizer {
 
   @Test
   public void testHonorsMinimumRegionCount() {
-    conf.setInt(MIN_REGION_COUNT_KEY, 1);
+    honorsMinimumRegionCount(MERGE_MIN_REGION_COUNT_KEY);
+  }
+
+  /**
+   * Test the backward compatibility of the deprecated MIN_REGION_COUNT_KEY configuration.
+   */
+  @Test
+  public void testHonorsOldMinimumRegionCount() {
+    honorsMinimumRegionCount(MIN_REGION_COUNT_KEY);
+  }
+
+  private void honorsMinimumRegionCount(String confKey) {
+    conf.setInt(confKey, 1);
     final TableName tableName = name.getTableName();
     final List<RegionInfo> regionInfos = createRegionInfos(tableName, 3);
     // create a table topology that results in both a merge plan and a split plan. Assert that the
@@ -350,6 +362,7 @@ public class TestSimpleRegionNormalizer {
     // threshold, and that the split plan is create in both cases.
     final Map<byte[], Integer> regionSizes = createRegionSizesMap(regionInfos, 1, 1, 10);
     setupMocksForNormalizer(regionSizes, regionInfos);
+    assertEquals(1, normalizer.getMergeMinRegionCount());
 
     List<NormalizationPlan> plans = normalizer.computePlansForTable(tableDescriptor);
     assertThat(plans,
@@ -358,15 +371,29 @@ public class TestSimpleRegionNormalizer {
           .addTarget(regionInfos.get(1), 1).build()));
 
     // have to call setupMocks again because we don't have dynamic config update on normalizer.
-    conf.setInt(MIN_REGION_COUNT_KEY, 4);
+    conf.setInt(confKey, 4);
     setupMocksForNormalizer(regionSizes, regionInfos);
+    assertEquals(4, normalizer.getMergeMinRegionCount());
     assertThat(normalizer.computePlansForTable(tableDescriptor),
       contains(new SplitNormalizationPlan(regionInfos.get(2), 10)));
   }
 
   @Test
   public void testHonorsMinimumRegionCountInTD() {
-    conf.setInt(MIN_REGION_COUNT_KEY, 1);
+    honorsOldMinimumRegionCountInTD(MERGE_MIN_REGION_COUNT_KEY);
+  }
+
+  /**
+   * Test the backward compatibility of the deprecated MIN_REGION_COUNT_KEY configuration in table
+   * descriptor.
+   */
+  @Test
+  public void testHonorsOldMinimumRegionCountInTD() {
+    honorsOldMinimumRegionCountInTD(MIN_REGION_COUNT_KEY);
+  }
+
+  private void honorsOldMinimumRegionCountInTD(String confKey) {
+    conf.setInt(confKey, 1);
     final TableName tableName = name.getTableName();
     final List<RegionInfo> regionInfos = createRegionInfos(tableName, 3);
     // create a table topology that results in both a merge plan and a split plan. Assert that the
@@ -374,6 +401,7 @@ public class TestSimpleRegionNormalizer {
     // threshold, and that the split plan is create in both cases.
     final Map<byte[], Integer> regionSizes = createRegionSizesMap(regionInfos, 1, 1, 10);
     setupMocksForNormalizer(regionSizes, regionInfos);
+    assertEquals(1, normalizer.getMergeMinRegionCount());
 
     List<NormalizationPlan> plans = normalizer.computePlansForTable(tableDescriptor);
     assertThat(plans,
@@ -381,7 +409,7 @@ public class TestSimpleRegionNormalizer {
         new MergeNormalizationPlan.Builder().addTarget(regionInfos.get(0), 1)
           .addTarget(regionInfos.get(1), 1).build()));
 
-    when(tableDescriptor.getValue(MIN_REGION_COUNT_KEY)).thenReturn("4");
+    when(tableDescriptor.getValue(confKey)).thenReturn("4");
     assertThat(normalizer.computePlansForTable(tableDescriptor),
       contains(new SplitNormalizationPlan(regionInfos.get(2), 10)));
   }
@@ -469,39 +497,6 @@ public class TestSimpleRegionNormalizer {
     assertThat(normalizer.computePlansForTable(tableDescriptor), empty());
   }
 
-  @Test
-  public void testHonorsMergeRequestMaxNumberOfRegionsCount() {
-    conf.setBoolean(SPLIT_ENABLED_KEY, false);
-    conf.setInt(MERGE_MIN_REGION_SIZE_MB_KEY, 0);
-    conf.setInt(MERGE_REQUEST_MAX_NUMBER_OF_REGIONS_COUNT_KEY, 3);
-    final TableName tableName = name.getTableName();
-    final List<RegionInfo> regionInfos = createRegionInfos(tableName, 5);
-    final Map<byte[], Integer> regionSizes = createRegionSizesMap(regionInfos, 0, 1, 0, 1, 0);
-    setupMocksForNormalizer(regionSizes, regionInfos);
-    assertEquals(3, normalizer.getMergeRequestMaxNumberOfRegionsCount());
-    List<NormalizationPlan> plans = normalizer.computePlansForTable(tableDescriptor);
-    assertThat(plans,
-      contains(
-        new MergeNormalizationPlan.Builder().addTarget(regionInfos.get(0), 0)
-          .addTarget(regionInfos.get(1), 1).addTarget(regionInfos.get(2), 0).build(),
-        new MergeNormalizationPlan.Builder().addTarget(regionInfos.get(3), 1)
-          .addTarget(regionInfos.get(4), 0).build()));
-  }
-
-  @Test
-  public void testHonorsMergeRequestMaxNumberOfRegionsCountDefault() {
-    conf.setBoolean(SPLIT_ENABLED_KEY, false);
-    conf.setInt(MERGE_MIN_REGION_SIZE_MB_KEY, 0);
-    final TableName tableName = name.getTableName();
-    final List<RegionInfo> regionInfos = createRegionInfos(tableName, 3);
-    final Map<byte[], Integer> regionSizes = createRegionSizesMap(regionInfos, 0, 0, 0);
-    setupMocksForNormalizer(regionSizes, regionInfos);
-    assertEquals(100, normalizer.getMergeRequestMaxNumberOfRegionsCount());
-    List<NormalizationPlan> plans = normalizer.computePlansForTable(tableDescriptor);
-    assertThat(plans, contains(new MergeNormalizationPlan.Builder().addTarget(regionInfos.get(0), 0)
-      .addTarget(regionInfos.get(1), 0).addTarget(regionInfos.get(2), 0).build()));
-  }
-
   @Test
   public void testMergeEmptyRegions0() {
     conf.setBoolean(SPLIT_ENABLED_KEY, false);
