@@ -116,6 +116,7 @@ public class DataBlockEncodingTool {
   private static int benchmarkNTimes = DEFAULT_BENCHMARK_N_TIMES;
   private static int benchmarkNOmit = DEFAULT_BENCHMARK_N_OMIT;
 
+  private final Configuration conf;
   private List<EncodedDataBlock> codecs = new ArrayList<>();
   private long totalPrefixLength = 0;
   private long totalKeyLength = 0;
@@ -154,7 +155,8 @@ public class DataBlockEncodingTool {
    * @param compressionAlgorithmName What kind of algorithm should be used as baseline for
    *                                 comparison (e.g. lzo, gz).
    */
-  public DataBlockEncodingTool(String compressionAlgorithmName) {
+  public DataBlockEncodingTool(Configuration conf, String compressionAlgorithmName) {
+    this.conf = conf;
     this.compressionAlgorithmName = compressionAlgorithmName;
     this.compressionAlgorithm = Compression.getCompressionAlgorithmByName(compressionAlgorithmName);
     this.compressor = this.compressionAlgorithm.getCompressor();
@@ -234,7 +236,7 @@ public class DataBlockEncodingTool {
       HFileContext meta = new HFileContextBuilder().withDataBlockEncoding(encoding)
         .withCompression(Compression.Algorithm.NONE).withIncludesMvcc(includesMemstoreTS)
         .withIncludesTags(USE_TAG).build();
-      codecs.add(new EncodedDataBlock(d, encoding, rawKVs, meta));
+      codecs.add(new EncodedDataBlock(conf, d, encoding, rawKVs, meta));
     }
   }
 
@@ -386,7 +388,7 @@ public class DataBlockEncodingTool {
    * @param name      Name of algorithm.
    * @param buffer    Buffer to be compressed.
    * @param offset    Position of the beginning of the data.
-   * @param length    Length of data in buffer.
+   * @param length    Length of data in buffer. n
    */
   public void benchmarkAlgorithm(Compression.Algorithm algorithm, String name, byte[] buffer,
     int offset, int length) throws IOException {
@@ -519,7 +521,7 @@ public class DataBlockEncodingTool {
   }
 
   /**
-   * Display statistics of different compression algorithms.
+   * Display statistics of different compression algorithms. n
    */
   public void displayStatistics() throws IOException {
     final String comprAlgo = compressionAlgorithmName.toUpperCase(Locale.ROOT);
@@ -588,7 +590,7 @@ public class DataBlockEncodingTool {
       reader.getStoreFileScanner(true, true, false, hsf.getMaxMemStoreTS(), 0, false);
     USE_TAG = reader.getHFileReader().getFileContext().isIncludesTags();
     // run the utilities
-    DataBlockEncodingTool comp = new DataBlockEncodingTool(compressionName);
+    DataBlockEncodingTool comp = new DataBlockEncodingTool(conf, compressionName);
     int majorVersion = reader.getHFileVersion();
     comp.useHBaseChecksum = majorVersion > 2 || (majorVersion == 2
       && reader.getHFileMinorVersion() >= HFileReaderImpl.MINOR_VERSION_WITH_CHECKSUM);
