@@ -17,6 +17,9 @@
  */
 package org.apache.hadoop.hbase.regionserver;
 
+import java.util.Collections;
+import java.util.List;
+
 public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrapper {
 
   @Override
@@ -69,6 +72,16 @@ public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrappe
     return 1025;
   }
 
+  @Override
+  public long getOnHeapMemStoreSize() {
+    return 500;
+  }
+
+  @Override
+  public long getOffHeapMemStoreSize() {
+    return 600;
+  }
+
   @Override
   public long getStoreFileSize() {
     return 1900;
@@ -139,6 +152,11 @@ public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrappe
     return 0;
   }
 
+  @Override
+  public int getActiveScanners() {
+    return 0;
+  }
+
   @Override
   public long getReadRequestsCount() {
     return 997;
@@ -214,6 +232,21 @@ public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrappe
     return 410;
   }
 
+  @Override
+  public long getBloomFilterRequestsCount() {
+    return 411;
+  }
+
+  @Override
+  public long getBloomFilterNegativeResultsCount() {
+    return 412;
+  }
+
+  @Override
+  public long getBloomFilterEligibleRequestsCount() {
+    return 413;
+  }
+
   @Override
   public double getPercentFileLocal() {
     return 99;
@@ -249,6 +282,16 @@ public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrappe
     return 419;
   }
 
+  @Override
+  public long getOnHeapMemStoreLimit() {
+    return 311;
+  }
+
+  @Override
+  public long getOffHeapMemStoreLimit() {
+    return 419;
+  }
+
   @Override
   public long getBlockCacheFreeSize() {
     return 413;
@@ -279,11 +322,6 @@ public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrappe
     return 422;
   }
 
-  @Override
-  public long getBlockCacheHitCachingCount() {
-    return 16;
-  }
-
   @Override
   public long getBlockCacheMissCount() {
     return 417;
@@ -294,11 +332,6 @@ public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrappe
     return 421;
   }
 
-  @Override
-  public long getBlockCacheMissCachingCount() {
-    return 17;
-  }
-
   @Override
   public long getBlockCacheEvictedCount() {
     return 418;
@@ -424,6 +457,11 @@ public class MetricsRegionServerWrapperStub implements MetricsRegionServerWrappe
     return 1024000;
   }
 
+  @Override
+  public List<String> getWALExcludeDNs() {
+    return Collections.emptyList();
+  }
+
   @Override
   public long getNumWALSlowAppend() {
     return 0;
