@@ -152,7 +152,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
   }
 
   /**
-   * A simple test which verifies the 3 possible states when scanning across snapshot.
+   * A simple test which verifies the 3 possible states when scanning across snapshot. nn
    */
   @Override
   @Test
@@ -194,7 +194,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
   }
 
   /**
-   * Test memstore snapshots
+   * Test memstore snapshots n
    */
   @Override
   @Test
@@ -213,7 +213,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
   //////////////////////////////////////////////////////////////////////////////
 
   /**
-   * Test getNextRow from memstore
+   * Test getNextRow from memstore n
    */
   @Override
   @Test
@@ -224,15 +224,15 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
     addRows(this.memstore);
     Cell closestToEmpty = ((CompactingMemStore) this.memstore).getNextRow(KeyValue.LOWESTKEY);
     assertTrue(CellComparator.getInstance().compareRows(closestToEmpty,
-      new KeyValue(Bytes.toBytes(0), System.currentTimeMillis())) == 0);
+      new KeyValue(Bytes.toBytes(0), EnvironmentEdgeManager.currentTime())) == 0);
     for (int i = 0; i < ROW_COUNT; i++) {
       Cell nr = ((CompactingMemStore) this.memstore)
-        .getNextRow(new KeyValue(Bytes.toBytes(i), System.currentTimeMillis()));
+        .getNextRow(new KeyValue(Bytes.toBytes(i), EnvironmentEdgeManager.currentTime()));
       if (i + 1 == ROW_COUNT) {
         assertNull(nr);
       } else {
         assertTrue(CellComparator.getInstance().compareRows(nr,
-          new KeyValue(Bytes.toBytes(i + 1), System.currentTimeMillis())) == 0);
+          new KeyValue(Bytes.toBytes(i + 1), EnvironmentEdgeManager.currentTime())) == 0);
       }
     }
     // starting from each row, validate results should contain the starting row
@@ -300,7 +300,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
 
   /**
    * Add keyvalues with a fixed memstoreTs, and checks that memstore size is decreased as older
-   * keyvalues are deleted from the memstore.
+   * keyvalues are deleted from the memstore. n
    */
   @Override
   @Test
@@ -338,7 +338,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
 
   /**
    * Tests that the timeOfOldestEdit is updated correctly for the various edit operations in
-   * memstore.
+   * memstore. n
    */
   @Override
   @Test
@@ -699,8 +699,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
     mss = memstore.getFlushableSize();
     MemStoreSnapshot snapshot = memstore.snapshot(); // push keys to snapshot
     // simulate flusher
-    region.decrMemStoreSize(mss.getDataSize(), mss.getHeapSize(), mss.getOffHeapSize(),
-      mss.getCellsCount());
+    region.decrMemStoreSize(mss);
     ImmutableSegment s = memstore.getSnapshot();
     assertEquals(7, s.getCellsCount());
     assertEquals(0, regionServicesForStores.getMemStoreSize());
@@ -777,8 +776,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
     mss = memstore.getFlushableSize();
     MemStoreSnapshot snapshot = memstore.snapshot(); // push keys to snapshot
     // simulate flusher
-    region.decrMemStoreSize(mss.getDataSize(), mss.getHeapSize(), mss.getOffHeapSize(),
-      mss.getCellsCount());
+    region.decrMemStoreSize(mss);
     ImmutableSegment s = memstore.getSnapshot();
     assertEquals(4, s.getCellsCount());
     assertEquals(0, regionServicesForStores.getMemStoreSize());
@@ -856,7 +854,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
     int cellsCount = hmc.getActive().getCellsCount();
     int totalLen = 0;
     for (int i = 0; i < keys.length; i++) {
-      long timestamp = System.currentTimeMillis();
+      long timestamp = EnvironmentEdgeManager.currentTime();
       Threads.sleep(1); // to make sure each kv gets a different ts
       byte[] row = Bytes.toBytes(keys[i]);
       byte[] val = Bytes.toBytes(keys[i] + i);
@@ -880,7 +878,7 @@ public class TestCompactingMemStore extends TestDefaultMemStore {
     int cellsCount = hmc.getActive().getCellsCount();
     int totalLen = 0;
     for (int i = 0; i < keys.length; i++) {
-      long timestamp = System.currentTimeMillis();
+      long timestamp = EnvironmentEdgeManager.currentTime();
       Threads.sleep(1); // to make sure each kv gets a different ts
       byte[] row = Bytes.toBytes(keys[i]);
       KeyValue kv = new KeyValue(row, fam, qf, timestamp, val);
