@@ -26,7 +26,9 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.NavigableMap;
 import java.util.Objects;
+import java.util.TreeMap;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
 import org.apache.hadoop.conf.Configuration;
@@ -42,6 +44,7 @@ import org.apache.hadoop.hbase.KeepDeletedCells;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.KeyValueTestUtil;
 import org.apache.hadoop.hbase.KeyValueUtil;
+import org.apache.hadoop.hbase.TableDescriptors;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Put;
@@ -157,7 +160,7 @@ public class TestDefaultMemStore {
   }
 
   /**
-   * Test memstore snapshot happening while scanning.
+   * Test memstore snapshot happening while scanning. n
    */
   @Test
   public void testScanAcrossSnapshot() throws IOException {
@@ -208,7 +211,7 @@ public class TestDefaultMemStore {
     }
     memstorescanners = this.memstore.getScanners(mvcc.getReadPoint());
     // Assert that new values are seen in kvset as we scan.
-    long ts = System.currentTimeMillis();
+    long ts = EnvironmentEdgeManager.currentTime();
     count = 0;
     int snapshotIndex = 5;
     try (StoreScanner s = new StoreScanner(scan, scanInfo, null, memstorescanners)) {
@@ -233,7 +236,7 @@ public class TestDefaultMemStore {
   }
 
   /**
-   * A simple test which verifies the 3 possible states when scanning across snapshot.
+   * A simple test which verifies the 3 possible states when scanning across snapshot. nn
    */
   @Test
   public void testScanAcrossSnapshot2() throws IOException, CloneNotSupportedException {
@@ -525,7 +528,7 @@ public class TestDefaultMemStore {
   }
 
   /**
-   * Test memstore snapshots
+   * Test memstore snapshots n
    */
   @Test
   public void testSnapshotting() throws IOException {
@@ -563,7 +566,7 @@ public class TestDefaultMemStore {
   //////////////////////////////////////////////////////////////////////////////
 
   /**
-   * Test getNextRow from memstore
+   * Test getNextRow from memstore n
    */
   @Test
   public void testGetNextRow() throws Exception {
@@ -573,15 +576,15 @@ public class TestDefaultMemStore {
     addRows(this.memstore);
     Cell closestToEmpty = ((DefaultMemStore) this.memstore).getNextRow(KeyValue.LOWESTKEY);
     assertTrue(CellComparatorImpl.COMPARATOR.compareRows(closestToEmpty,
-      new KeyValue(Bytes.toBytes(0), System.currentTimeMillis())) == 0);
+      new KeyValue(Bytes.toBytes(0), EnvironmentEdgeManager.currentTime())) == 0);
     for (int i = 0; i < ROW_COUNT; i++) {
       Cell nr = ((DefaultMemStore) this.memstore)
-        .getNextRow(new KeyValue(Bytes.toBytes(i), System.currentTimeMillis()));
+        .getNextRow(new KeyValue(Bytes.toBytes(i), EnvironmentEdgeManager.currentTime()));
       if (i + 1 == ROW_COUNT) {
         assertNull(nr);
       } else {
         assertTrue(CellComparatorImpl.COMPARATOR.compareRows(nr,
-          new KeyValue(Bytes.toBytes(i + 1), System.currentTimeMillis())) == 0);
+          new KeyValue(Bytes.toBytes(i + 1), EnvironmentEdgeManager.currentTime())) == 0);
       }
     }
     // starting from each row, validate results should contain the starting row
@@ -813,7 +816,7 @@ public class TestDefaultMemStore {
 
   /**
    * Add keyvalues with a fixed memstoreTs, and checks that memstore size is decreased as older
-   * keyvalues are deleted from the memstore.
+   * keyvalues are deleted from the memstore. n
    */
   @Test
   public void testUpsertMemstoreSize() throws Exception {
@@ -857,7 +860,7 @@ public class TestDefaultMemStore {
 
   /**
    * Tests that the timeOfOldestEdit is updated correctly for the various edit operations in
-   * memstore.
+   * memstore. n
    */
   @Test
   public void testUpdateToTimeOfOldestEdit() throws Exception {
@@ -898,7 +901,7 @@ public class TestDefaultMemStore {
   /**
    * Tests the HRegion.shouldFlush method - adds an edit in the memstore and checks that shouldFlush
    * returns true, and another where it disables the periodic flush functionality and tests whether
-   * shouldFlush returns false.
+   * shouldFlush returns false. n
    */
   @Test
   public void testShouldFlush() throws Exception {
@@ -946,9 +949,10 @@ public class TestDefaultMemStore {
     EnvironmentEdgeManager.injectEdge(edge);
     edge.setCurrentTimeMillis(1234);
     WALFactory wFactory = new WALFactory(conf, "1234");
+    TableDescriptors tds = new FSTableDescriptors(conf);
+    FSTableDescriptors.tryUpdateMetaTableDescriptor(conf);
     HRegion meta = HRegion.createHRegion(RegionInfoBuilder.FIRST_META_REGIONINFO, testDir, conf,
-      FSTableDescriptors.createMetaTableDescriptorBuilder(conf).build(),
-      wFactory.getWAL(RegionInfoBuilder.FIRST_META_REGIONINFO));
+      tds.get(TableName.META_TABLE_NAME), wFactory.getWAL(RegionInfoBuilder.FIRST_META_REGIONINFO));
     // parameterized tests add [#] suffix get rid of [ and ].
     TableDescriptor desc = TableDescriptorBuilder
       .newBuilder(TableName.valueOf(name.getMethodName().replaceAll("[\\[\\]]", "_")))
@@ -965,13 +969,11 @@ public class TestDefaultMemStore {
   }
 
   /**
-   * Inserts a new region's meta information into the passed <code>meta</code> region. Used by the
-   * HMaster bootstrap code adding new table to hbase:meta table.
+   * Inserts a new region's meta information into the passed <code>meta</code> region.
    * @param meta hbase:meta HRegion to be updated
    * @param r    HRegion to add to <code>meta</code>
    */
-  public static void addRegionToMETA(final HRegion meta, final HRegion r) throws IOException {
-    meta.checkResources();
+  private static void addRegionToMETA(final HRegion meta, final HRegion r) throws IOException {
     // The row key is the region name
     byte[] row = r.getRegionInfo().getRegionName();
     final long now = EnvironmentEdgeManager.currentTime();
@@ -981,7 +983,9 @@ public class TestDefaultMemStore {
     // Set into the root table the version of the meta table.
     cells.add(new KeyValue(row, HConstants.CATALOG_FAMILY, HConstants.META_VERSION_QUALIFIER, now,
       Bytes.toBytes(HConstants.META_VERSION)));
-    meta.put(row, HConstants.CATALOG_FAMILY, cells);
+    NavigableMap<byte[], List<Cell>> familyMap = new TreeMap<>(Bytes.BYTES_COMPARATOR);
+    familyMap.put(HConstants.CATALOG_FAMILY, cells);
+    meta.put(new Put(row, HConstants.LATEST_TIMESTAMP, familyMap));
   }
 
   private class EnvironmentEdgeForMemstoreTest implements EnvironmentEdge {
@@ -1000,7 +1004,7 @@ public class TestDefaultMemStore {
   /**
    * Adds {@link #ROW_COUNT} rows and {@link #QUALIFIER_COUNT}
    * @param hmc Instance to add rows to.
-   * @return How many rows we added.
+   * @return How many rows we added. n
    */
   protected int addRows(final AbstractMemStore hmc) {
     return addRows(hmc, HConstants.LATEST_TIMESTAMP);
@@ -1009,11 +1013,12 @@ public class TestDefaultMemStore {
   /**
    * Adds {@link #ROW_COUNT} rows and {@link #QUALIFIER_COUNT}
    * @param hmc Instance to add rows to.
-   * @return How many rows we added.
+   * @return How many rows we added. n
    */
   protected int addRows(final MemStore hmc, final long ts) {
     for (int i = 0; i < ROW_COUNT; i++) {
-      long timestamp = ts == HConstants.LATEST_TIMESTAMP ? System.currentTimeMillis() : ts;
+      long timestamp =
+        ts == HConstants.LATEST_TIMESTAMP ? EnvironmentEdgeManager.currentTime() : ts;
       for (int ii = 0; ii < QUALIFIER_COUNT; ii++) {
         byte[] row = Bytes.toBytes(i);
         byte[] qf = makeQualifier(i, ii);
