@@ -69,6 +69,7 @@ import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.wal.WALFactory;
 import org.junit.Assert;
 import org.junit.Before;
@@ -114,13 +115,13 @@ public class TestHMobStore {
   private Cell seekKey3;
   private NavigableSet<byte[]> qualifiers = new ConcurrentSkipListSet<>(Bytes.BYTES_COMPARATOR);
   private List<Cell> expected = new ArrayList<>();
-  private long id = System.currentTimeMillis();
+  private long id = EnvironmentEdgeManager.currentTime();
   private Get get = new Get(row);
   private final static HBaseTestingUtility TEST_UTIL = new HBaseTestingUtility();
   private final String DIR = TEST_UTIL.getDataTestDir("TestHMobStore").toString();
 
   /**
-   * Setup
+   * Setup n
    */
   @Before
   public void setUp() throws Exception {
@@ -204,7 +205,7 @@ public class TestHMobStore {
   }
 
   /**
-   * Getting data from memstore
+   * Getting data from memstore n
    */
   @Test
   public void testGetFromMemStore() throws IOException {
@@ -237,7 +238,7 @@ public class TestHMobStore {
   }
 
   /**
-   * Getting MOB data from files
+   * Getting MOB data from files n
    */
   @Test
   public void testGetFromFiles() throws IOException {
@@ -279,7 +280,7 @@ public class TestHMobStore {
   }
 
   /**
-   * Getting the reference data from files
+   * Getting the reference data from files n
    */
   @Test
   public void testGetReferencesFromFiles() throws IOException {
@@ -323,7 +324,7 @@ public class TestHMobStore {
   }
 
   /**
-   * Getting data from memstore and files
+   * Getting data from memstore and files n
    */
   @Test
   public void testGetFromMemStoreAndFiles() throws IOException {
@@ -365,7 +366,7 @@ public class TestHMobStore {
   }
 
   /**
-   * Getting data from memstore and files
+   * Getting data from memstore and files n
    */
   @Test
   public void testMobCellSizeThreshold() throws IOException {
@@ -448,7 +449,6 @@ public class TestHMobStore {
    * Flush the memstore
    */
   private void flush(int storeFilesSize) throws IOException {
-    this.store.snapshot();
     flushStore(store, id++);
     Assert.assertEquals(storeFilesSize, this.store.getStorefiles().size());
     Assert.assertEquals(0, ((AbstractMemStore) this.store.memstore).getActive().getCellsCount());
