@@ -59,6 +59,8 @@ import org.apache.hadoop.hbase.client.RegionInfoBuilder;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.executor.ExecutorService;
+import org.apache.hadoop.hbase.executor.ExecutorService.ExecutorConfig;
+import org.apache.hadoop.hbase.executor.ExecutorType;
 import org.apache.hadoop.hbase.io.hfile.HFile;
 import org.apache.hadoop.hbase.io.hfile.HFileContextBuilder;
 import org.apache.hadoop.hbase.regionserver.HRegion.FlushResultImpl;
@@ -171,7 +173,7 @@ public class TestHRegionReplayEvents {
     }
     htd = builder.build();
 
-    long time = System.currentTimeMillis();
+    long time = EnvironmentEdgeManager.currentTime();
     ChunkCreator.initialize(MemStoreLAB.CHUNK_SIZE_DEFAULT, false, 0, 0, 0, null,
       MemStoreLAB.INDEX_CHUNK_SIZE_PERCENTAGE_DEFAULT);
     primaryHri =
@@ -190,7 +192,8 @@ public class TestHRegionReplayEvents {
     String string =
       org.apache.hadoop.hbase.executor.EventType.RS_COMPACTED_FILES_DISCHARGER.toString();
     ExecutorService es = new ExecutorService(string);
-    es.startExecutorService(string + "-" + string, 1);
+    es.startExecutorService(es.new ExecutorConfig().setCorePoolSize(1)
+      .setExecutorType(ExecutorType.RS_COMPACTED_FILES_DISCHARGER));
     when(rss.getExecutorService()).thenReturn(es);
     primaryRegion = HRegion.createHRegion(primaryHri, rootDir, CONF, htd, walPrimary);
     primaryRegion.close();
@@ -1136,7 +1139,7 @@ public class TestHRegionReplayEvents {
 
   /**
    * Tests that a region opened in secondary mode would not write region open / close events to its
-   * WAL.
+   * WAL. n
    */
   @Test
   public void testSecondaryRegionDoesNotWriteRegionEventsToWAL() throws IOException {
@@ -1647,7 +1650,7 @@ public class TestHRegionReplayEvents {
   /**
    * Puts a total of numRows + numRowsAfterFlush records indexed with numeric row keys. Does a flush
    * every flushInterval number of records. Then it puts numRowsAfterFlush number of more rows but
-   * does not execute flush after
+   * does not execute flush after n
    */
   private void putDataWithFlushes(HRegion region, int flushInterval, int numRows,
     int numRowsAfterFlush) throws IOException {
