@@ -91,7 +91,6 @@ import org.apache.hadoop.hbase.master.assignment.RegionStates;
 import org.apache.hadoop.hbase.procedure2.ProcedureTestingUtility;
 import org.apache.hadoop.hbase.regionserver.compactions.CompactionContext;
 import org.apache.hadoop.hbase.regionserver.compactions.CompactionLifeCycleTracker;
-import org.apache.hadoop.hbase.regionserver.compactions.CompactionProgress;
 import org.apache.hadoop.hbase.regionserver.throttle.NoLimitThroughputController;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.RegionServerTests;
@@ -614,17 +613,11 @@ public class TestSplitTransactionOnCluster {
     assertEquals(1, region.getStores().size());
     HStore store = region.getStores().get(0);
     while (store.hasReferences()) {
-      // Wait on any current compaction to complete first.
-      CompactionProgress progress = store.getCompactionProgress();
-      if (progress != null && progress.getProgressPct() < 1.0f) {
-        while (progress.getProgressPct() < 1.0f) {
-          LOG.info("Waiting, progress={}", progress.getProgressPct());
-          Threads.sleep(1000);
-        }
-      } else {
-        // Run new compaction. Shoudn't be any others running.
-        region.compact(true);
+      while (store.storeEngine.getCompactor().isCompacting()) {
+        Threads.sleep(100);
       }
+      // Run new compaction. Shoudn't be any others running.
+      region.compact(true);
       store.closeAndArchiveCompactedFiles();
     }
   }
@@ -1009,7 +1002,8 @@ public class TestSplitTransactionOnCluster {
 
   /**
    * Ensure single table region is not on same server as the single hbase:meta table region.
-   * @return Index of the server hosting the single table region
+   * @return Index of the server hosting the single table region nn * @throws
+   *         org.apache.hadoop.hbase.ZooKeeperConnectionException n
    */
   private int ensureTableRegionNotOnSameServerAsMeta(final Admin admin, final RegionInfo hri)
     throws IOException, MasterNotRunningException, ZooKeeperConnectionException,
@@ -1058,8 +1052,8 @@ public class TestSplitTransactionOnCluster {
 
   /**
    * Find regionserver other than the one passed. Can't rely on indexes into list of regionservers
-   * since crashed servers occupy an index.
-   * @return A regionserver that is not <code>notThisOne</code> or null if none found
+   * since crashed servers occupy an index. nn * @return A regionserver that is not
+   * <code>notThisOne</code> or null if none found
    */
   private HRegionServer getOtherRegionServer(final MiniHBaseCluster cluster,
     final HRegionServer notThisOne) {
