@@ -57,6 +57,7 @@ import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CollectionBackedScanner;
 import org.apache.hadoop.hbase.util.EnvironmentEdge;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.EnvironmentEdgeManagerTestHelper;
 import org.junit.ClassRule;
 import org.junit.Ignore;
@@ -322,7 +323,7 @@ public class TestStoreScanner {
   }
 
   /*
-   * Test utility for building a NavigableSet for scanners.
+   * Test utility for building a NavigableSet for scanners. nn
    */
   NavigableSet<byte[]> getCols(String... strCols) {
     NavigableSet<byte[]> cols = new TreeSet<>(Bytes.BYTES_COMPARATOR);
@@ -549,7 +550,7 @@ public class TestStoreScanner {
   /*
    * Test test shows exactly how the matcher's return codes confuses the StoreScanner and prevent it
    * from doing the right thing. Seeking once, then nexting twice should return R1, then R2, but in
-   * this case it doesnt. TODO this comment makes no sense above. Appears to do the right thing.
+   * this case it doesnt. TODO this comment makes no sense above. Appears to do the right thing. n
    */
   @Test
   public void testWontNextToNext() throws IOException {
@@ -618,7 +619,7 @@ public class TestStoreScanner {
 
   @Test
   public void testDeleteVersionMaskingMultiplePuts() throws IOException {
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     KeyValue[] kvs1 = new KeyValue[] { create("R1", "cf", "a", now, KeyValue.Type.Put, "dont-care"),
       create("R1", "cf", "a", now, KeyValue.Type.Delete, "dont-care") };
     KeyValue[] kvs2 =
@@ -641,7 +642,7 @@ public class TestStoreScanner {
 
   @Test
   public void testDeleteVersionsMixedAndMultipleVersionReturn() throws IOException {
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     KeyValue[] kvs1 = new KeyValue[] { create("R1", "cf", "a", now, KeyValue.Type.Put, "dont-care"),
       create("R1", "cf", "a", now, KeyValue.Type.Delete, "dont-care") };
     KeyValue[] kvs2 =
@@ -802,7 +803,7 @@ public class TestStoreScanner {
    */
   @Test
   public void testWildCardTtlScan() throws IOException {
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     KeyValue[] kvs =
       new KeyValue[] { create("R1", "cf", "a", now - 1000, KeyValue.Type.Put, "dont-care"),
         create("R1", "cf", "b", now - 10, KeyValue.Type.Put, "dont-care"),
@@ -866,7 +867,7 @@ public class TestStoreScanner {
    */
   @Test
   public void testExpiredDeleteFamily() throws Exception {
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     KeyValue[] kvs = new KeyValue[] {
       new KeyValue(Bytes.toBytes("R1"), Bytes.toBytes("cf"), null, now - 1000,
         KeyValue.Type.DeleteFamily),
@@ -891,7 +892,7 @@ public class TestStoreScanner {
   @Test
   public void testDeleteMarkerLongevity() throws Exception {
     try {
-      final long now = System.currentTimeMillis();
+      final long now = EnvironmentEdgeManager.currentTime();
       EnvironmentEdgeManagerTestHelper.injectEdge(new EnvironmentEdge() {
         @Override
         public long currentTime() {
@@ -960,7 +961,7 @@ public class TestStoreScanner {
 
   @Test
   public void testPreadNotEnabledForCompactionStoreScanners() throws Exception {
-    long now = System.currentTimeMillis();
+    long now = EnvironmentEdgeManager.currentTime();
     KeyValue[] kvs = new KeyValue[] {
       new KeyValue(Bytes.toBytes("R1"), Bytes.toBytes("cf"), null, now - 1000,
         KeyValue.Type.DeleteFamily),
