@@ -40,6 +40,7 @@ import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.coprocessor.CoprocessorHost;
 import org.apache.hadoop.hbase.coprocessor.SampleRegionWALCoprocessor;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.wal.WAL;
 import org.apache.hadoop.hbase.wal.WALEdit;
 import org.apache.hadoop.hbase.wal.WALFactory;
@@ -52,8 +53,6 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TestName;
 
-import org.apache.hadoop.hbase.shaded.protobuf.generated.WALProtos.WALTrailer;
-
 /**
  * WAL tests that can be reused across providers.
  */
@@ -108,13 +107,10 @@ public abstract class AbstractTestProtobufLog<W extends Closeable> {
   }
 
   /**
-   * Reads the WAL with and without WALTrailer.
+   * Reads the WAL with and without WALTrailer. n
    */
   @Test
   public void testWALTrailer() throws IOException {
-    // make sure that the size for WALTrailer is 0, we need this assumption when reading partial
-    // WALTrailer
-    assertEquals(0, WALTrailer.newBuilder().build().getSerializedSize());
     // read With trailer.
     doRead(true);
     // read without trailer
@@ -127,14 +123,14 @@ public abstract class AbstractTestProtobufLog<W extends Closeable> {
    *                    so that a trailer is appended to the WAL. Otherwise, it starts reading after
    *                    the sync call. This means that reader is not aware of the trailer. In this
    *                    scenario, if the reader tries to read the trailer in its next() call, it
-   *                    returns false from ProtoBufLogReader.
+   *                    returns false from ProtoBufLogReader. n
    */
   private void doRead(boolean withTrailer) throws IOException {
     final int columnCount = 5;
     final int recordCount = 5;
     final TableName tableName = TableName.valueOf("tablename");
     final byte[] row = Bytes.toBytes("row");
-    long timestamp = System.currentTimeMillis();
+    long timestamp = EnvironmentEdgeManager.currentTime();
     Path path = new Path(dir, "tempwal");
     // delete the log if already exists, for test only
     fs.delete(path, true);
