@@ -42,6 +42,7 @@ import java.util.Set;
 import java.util.TreeMap;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
+import java.util.function.Consumer;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FileStatus;
@@ -66,6 +67,7 @@ import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.io.asyncfs.monitor.StreamSlowMonitor;
 import org.apache.hadoop.hbase.monitoring.MonitoredTask;
 import org.apache.hadoop.hbase.regionserver.DefaultStoreEngine;
 import org.apache.hadoop.hbase.regionserver.DefaultStoreFlusher;
@@ -151,9 +153,8 @@ public abstract class AbstractTestWALReplay {
     this.fs = TEST_UTIL.getDFSCluster().getFileSystem();
     this.hbaseRootDir = CommonFSUtils.getRootDir(this.conf);
     this.oldLogDir = new Path(this.hbaseRootDir, HConstants.HREGION_OLDLOGDIR_NAME);
-    String serverName =
-      ServerName.valueOf(currentTest.getMethodName() + "-manual", 16010, System.currentTimeMillis())
-        .toString();
+    String serverName = ServerName
+      .valueOf(currentTest.getMethodName() + "-manual", 16010, ee.currentTime()).toString();
     this.logName = AbstractFSWALProvider.getWALDirectoryName(serverName);
     this.logDir = new Path(this.hbaseRootDir, logName);
     if (TEST_UTIL.getDFSCluster().getFileSystem().exists(this.hbaseRootDir)) {
@@ -180,7 +181,8 @@ public abstract class AbstractTestWALReplay {
   }
 
   /**
-   *   */
+   * n
+   */
   @Test
   public void testReplayEditsAfterRegionMovedWithMultiCF() throws Exception {
     final TableName tableName = TableName.valueOf("testReplayEditsAfterRegionMovedWithMultiCF");
@@ -256,8 +258,8 @@ public abstract class AbstractTestWALReplay {
   }
 
   /**
-   * Tests for hbase-2727.
-   * @see <a href="https://issues.apache.org/jira/browse/HBASE-2727">HBASE-2727</a>
+   * Tests for hbase-2727. n * @see
+   * <a href="https://issues.apache.org/jira/browse/HBASE-2727">HBASE-2727</a>
    */
   @Test
   public void test2727() throws Exception {
@@ -319,6 +321,7 @@ public abstract class AbstractTestWALReplay {
 
   /**
    * Test case of HRegion that is only made out of bulk loaded files. Assert that we don't 'crash'.
+   * nnnnn
    */
   @Test
   public void testRegionMadeOfBulkLoadedFilesOnly() throws IOException, SecurityException,
@@ -375,7 +378,7 @@ public abstract class AbstractTestWALReplay {
   /**
    * HRegion test case that is made of a major compacted HFile (created with three bulk loaded
    * files) and an edit in the memstore. This is for HBASE-10958 "[dataloss] Bulk loading with
-   * seqids can prevent some log entries from being replayed"
+   * seqids can prevent some log entries from being replayed" nnnnn
    */
   @Test
   public void testCompactedBulkLoadedFiles() throws IOException, SecurityException,
@@ -436,7 +439,7 @@ public abstract class AbstractTestWALReplay {
 
   /**
    * Test writing edits into an HRegion, closing it, splitting logs, opening Region again. Verify
-   * seqids.
+   * seqids. nnnnn
    */
   @Test
   public void testReplayEditsWrittenViaHRegion() throws IOException, SecurityException,
@@ -529,7 +532,7 @@ public abstract class AbstractTestWALReplay {
    * The way we get around this is by flushing at the region level, and then deleting the recently
    * flushed store file for one of the Stores. This would put us back in the situation where all but
    * that store got flushed and the region died. We restart Region again, and verify that the edits
-   * were replayed.
+   * were replayed. nnnnn
    */
   @Test
   public void testReplayEditsAfterPartialFlush() throws IOException, SecurityException,
@@ -599,17 +602,19 @@ public abstract class AbstractTestWALReplay {
     @Override
     public List<Path> flushSnapshot(MemStoreSnapshot snapshot, long cacheFlushId,
       MonitoredTask status, ThroughputController throughputController,
-      FlushLifeCycleTracker tracker) throws IOException {
+      FlushLifeCycleTracker tracker, Consumer<Path> writerCreationTracker) throws IOException {
       if (throwExceptionWhenFlushing.get()) {
         throw new IOException("Simulated exception by tests");
       }
-      return super.flushSnapshot(snapshot, cacheFlushId, status, throughputController, tracker);
+      return super.flushSnapshot(snapshot, cacheFlushId, status, throughputController, tracker,
+        writerCreationTracker);
     }
   };
 
   /**
    * Test that we could recover the data correctly after aborting flush. In the test, first we abort
    * flush after writing some data, then writing more data and flush again, at last verify the data.
+   * n
    */
   @Test
   public void testReplayEditsAfterAbortingFlush() throws IOException {
@@ -702,7 +707,7 @@ public abstract class AbstractTestWALReplay {
   }
 
   /**
-   * Create an HRegion with the result of a WAL split and test we only see the good edits
+   * Create an HRegion with the result of a WAL split and test we only see the good edits n
    */
   @Test
   public void testReplayEditsWrittenIntoWAL() throws Exception {
@@ -1138,8 +1143,7 @@ public abstract class AbstractTestWALReplay {
   }
 
   /*
-   * Run the split. Verify only single split file made.
-   * @return The single split file made
+   * Run the split. Verify only single split file made. n * @return The single split file made n
    */
   private Path runWALSplit(final Configuration c) throws IOException {
     List<Path> splits =
@@ -1167,7 +1171,8 @@ public abstract class AbstractTestWALReplay {
     throws IOException, StreamLacksCapabilityException {
     fs.mkdirs(file.getParent());
     ProtobufLogWriter writer = new ProtobufLogWriter();
-    writer.init(fs, file, conf, true, WALUtil.getWALBlockSize(conf, fs, file));
+    writer.init(fs, file, conf, true, WALUtil.getWALBlockSize(conf, fs, file),
+      StreamSlowMonitor.create(conf, "testMonitor"));
     for (FSWALEntry entry : entries) {
       writer.append(entry);
     }
