@@ -52,6 +52,7 @@ import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.VerySlowRegionServerTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.JVMClusterUtil;
 import org.apache.hadoop.hbase.util.RecoverLeaseFSUtils;
 import org.apache.hadoop.hbase.wal.AbstractFSWALProvider;
@@ -293,7 +294,7 @@ public class TestLogRolling extends AbstractTestLogRolling {
     }
     Put tmpPut = new Put(Bytes.toBytes("tmprow"));
     tmpPut.addColumn(HConstants.CATALOG_FAMILY, null, value);
-    long startTime = System.currentTimeMillis();
+    long startTime = EnvironmentEdgeManager.currentTime();
     long remaining = timeout;
     while (remaining > 0) {
       if (log.isLowReplicationRollEnabled() == expect) {
@@ -306,7 +307,7 @@ public class TestLogRolling extends AbstractTestLogRolling {
         } catch (InterruptedException e) {
           // continue
         }
-        remaining = timeout - (System.currentTimeMillis() - startTime);
+        remaining = timeout - (EnvironmentEdgeManager.currentTime() - startTime);
       }
     }
   }
@@ -371,7 +372,7 @@ public class TestLogRolling extends AbstractTestLogRolling {
 
     writeData(table, 2);
 
-    long curTime = System.currentTimeMillis();
+    long curTime = EnvironmentEdgeManager.currentTime();
     LOG.info("log.getCurrentFileName(): " + log.getCurrentFileName());
     long oldFilenum = AbstractFSWALProvider.extractFileNumFromWAL(log);
     assertTrue("Log should have a timestamp older than now",
@@ -422,7 +423,7 @@ public class TestLogRolling extends AbstractTestLogRolling {
   }
 
   /**
-   * Test that WAL is rolled when all data nodes in the pipeline have been restarted.
+   * Test that WAL is rolled when all data nodes in the pipeline have been restarted. n
    */
   @Test
   public void testLogRollOnPipelineRestart() throws Exception {
@@ -465,7 +466,7 @@ public class TestLogRolling extends AbstractTestLogRolling {
 
       writeData(table, 1002);
 
-      long curTime = System.currentTimeMillis();
+      long curTime = EnvironmentEdgeManager.currentTime();
       LOG.info("log.getCurrentFileName()): " + AbstractFSWALProvider.getCurrentFileName(log));
       long oldFilenum = AbstractFSWALProvider.extractFileNumFromWAL(log);
       assertTrue("Log should have a timestamp older than now",
