@@ -52,14 +52,14 @@ import org.apache.hadoop.hbase.client.Get;
 import org.apache.hadoop.hbase.client.RegionLocator;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
-import org.apache.hadoop.hbase.client.RetriesExhaustedWithDetailsException;
+import org.apache.hadoop.hbase.client.RetriesExhaustedException;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
-import org.apache.hadoop.hbase.regionserver.RegionServerCoprocessorHost;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.ReplicationTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.HFileTestUtil;
 import org.junit.AfterClass;
 import org.junit.Assert;
@@ -129,9 +129,7 @@ public class TestReplicationSink {
     TEST_UTIL.getConfiguration().set("hbase.replication.source.fs.conf.provider",
       TestSourceFSConfigurationProvider.class.getCanonicalName());
     TEST_UTIL.startMiniCluster(3);
-    RegionServerCoprocessorHost rsCpHost =
-      TEST_UTIL.getMiniHBaseCluster().getRegionServer(0).getRegionServerCoprocessorHost();
-    SINK = new ReplicationSink(new Configuration(TEST_UTIL.getConfiguration()), rsCpHost);
+    SINK = new ReplicationSink(new Configuration(TEST_UTIL.getConfiguration()));
     table1 = TEST_UTIL.createTable(TABLE_NAME1, FAM_NAME1);
     table2 = TEST_UTIL.createTable(TABLE_NAME2, FAM_NAME2);
     Path rootDir = CommonFSUtils.getRootDir(TEST_UTIL.getConfiguration());
@@ -159,7 +157,7 @@ public class TestReplicationSink {
   }
 
   /**
-   * Insert a whole batch of entries
+   * Insert a whole batch of entries n
    */
   @Test
   public void testBatchSink() throws Exception {
@@ -176,7 +174,7 @@ public class TestReplicationSink {
   }
 
   /**
-   * Insert a mix of puts and deletes
+   * Insert a mix of puts and deletes n
    */
   @Test
   public void testMixedPutDelete() throws Exception {
@@ -236,7 +234,7 @@ public class TestReplicationSink {
   }
 
   /**
-   * Insert to 2 different tables
+   * Insert to 2 different tables n
    */
   @Test
   public void testMixedPutTables() throws Exception {
@@ -260,7 +258,7 @@ public class TestReplicationSink {
   }
 
   /**
-   * Insert then do different types of deletes
+   * Insert then do different types of deletes n
    */
   @Test
   public void testMixedDeletes() throws Exception {
@@ -287,7 +285,7 @@ public class TestReplicationSink {
 
   /**
    * Puts are buffered, but this tests when a delete (not-buffered) is applied before the actual Put
-   * that creates it.
+   * that creates it. n
    */
   @Test
   public void testApplyDeleteBeforePut() throws Exception {
@@ -332,8 +330,8 @@ public class TestReplicationSink {
         try {
           SINK.replicateEntries(entries, CellUtil.createCellScanner(cells.iterator()),
             replicationClusterId, baseNamespaceDir, hfileArchiveDir);
-          Assert.fail("Should re-throw RetriesExhaustedWithDetailsException.");
-        } catch (RetriesExhaustedWithDetailsException e) {
+          Assert.fail("Should re-throw RetriesExhaustedException.");
+        } catch (RetriesExhaustedException e) {
         } finally {
           admin.enableTable(TABLE_NAME1);
         }
@@ -490,7 +488,7 @@ public class TestReplicationSink {
     } catch (InterruptedException e) {
       LOG.info("Was interrupted while sleep, meh", e);
     }
-    final long now = System.currentTimeMillis();
+    final long now = EnvironmentEdgeManager.currentTime();
     KeyValue kv = null;
     if (type.getCode() == KeyValue.Type.Put.getCode()) {
       kv = new KeyValue(rowBytes, fam, fam, now, KeyValue.Type.Put, Bytes.toBytes(row));
@@ -514,7 +512,7 @@ public class TestReplicationSink {
     uuidBuilder.setMostSigBits(HConstants.DEFAULT_CLUSTER_ID.getMostSignificantBits());
     keyBuilder.setClusterId(uuidBuilder.build());
     keyBuilder.setTableName(UnsafeByteOperations.unsafeWrap(table.getName()));
-    keyBuilder.setWriteTime(System.currentTimeMillis());
+    keyBuilder.setWriteTime(EnvironmentEdgeManager.currentTime());
     keyBuilder.setEncodedRegionName(UnsafeByteOperations.unsafeWrap(HConstants.EMPTY_BYTE_ARRAY));
     keyBuilder.setLogSequenceNumber(-1);
     builder.setKey(keyBuilder.build());
