@@ -72,11 +72,11 @@ import org.apache.hadoop.hbase.replication.ReplicationQueueStorage;
 import org.apache.hadoop.hbase.replication.ReplicationSourceDummy;
 import org.apache.hadoop.hbase.replication.ReplicationStorageFactory;
 import org.apache.hadoop.hbase.replication.ZKReplicationPeerStorage;
-import org.apache.hadoop.hbase.replication.regionserver.ReplicationSourceManager.NodeFailoverWorker;
 import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.testclassification.ReplicationTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.JVMClusterUtil;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.hbase.wal.WAL;
@@ -283,9 +283,8 @@ public abstract class TestReplicationSourceManager {
         wal.rollWriter();
       }
       LOG.info(Long.toString(i));
-      final long txid = wal.appendData(hri,
-        new WALKeyImpl(hri.getEncodedNameAsBytes(), test, System.currentTimeMillis(), mvcc, scopes),
-        edit);
+      final long txid = wal.appendData(hri, new WALKeyImpl(hri.getEncodedNameAsBytes(), test,
+        EnvironmentEdgeManager.currentTime(), mvcc, scopes), edit);
       wal.sync(txid);
     }
 
@@ -297,9 +296,8 @@ public abstract class TestReplicationSourceManager {
     LOG.info(baseline + " and " + time);
 
     for (int i = 0; i < 3; i++) {
-      wal.appendData(hri,
-        new WALKeyImpl(hri.getEncodedNameAsBytes(), test, System.currentTimeMillis(), mvcc, scopes),
-        edit);
+      wal.appendData(hri, new WALKeyImpl(hri.getEncodedNameAsBytes(), test,
+        EnvironmentEdgeManager.currentTime(), mvcc, scopes), edit);
     }
     wal.sync();
 
@@ -315,9 +313,8 @@ public abstract class TestReplicationSourceManager {
     manager.logPositionAndCleanOldLogs(manager.getSources().get(0),
       new WALEntryBatch(0, manager.getSources().get(0).getCurrentPath()));
 
-    wal.appendData(hri,
-      new WALKeyImpl(hri.getEncodedNameAsBytes(), test, System.currentTimeMillis(), mvcc, scopes),
-      edit);
+    wal.appendData(hri, new WALKeyImpl(hri.getEncodedNameAsBytes(), test,
+      EnvironmentEdgeManager.currentTime(), mvcc, scopes), edit);
     wal.sync();
 
     assertEquals(1, manager.getWALs().size());
@@ -380,9 +377,7 @@ public abstract class TestReplicationSourceManager {
     ReplicationPeers rp1 =
       ReplicationFactory.getReplicationPeers(s1.getZooKeeper(), s1.getConfiguration());
     rp1.init();
-    NodeFailoverWorker w1 = manager.new NodeFailoverWorker(server.getServerName());
-    w1.start();
-    w1.join();
+    manager.claimQueue(server.getServerName(), "1");
     assertEquals(1, manager.getWalsByIdRecoveredQueues().size());
     String id = "1-" + server.getServerName().getServerName();
     assertEquals(files, manager.getWalsByIdRecoveredQueues().get(id).get(group));
@@ -402,9 +397,7 @@ public abstract class TestReplicationSourceManager {
     rq.addWAL(server.getServerName(), "2", group + ".log1");
     rq.addWAL(server.getServerName(), "2", group + ".log2");
 
-    NodeFailoverWorker w1 = manager.new NodeFailoverWorker(server.getServerName());
-    w1.start();
-    w1.join();
+    manager.claimQueue(server.getServerName(), "2");
 
     // The log of the unknown peer should be removed from zk
     for (String peer : manager.getAllQueues()) {
@@ -469,7 +462,7 @@ public abstract class TestReplicationSourceManager {
   /**
    * Test whether calling removePeer() on a ReplicationSourceManager that failed on initializing the
    * corresponding ReplicationSourceInterface correctly cleans up the corresponding replication
-   * queue and ReplicationPeer. See HBASE-16096.
+   * queue and ReplicationPeer. See HBASE-16096. n
    */
   @Test
   public void testPeerRemovalCleanup() throws Exception {
@@ -561,44 +554,9 @@ public abstract class TestReplicationSourceManager {
     }
   }
 
-  @Test
-  public void testDisablePeerMetricsCleanup() throws Exception {
-    final String peerId = "DummyPeer";
-    final ReplicationPeerConfig peerConfig = ReplicationPeerConfig.newBuilder()
-      .setClusterKey(utility.getZkCluster().getAddress().toString() + ":/hbase").build();
-    try {
-      MetricsReplicationSourceSource globalSource = getGlobalSource();
-      final int globalLogQueueSizeInitial = globalSource.getSizeOfLogQueue();
-      final long sizeOfLatestPath = getSizeOfLatestPath();
-      addPeerAndWait(peerId, peerConfig, true);
-      assertEquals(sizeOfLatestPath + globalLogQueueSizeInitial, globalSource.getSizeOfLogQueue());
-      ReplicationSourceInterface source = manager.getSource(peerId);
-      // Sanity check
-      assertNotNull(source);
-      final int sizeOfSingleLogQueue = source.getSourceMetrics().getSizeOfLogQueue();
-      // Enqueue log and check if metrics updated
-      source.enqueueLog(new Path("abc"));
-      assertEquals(1 + sizeOfSingleLogQueue, source.getSourceMetrics().getSizeOfLogQueue());
-      assertEquals(source.getSourceMetrics().getSizeOfLogQueue() + globalLogQueueSizeInitial,
-        globalSource.getSizeOfLogQueue());
-
-      // Refreshing the peer should decrement the global and single source metrics
-      manager.refreshSources(peerId);
-      assertEquals(globalLogQueueSizeInitial, globalSource.getSizeOfLogQueue());
-
-      source = manager.getSource(peerId);
-      assertNotNull(source);
-      assertEquals(sizeOfSingleLogQueue, source.getSourceMetrics().getSizeOfLogQueue());
-      assertEquals(source.getSourceMetrics().getSizeOfLogQueue() + globalLogQueueSizeInitial,
-        globalSource.getSizeOfLogQueue());
-    } finally {
-      removePeerAndWait(peerId);
-    }
-  }
-
   /**
-   * Add a peer and wait for it to initialize
-   * @param waitForSource Whether to wait for replication source to initialize
+   * Add a peer and wait for it to initialize nn * @param waitForSource Whether to wait for
+   * replication source to initialize n
    */
   private void addPeerAndWait(final String peerId, final ReplicationPeerConfig peerConfig,
     final boolean waitForSource) throws Exception {
@@ -636,7 +594,7 @@ public abstract class TestReplicationSourceManager {
   }
 
   /**
-   * Remove a peer and wait for it to get cleaned up
+   * Remove a peer and wait for it to get cleaned up nn
    */
   private void removePeerAndWait(final String peerId) throws Exception {
     final ReplicationPeers rp = manager.getReplicationPeers();
