@@ -21,26 +21,26 @@ import static org.apache.hadoop.hbase.ipc.TestProtobufRpcServiceImpl.SERVICE;
 import static org.apache.hadoop.hbase.ipc.TestProtobufRpcServiceImpl.newBlockingStub;
 import static org.apache.hadoop.hbase.security.HBaseKerberosUtils.getKeytabFileForTesting;
 import static org.apache.hadoop.hbase.security.HBaseKerberosUtils.getPrincipalForTesting;
-import static org.apache.hadoop.hbase.security.HBaseKerberosUtils.getSecuredConfiguration;
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.hamcrest.Matchers.either;
-import static org.hamcrest.Matchers.instanceOf;
+import static org.apache.hadoop.hbase.security.HBaseKerberosUtils.setSecuredConfiguration;
+import static org.apache.hadoop.hbase.security.provider.SaslClientAuthenticationProviders.SELECTOR_KEY;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotSame;
 import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.fail;
 
-import java.io.EOFException;
 import java.io.File;
 import java.io.IOException;
+import java.lang.reflect.Field;
+import java.net.InetAddress;
 import java.net.InetSocketAddress;
-import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
+import java.util.Map;
+import javax.security.sasl.SaslClient;
 import javax.security.sasl.SaslException;
 import org.apache.commons.lang3.RandomStringUtils;
 import org.apache.hadoop.conf.Configuration;
@@ -48,9 +48,7 @@ import org.apache.hadoop.fs.CommonConfigurationKeys;
 import org.apache.hadoop.hbase.HBaseClassTestRule;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.exceptions.ConnectionClosedException;
 import org.apache.hadoop.hbase.ipc.BlockingRpcClient;
-import org.apache.hadoop.hbase.ipc.FallbackDisallowedException;
 import org.apache.hadoop.hbase.ipc.FifoRpcScheduler;
 import org.apache.hadoop.hbase.ipc.NettyRpcClient;
 import org.apache.hadoop.hbase.ipc.NettyRpcServer;
@@ -58,12 +56,20 @@ import org.apache.hadoop.hbase.ipc.RpcClient;
 import org.apache.hadoop.hbase.ipc.RpcClientFactory;
 import org.apache.hadoop.hbase.ipc.RpcServer;
 import org.apache.hadoop.hbase.ipc.RpcServerFactory;
+import org.apache.hadoop.hbase.ipc.RpcServerInterface;
 import org.apache.hadoop.hbase.ipc.SimpleRpcServer;
+import org.apache.hadoop.hbase.security.provider.AuthenticationProviderSelector;
+import org.apache.hadoop.hbase.security.provider.BuiltInProviderSelector;
+import org.apache.hadoop.hbase.security.provider.SaslAuthMethod;
+import org.apache.hadoop.hbase.security.provider.SaslClientAuthenticationProvider;
 import org.apache.hadoop.hbase.testclassification.LargeTests;
 import org.apache.hadoop.hbase.testclassification.SecurityTests;
+import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.minikdc.MiniKdc;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.hadoop.security.UserGroupInformation.AuthenticationMethod;
+import org.apache.hadoop.security.token.Token;
+import org.apache.hadoop.security.token.TokenIdentifier;
 import org.junit.AfterClass;
 import org.junit.Before;
 import org.junit.BeforeClass;
@@ -81,6 +87,7 @@ import org.apache.hbase.thirdparty.com.google.protobuf.BlockingService;
 
 import org.apache.hadoop.hbase.shaded.ipc.protobuf.generated.TestProtos;
 import org.apache.hadoop.hbase.shaded.ipc.protobuf.generated.TestRpcServiceProtos.TestProtobufRpcProto.BlockingInterface;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.RPCProtos.UserInformation;
 
 @RunWith(Parameterized.class)
 @Category({ SecurityTests.class, LargeTests.class })
@@ -99,11 +106,11 @@ public class TestSecureIPC {
   private static String HOST = "localhost";
   private static String PRINCIPAL;
 
-  String krbKeytab;
-  String krbPrincipal;
-  UserGroupInformation ugi;
-  Configuration clientConf;
-  Configuration serverConf;
+  private String krbKeytab;
+  private String krbPrincipal;
+  private UserGroupInformation ugi;
+  private Configuration clientConf;
+  private Configuration serverConf;
 
   @Parameters(name = "{index}: rpcClientImpl={0}, rpcServerImpl={1}")
   public static Collection<Object[]> parameters() {
@@ -132,6 +139,9 @@ public class TestSecureIPC {
     PRINCIPAL = "hbase/" + HOST;
     KDC.createPrincipal(KEYTAB_FILE, PRINCIPAL);
     HBaseKerberosUtils.setPrincipalForTesting(PRINCIPAL + "@" + KDC.getRealm());
+    // set a smaller timeout and retry to speed up tests
+    TEST_UTIL.getConfiguration().setInt(RpcClient.SOCKET_TIMEOUT_READ, 2000);
+    TEST_UTIL.getConfiguration().setInt("hbase.security.relogin.maxretries", 1);
   }
 
   @AfterClass
@@ -147,9 +157,11 @@ public class TestSecureIPC {
     krbKeytab = getKeytabFileForTesting();
     krbPrincipal = getPrincipalForTesting();
     ugi = loginKerberosPrincipal(krbKeytab, krbPrincipal);
-    clientConf = getSecuredConfiguration();
+    clientConf = new Configuration(TEST_UTIL.getConfiguration());
+    setSecuredConfiguration(clientConf);
     clientConf.set(RpcClientFactory.CUSTOM_RPC_CLIENT_IMPL_CONF_KEY, rpcClientImpl);
-    serverConf = getSecuredConfiguration();
+    serverConf = new Configuration(TEST_UTIL.getConfiguration());
+    setSecuredConfiguration(serverConf);
     serverConf.set(RpcServerFactory.CUSTOM_RPC_SERVER_IMPL_CONF_KEY, rpcServerImpl);
   }
 
@@ -166,7 +178,118 @@ public class TestSecureIPC {
   }
 
   @Test
-  public void testRpcServerFallbackToSimpleAuth() throws Exception {
+  public void testRpcCallWithEnabledKerberosSaslAuth_CanonicalHostname() throws Exception {
+    UserGroupInformation ugi2 = UserGroupInformation.getCurrentUser();
+
+    // check that the login user is okay:
+    assertSame(ugi2, ugi);
+    assertEquals(AuthenticationMethod.KERBEROS, ugi.getAuthenticationMethod());
+    assertEquals(krbPrincipal, ugi.getUserName());
+
+    enableCanonicalHostnameTesting(clientConf, "localhost");
+    clientConf.setBoolean(
+      SecurityConstants.UNSAFE_HBASE_CLIENT_KERBEROS_HOSTNAME_DISABLE_REVERSEDNS, false);
+    clientConf.set(HBaseKerberosUtils.KRB_PRINCIPAL, "hbase/_HOST@" + KDC.getRealm());
+
+    callRpcService(User.create(ugi2));
+  }
+
+  @Test
+  public void testRpcCallWithEnabledKerberosSaslAuth_NoCanonicalHostname() throws Exception {
+    UserGroupInformation ugi2 = UserGroupInformation.getCurrentUser();
+
+    // check that the login user is okay:
+    assertSame(ugi2, ugi);
+    assertEquals(AuthenticationMethod.KERBEROS, ugi.getAuthenticationMethod());
+    assertEquals(krbPrincipal, ugi.getUserName());
+
+    enableCanonicalHostnameTesting(clientConf, "127.0.0.1");
+    clientConf
+      .setBoolean(SecurityConstants.UNSAFE_HBASE_CLIENT_KERBEROS_HOSTNAME_DISABLE_REVERSEDNS, true);
+    clientConf.set(HBaseKerberosUtils.KRB_PRINCIPAL, "hbase/_HOST@" + KDC.getRealm());
+
+    callRpcService(User.create(ugi2));
+  }
+
+  private static void enableCanonicalHostnameTesting(Configuration conf, String canonicalHostname) {
+    conf.setClass(SELECTOR_KEY, CanonicalHostnameTestingAuthenticationProviderSelector.class,
+      AuthenticationProviderSelector.class);
+    conf.set(CanonicalHostnameTestingAuthenticationProviderSelector.CANONICAL_HOST_NAME_KEY,
+      canonicalHostname);
+  }
+
+  public static class CanonicalHostnameTestingAuthenticationProviderSelector
+    extends BuiltInProviderSelector {
+    private static final String CANONICAL_HOST_NAME_KEY =
+      "CanonicalHostnameTestingAuthenticationProviderSelector.canonicalHostName";
+
+    @Override
+    public Pair<SaslClientAuthenticationProvider, Token<? extends TokenIdentifier>>
+      selectProvider(String clusterId, User user) {
+      final Pair<SaslClientAuthenticationProvider, Token<? extends TokenIdentifier>> pair =
+        super.selectProvider(clusterId, user);
+      pair.setFirst(createCanonicalHostNameTestingProvider(pair.getFirst()));
+      return pair;
+    }
+
+    SaslClientAuthenticationProvider
+      createCanonicalHostNameTestingProvider(SaslClientAuthenticationProvider delegate) {
+      return new SaslClientAuthenticationProvider() {
+        @Override
+        public SaslClient createClient(Configuration conf, InetAddress serverAddr,
+          SecurityInfo securityInfo, Token<? extends TokenIdentifier> token,
+          boolean fallbackAllowed, Map<String, String> saslProps) throws IOException {
+          final String s = conf.get(CANONICAL_HOST_NAME_KEY);
+          if (s != null) {
+            try {
+              final Field canonicalHostName =
+                InetAddress.class.getDeclaredField("canonicalHostName");
+              canonicalHostName.setAccessible(true);
+              canonicalHostName.set(serverAddr, s);
+            } catch (NoSuchFieldException | IllegalAccessException e) {
+              throw new RuntimeException(e);
+            }
+          }
+
+          return delegate.createClient(conf, serverAddr, securityInfo, token, fallbackAllowed,
+            saslProps);
+        }
+
+        @Override
+        public UserInformation getUserInfo(User user) {
+          return delegate.getUserInfo(user);
+        }
+
+        @Override
+        public UserGroupInformation getRealUser(User ugi) {
+          return delegate.getRealUser(ugi);
+        }
+
+        @Override
+        public boolean canRetry() {
+          return delegate.canRetry();
+        }
+
+        @Override
+        public void relogin() throws IOException {
+          delegate.relogin();
+        }
+
+        @Override
+        public SaslAuthMethod getSaslAuthMethod() {
+          return delegate.getSaslAuthMethod();
+        }
+
+        @Override
+        public String getTokenKind() {
+          return delegate.getTokenKind();
+        }
+      };
+    }
+  }
+
+  @Test
+  public void testRpcFallbackToSimpleAuth() throws Exception {
     String clientUsername = "testuser";
     UserGroupInformation clientUgi =
       UserGroupInformation.createUserForTesting(clientUsername, new String[] { clientUsername });
@@ -181,115 +304,62 @@ public class TestSecureIPC {
     callRpcService(User.create(clientUgi));
   }
 
-  @Test
-  public void testRpcServerDisallowFallbackToSimpleAuth() throws Exception {
-    String clientUsername = "testuser";
-    UserGroupInformation clientUgi =
-      UserGroupInformation.createUserForTesting(clientUsername, new String[] { clientUsername });
-
-    // check that the client user is insecure
-    assertNotSame(ugi, clientUgi);
-    assertEquals(AuthenticationMethod.SIMPLE, clientUgi.getAuthenticationMethod());
-    assertEquals(clientUsername, clientUgi.getUserName());
-
-    clientConf.set(User.HBASE_SECURITY_CONF_KEY, "simple");
-    serverConf.setBoolean(RpcServer.FALLBACK_TO_INSECURE_CLIENT_AUTH, false);
-    IOException error =
-      assertThrows(IOException.class, () -> callRpcService(User.create(clientUgi)));
-    // server just closes the connection, so we could get broken pipe, or EOF, or connection closed
-    if (error.getMessage() == null || !error.getMessage().contains("Broken pipe")) {
-      assertThat(error,
-        either(instanceOf(EOFException.class)).or(instanceOf(ConnectionClosedException.class)));
-    }
-  }
-
-  @Test
-  public void testRpcClientFallbackToSimpleAuth() throws Exception {
-    String serverUsername = "testuser";
-    UserGroupInformation serverUgi =
-      UserGroupInformation.createUserForTesting(serverUsername, new String[] { serverUsername });
-    // check that the server user is insecure
-    assertNotSame(ugi, serverUgi);
-    assertEquals(AuthenticationMethod.SIMPLE, serverUgi.getAuthenticationMethod());
-    assertEquals(serverUsername, serverUgi.getUserName());
-
-    serverConf.set(User.HBASE_SECURITY_CONF_KEY, "simple");
-    clientConf.setBoolean(RpcClient.IPC_CLIENT_FALLBACK_TO_SIMPLE_AUTH_ALLOWED_KEY, true);
-    callRpcService(User.create(serverUgi), User.create(ugi));
-  }
-
-  @Test
-  public void testRpcClientDisallowFallbackToSimpleAuth() throws Exception {
-    String serverUsername = "testuser";
-    UserGroupInformation serverUgi =
-      UserGroupInformation.createUserForTesting(serverUsername, new String[] { serverUsername });
-    // check that the server user is insecure
-    assertNotSame(ugi, serverUgi);
-    assertEquals(AuthenticationMethod.SIMPLE, serverUgi.getAuthenticationMethod());
-    assertEquals(serverUsername, serverUgi.getUserName());
-
-    serverConf.set(User.HBASE_SECURITY_CONF_KEY, "simple");
-    clientConf.setBoolean(RpcClient.IPC_CLIENT_FALLBACK_TO_SIMPLE_AUTH_ALLOWED_KEY, false);
-    assertThrows(FallbackDisallowedException.class,
-      () -> callRpcService(User.create(serverUgi), User.create(ugi)));
-  }
-
   private void setRpcProtection(String clientProtection, String serverProtection) {
     clientConf.set("hbase.rpc.protection", clientProtection);
     serverConf.set("hbase.rpc.protection", serverProtection);
   }
 
   /**
-   * Test various combinations of Server and Client qops.
+   * Test various combinations of Server and Client qops. n
    */
   @Test
   public void testSaslWithCommonQop() throws Exception {
     setRpcProtection("privacy,authentication", "authentication");
-    callRpcService();
+    callRpcService(User.create(ugi));
 
     setRpcProtection("authentication", "privacy,authentication");
-    callRpcService();
+    callRpcService(User.create(ugi));
 
     setRpcProtection("integrity,authentication", "privacy,authentication");
-    callRpcService();
+    callRpcService(User.create(ugi));
 
     setRpcProtection("integrity,authentication", "integrity,authentication");
-    callRpcService();
+    callRpcService(User.create(ugi));
 
     setRpcProtection("privacy,authentication", "privacy,authentication");
-    callRpcService();
+    callRpcService(User.create(ugi));
   }
 
   @Test
   public void testSaslNoCommonQop() throws Exception {
     setRpcProtection("integrity", "privacy");
-    SaslException se = assertThrows(SaslException.class, () -> callRpcService());
+    SaslException se = assertThrows(SaslException.class, () -> callRpcService(User.create(ugi)));
     assertEquals("No common protection layer between client and server", se.getMessage());
   }
 
   /**
-   * Test sasl encryption with Crypto AES.
+   * Test sasl encryption with Crypto AES. n
    */
   @Test
   public void testSaslWithCryptoAES() throws Exception {
     setRpcProtection("privacy", "privacy");
     setCryptoAES("true", "true");
-    callRpcService();
+    callRpcService(User.create(ugi));
   }
 
   /**
-   * Test various combinations of Server and Client configuration for Crypto AES.
+   * Test various combinations of Server and Client configuration for Crypto AES. n
    */
   @Test
   public void testDifferentConfWithCryptoAES() throws Exception {
     setRpcProtection("privacy", "privacy");
 
     setCryptoAES("false", "true");
-    callRpcService();
+    callRpcService(User.create(ugi));
 
     setCryptoAES("true", "false");
     try {
-      callRpcService();
+      callRpcService(User.create(ugi));
       fail("The exception should be thrown out for the rpc timeout.");
     } catch (Exception e) {
       // ignore the expected exception
@@ -314,7 +384,7 @@ public class TestSecureIPC {
    * Sets up a RPC Server and a Client. Does a RPC checks the result. If an exception is thrown from
    * the stub, this function will throw root cause of that exception.
    */
-  private void callRpcService(User serverUser, User clientUser) throws Exception {
+  private void callRpcService(User clientUser) throws Exception {
     SecurityInfo securityInfoMock = Mockito.mock(SecurityInfo.class);
     Mockito.when(securityInfoMock.getServerPrincipal())
       .thenReturn(HBaseKerberosUtils.KRB_PRINCIPAL);
@@ -322,12 +392,10 @@ public class TestSecureIPC {
 
     InetSocketAddress isa = new InetSocketAddress(HOST, 0);
 
-    RpcServer rpcServer = serverUser.getUGI()
-      .doAs((PrivilegedExceptionAction<
-        RpcServer>) () -> RpcServerFactory.createRpcServer(null, "AbstractTestSecureIPC",
-          Lists.newArrayList(
-            new RpcServer.BlockingServiceAndInterface((BlockingService) SERVICE, null)),
-          isa, serverConf, new FifoRpcScheduler(serverConf, 1)));
+    RpcServerInterface rpcServer = RpcServerFactory.createRpcServer(null, "AbstractTestSecureIPC",
+      Lists
+        .newArrayList(new RpcServer.BlockingServiceAndInterface((BlockingService) SERVICE, null)),
+      isa, serverConf, new FifoRpcScheduler(serverConf, 1));
     rpcServer.start();
     try (RpcClient rpcClient =
       RpcClientFactory.createClient(clientConf, HConstants.DEFAULT_CLUSTER_ID.toString())) {
@@ -357,14 +425,6 @@ public class TestSecureIPC {
     }
   }
 
-  private void callRpcService(User clientUser) throws Exception {
-    callRpcService(User.create(ugi), clientUser);
-  }
-
-  private void callRpcService() throws Exception {
-    callRpcService(User.create(ugi));
-  }
-
   public static class TestThread extends Thread {
     private final BlockingInterface stub;
 
