@@ -94,7 +94,7 @@ public final class SnapshotTestingUtils {
   }
 
   /**
-   * Assert that we don't have any snapshots lists if the admin operation fails
+   * Assert that we don't have any snapshots lists n * if the admin operation fails
    */
   public static void assertNoSnapshots(Admin admin) throws IOException {
     assertEquals("Have some previous snapshots", 0, admin.listSnapshots().size());
@@ -297,21 +297,11 @@ public final class SnapshotTestingUtils {
    */
   public static void snapshot(Admin admin, final String snapshotName, final TableName tableName,
     final SnapshotType type, final int numTries) throws IOException {
-    snapshot(admin, snapshotName, tableName, type, numTries, null);
-  }
-
-  /*
-   * Take snapshot having snapshot properties with maximum of numTries attempts, ignoring
-   * CorruptedSnapshotException except for the last CorruptedSnapshotException
-   */
-  public static void snapshot(Admin admin, final String snapshotName, final TableName tableName,
-    final SnapshotType type, final int numTries, Map<String, Object> snapshotProps)
-    throws IOException {
     int tries = 0;
     CorruptedSnapshotException lastEx = null;
     while (tries++ < numTries) {
       try {
-        admin.snapshot(snapshotName, tableName, type, snapshotProps);
+        admin.snapshot(snapshotName, tableName, type);
         return;
       } catch (CorruptedSnapshotException cse) {
         LOG.warn("Got CorruptedSnapshotException", cse);
@@ -501,7 +491,7 @@ public final class SnapshotTestingUtils {
         this.desc = desc;
         this.tableRegions = tableRegions;
         this.snapshotDir = SnapshotDescriptionUtils.getWorkingSnapshotDir(desc, rootDir, conf);
-        new FSTableDescriptors(conf).createTableDescriptorForTableDirectory(
+        FSTableDescriptors.createTableDescriptorForTableDirectory(
           this.snapshotDir.getFileSystem(conf), snapshotDir, htd, false);
       }
 
@@ -539,6 +529,7 @@ public final class SnapshotTestingUtils {
         RegionData regionData = tableRegions[this.snapshotted++];
         ForeignExceptionDispatcher monitor = new ForeignExceptionDispatcher(desc.getName());
         SnapshotManifest manifest = SnapshotManifest.create(conf, fs, snapshotDir, desc, monitor);
+        manifest.addTableDescriptor(htd);
         manifest.addRegion(regionData.tableDir, regionData.hri);
         return regionData.files;
       }
@@ -830,7 +821,7 @@ public final class SnapshotTestingUtils {
     assertTrue(rows >= KEYS.length);
     for (byte k0 : KEYS) {
       byte[] k = new byte[] { k0 };
-      byte[] value = Bytes.add(Bytes.toBytes(System.currentTimeMillis()), k);
+      byte[] value = Bytes.add(Bytes.toBytes(EnvironmentEdgeManager.currentTime()), k);
       byte[] key = Bytes.add(k, Bytes.toBytes(MD5Hash.getMD5AsHex(value)));
       final byte[][] families1 = families;
       final byte[] key1 = key;
@@ -841,7 +832,8 @@ public final class SnapshotTestingUtils {
 
     // Add other extra rows. more rows, more files
     while (rows-- > 0) {
-      byte[] value = Bytes.add(Bytes.toBytes(System.currentTimeMillis()), Bytes.toBytes(rows));
+      byte[] value =
+        Bytes.add(Bytes.toBytes(EnvironmentEdgeManager.currentTime()), Bytes.toBytes(rows));
       byte[] key = Bytes.toBytes(MD5Hash.getMD5AsHex(value));
       final byte[][] families1 = families;
       final byte[] key1 = key;
