@@ -215,7 +215,7 @@ public class BaseTestHBaseFsck {
 
   /**
    * Setup a clean table before we start mucking with it. It will set tbl which needs to be closed
-   * after test
+   * after test nnn
    */
   void setupTable(TableName tablename) throws Exception {
     setupTableWithRegionReplica(tablename, 1);
@@ -223,7 +223,7 @@ public class BaseTestHBaseFsck {
 
   /**
    * Setup a clean table with a certain region_replica count It will set tbl which needs to be
-   * closed after test
+   * closed after test n
    */
   void setupTableWithRegionReplica(TableName tablename, int replicaCount) throws Exception {
     HTableDescriptor desc = new HTableDescriptor(tablename);
@@ -244,7 +244,7 @@ public class BaseTestHBaseFsck {
 
   /**
    * Setup a clean table with a mob-enabled column.
-   * @param tablename The name of a table to be created.
+   * @param tablename The name of a table to be created. n
    */
   void setupMobTable(TableName tablename) throws Exception {
     HTableDescriptor desc = new HTableDescriptor(tablename);
@@ -279,7 +279,7 @@ public class BaseTestHBaseFsck {
   }
 
   /**
-   * delete table in preparation for next test
+   * delete table in preparation for next test nn
    */
   void cleanupTable(TableName tablename) throws Exception {
     if (tbl != null) {
@@ -335,8 +335,7 @@ public class BaseTestHBaseFsck {
 
   /**
    * We don't have an easy way to verify that a flush completed, so we loop until we find a
-   * legitimate hfile and return it.
-   * @return Path of a flushed hfile.
+   * legitimate hfile and return it. nn * @return Path of a flushed hfile. n
    */
   Path getFlushedHFile(FileSystem fs, TableName table) throws IOException {
     Path tableDir = CommonFSUtils.getTableDir(CommonFSUtils.getRootDir(conf), table);
@@ -361,7 +360,7 @@ public class BaseTestHBaseFsck {
    * Gets flushed mob files.
    * @param fs    The current file system.
    * @param table The current table name.
-   * @return Path of a flushed hfile.
+   * @return Path of a flushed hfile. n
    */
   Path getFlushedMobFile(FileSystem fs, TableName table) throws IOException {
     Path famDir = MobUtils.getMobFamilyPath(conf, table, FAM_STR);
@@ -390,7 +389,7 @@ public class BaseTestHBaseFsck {
     String startKey = mobFileName.getStartKey();
     String date = mobFileName.getDate();
     return MobFileName
-      .create(startKey, date, TEST_UTIL.getRandomUUID().toString().replaceAll("-", ""))
+      .create(startKey, date, TEST_UTIL.getRandomUUID().toString().replaceAll("-", ""), "abcdef")
       .getFileName();
   }
 
