@@ -33,6 +33,7 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.Abortable;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.client.RegionInfo;
+import org.apache.hadoop.hbase.io.asyncfs.monitor.StreamSlowMonitor;
 import org.apache.hadoop.hbase.regionserver.wal.FSHLog;
 import org.apache.hadoop.hbase.regionserver.wal.ProtobufLogWriter;
 import org.apache.hadoop.hbase.regionserver.wal.WALActionsListener;
@@ -179,7 +180,7 @@ public class IOTestProvider implements WALProvider {
      * @param prefix          should always be hostname and port in distributed env and it will be
      *                        URL encoded before being used. If prefix is null, "wal" will be used
      * @param suffix          will be url encoded. null is treated as empty. non-empty must start
-     *                        with {@link AbstractFSWALProvider#WAL_FILE_NAME_DELIMITER}
+     *                        with {@link AbstractFSWALProvider#WAL_FILE_NAME_DELIMITER} n
      */
     public IOTestWAL(final FileSystem fs, final Path rootDir, final String logDir,
       final String archiveDir, final Configuration conf, final List<WALActionsListener> listeners,
@@ -205,7 +206,8 @@ public class IOTestProvider implements WALProvider {
         LOG.info("creating new writer instance.");
         final ProtobufLogWriter writer = new IOTestWriter();
         try {
-          writer.init(fs, path, conf, false, this.blocksize);
+          writer.init(fs, path, conf, false, this.blocksize,
+            StreamSlowMonitor.create(conf, path.getName()));
         } catch (CommonFSUtils.StreamLacksCapabilityException exception) {
           throw new IOException("Can't create writer instance because underlying FileSystem "
             + "doesn't support needed stream capabilities.", exception);
@@ -233,7 +235,8 @@ public class IOTestProvider implements WALProvider {
 
     @Override
     public void init(FileSystem fs, Path path, Configuration conf, boolean overwritable,
-      long blocksize) throws IOException, CommonFSUtils.StreamLacksCapabilityException {
+      long blocksize, StreamSlowMonitor monitor)
+      throws IOException, CommonFSUtils.StreamLacksCapabilityException {
       Collection<String> operations = conf.getStringCollection(ALLOWED_OPERATIONS);
       if (operations.isEmpty() || operations.contains(AllowedOperations.all.name())) {
         doAppends = doSyncs = true;
@@ -245,7 +248,7 @@ public class IOTestProvider implements WALProvider {
       }
       LOG.info("IOTestWriter initialized with appends " + (doAppends ? "enabled" : "disabled")
         + " and syncs " + (doSyncs ? "enabled" : "disabled"));
-      super.init(fs, path, conf, overwritable, blocksize);
+      super.init(fs, path, conf, overwritable, blocksize, monitor);
     }
 
     @Override
