@@ -67,6 +67,7 @@ import org.apache.hadoop.hbase.testclassification.MediumTests;
 import org.apache.hadoop.hbase.testclassification.RegionServerTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.RecoverLeaseFSUtils;
 import org.apache.hadoop.hbase.util.Threads;
 import org.apache.hadoop.hbase.wal.WALFactory.Providers;
@@ -174,7 +175,7 @@ public class TestWALFactory {
   }
 
   /**
-   * Just write multiple logs then split. Before fix for HADOOP-2283, this would fail.
+   * Just write multiple logs then split. Before fix for HADOOP-2283, this would fail. n
    */
   @Test
   public void testSplit() throws IOException {
@@ -206,10 +207,11 @@ public class TestWALFactory {
           byte[] family = Bytes.toBytes("column");
           byte[] qualifier = Bytes.toBytes(Integer.toString(j));
           byte[] column = Bytes.toBytes("column:" + Integer.toString(j));
-          edit.add(new KeyValue(rowName, family, qualifier, System.currentTimeMillis(), column));
+          edit.add(
+            new KeyValue(rowName, family, qualifier, EnvironmentEdgeManager.currentTime(), column));
           LOG.info("Region " + i + ": " + edit);
           WALKeyImpl walKey = new WALKeyImpl(infos[i].getEncodedNameAsBytes(), tableName,
-            System.currentTimeMillis(), mvcc, scopes);
+            EnvironmentEdgeManager.currentTime(), mvcc, scopes);
           log.appendData(infos[i], walKey, edit);
           walKey.getWriteEntry();
         }
@@ -229,7 +231,7 @@ public class TestWALFactory {
   }
 
   /**
-   * Test new HDFS-265 sync.
+   * Test new HDFS-265 sync. n
    */
   @Test
   public void Broken_testSync() throws Exception {
@@ -271,7 +273,7 @@ public class TestWALFactory {
         WALEdit kvs = new WALEdit();
         kvs.add(new KeyValue(Bytes.toBytes(i), tableName.getName(), tableName.getName()));
         wal.appendData(info, new WALKeyImpl(info.getEncodedNameAsBytes(), tableName,
-          System.currentTimeMillis(), mvcc, scopes), kvs);
+          EnvironmentEdgeManager.currentTime(), mvcc, scopes), kvs);
       }
       // Now call sync and try reading. Opening a Reader before you sync just
       // gives you EOFE.
@@ -291,7 +293,7 @@ public class TestWALFactory {
         WALEdit kvs = new WALEdit();
         kvs.add(new KeyValue(Bytes.toBytes(i), tableName.getName(), tableName.getName()));
         wal.appendData(info, new WALKeyImpl(info.getEncodedNameAsBytes(), tableName,
-          System.currentTimeMillis(), mvcc, scopes), kvs);
+          EnvironmentEdgeManager.currentTime(), mvcc, scopes), kvs);
       }
       wal.sync();
       reader = wals.createReader(fs, walPath);
@@ -315,7 +317,7 @@ public class TestWALFactory {
         WALEdit kvs = new WALEdit();
         kvs.add(new KeyValue(Bytes.toBytes(i), tableName.getName(), value));
         wal.appendData(info, new WALKeyImpl(info.getEncodedNameAsBytes(), tableName,
-          System.currentTimeMillis(), mvcc, scopes), kvs);
+          EnvironmentEdgeManager.currentTime(), mvcc, scopes), kvs);
       }
       // Now I should have written out lots of blocks. Sync then read.
       wal.sync();
@@ -389,7 +391,7 @@ public class TestWALFactory {
       WALEdit kvs = new WALEdit();
       kvs.add(new KeyValue(Bytes.toBytes(i), tableName.getName(), tableName.getName()));
       wal.appendData(regionInfo, new WALKeyImpl(regionInfo.getEncodedNameAsBytes(), tableName,
-        System.currentTimeMillis(), mvcc, scopes), kvs);
+        EnvironmentEdgeManager.currentTime(), mvcc, scopes), kvs);
     }
     // Now call sync to send the data to HDFS datanodes
     wal.sync();
@@ -507,7 +509,7 @@ public class TestWALFactory {
 
       // Write columns named 1, 2, 3, etc. and then values of single byte
       // 1, 2, 3...
-      long timestamp = System.currentTimeMillis();
+      long timestamp = EnvironmentEdgeManager.currentTime();
       WALEdit cols = new WALEdit();
       for (int i = 0; i < colCount; i++) {
         cols.add(new KeyValue(row, Bytes.toBytes("column"), Bytes.toBytes(Integer.toString(i)),
@@ -518,7 +520,7 @@ public class TestWALFactory {
       final WAL log = wals.getWAL(info);
 
       final long txid = log.appendData(info, new WALKeyImpl(info.getEncodedNameAsBytes(),
-        htd.getTableName(), System.currentTimeMillis(), mvcc, scopes), cols);
+        htd.getTableName(), EnvironmentEdgeManager.currentTime(), mvcc, scopes), cols);
       log.sync(txid);
       log.startCacheFlush(info.getEncodedNameAsBytes(), htd.getColumnFamilyNames());
       log.completeCacheFlush(info.getEncodedNameAsBytes(), HConstants.NO_SEQNUM);
@@ -564,7 +566,7 @@ public class TestWALFactory {
     try {
       // Write columns named 1, 2, 3, etc. and then values of single byte
       // 1, 2, 3...
-      long timestamp = System.currentTimeMillis();
+      long timestamp = EnvironmentEdgeManager.currentTime();
       WALEdit cols = new WALEdit();
       for (int i = 0; i < colCount; i++) {
         cols.add(new KeyValue(row, Bytes.toBytes("column"), Bytes.toBytes(Integer.toString(i)),
@@ -573,7 +575,7 @@ public class TestWALFactory {
       RegionInfo hri = RegionInfoBuilder.newBuilder(htd.getTableName()).build();
       final WAL log = wals.getWAL(hri);
       final long txid = log.appendData(hri, new WALKeyImpl(hri.getEncodedNameAsBytes(),
-        htd.getTableName(), System.currentTimeMillis(), mvcc, scopes), cols);
+        htd.getTableName(), EnvironmentEdgeManager.currentTime(), mvcc, scopes), cols);
       log.sync(txid);
       log.startCacheFlush(hri.getEncodedNameAsBytes(), htd.getColumnFamilyNames());
       log.completeCacheFlush(hri.getEncodedNameAsBytes(), HConstants.NO_SEQNUM);
@@ -602,7 +604,7 @@ public class TestWALFactory {
   }
 
   /**
-   * Test that we can visit entries before they are appended
+   * Test that we can visit entries before they are appended n
    */
   @Test
   public void testVisitors() throws Exception {
@@ -611,7 +613,7 @@ public class TestWALFactory {
     final byte[] row = Bytes.toBytes("row");
     final DumbWALActionsListener visitor = new DumbWALActionsListener();
     final MultiVersionConcurrencyControl mvcc = new MultiVersionConcurrencyControl(1);
-    long timestamp = System.currentTimeMillis();
+    long timestamp = EnvironmentEdgeManager.currentTime();
     NavigableMap<byte[], Integer> scopes = new TreeMap<>(Bytes.BYTES_COMPARATOR);
     scopes.put(Bytes.toBytes("column"), 0);
 
@@ -623,7 +625,7 @@ public class TestWALFactory {
       cols.add(new KeyValue(row, Bytes.toBytes("column"), Bytes.toBytes(Integer.toString(i)),
         timestamp, new byte[] { (byte) (i + '0') }));
       log.appendData(hri, new WALKeyImpl(hri.getEncodedNameAsBytes(), tableName,
-        System.currentTimeMillis(), mvcc, scopes), cols);
+        EnvironmentEdgeManager.currentTime(), mvcc, scopes), cols);
     }
     log.sync();
     assertEquals(COL_COUNT, visitor.increments);
@@ -632,7 +634,7 @@ public class TestWALFactory {
     cols.add(new KeyValue(row, Bytes.toBytes("column"), Bytes.toBytes(Integer.toString(11)),
       timestamp, new byte[] { (byte) (11 + '0') }));
     log.appendData(hri, new WALKeyImpl(hri.getEncodedNameAsBytes(), tableName,
-      System.currentTimeMillis(), mvcc, scopes), cols);
+      EnvironmentEdgeManager.currentTime(), mvcc, scopes), cols);
     log.sync();
     assertEquals(COL_COUNT, visitor.increments);
   }
@@ -655,13 +657,6 @@ public class TestWALFactory {
     public void visitLogEntryBeforeWrite(RegionInfo info, WALKey logKey, WALEdit logEdit) {
       increments++;
     }
-
-    @Override
-    public void visitLogEntryBeforeWrite(WALKey logKey, WALEdit logEdit) {
-      // To change body of implemented methods use File | Settings | File
-      // Templates.
-      increments++;
-    }
   }
 
   @Test
@@ -782,10 +777,10 @@ public class TestWALFactory {
       // Write one column in one edit.
       WALEdit cols = new WALEdit();
       cols.add(new KeyValue(row, Bytes.toBytes("column"), Bytes.toBytes("0"),
-        System.currentTimeMillis(), new byte[] { 0 }));
+        EnvironmentEdgeManager.currentTime(), new byte[] { 0 }));
       final WAL log = customFactory.getWAL(hri);
       final long txid = log.appendData(hri, new WALKeyImpl(hri.getEncodedNameAsBytes(),
-        htd.getTableName(), System.currentTimeMillis(), mvcc, scopes), cols);
+        htd.getTableName(), EnvironmentEdgeManager.currentTime(), mvcc, scopes), cols);
       // Sync the edit to the WAL
       log.sync(txid);
       log.startCacheFlush(hri.getEncodedNameAsBytes(), htd.getColumnFamilyNames());
