@@ -39,6 +39,7 @@ import org.apache.hadoop.hbase.testclassification.RegionServerTests;
 import org.apache.hadoop.hbase.testclassification.SmallTests;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.CommonFSUtils;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.wal.WALSplitter.PipelineController;
 import org.junit.ClassRule;
 import org.junit.Test;
@@ -78,7 +79,7 @@ public class TestWALMethods {
 
   /**
    * Assert that getSplitEditFilesSorted returns files in expected order and that it skips
-   * moved-aside files.
+   * moved-aside files. n
    */
   @Test
   public void testGetSplitEditFilesSorted() throws IOException {
@@ -97,7 +98,7 @@ public class TestWALMethods {
     String last = WALSplitUtil.formatRecoveredEditsFileName(Long.MAX_VALUE);
     createFile(fs, recoverededits, last);
     createFile(fs, recoverededits,
-      Long.toString(Long.MAX_VALUE) + "." + System.currentTimeMillis());
+      Long.toString(Long.MAX_VALUE) + "." + EnvironmentEdgeManager.currentTime());
 
     final Configuration walConf = new Configuration(util.getConfiguration());
     CommonFSUtils.setRootDir(walConf, regiondir);
