@@ -188,8 +188,8 @@ public class TestWALSplit {
     Collections.addAll(REGIONS, "bbb", "ccc");
     InstrumentedLogWriter.activateFailure = false;
     wals = new WALFactory(conf, name.getMethodName());
-    WALDIR = new Path(HBASELOGDIR, AbstractFSWALProvider.getWALDirectoryName(
-      ServerName.valueOf(name.getMethodName(), 16010, System.currentTimeMillis()).toString()));
+    WALDIR = new Path(HBASELOGDIR, AbstractFSWALProvider.getWALDirectoryName(ServerName
+      .valueOf(name.getMethodName(), 16010, EnvironmentEdgeManager.currentTime()).toString()));
     // fs.mkdirs(WALDIR);
   }
 
@@ -270,7 +270,7 @@ public class TestWALSplit {
    * log entry. Does its writing as an alternate user in another filesystem instance to simulate
    * better it being a regionserver.
    */
-  private class ZombieLastLogWriterRegionServer extends Thread {
+  class ZombieLastLogWriterRegionServer extends Thread {
     final AtomicLong editsCount;
     final AtomicBoolean stop;
     final int numOfWriters;
@@ -396,6 +396,10 @@ public class TestWALSplit {
 
   private Path createRecoveredEditsPathForRegion() throws IOException {
     byte[] encoded = RegionInfoBuilder.FIRST_META_REGIONINFO.getEncodedNameAsBytes();
+    long now = EnvironmentEdgeManager.currentTime();
+    Entry entry = new Entry(
+      new WALKeyImpl(encoded, TableName.META_TABLE_NAME, 1, now, HConstants.DEFAULT_CLUSTER_ID),
+      new WALEdit());
     Path p = WALSplitUtil.getRegionSplitEditsPath(TableName.META_TABLE_NAME, encoded, 1,
       FILENAME_BEING_SPLIT, TMPDIRNAME, conf);
     return p;
@@ -951,8 +955,8 @@ public class TestWALSplit {
   /**
    * Sets up a log splitter with a mock reader and writer. The mock reader generates a specified
    * number of edits spread across 5 regions. The mock writer optionally sleeps for each edit it is
-   * fed. After the split is complete, verifies that the statistics show the correct number of edits
-   * output into each region.
+   * fed. * After the split is complete, verifies that the statistics show the correct number of
+   * edits output into each region.
    * @param numFakeEdits   number of fake edits to push through pipeline
    * @param bufferSize     size of in-memory buffer
    * @param writerSlowness writer threads will sleep this many ms per edit
@@ -1163,44 +1167,7 @@ public class TestWALSplit {
     } finally {
       conf.unset(HConstants.WAL_STORAGE_POLICY);
     }
-  }
 
-  /**
-   * See HBASE-27644, typically we should not have empty WALEdit but we should be able to process
-   * it, instead of losing data after it.
-   */
-  @Test
-  public void testEmptyWALEdit() throws IOException {
-    final String region = "region__5";
-    REGIONS.clear();
-    REGIONS.add(region);
-    makeRegionDirs(REGIONS);
-    fs.mkdirs(WALDIR);
-    Path path = new Path(WALDIR, WAL_FILE_PREFIX + 5);
-    generateEmptyEditWAL(path, Bytes.toBytes(region));
-    useDifferentDFSClient();
-
-    Path regiondir = new Path(TABLEDIR, region);
-    fs.mkdirs(regiondir);
-    List<Path> splitPaths = WALSplitter.split(HBASELOGDIR, WALDIR, OLDLOGDIR, fs, conf, wals);
-    // Make sure that WALSplitter generate the split file
-    assertEquals(1, splitPaths.size());
-
-    Path originalLog = (fs.listStatus(OLDLOGDIR))[0].getPath();
-    assertEquals(11, countWAL(originalLog));
-    // we will skip the empty WAL when splitting
-    assertEquals(10, countWAL(splitPaths.get(0)));
-  }
-
-  private void generateEmptyEditWAL(Path path, byte[] region) throws IOException {
-    fs.mkdirs(WALDIR);
-    try (Writer writer = wals.createWALWriter(fs, path)) {
-      long seq = 0;
-      appendEmptyEntry(writer, TABLE_NAME, region, seq++);
-      for (int i = 0; i < 10; i++) {
-        appendEntry(writer, TABLE_NAME, region, Bytes.toBytes(i), FAMILY, QUALIFIER, VALUE, seq++);
-      }
-    }
   }
 
   private Writer generateWALs(int leaveOpen) throws IOException {
@@ -1393,7 +1360,7 @@ public class TestWALSplit {
     w.sync(false);
   }
 
-  private static long appendEntry(Writer writer, TableName table, byte[] region, byte[] row,
+  public static long appendEntry(Writer writer, TableName table, byte[] region, byte[] row,
     byte[] family, byte[] qualifier, byte[] value, long seq) throws IOException {
     LOG.info(Thread.currentThread().getName() + " append");
     writer.append(createTestEntry(table, region, row, family, qualifier, value, seq));
@@ -1406,27 +1373,13 @@ public class TestWALSplit {
     byte[] qualifier, byte[] value, long seq) {
     long time = System.nanoTime();
 
+    seq++;
     final KeyValue cell = new KeyValue(row, family, qualifier, time, KeyValue.Type.Put, value);
     WALEdit edit = new WALEdit();
     edit.add(cell);
     return new Entry(new WALKeyImpl(region, table, seq, time, HConstants.DEFAULT_CLUSTER_ID), edit);
   }
 
-  private static long appendEmptyEntry(Writer writer, TableName table, byte[] region, long seq)
-    throws IOException {
-    LOG.info(Thread.currentThread().getName() + " append");
-    writer.append(createEmptyEntry(table, region, seq));
-    LOG.info(Thread.currentThread().getName() + " sync");
-    writer.sync(false);
-    return seq;
-  }
-
-  private static Entry createEmptyEntry(TableName table, byte[] region, long seq) {
-    long time = System.nanoTime();
-    return new Entry(new WALKeyImpl(region, table, seq, time, HConstants.DEFAULT_CLUSTER_ID),
-      new WALEdit());
-  }
-
   private void injectEmptyFile(String suffix, boolean closeFile) throws IOException {
     Writer writer =
       WALFactory.createWALWriter(fs, new Path(WALDIR, WAL_FILE_PREFIX + suffix), conf);
@@ -1436,19 +1389,22 @@ public class TestWALSplit {
   }
 
   private boolean logsAreEqual(Path p1, Path p2) throws IOException {
-    try (Reader in1 = wals.createReader(fs, p1); Reader in2 = wals.createReader(fs, p2)) {
-      Entry entry1;
-      Entry entry2;
-      while ((entry1 = in1.next()) != null) {
-        entry2 = in2.next();
-        if (
-          (entry1.getKey().compareTo(entry2.getKey()) != 0)
-            || (!entry1.getEdit().toString().equals(entry2.getEdit().toString()))
-        ) {
-          return false;
-        }
+    Reader in1, in2;
+    in1 = wals.createReader(fs, p1);
+    in2 = wals.createReader(fs, p2);
+    Entry entry1;
+    Entry entry2;
+    while ((entry1 = in1.next()) != null) {
+      entry2 = in2.next();
+      if (
+        (entry1.getKey().compareTo(entry2.getKey()) != 0)
+          || (!entry1.getEdit().toString().equals(entry2.getEdit().toString()))
+      ) {
+        return false;
       }
     }
+    in1.close();
+    in2.close();
     return true;
   }
 }
