@@ -254,7 +254,7 @@ public class ThriftHBaseServiceHandler extends HBaseServiceHandler implements Hb
   }
 
   /**
-   * @return the list of regions in the given table, or an empty list if the table does not exist
+   * Returns the list of regions in the given table, or an empty list if the table does not exist
    */
   @Override
   public List<TRegionInfo> getTableRegions(ByteBuffer tableName) throws IOError {
@@ -1217,6 +1217,11 @@ public class ThriftHBaseServiceHandler extends HBaseServiceHandler implements Hb
     return TThriftServerType.ONE;
   }
 
+  @Override
+  public String getClusterId() throws TException {
+    return connectionCache.getClusterId();
+  }
+
   private static IOError getIOError(Throwable throwable) {
     IOError error = new IOErrorWithCause(throwable);
     error.setCanRetry(!(throwable instanceof DoNotRetryIOException));
