@@ -105,6 +105,7 @@ import org.apache.hadoop.hbase.security.SecurityUtil;
 import org.apache.hadoop.hbase.security.UserProvider;
 import org.apache.hadoop.hbase.thrift.generated.Hbase;
 import org.apache.hadoop.hbase.util.DNS;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.JvmPauseMonitor;
 import org.apache.hadoop.hbase.util.Strings;
 import org.apache.hadoop.hbase.util.VersionInfo;
@@ -296,7 +297,7 @@ public class ThriftServer extends Configured implements Tool {
     int port = conf.getInt(THRIFT_INFO_SERVER_PORT, THRIFT_INFO_SERVER_PORT_DEFAULT);
 
     if (port >= 0) {
-      conf.setLong("startcode", System.currentTimeMillis());
+      conf.setLong("startcode", EnvironmentEdgeManager.currentTime());
       String a =
         conf.get(THRIFT_INFO_SERVER_BINDING_ADDRESS, THRIFT_INFO_SERVER_BINDING_ADDRESS_DEFAULT);
       infoServer = new InfoServer("thrift", a, port, false, conf);
@@ -832,9 +833,9 @@ public class ThriftServer extends Configured implements Tool {
     } else {
       setupServer();
     }
-    return serviceUGI.doAs(new PrivilegedAction<Integer>() {
+    serviceUGI.doAs(new PrivilegedAction<Object>() {
       @Override
-      public Integer run() {
+      public Object run() {
         try {
           startInfoServer();
           if (httpEnabled) {
@@ -843,13 +844,15 @@ public class ThriftServer extends Configured implements Tool {
           } else {
             tserver.serve();
           }
-          return 0;
         } catch (Exception e) {
           LOG.error(HBaseMarkers.FATAL, "Cannot run ThriftServer", e);
-          return -1;
+
+          System.exit(-1);
         }
+        return null;
       }
     });
+    return 0;
   }
 
   public static void main(String[] args) throws Exception {
