@@ -64,6 +64,7 @@ import org.apache.hadoop.hbase.thrift.generated.TRowResult;
 import org.apache.hadoop.hbase.thrift.generated.TScan;
 import org.apache.hadoop.hbase.thrift.generated.TThriftServerType;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.EnvironmentEdgeManager;
 import org.apache.hadoop.hbase.util.TableDescriptorChecker;
 import org.apache.hadoop.hbase.util.Threads;
 import org.apache.thrift.protocol.TBinaryProtocol;
@@ -138,7 +139,7 @@ public class TestThriftServer {
   /**
    * Runs all of the tests under a single JUnit test method. We consolidate all testing to one
    * method because HBaseClusterTestCase is prone to OutOfMemoryExceptions when there are three or
-   * more JUnit test methods.
+   * more JUnit test methods. n
    */
   @Test
   public void testAll() throws Exception {
@@ -158,7 +159,7 @@ public class TestThriftServer {
 
   /**
    * Tests for creating, enabling, disabling, and deleting tables. Also tests that creating a table
-   * with an invalid column name yields an IllegalArgument exception.
+   * with an invalid column name yields an IllegalArgument exception. n
    */
   public void doTestTableCreateDrop() throws Exception {
     ThriftHBaseServiceHandler handler = new ThriftHBaseServiceHandler(UTIL.getConfiguration(),
@@ -188,7 +189,7 @@ public class TestThriftServer {
   /**
    * TODO: These counts are supposed to be zero but sometimes they are not, they are equal to the
    * passed in maybe. Investigate why. My guess is they are set by the test that runs just previous
-   * to this one. Sometimes they are cleared. Sometimes not.
+   * to this one. Sometimes they are cleared. Sometimes not. nnnn
    */
   private int getCurrentCount(final String name, final int maybe, final ThriftMetrics metrics) {
     int currentCount = 0;
@@ -320,7 +321,7 @@ public class TestThriftServer {
 
   /**
    * Tests adding a series of Mutations and BatchMutations, including a delete mutation. Also tests
-   * data retrieval, and getting back multiple versions.
+   * data retrieval, and getting back multiple versions. n
    */
   public void doTestTableMutations() throws Exception {
     ThriftHBaseServiceHandler handler = new ThriftHBaseServiceHandler(UTIL.getConfiguration(),
@@ -392,7 +393,7 @@ public class TestThriftServer {
 
   /**
    * Similar to testTableMutations(), except Mutations are applied with specific timestamps and data
-   * retrieval uses these timestamps to extract specific versions of data.
+   * retrieval uses these timestamps to extract specific versions of data. n
    */
   public void doTestTableTimestampsAndColumns() throws Exception {
     // Setup
@@ -401,13 +402,13 @@ public class TestThriftServer {
     handler.createTable(tableAname, getColumnDescriptors());
 
     // Apply timestamped Mutations to rowA
-    long time1 = System.currentTimeMillis();
+    long time1 = EnvironmentEdgeManager.currentTime();
     handler.mutateRowTs(tableAname, rowAname, getMutations(), time1, null);
 
     Thread.sleep(1000);
 
     // Apply timestamped BatchMutations for rowA and rowB
-    long time2 = System.currentTimeMillis();
+    long time2 = EnvironmentEdgeManager.currentTime();
     handler.mutateRowsTs(tableAname, getBatchMutations(), time2, null);
 
     // Apply an overlapping timestamped mutation to rowB
@@ -469,7 +470,7 @@ public class TestThriftServer {
 
   /**
    * Tests the four different scanner-opening methods (with and without a stoprow, with and without
-   * a timestamp).
+   * a timestamp). n
    */
   public void doTestTableScanners() throws Exception {
     // Setup
@@ -478,7 +479,7 @@ public class TestThriftServer {
     handler.createTable(tableAname, getColumnDescriptors());
 
     // Apply timestamped Mutations to rowA
-    long time1 = System.currentTimeMillis();
+    long time1 = EnvironmentEdgeManager.currentTime();
     handler.mutateRowTs(tableAname, rowAname, getMutations(), time1, null);
 
     // Sleep to assure that 'time1' and 'time2' will be different even with a
@@ -486,7 +487,7 @@ public class TestThriftServer {
     Thread.sleep(1000);
 
     // Apply timestamped BatchMutations for rowA and rowB
-    long time2 = System.currentTimeMillis();
+    long time2 = EnvironmentEdgeManager.currentTime();
     handler.mutateRowsTs(tableAname, getBatchMutations(), time2, null);
 
     time1 += 1;
@@ -587,7 +588,7 @@ public class TestThriftServer {
   }
 
   /**
-   * For HBASE-2556 Tests for GetTableRegions
+   * For HBASE-2556 Tests for GetTableRegions n
    */
   public void doTestGetTableRegions() throws Exception {
     ThriftHBaseServiceHandler handler = new ThriftHBaseServiceHandler(UTIL.getConfiguration(),
@@ -646,7 +647,7 @@ public class TestThriftServer {
   }
 
   /**
-   * Appends the value to a cell and checks that the cell value is updated properly.
+   * Appends the value to a cell and checks that the cell value is updated properly. n
    */
   public static void doTestAppend() throws Exception {
     ThriftHBaseServiceHandler handler = new ThriftHBaseServiceHandler(UTIL.getConfiguration(),
@@ -677,7 +678,7 @@ public class TestThriftServer {
 
   /**
    * Check that checkAndPut fails if the cell does not exist, then put in the cell, then check that
-   * the checkAndPut succeeds.
+   * the checkAndPut succeeds. n
    */
   public static void doTestCheckAndPut() throws Exception {
     ThriftHBaseServiceHandler handler = new ThriftHBaseServiceHandler(UTIL.getConfiguration(),
@@ -743,7 +744,7 @@ public class TestThriftServer {
       tableDesc.addFamily(new HColumnDescriptor(family));
 
       Table table = UTIL.createTable(tableDesc, null);
-      long now = System.currentTimeMillis();
+      long now = EnvironmentEdgeManager.currentTime();
       table.put(new Put(Bytes.toBytes(rowkey)).addColumn(Bytes.toBytes(family), Bytes.toBytes(col),
         now, Bytes.toBytes("val1")));
 
@@ -869,7 +870,7 @@ public class TestThriftServer {
   /**
    * Asserts that the passed scanner is exhausted, and then closes the scanner.
    * @param scannerId the scanner to close
-   * @param handler   the HBaseServiceHandler interfacing to HBase
+   * @param handler   the HBaseServiceHandler interfacing to HBase n
    */
   private void closeScanner(int scannerId, ThriftHBaseServiceHandler handler) throws Exception {
     handler.scannerGet(scannerId);
